Class ApiClientImpl

java.lang.Object
com.commercetools.api.models.api_client.ApiClientImpl
All Implemented Interfaces:
ApiClient, Identifiable<ApiClient>, io.vrap.rmf.base.client.ModelBase

public class ApiClientImpl extends Object implements ApiClient, io.vrap.rmf.base.client.ModelBase
ApiClient
  • Constructor Details

    • ApiClientImpl

      public ApiClientImpl()
      create empty instance
  • Method Details

    • getId

      public String getId()

      The OAuth2 client_id that can be used to obtain an access token.

      Specified by:
      getId in interface ApiClient
      Specified by:
      getId in interface Identifiable<ApiClient>
      Returns:
      id
    • getName

      public String getName()

      Name of the APIClient.

      Specified by:
      getName in interface ApiClient
      Returns:
      name
    • getScope

      public String getScope()

      Whitespace-separated list of OAuth scopes that can be used when obtaining an access token.

      Specified by:
      getScope in interface ApiClient
      Returns:
      scope
    • getSecret

      public String getSecret()

      Only shown once in the response of creating the APIClient. This is the OAuth2 client_secret that can be used to obtain an access token.

      Specified by:
      getSecret in interface ApiClient
      Returns:
      secret
    • getLastUsedAt

      public LocalDate getLastUsedAt()

      Date of the last day this APIClient was used to obtain an access token.

      Specified by:
      getLastUsedAt in interface ApiClient
      Returns:
      lastUsedAt
    • getDeleteAt

      public ZonedDateTime getDeleteAt()

      If set, the Client will be deleted on (or shortly after) this point in time.

      Specified by:
      getDeleteAt in interface ApiClient
      Returns:
      deleteAt
    • getCreatedAt

      public ZonedDateTime getCreatedAt()

      Date and time (UTC) the APIClient was initially created.

      Specified by:
      getCreatedAt in interface ApiClient
      Returns:
      createdAt
    • getAccessTokenValiditySeconds

      public Integer getAccessTokenValiditySeconds()

      Expiration time in seconds for each access token obtained by the APIClient. Only present when set with the APIClientDraft. If not present the default value applies.

      Specified by:
      getAccessTokenValiditySeconds in interface ApiClient
      Returns:
      accessTokenValiditySeconds
    • getRefreshTokenValiditySeconds

      public Integer getRefreshTokenValiditySeconds()

      Inactivity expiration time in seconds for each refresh token obtained by the APIClient. Only present when set with the APIClientDraft. If not present the default value applies.

      Specified by:
      getRefreshTokenValiditySeconds in interface ApiClient
      Returns:
      refreshTokenValiditySeconds
    • setId

      public void setId(String id)
      Description copied from interface: ApiClient

      The OAuth2 client_id that can be used to obtain an access token.

      Specified by:
      setId in interface ApiClient
      Parameters:
      id - value to be set
    • setName

      public void setName(String name)
      Description copied from interface: ApiClient

      Name of the APIClient.

      Specified by:
      setName in interface ApiClient
      Parameters:
      name - value to be set
    • setScope

      public void setScope(String scope)
      Description copied from interface: ApiClient

      Whitespace-separated list of OAuth scopes that can be used when obtaining an access token.

      Specified by:
      setScope in interface ApiClient
      Parameters:
      scope - value to be set
    • setSecret

      public void setSecret(String secret)
      Description copied from interface: ApiClient

      Only shown once in the response of creating the APIClient. This is the OAuth2 client_secret that can be used to obtain an access token.

      Specified by:
      setSecret in interface ApiClient
      Parameters:
      secret - value to be set
    • setLastUsedAt

      public void setLastUsedAt(LocalDate lastUsedAt)
      Description copied from interface: ApiClient

      Date of the last day this APIClient was used to obtain an access token.

      Specified by:
      setLastUsedAt in interface ApiClient
      Parameters:
      lastUsedAt - value to be set
    • setDeleteAt

      public void setDeleteAt(ZonedDateTime deleteAt)
      Description copied from interface: ApiClient

      If set, the Client will be deleted on (or shortly after) this point in time.

      Specified by:
      setDeleteAt in interface ApiClient
      Parameters:
      deleteAt - value to be set
    • setCreatedAt

      public void setCreatedAt(ZonedDateTime createdAt)
      Description copied from interface: ApiClient

      Date and time (UTC) the APIClient was initially created.

      Specified by:
      setCreatedAt in interface ApiClient
      Parameters:
      createdAt - value to be set
    • setAccessTokenValiditySeconds

      public void setAccessTokenValiditySeconds(Integer accessTokenValiditySeconds)
      Description copied from interface: ApiClient

      Expiration time in seconds for each access token obtained by the APIClient. Only present when set with the APIClientDraft. If not present the default value applies.

      Specified by:
      setAccessTokenValiditySeconds in interface ApiClient
      Parameters:
      accessTokenValiditySeconds - value to be set
    • setRefreshTokenValiditySeconds

      public void setRefreshTokenValiditySeconds(Integer refreshTokenValiditySeconds)
      Description copied from interface: ApiClient

      Inactivity expiration time in seconds for each refresh token obtained by the APIClient. Only present when set with the APIClientDraft. If not present the default value applies.

      Specified by:
      setRefreshTokenValiditySeconds in interface ApiClient
      Parameters:
      refreshTokenValiditySeconds - value to be set
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • toString

      public String toString()
      Overrides:
      toString in class Object
    • copyDeep

      public ApiClient copyDeep()
      Specified by:
      copyDeep in interface ApiClient