Class ApiClientPagedQueryResponseBuilder

java.lang.Object
com.commercetools.api.models.api_client.ApiClientPagedQueryResponseBuilder
All Implemented Interfaces:
io.vrap.rmf.base.client.Builder<ApiClientPagedQueryResponse>

public class ApiClientPagedQueryResponseBuilder extends Object implements io.vrap.rmf.base.client.Builder<ApiClientPagedQueryResponse>
ApiClientPagedQueryResponseBuilder
Example to create an instance using the builder pattern

     ApiClientPagedQueryResponse apiClientPagedQueryResponse = ApiClientPagedQueryResponse.builder()
             .limit(0.3)
             .offset(0.3)
             .count(0.3)
             .plusResults(resultsBuilder -> resultsBuilder)
             .build()
 
  • Constructor Details

    • ApiClientPagedQueryResponseBuilder

      public ApiClientPagedQueryResponseBuilder()
  • Method Details

    • limit

      Number of results requested.

      Parameters:
      limit - value to be set
      Returns:
      Builder
    • offset

      public ApiClientPagedQueryResponseBuilder offset(Long offset)

      Number of elements skipped.

      Parameters:
      offset - value to be set
      Returns:
      Builder
    • count

      Actual number of results returned.

      Parameters:
      count - value to be set
      Returns:
      Builder
    • total

      public ApiClientPagedQueryResponseBuilder total(@Nullable Long total)

      Total number of results matching the query. This number is an estimation that is not strongly consistent. This field is returned by default. For improved performance, calculating this field can be deactivated by using the query parameter withTotal=false. When the results are filtered with a Query Predicate, total is subject to a limit.

      Parameters:
      total - value to be set
      Returns:
      Builder
    • results

      public ApiClientPagedQueryResponseBuilder results(ApiClient... results)

      APIClients matching the query.

      Parameters:
      results - value to be set
      Returns:
      Builder
    • results

      APIClients matching the query.

      Parameters:
      results - value to be set
      Returns:
      Builder
    • plusResults

      public ApiClientPagedQueryResponseBuilder plusResults(ApiClient... results)

      APIClients matching the query.

      Parameters:
      results - value to be set
      Returns:
      Builder
    • plusResults

      APIClients matching the query.

      Parameters:
      builder - function to build the results value
      Returns:
      Builder
    • withResults

      APIClients matching the query.

      Parameters:
      builder - function to build the results value
      Returns:
      Builder
    • addResults

      APIClients matching the query.

      Parameters:
      builder - function to build the results value
      Returns:
      Builder
    • setResults

      APIClients matching the query.

      Parameters:
      builder - function to build the results value
      Returns:
      Builder
    • getLimit

      public Long getLimit()

      Number of results requested.

      Returns:
      limit
    • getOffset

      public Long getOffset()

      Number of elements skipped.

      Returns:
      offset
    • getCount

      public Long getCount()

      Actual number of results returned.

      Returns:
      count
    • getTotal

      @Nullable public Long getTotal()

      Total number of results matching the query. This number is an estimation that is not strongly consistent. This field is returned by default. For improved performance, calculating this field can be deactivated by using the query parameter withTotal=false. When the results are filtered with a Query Predicate, total is subject to a limit.

      Returns:
      total
    • getResults

      public List<ApiClient> getResults()

      APIClients matching the query.

      Returns:
      results
    • build

      builds ApiClientPagedQueryResponse with checking for non-null required values
      Specified by:
      build in interface io.vrap.rmf.base.client.Builder<ApiClientPagedQueryResponse>
      Returns:
      ApiClientPagedQueryResponse
    • buildUnchecked

      public ApiClientPagedQueryResponse buildUnchecked()
      builds ApiClientPagedQueryResponse without checking for non-null required values
      Returns:
      ApiClientPagedQueryResponse
    • of

      factory method for an instance of ApiClientPagedQueryResponseBuilder
      Returns:
      builder
    • of

      create builder for ApiClientPagedQueryResponse instance
      Parameters:
      template - instance with prefilled values for the builder
      Returns:
      builder