Class ApiClientPagedQueryResponseImpl
- All Implemented Interfaces:
ApiClientPagedQueryResponse,ResourcePagedQueryResponse<ApiClient>,io.vrap.rmf.base.client.ModelBase
PagedQueryResult with results containing an array of APIClient.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCount()Actual number of results returned.getLimit()Number of results requested.Number of elements skipped.APIClients matching the query.getTotal()Total number of results matching the query.inthashCode()voidActual number of results returned.voidNumber of results requested.voidNumber of elements skipped.voidsetResults(ApiClient... results) APIClients matching the query.voidsetResults(List<ApiClient> results) APIClients matching the query.voidTotal number of results matching the query.toString()Methods inherited from interface com.commercetools.api.models.api_client.ApiClientPagedQueryResponse
withApiClientPagedQueryResponseMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.ResourcePagedQueryResponse
getPageIndex, getTotalPages, head, isFirst, isLast
-
Constructor Details
-
ApiClientPagedQueryResponseImpl
public ApiClientPagedQueryResponseImpl()create empty instance
-
-
Method Details
-
getLimit
Number of results requested.
- Specified by:
getLimitin interfaceApiClientPagedQueryResponse- Specified by:
getLimitin interfaceResourcePagedQueryResponse<ApiClient>- Returns:
- limit
-
getOffset
Number of elements skipped.
- Specified by:
getOffsetin interfaceApiClientPagedQueryResponse- Specified by:
getOffsetin interfaceResourcePagedQueryResponse<ApiClient>- Returns:
- offset
-
getCount
Actual number of results returned.
- Specified by:
getCountin interfaceApiClientPagedQueryResponse- Specified by:
getCountin interfaceResourcePagedQueryResponse<ApiClient>- Returns:
- count
-
getTotal
Total number of results matching the query. This number is an estimation that is not strongly consistent. This field is returned by default. For improved performance, calculating this field can be deactivated by using the query parameter
withTotal=false. When the results are filtered with a Query Predicate,totalis subject to a limit.- Specified by:
getTotalin interfaceApiClientPagedQueryResponse- Specified by:
getTotalin interfaceResourcePagedQueryResponse<ApiClient>- Returns:
- total
-
getResults
APIClients matching the query.
- Specified by:
getResultsin interfaceApiClientPagedQueryResponse- Specified by:
getResultsin interfaceResourcePagedQueryResponse<ApiClient>- Returns:
- results
-
setLimit
Description copied from interface:ApiClientPagedQueryResponseNumber of results requested.
- Specified by:
setLimitin interfaceApiClientPagedQueryResponse- Parameters:
limit- value to be set
-
setOffset
Description copied from interface:ApiClientPagedQueryResponseNumber of elements skipped.
- Specified by:
setOffsetin interfaceApiClientPagedQueryResponse- Parameters:
offset- value to be set
-
setCount
Description copied from interface:ApiClientPagedQueryResponseActual number of results returned.
- Specified by:
setCountin interfaceApiClientPagedQueryResponse- Parameters:
count- value to be set
-
setTotal
Description copied from interface:ApiClientPagedQueryResponseTotal number of results matching the query. This number is an estimation that is not strongly consistent. This field is returned by default. For improved performance, calculating this field can be deactivated by using the query parameter
withTotal=false. When the results are filtered with a Query Predicate,totalis subject to a limit.- Specified by:
setTotalin interfaceApiClientPagedQueryResponse- Parameters:
total- value to be set
-
setResults
Description copied from interface:ApiClientPagedQueryResponseAPIClients matching the query.
- Specified by:
setResultsin interfaceApiClientPagedQueryResponse- Parameters:
results- values to be set
-
setResults
Description copied from interface:ApiClientPagedQueryResponseAPIClients matching the query.
- Specified by:
setResultsin interfaceApiClientPagedQueryResponse- Parameters:
results- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceApiClientPagedQueryResponse
-