Class BaseAddressImpl
- All Implemented Interfaces:
BaseAddress,BaseAddressMixin,WithKey,io.vrap.rmf.base.client.ModelBase
Polymorphic base type that represents a postal address and contact details. Depending on the read or write action, it can be either Address or AddressDraft that only differ in the data type for the optional custom field.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanFurther information on the Address.Further information on the street address.Number or name of the apartment.Number or name of the building.getCity()Name of the city.Name of the company.Name of the country.Name of the department.getEmail()Email address of the contact.ID for the contact used in an external system.getFax()Fax number of the contact.Given name (first name) of the contact.getId()Unique identifier of the Address.getKey()User-defined identifier of the Address that must be unique when multiple addresses are referenced in BusinessUnits, Customers, anditemShippingAddresses(LineItem-specific addresses) of a Cart, Order, QuoteRequest, or Quote.Family name (last name) of the contact.Mobile phone number of the contact.getPhone()Phone number of the contact.getPOBox()Post office box number.Postal code.Name of the region.Salutation of the contact, for example 'Mr.' or 'Ms.'getState()Name of the state, for example, Colorado.Name of the street.Street number.getTitle()Title of the contact, for example 'Dr.'inthashCode()voidsetAdditionalAddressInfo(String additionalAddressInfo) Further information on the Address.voidsetAdditionalStreetInfo(String additionalStreetInfo) Further information on the street address.voidsetApartment(String apartment) Number or name of the apartment.voidsetBuilding(String building) Number or name of the building.voidName of the city.voidsetCompany(String company) Name of the company.voidsetCountry(String country) Name of the country.voidsetDepartment(String department) Name of the department.voidEmail address of the contact.voidsetExternalId(String externalId) ID for the contact used in an external system.voidFax number of the contact.voidsetFirstName(String firstName) Given name (first name) of the contact.voidUnique identifier of the Address.voidUser-defined identifier of the Address that must be unique when multiple addresses are referenced in BusinessUnits, Customers, anditemShippingAddresses(LineItem-specific addresses) of a Cart, Order, QuoteRequest, or Quote.voidsetLastName(String lastName) Family name (last name) of the contact.voidMobile phone number of the contact.voidPhone number of the contact.voidPost office box number.voidsetPostalCode(String postalCode) Postal code.voidName of the region.voidsetSalutation(String salutation) Salutation of the contact, for example 'Mr.' or 'Ms.'voidName of the state, for example, Colorado.voidsetStreetName(String streetName) Name of the street.voidsetStreetNumber(String streetNumber) Street number.voidTitle of the contact, for example 'Dr.'toString()Methods inherited from interface com.commercetools.api.models.common.BaseAddress
withBaseAddressMethods inherited from interface com.commercetools.api.models.common.BaseAddressMixin
equalsIgnoreId, toDraft, toDraftBuilderMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
BaseAddressImpl
public BaseAddressImpl()create empty instance
-
-
Method Details
-
getId
Unique identifier of the Address.
It is not recommended to set it manually since the API overwrites this ID when creating an Address for a Customer. Use
keyinstead and omit this field from the request to let the API generate the ID for the Address.- Specified by:
getIdin interfaceBaseAddress- Returns:
- id
-
getKey
User-defined identifier of the Address that must be unique when multiple addresses are referenced in BusinessUnits, Customers, and
itemShippingAddresses(LineItem-specific addresses) of a Cart, Order, QuoteRequest, or Quote.- Specified by:
getKeyin interfaceBaseAddress- Specified by:
getKeyin interfaceBaseAddressMixin- Specified by:
getKeyin interfaceWithKey- Returns:
- key
-
getCountry
Name of the country.
- Specified by:
getCountryin interfaceBaseAddress- Specified by:
getCountryin interfaceBaseAddressMixin- Returns:
- country
-
getTitle
Title of the contact, for example 'Dr.'
- Specified by:
getTitlein interfaceBaseAddress- Specified by:
getTitlein interfaceBaseAddressMixin- Returns:
- title
-
getSalutation
Salutation of the contact, for example 'Mr.' or 'Ms.'
- Specified by:
getSalutationin interfaceBaseAddress- Specified by:
getSalutationin interfaceBaseAddressMixin- Returns:
- salutation
-
getFirstName
Given name (first name) of the contact.
- Specified by:
getFirstNamein interfaceBaseAddress- Specified by:
getFirstNamein interfaceBaseAddressMixin- Returns:
- firstName
-
getLastName
Family name (last name) of the contact.
- Specified by:
getLastNamein interfaceBaseAddress- Specified by:
getLastNamein interfaceBaseAddressMixin- Returns:
- lastName
-
getStreetName
Name of the street.
- Specified by:
getStreetNamein interfaceBaseAddress- Specified by:
getStreetNamein interfaceBaseAddressMixin- Returns:
- streetName
-
getStreetNumber
Street number.
- Specified by:
getStreetNumberin interfaceBaseAddress- Specified by:
getStreetNumberin interfaceBaseAddressMixin- Returns:
- streetNumber
-
getAdditionalStreetInfo
Further information on the street address.
- Specified by:
getAdditionalStreetInfoin interfaceBaseAddress- Specified by:
getAdditionalStreetInfoin interfaceBaseAddressMixin- Returns:
- additionalStreetInfo
-
getPostalCode
Postal code.
- Specified by:
getPostalCodein interfaceBaseAddress- Specified by:
getPostalCodein interfaceBaseAddressMixin- Returns:
- postalCode
-
getCity
Name of the city.
- Specified by:
getCityin interfaceBaseAddress- Specified by:
getCityin interfaceBaseAddressMixin- Returns:
- city
-
getRegion
Name of the region.
- Specified by:
getRegionin interfaceBaseAddress- Specified by:
getRegionin interfaceBaseAddressMixin- Returns:
- region
-
getState
Name of the state, for example, Colorado.
- Specified by:
getStatein interfaceBaseAddress- Specified by:
getStatein interfaceBaseAddressMixin- Returns:
- state
-
getCompany
Name of the company.
- Specified by:
getCompanyin interfaceBaseAddress- Specified by:
getCompanyin interfaceBaseAddressMixin- Returns:
- company
-
getDepartment
Name of the department.
- Specified by:
getDepartmentin interfaceBaseAddress- Specified by:
getDepartmentin interfaceBaseAddressMixin- Returns:
- department
-
getBuilding
Number or name of the building.
- Specified by:
getBuildingin interfaceBaseAddress- Specified by:
getBuildingin interfaceBaseAddressMixin- Returns:
- building
-
getApartment
Number or name of the apartment.
- Specified by:
getApartmentin interfaceBaseAddress- Specified by:
getApartmentin interfaceBaseAddressMixin- Returns:
- apartment
-
getPOBox
Post office box number.
- Specified by:
getPOBoxin interfaceBaseAddress- Specified by:
getPOBoxin interfaceBaseAddressMixin- Returns:
- pOBox
-
getPhone
Phone number of the contact.
- Specified by:
getPhonein interfaceBaseAddress- Specified by:
getPhonein interfaceBaseAddressMixin- Returns:
- phone
-
getMobile
Mobile phone number of the contact.
- Specified by:
getMobilein interfaceBaseAddress- Specified by:
getMobilein interfaceBaseAddressMixin- Returns:
- mobile
-
getEmail
Email address of the contact.
- Specified by:
getEmailin interfaceBaseAddress- Specified by:
getEmailin interfaceBaseAddressMixin- Returns:
-
getFax
Fax number of the contact.
- Specified by:
getFaxin interfaceBaseAddress- Specified by:
getFaxin interfaceBaseAddressMixin- Returns:
- fax
-
getAdditionalAddressInfo
Further information on the Address.
- Specified by:
getAdditionalAddressInfoin interfaceBaseAddress- Specified by:
getAdditionalAddressInfoin interfaceBaseAddressMixin- Returns:
- additionalAddressInfo
-
getExternalId
ID for the contact used in an external system.
- Specified by:
getExternalIdin interfaceBaseAddress- Specified by:
getExternalIdin interfaceBaseAddressMixin- Returns:
- externalId
-
setId
Description copied from interface:BaseAddressUnique identifier of the Address.
It is not recommended to set it manually since the API overwrites this ID when creating an Address for a Customer. Use
keyinstead and omit this field from the request to let the API generate the ID for the Address.- Specified by:
setIdin interfaceBaseAddress- Parameters:
id- value to be set
-
setKey
Description copied from interface:BaseAddressUser-defined identifier of the Address that must be unique when multiple addresses are referenced in BusinessUnits, Customers, and
itemShippingAddresses(LineItem-specific addresses) of a Cart, Order, QuoteRequest, or Quote.- Specified by:
setKeyin interfaceBaseAddress- Parameters:
key- value to be set
-
setCountry
Description copied from interface:BaseAddressName of the country.
- Specified by:
setCountryin interfaceBaseAddress- Parameters:
country- value to be set
-
setTitle
Description copied from interface:BaseAddressTitle of the contact, for example 'Dr.'
- Specified by:
setTitlein interfaceBaseAddress- Parameters:
title- value to be set
-
setSalutation
Description copied from interface:BaseAddressSalutation of the contact, for example 'Mr.' or 'Ms.'
- Specified by:
setSalutationin interfaceBaseAddress- Parameters:
salutation- value to be set
-
setFirstName
Description copied from interface:BaseAddressGiven name (first name) of the contact.
- Specified by:
setFirstNamein interfaceBaseAddress- Parameters:
firstName- value to be set
-
setLastName
Description copied from interface:BaseAddressFamily name (last name) of the contact.
- Specified by:
setLastNamein interfaceBaseAddress- Parameters:
lastName- value to be set
-
setStreetName
Description copied from interface:BaseAddressName of the street.
- Specified by:
setStreetNamein interfaceBaseAddress- Parameters:
streetName- value to be set
-
setStreetNumber
Description copied from interface:BaseAddressStreet number.
- Specified by:
setStreetNumberin interfaceBaseAddress- Parameters:
streetNumber- value to be set
-
setAdditionalStreetInfo
Description copied from interface:BaseAddressFurther information on the street address.
- Specified by:
setAdditionalStreetInfoin interfaceBaseAddress- Parameters:
additionalStreetInfo- value to be set
-
setPostalCode
Description copied from interface:BaseAddressPostal code.
- Specified by:
setPostalCodein interfaceBaseAddress- Parameters:
postalCode- value to be set
-
setCity
Description copied from interface:BaseAddressName of the city.
- Specified by:
setCityin interfaceBaseAddress- Parameters:
city- value to be set
-
setRegion
Description copied from interface:BaseAddressName of the region.
- Specified by:
setRegionin interfaceBaseAddress- Parameters:
region- value to be set
-
setState
Description copied from interface:BaseAddressName of the state, for example, Colorado.
- Specified by:
setStatein interfaceBaseAddress- Parameters:
state- value to be set
-
setCompany
Description copied from interface:BaseAddressName of the company.
- Specified by:
setCompanyin interfaceBaseAddress- Parameters:
company- value to be set
-
setDepartment
Description copied from interface:BaseAddressName of the department.
- Specified by:
setDepartmentin interfaceBaseAddress- Parameters:
department- value to be set
-
setBuilding
Description copied from interface:BaseAddressNumber or name of the building.
- Specified by:
setBuildingin interfaceBaseAddress- Parameters:
building- value to be set
-
setApartment
Description copied from interface:BaseAddressNumber or name of the apartment.
- Specified by:
setApartmentin interfaceBaseAddress- Parameters:
apartment- value to be set
-
setPOBox
Description copied from interface:BaseAddressPost office box number.
- Specified by:
setPOBoxin interfaceBaseAddress- Parameters:
pOBox- value to be set
-
setPhone
Description copied from interface:BaseAddressPhone number of the contact.
- Specified by:
setPhonein interfaceBaseAddress- Parameters:
phone- value to be set
-
setMobile
Description copied from interface:BaseAddressMobile phone number of the contact.
- Specified by:
setMobilein interfaceBaseAddress- Parameters:
mobile- value to be set
-
setEmail
Description copied from interface:BaseAddressEmail address of the contact.
- Specified by:
setEmailin interfaceBaseAddress- Parameters:
email- value to be set
-
setFax
Description copied from interface:BaseAddressFax number of the contact.
- Specified by:
setFaxin interfaceBaseAddress- Parameters:
fax- value to be set
-
setAdditionalAddressInfo
Description copied from interface:BaseAddressFurther information on the Address.
- Specified by:
setAdditionalAddressInfoin interfaceBaseAddress- Parameters:
additionalAddressInfo- value to be set
-
setExternalId
Description copied from interface:BaseAddressID for the contact used in an external system.
- Specified by:
setExternalIdin interfaceBaseAddress- Parameters:
externalId- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceBaseAddress
-