Interface BaseResource

All Known Subinterfaces:
ApprovalFlow, ApprovalFlowApprovedMessage, ApprovalFlowCompletedMessage, ApprovalFlowCreatedMessage, ApprovalFlowRejectedMessage, ApprovalRule, ApprovalRuleApproversSetMessage, ApprovalRuleCreatedMessage, ApprovalRuleDescriptionSetMessage, ApprovalRuleKeySetMessage, ApprovalRuleNameSetMessage, ApprovalRulePredicateSetMessage, ApprovalRuleRequestersSetMessage, ApprovalRuleStatusSetMessage, AssociateRole, AssociateRoleBuyerAssignableChangedMessage, AssociateRoleCreatedMessage, AssociateRoleDeletedMessage, AssociateRoleNameSetMessage, AssociateRolePermissionAddedMessage, AssociateRolePermissionRemovedMessage, AssociateRolePermissionsSetMessage, AttributeGroup, BusinessUnit, BusinessUnitAddressAddedMessage, BusinessUnitAddressChangedMessage, BusinessUnitAddressCustomFieldAddedMessage, BusinessUnitAddressCustomFieldChangedMessage, BusinessUnitAddressCustomFieldRemovedMessage, BusinessUnitAddressCustomTypeRemovedMessage, BusinessUnitAddressCustomTypeSetMessage, BusinessUnitAddressRemovedMessage, BusinessUnitApprovalRuleModeChangedMessage, BusinessUnitAssociateAddedMessage, BusinessUnitAssociateChangedMessage, BusinessUnitAssociateModeChangedMessage, BusinessUnitAssociateRemovedMessage, BusinessUnitAssociatesSetMessage, BusinessUnitBillingAddressAddedMessage, BusinessUnitBillingAddressRemovedMessage, BusinessUnitContactEmailSetMessage, BusinessUnitCreatedMessage, BusinessUnitCustomerGroupAssignmentAddedMessage, BusinessUnitCustomerGroupAssignmentRemovedMessage, BusinessUnitCustomerGroupAssignmentsSetMessage, BusinessUnitCustomFieldAddedMessage, BusinessUnitCustomFieldChangedMessage, BusinessUnitCustomFieldRemovedMessage, BusinessUnitCustomTypeRemovedMessage, BusinessUnitCustomTypeSetMessage, BusinessUnitDefaultBillingAddressSetMessage, BusinessUnitDefaultShippingAddressSetMessage, BusinessUnitDeletedMessage, BusinessUnitNameChangedMessage, BusinessUnitParentChangedMessage, BusinessUnitShippingAddressAddedMessage, BusinessUnitShippingAddressRemovedMessage, BusinessUnitStatusChangedMessage, BusinessUnitStoreAddedMessage, BusinessUnitStoreModeChangedMessage, BusinessUnitStoreRemovedMessage, BusinessUnitStoresSetMessage, BusinessUnitTopLevelUnitSetMessage, BusinessUnitTypeSetMessage, Cart, CartDiscount, CartDiscountCreatedMessage, CartDiscountDeletedMessage, CartDiscountStoreAddedMessage, CartDiscountStoreRemovedMessage, CartDiscountStoresSetMessage, CartFrozenMessage, CartPurchaseOrderNumberSetMessage, CartUnfrozenMessage, Category, CategoryCreatedMessage, CategorySlugChangedMessage, Channel, Company, Customer, CustomerAddressAddedMessage, CustomerAddressChangedMessage, CustomerAddressCustomFieldAddedMessage, CustomerAddressCustomFieldChangedMessage, CustomerAddressCustomFieldRemovedMessage, CustomerAddressCustomTypeRemovedMessage, CustomerAddressCustomTypeSetMessage, CustomerAddressRemovedMessage, CustomerBillingAddressAddedMessage, CustomerBillingAddressRemovedMessage, CustomerCompanyNameSetMessage, CustomerCreatedMessage, CustomerCustomFieldAddedMessage, CustomerCustomFieldChangedMessage, CustomerCustomFieldRemovedMessage, CustomerCustomTypeRemovedMessage, CustomerCustomTypeSetMessage, CustomerDateOfBirthSetMessage, CustomerDefaultBillingAddressSetMessage, CustomerDefaultShippingAddressSetMessage, CustomerDeletedMessage, CustomerEmailChangedMessage, CustomerEmailTokenCreatedMessage, CustomerEmailVerifiedMessage, CustomerExternalIdSetMessage, CustomerFirstNameSetMessage, CustomerGroup, CustomerGroupAssignmentAddedMessage, CustomerGroupAssignmentRemovedMessage, CustomerGroupAssignmentsSetMessage, CustomerGroupCustomFieldAddedMessage, CustomerGroupCustomFieldChangedMessage, CustomerGroupCustomFieldRemovedMessage, CustomerGroupCustomTypeRemovedMessage, CustomerGroupCustomTypeSetMessage, CustomerGroupSetMessage, CustomerLastNameSetMessage, CustomerPasswordTokenCreatedMessage, CustomerPasswordUpdatedMessage, CustomerShippingAddressAddedMessage, CustomerShippingAddressRemovedMessage, CustomerStoresSetMessage, CustomerTitleSetMessage, CustomLineItemStateTransitionMessage, CustomObject, DeliveryAddedMessage, DeliveryAddressSetMessage, DeliveryCustomFieldAddedMessage, DeliveryCustomFieldChangedMessage, DeliveryCustomFieldRemovedMessage, DeliveryCustomTypeRemovedMessage, DeliveryCustomTypeSetMessage, DeliveryItemsUpdatedMessage, DeliveryRemovedMessage, DiscountCode, DiscountCodeCreatedMessage, DiscountCodeDeletedMessage, DiscountCodeKeySetMessage, DiscountGroup, DiscountGroupCreatedMessage, DiscountGroupDeletedMessage, DiscountGroupIsActiveSetMessage, DiscountGroupKeySetMessage, DiscountGroupSortOrderSetMessage, Division, Extension, GenericCustomObject<TValue>, InventoryEntry, InventoryEntryCreatedMessage, InventoryEntryDeletedMessage, InventoryEntryQuantitySetMessage, LineItemStateTransitionMessage, Message, Order, OrderBillingAddressSetMessage, OrderBusinessUnitSetMessage, OrderCreatedFromRecurringOrderMessage, OrderCreatedMessage, OrderCustomerEmailSetMessage, OrderCustomerGroupSetMessage, OrderCustomerSetMessage, OrderCustomFieldAddedMessage, OrderCustomFieldChangedMessage, OrderCustomFieldRemovedMessage, OrderCustomLineItemAddedMessage, OrderCustomLineItemDiscountSetMessage, OrderCustomLineItemQuantityChangedMessage, OrderCustomLineItemRemovedMessage, OrderCustomTypeRemovedMessage, OrderCustomTypeSetMessage, OrderDeletedMessage, OrderDiscountCodeAddedMessage, OrderDiscountCodeRemovedMessage, OrderDiscountCodeStateSetMessage, OrderEdit, OrderEditAppliedMessage, OrderImportedMessage, OrderLineItemAddedMessage, OrderLineItemDiscountSetMessage, OrderLineItemDistributionChannelSetMessage, OrderLineItemRemovedMessage, OrderMessage, OrderPaymentAddedMessage, OrderPaymentRemovedMessage, OrderPaymentStateChangedMessage, OrderPurchaseOrderNumberSetMessage, OrderReturnShipmentStateChangedMessage, OrderShipmentStateChangedMessage, OrderShippingAddressSetMessage, OrderShippingInfoSetMessage, OrderShippingRateInputSetMessage, OrderStateChangedMessage, OrderStateTransitionMessage, OrderStoreSetMessage, ParcelAddedToDeliveryMessage, ParcelItemsUpdatedMessage, ParcelMeasurementsUpdatedMessage, ParcelRemovedFromDeliveryMessage, ParcelTrackingDataUpdatedMessage, Payment, PaymentCreatedMessage, PaymentInteractionAddedMessage, PaymentInterfaceIdSetMessage, PaymentMethod, PaymentMethodCreatedMessage, PaymentMethodCustomFieldAddedMessage, PaymentMethodCustomFieldChangedMessage, PaymentMethodCustomFieldRemovedMessage, PaymentMethodCustomTypeRemovedMessage, PaymentMethodCustomTypeSetMessage, PaymentMethodDefaultSetMessage, PaymentMethodDeletedMessage, PaymentMethodInfoCustomFieldAddedMessage, PaymentMethodInfoCustomFieldChangedMessage, PaymentMethodInfoCustomFieldRemovedMessage, PaymentMethodInfoCustomTypeRemovedMessage, PaymentMethodInfoCustomTypeSetMessage, PaymentMethodInfoInterfaceAccountSetMessage, PaymentMethodInfoInterfaceSetMessage, PaymentMethodInfoMethodSetMessage, PaymentMethodInfoNameSetMessage, PaymentMethodInfoTokenSetMessage, PaymentMethodInterfaceAccountSetMessage, PaymentMethodKeySetMessage, PaymentMethodMethodSetMessage, PaymentMethodNameSetMessage, PaymentMethodPaymentInterfaceSetMessage, PaymentMethodPaymentMethodStatusSetMessage, PaymentStatusInterfaceCodeSetMessage, PaymentStatusStateTransitionMessage, PaymentTransactionAddedMessage, PaymentTransactionInterfaceIdSetMessage, PaymentTransactionStateChangedMessage, Product, ProductAddedToCategoryMessage, ProductCreatedMessage, ProductDeletedMessage, ProductDiscount, ProductImageAddedMessage, ProductPriceAddedMessage, ProductPriceChangedMessage, ProductPriceCustomFieldAddedMessage, ProductPriceCustomFieldChangedMessage, ProductPriceCustomFieldRemovedMessage, ProductPriceCustomFieldsRemovedMessage, ProductPriceCustomFieldsSetMessage, ProductPriceDiscountsSetMessage, ProductPriceExternalDiscountSetMessage, ProductPriceKeySetMessage, ProductPriceModeSetMessage, ProductPriceRemovedMessage, ProductPricesSetMessage, ProductProjection, ProductPublishedMessage, ProductRemovedFromCategoryMessage, ProductRevertedStagedChangesMessage, ProductSelection, ProductSelectionCreatedMessage, ProductSelectionDeletedMessage, ProductSelectionProductAddedMessage, ProductSelectionProductExcludedMessage, ProductSelectionProductRemovedMessage, ProductSelectionVariantExclusionChangedMessage, ProductSelectionVariantSelectionChangedMessage, ProductSlugChangedMessage, ProductStateTransitionMessage, ProductTailoring, ProductTailoringCreatedMessage, ProductTailoringDeletedMessage, ProductTailoringDescriptionSetMessage, ProductTailoringImageAddedMessage, ProductTailoringImagesSetMessage, ProductTailoringNameSetMessage, ProductTailoringPublishedMessage, ProductTailoringSlugSetMessage, ProductTailoringUnpublishedMessage, ProductType, ProductUnpublishedMessage, ProductVariantAddedMessage, ProductVariantDeletedMessage, ProductVariantTailoringAddedMessage, ProductVariantTailoringRemovedMessage, Quote, QuoteCreatedMessage, QuoteCustomerChangedMessage, QuoteDeletedMessage, QuoteRenegotiationRequestedMessage, QuoteRequest, QuoteRequestCreatedMessage, QuoteRequestCustomerChangedMessage, QuoteRequestDeletedMessage, QuoteRequestStateChangedMessage, QuoteRequestStateTransitionMessage, QuoteStateChangedMessage, QuoteStateTransitionMessage, RecurrencePolicy, RecurringOrder, RecurringOrderCreatedMessage, RecurringOrderCustomFieldAddedMessage, RecurringOrderCustomFieldChangedMessage, RecurringOrderCustomFieldRemovedMessage, RecurringOrderCustomTypeRemovedMessage, RecurringOrderCustomTypeSetMessage, RecurringOrderDeletedMessage, RecurringOrderExpiresAtSetMessage, RecurringOrderFailedMessage, RecurringOrderKeySetMessage, RecurringOrderScheduleSetMessage, RecurringOrderStartsAtSetMessage, RecurringOrderStateChangedMessage, RecurringOrderStateTransitionMessage, ReturnInfoAddedMessage, ReturnInfoSetMessage, Review, ReviewCreatedMessage, ReviewRatingSetMessage, ReviewStateTransitionMessage, ShippingMethod, ShoppingList, ShoppingListLineItemAddedMessage, ShoppingListLineItemRemovedMessage, ShoppingListMessage, StagedOrder, StagedQuote, StagedQuoteCreatedMessage, StagedQuoteDeletedMessage, StagedQuoteSellerCommentSetMessage, StagedQuoteStateChangedMessage, StagedQuoteStateTransitionMessage, StagedQuoteValidToSetMessage, StandalonePrice, StandalonePriceActiveChangedMessage, StandalonePriceCreatedMessage, StandalonePriceDeletedMessage, StandalonePriceDiscountSetMessage, StandalonePriceExternalDiscountSetMessage, StandalonePriceKeySetMessage, StandalonePriceStagedChangesAppliedMessage, StandalonePriceStagedChangesRemovedMessage, StandalonePriceTierAddedMessage, StandalonePriceTierRemovedMessage, StandalonePriceTiersSetMessage, StandalonePriceValidFromAndUntilSetMessage, StandalonePriceValidFromSetMessage, StandalonePriceValidUntilSetMessage, StandalonePriceValueChangedMessage, State, Store, StoreCountriesChangedMessage, StoreCreatedMessage, StoreDeletedMessage, StoreDistributionChannelsChangedMessage, StoreLanguagesChangedMessage, StoreNameSetMessage, StoreProductSelectionsChangedMessage, StoreSupplyChannelsChangedMessage, Subscription, TaxCategory, Type, Zone
All Known Implementing Classes:
ApprovalFlowApprovedMessageImpl, ApprovalFlowCompletedMessageImpl, ApprovalFlowCreatedMessageImpl, ApprovalFlowImpl, ApprovalFlowRejectedMessageImpl, ApprovalRuleApproversSetMessageImpl, ApprovalRuleCreatedMessageImpl, ApprovalRuleDescriptionSetMessageImpl, ApprovalRuleImpl, ApprovalRuleKeySetMessageImpl, ApprovalRuleNameSetMessageImpl, ApprovalRulePredicateSetMessageImpl, ApprovalRuleRequestersSetMessageImpl, ApprovalRuleStatusSetMessageImpl, AssociateRoleBuyerAssignableChangedMessageImpl, AssociateRoleCreatedMessageImpl, AssociateRoleDeletedMessageImpl, AssociateRoleImpl, AssociateRoleNameSetMessageImpl, AssociateRolePermissionAddedMessageImpl, AssociateRolePermissionRemovedMessageImpl, AssociateRolePermissionsSetMessageImpl, AttributeGroupImpl, BaseResourceImpl, BusinessUnitAddressAddedMessageImpl, BusinessUnitAddressChangedMessageImpl, BusinessUnitAddressCustomFieldAddedMessageImpl, BusinessUnitAddressCustomFieldChangedMessageImpl, BusinessUnitAddressCustomFieldRemovedMessageImpl, BusinessUnitAddressCustomTypeRemovedMessageImpl, BusinessUnitAddressCustomTypeSetMessageImpl, BusinessUnitAddressRemovedMessageImpl, BusinessUnitApprovalRuleModeChangedMessageImpl, BusinessUnitAssociateAddedMessageImpl, BusinessUnitAssociateChangedMessageImpl, BusinessUnitAssociateModeChangedMessageImpl, BusinessUnitAssociateRemovedMessageImpl, BusinessUnitAssociatesSetMessageImpl, BusinessUnitBillingAddressAddedMessageImpl, BusinessUnitBillingAddressRemovedMessageImpl, BusinessUnitContactEmailSetMessageImpl, BusinessUnitCreatedMessageImpl, BusinessUnitCustomerGroupAssignmentAddedMessageImpl, BusinessUnitCustomerGroupAssignmentRemovedMessageImpl, BusinessUnitCustomerGroupAssignmentsSetMessageImpl, BusinessUnitCustomFieldAddedMessageImpl, BusinessUnitCustomFieldChangedMessageImpl, BusinessUnitCustomFieldRemovedMessageImpl, BusinessUnitCustomTypeRemovedMessageImpl, BusinessUnitCustomTypeSetMessageImpl, BusinessUnitDefaultBillingAddressSetMessageImpl, BusinessUnitDefaultShippingAddressSetMessageImpl, BusinessUnitDeletedMessageImpl, BusinessUnitImpl, BusinessUnitNameChangedMessageImpl, BusinessUnitParentChangedMessageImpl, BusinessUnitShippingAddressAddedMessageImpl, BusinessUnitShippingAddressRemovedMessageImpl, BusinessUnitStatusChangedMessageImpl, BusinessUnitStoreAddedMessageImpl, BusinessUnitStoreModeChangedMessageImpl, BusinessUnitStoreRemovedMessageImpl, BusinessUnitStoresSetMessageImpl, BusinessUnitTopLevelUnitSetMessageImpl, BusinessUnitTypeSetMessageImpl, CartDiscountCreatedMessageImpl, CartDiscountDeletedMessageImpl, CartDiscountImpl, CartDiscountStoreAddedMessageImpl, CartDiscountStoreRemovedMessageImpl, CartDiscountStoresSetMessageImpl, CartFrozenMessageImpl, CartImpl, CartPurchaseOrderNumberSetMessageImpl, CartUnfrozenMessageImpl, CategoryCreatedMessageImpl, CategoryImpl, CategorySlugChangedMessageImpl, ChannelImpl, CompanyImpl, CustomerAddressAddedMessageImpl, CustomerAddressChangedMessageImpl, CustomerAddressCustomFieldAddedMessageImpl, CustomerAddressCustomFieldChangedMessageImpl, CustomerAddressCustomFieldRemovedMessageImpl, CustomerAddressCustomTypeRemovedMessageImpl, CustomerAddressCustomTypeSetMessageImpl, CustomerAddressRemovedMessageImpl, CustomerBillingAddressAddedMessageImpl, CustomerBillingAddressRemovedMessageImpl, CustomerCompanyNameSetMessageImpl, CustomerCreatedMessageImpl, CustomerCustomFieldAddedMessageImpl, CustomerCustomFieldChangedMessageImpl, CustomerCustomFieldRemovedMessageImpl, CustomerCustomTypeRemovedMessageImpl, CustomerCustomTypeSetMessageImpl, CustomerDateOfBirthSetMessageImpl, CustomerDefaultBillingAddressSetMessageImpl, CustomerDefaultShippingAddressSetMessageImpl, CustomerDeletedMessageImpl, CustomerEmailChangedMessageImpl, CustomerEmailTokenCreatedMessageImpl, CustomerEmailVerifiedMessageImpl, CustomerExternalIdSetMessageImpl, CustomerFirstNameSetMessageImpl, CustomerGroupAssignmentAddedMessageImpl, CustomerGroupAssignmentRemovedMessageImpl, CustomerGroupAssignmentsSetMessageImpl, CustomerGroupCustomFieldAddedMessageImpl, CustomerGroupCustomFieldChangedMessageImpl, CustomerGroupCustomFieldRemovedMessageImpl, CustomerGroupCustomTypeRemovedMessageImpl, CustomerGroupCustomTypeSetMessageImpl, CustomerGroupImpl, CustomerGroupSetMessageImpl, CustomerImpl, CustomerLastNameSetMessageImpl, CustomerPasswordTokenCreatedMessageImpl, CustomerPasswordUpdatedMessageImpl, CustomerShippingAddressAddedMessageImpl, CustomerShippingAddressRemovedMessageImpl, CustomerStoresSetMessageImpl, CustomerTitleSetMessageImpl, CustomLineItemStateTransitionMessageImpl, CustomObjectImpl, DeliveryAddedMessageImpl, DeliveryAddressSetMessageImpl, DeliveryCustomFieldAddedMessageImpl, DeliveryCustomFieldChangedMessageImpl, DeliveryCustomFieldRemovedMessageImpl, DeliveryCustomTypeRemovedMessageImpl, DeliveryCustomTypeSetMessageImpl, DeliveryItemsUpdatedMessageImpl, DeliveryRemovedMessageImpl, DiscountCodeCreatedMessageImpl, DiscountCodeDeletedMessageImpl, DiscountCodeImpl, DiscountCodeKeySetMessageImpl, DiscountGroupCreatedMessageImpl, DiscountGroupDeletedMessageImpl, DiscountGroupImpl, DiscountGroupIsActiveSetMessageImpl, DiscountGroupKeySetMessageImpl, DiscountGroupSortOrderSetMessageImpl, DivisionImpl, ExtensionImpl, GenericCustomObjectImpl, InventoryEntryCreatedMessageImpl, InventoryEntryDeletedMessageImpl, InventoryEntryImpl, InventoryEntryQuantitySetMessageImpl, LineItemStateTransitionMessageImpl, MessageImpl, OrderBillingAddressSetMessageImpl, OrderBusinessUnitSetMessageImpl, OrderCreatedFromRecurringOrderMessageImpl, OrderCreatedMessageImpl, OrderCustomerEmailSetMessageImpl, OrderCustomerGroupSetMessageImpl, OrderCustomerSetMessageImpl, OrderCustomFieldAddedMessageImpl, OrderCustomFieldChangedMessageImpl, OrderCustomFieldRemovedMessageImpl, OrderCustomLineItemAddedMessageImpl, OrderCustomLineItemDiscountSetMessageImpl, OrderCustomLineItemQuantityChangedMessageImpl, OrderCustomLineItemRemovedMessageImpl, OrderCustomTypeRemovedMessageImpl, OrderCustomTypeSetMessageImpl, OrderDeletedMessageImpl, OrderDiscountCodeAddedMessageImpl, OrderDiscountCodeRemovedMessageImpl, OrderDiscountCodeStateSetMessageImpl, OrderEditAppliedMessageImpl, OrderEditImpl, OrderImpl, OrderImportedMessageImpl, OrderLineItemAddedMessageImpl, OrderLineItemDiscountSetMessageImpl, OrderLineItemDistributionChannelSetMessageImpl, OrderLineItemRemovedMessageImpl, OrderMessageImpl, OrderPaymentAddedMessageImpl, OrderPaymentRemovedMessageImpl, OrderPaymentStateChangedMessageImpl, OrderPurchaseOrderNumberSetMessageImpl, OrderReturnShipmentStateChangedMessageImpl, OrderShipmentStateChangedMessageImpl, OrderShippingAddressSetMessageImpl, OrderShippingInfoSetMessageImpl, OrderShippingRateInputSetMessageImpl, OrderStateChangedMessageImpl, OrderStateTransitionMessageImpl, OrderStoreSetMessageImpl, ParcelAddedToDeliveryMessageImpl, ParcelItemsUpdatedMessageImpl, ParcelMeasurementsUpdatedMessageImpl, ParcelRemovedFromDeliveryMessageImpl, ParcelTrackingDataUpdatedMessageImpl, PaymentCreatedMessageImpl, PaymentImpl, PaymentInteractionAddedMessageImpl, PaymentInterfaceIdSetMessageImpl, PaymentMethodCreatedMessageImpl, PaymentMethodCustomFieldAddedMessageImpl, PaymentMethodCustomFieldChangedMessageImpl, PaymentMethodCustomFieldRemovedMessageImpl, PaymentMethodCustomTypeRemovedMessageImpl, PaymentMethodCustomTypeSetMessageImpl, PaymentMethodDefaultSetMessageImpl, PaymentMethodDeletedMessageImpl, PaymentMethodImpl, PaymentMethodInfoCustomFieldAddedMessageImpl, PaymentMethodInfoCustomFieldChangedMessageImpl, PaymentMethodInfoCustomFieldRemovedMessageImpl, PaymentMethodInfoCustomTypeRemovedMessageImpl, PaymentMethodInfoCustomTypeSetMessageImpl, PaymentMethodInfoInterfaceAccountSetMessageImpl, PaymentMethodInfoInterfaceSetMessageImpl, PaymentMethodInfoMethodSetMessageImpl, PaymentMethodInfoNameSetMessageImpl, PaymentMethodInfoTokenSetMessageImpl, PaymentMethodInterfaceAccountSetMessageImpl, PaymentMethodKeySetMessageImpl, PaymentMethodMethodSetMessageImpl, PaymentMethodNameSetMessageImpl, PaymentMethodPaymentInterfaceSetMessageImpl, PaymentMethodPaymentMethodStatusSetMessageImpl, PaymentStatusInterfaceCodeSetMessageImpl, PaymentStatusStateTransitionMessageImpl, PaymentTransactionAddedMessageImpl, PaymentTransactionInterfaceIdSetMessageImpl, PaymentTransactionStateChangedMessageImpl, ProductAddedToCategoryMessageImpl, ProductCreatedMessageImpl, ProductDeletedMessageImpl, ProductDiscountImpl, ProductImageAddedMessageImpl, ProductImpl, ProductPriceAddedMessageImpl, ProductPriceChangedMessageImpl, ProductPriceCustomFieldAddedMessageImpl, ProductPriceCustomFieldChangedMessageImpl, ProductPriceCustomFieldRemovedMessageImpl, ProductPriceCustomFieldsRemovedMessageImpl, ProductPriceCustomFieldsSetMessageImpl, ProductPriceDiscountsSetMessageImpl, ProductPriceExternalDiscountSetMessageImpl, ProductPriceKeySetMessageImpl, ProductPriceModeSetMessageImpl, ProductPriceRemovedMessageImpl, ProductPricesSetMessageImpl, ProductProjectionImpl, ProductPublishedMessageImpl, ProductRemovedFromCategoryMessageImpl, ProductRevertedStagedChangesMessageImpl, ProductSelectionCreatedMessageImpl, ProductSelectionDeletedMessageImpl, ProductSelectionImpl, ProductSelectionProductAddedMessageImpl, ProductSelectionProductExcludedMessageImpl, ProductSelectionProductRemovedMessageImpl, ProductSelectionVariantExclusionChangedMessageImpl, ProductSelectionVariantSelectionChangedMessageImpl, ProductSlugChangedMessageImpl, ProductStateTransitionMessageImpl, ProductTailoringCreatedMessageImpl, ProductTailoringDeletedMessageImpl, ProductTailoringDescriptionSetMessageImpl, ProductTailoringImageAddedMessageImpl, ProductTailoringImagesSetMessageImpl, ProductTailoringImpl, ProductTailoringNameSetMessageImpl, ProductTailoringPublishedMessageImpl, ProductTailoringSlugSetMessageImpl, ProductTailoringUnpublishedMessageImpl, ProductTypeImpl, ProductUnpublishedMessageImpl, ProductVariantAddedMessageImpl, ProductVariantDeletedMessageImpl, ProductVariantTailoringAddedMessageImpl, ProductVariantTailoringRemovedMessageImpl, QuoteCreatedMessageImpl, QuoteCustomerChangedMessageImpl, QuoteDeletedMessageImpl, QuoteImpl, QuoteRenegotiationRequestedMessageImpl, QuoteRequestCreatedMessageImpl, QuoteRequestCustomerChangedMessageImpl, QuoteRequestDeletedMessageImpl, QuoteRequestImpl, QuoteRequestStateChangedMessageImpl, QuoteRequestStateTransitionMessageImpl, QuoteStateChangedMessageImpl, QuoteStateTransitionMessageImpl, RecurrencePolicyImpl, RecurringOrderCreatedMessageImpl, RecurringOrderCustomFieldAddedMessageImpl, RecurringOrderCustomFieldChangedMessageImpl, RecurringOrderCustomFieldRemovedMessageImpl, RecurringOrderCustomTypeRemovedMessageImpl, RecurringOrderCustomTypeSetMessageImpl, RecurringOrderDeletedMessageImpl, RecurringOrderExpiresAtSetMessageImpl, RecurringOrderFailedMessageImpl, RecurringOrderImpl, RecurringOrderKeySetMessageImpl, RecurringOrderScheduleSetMessageImpl, RecurringOrderStartsAtSetMessageImpl, RecurringOrderStateChangedMessageImpl, RecurringOrderStateTransitionMessageImpl, ReturnInfoAddedMessageImpl, ReturnInfoSetMessageImpl, ReviewCreatedMessageImpl, ReviewImpl, ReviewRatingSetMessageImpl, ReviewStateTransitionMessageImpl, ShippingMethodImpl, ShoppingListImpl, ShoppingListLineItemAddedMessageImpl, ShoppingListLineItemRemovedMessageImpl, ShoppingListMessageImpl, StagedOrderImpl, StagedQuoteCreatedMessageImpl, StagedQuoteDeletedMessageImpl, StagedQuoteImpl, StagedQuoteSellerCommentSetMessageImpl, StagedQuoteStateChangedMessageImpl, StagedQuoteStateTransitionMessageImpl, StagedQuoteValidToSetMessageImpl, StandalonePriceActiveChangedMessageImpl, StandalonePriceCreatedMessageImpl, StandalonePriceDeletedMessageImpl, StandalonePriceDiscountSetMessageImpl, StandalonePriceExternalDiscountSetMessageImpl, StandalonePriceImpl, StandalonePriceKeySetMessageImpl, StandalonePriceStagedChangesAppliedMessageImpl, StandalonePriceStagedChangesRemovedMessageImpl, StandalonePriceTierAddedMessageImpl, StandalonePriceTierRemovedMessageImpl, StandalonePriceTiersSetMessageImpl, StandalonePriceValidFromAndUntilSetMessageImpl, StandalonePriceValidFromSetMessageImpl, StandalonePriceValidUntilSetMessageImpl, StandalonePriceValueChangedMessageImpl, StateImpl, StoreCountriesChangedMessageImpl, StoreCreatedMessageImpl, StoreDeletedMessageImpl, StoreDistributionChannelsChangedMessageImpl, StoreImpl, StoreLanguagesChangedMessageImpl, StoreNameSetMessageImpl, StoreProductSelectionsChangedMessageImpl, StoreSupplyChannelsChangedMessageImpl, SubscriptionImpl, TaxCategoryImpl, TypeImpl, ZoneImpl

public interface BaseResource
BaseResource
Example to create an instance using the builder pattern

     BaseResource baseResource = BaseResource.builder()
             .id("{id}")
             .version(0.3)
             .createdAt(ZonedDateTime.parse("2022-01-01T12:00:00.301Z"))
             .lastModifiedAt(ZonedDateTime.parse("2022-01-01T12:00:00.301Z"))
             .build()
 
  • Method Details

    • getId

      @NotNull @NotNull String getId()
      Returns:
      id
    • getVersion

      @NotNull @NotNull Long getVersion()
      Returns:
      version
    • getCreatedAt

      @NotNull @NotNull ZonedDateTime getCreatedAt()
      Returns:
      createdAt
    • getLastModifiedAt

      @NotNull @NotNull ZonedDateTime getLastModifiedAt()
      Returns:
      lastModifiedAt
    • setId

      void setId(String id)
      set id
      Parameters:
      id - value to be set
    • setVersion

      void setVersion(Long version)
      set version
      Parameters:
      version - value to be set
    • setCreatedAt

      void setCreatedAt(ZonedDateTime createdAt)
      set createdAt
      Parameters:
      createdAt - value to be set
    • setLastModifiedAt

      void setLastModifiedAt(ZonedDateTime lastModifiedAt)
      set lastModifiedAt
      Parameters:
      lastModifiedAt - value to be set
    • copyDeep

      BaseResource copyDeep()
    • deepCopy

      @Nullable static BaseResource deepCopy(@Nullable BaseResource template)
      factory method to create a deep copy of BaseResource
      Parameters:
      template - instance to be copied
      Returns:
      copy instance
    • withBaseResource

      default <T> T withBaseResource(Function<BaseResource,T> helper)
      accessor map function
      Type Parameters:
      T - mapped type
      Parameters:
      helper - function to map the object
      Returns:
      mapped value
    • typeReference

      static com.fasterxml.jackson.core.type.TypeReference<BaseResource> typeReference()
      gives a TypeReference for usage with Jackson DataBind
      Returns:
      TypeReference