Class KeyReferenceImpl
java.lang.Object
com.commercetools.api.models.common.KeyReferenceImpl
- All Implemented Interfaces:
KeyReference,WithKey,io.vrap.rmf.base.client.ModelBase
public class KeyReferenceImpl
extends Object
implements KeyReference, io.vrap.rmf.base.client.ModelBase
A KeyReference represents a loose reference to another resource in the same Project identified by the resource's key field. If available, the key is immutable and mandatory. KeyReferences do not support Reference Expansion.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.common.KeyReference
withKeyReferenceMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
KeyReferenceImpl
public KeyReferenceImpl()create empty instance
-
-
Method Details
-
getTypeId
Type of referenced resource.
- Specified by:
getTypeIdin interfaceKeyReference- Returns:
- typeId
-
getKey
User-defined unique and immutable key of the referenced resource.
- Specified by:
getKeyin interfaceKeyReference- Specified by:
getKeyin interfaceWithKey- Returns:
- key
-
setKey
Description copied from interface:KeyReferenceUser-defined unique and immutable key of the referenced resource.
- Specified by:
setKeyin interfaceKeyReference- Parameters:
key- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceKeyReference
-