Class QueryPriceImpl
- All Implemented Interfaces:
QueryPrice,Customizable<QueryPrice>,io.vrap.rmf.base.client.ModelBase
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanProductDistributionChannel for which the given Price is valid.Country for which the given Price is valid.Custom Fields for the Price.CustomerGroup for which the given Price is valid.DiscountedPrice you specify for the given Price.getId()Unique identifier of the given Price.getTiers()Price tier applied when the minimum quantity for the LineItem of a ProductVariant with the related Price is reached in a Cart.Date from which the given Price is valid.Date until which the given Price is valid.getValue()Money value of the given Price.inthashCode()voidsetChannel(ChannelReference channel) ProductDistributionChannel for which the given Price is valid.voidsetCountry(String country) Country for which the given Price is valid.voidsetCustom(CustomFields custom) Custom Fields for the Price.voidsetCustomerGroup(CustomerGroupReference customerGroup) CustomerGroup for which the given Price is valid.voidsetDiscounted(DiscountedPriceDraft discounted) DiscountedPrice you specify for the given Price.voidUnique identifier of the given Price.voidsetTiers(PriceTierDraft... tiers) Price tier applied when the minimum quantity for the LineItem of a ProductVariant with the related Price is reached in a Cart.voidsetTiers(List<PriceTierDraft> tiers) Price tier applied when the minimum quantity for the LineItem of a ProductVariant with the related Price is reached in a Cart.voidsetValidFrom(ZonedDateTime validFrom) Date from which the given Price is valid.voidsetValidUntil(ZonedDateTime validUntil) Date until which the given Price is valid.voidMoney value of the given Price.toString()Methods inherited from interface com.commercetools.api.models.Customizable
unwrapCustomizableMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.common.QueryPrice
withQueryPrice
-
Constructor Details
-
QueryPriceImpl
public QueryPriceImpl()create empty instance
-
-
Method Details
-
getId
Unique identifier of the given Price.
- Specified by:
getIdin interfaceQueryPrice- Returns:
- id
-
getValue
Money value of the given Price.
- Specified by:
getValuein interfaceQueryPrice- Returns:
- value
-
getCountry
Country for which the given Price is valid.
- Specified by:
getCountryin interfaceQueryPrice- Returns:
- country
-
getCustomerGroup
CustomerGroup for which the given Price is valid.
- Specified by:
getCustomerGroupin interfaceQueryPrice- Returns:
- customerGroup
-
getChannel
ProductDistributionChannel for which the given Price is valid.- Specified by:
getChannelin interfaceQueryPrice- Returns:
- channel
-
getValidFrom
Date from which the given Price is valid.
- Specified by:
getValidFromin interfaceQueryPrice- Returns:
- validFrom
-
getValidUntil
Date until which the given Price is valid.
- Specified by:
getValidUntilin interfaceQueryPrice- Returns:
- validUntil
-
getDiscounted
DiscountedPrice you specify for the given Price.
- Specified by:
getDiscountedin interfaceQueryPrice- Returns:
- discounted
-
getCustom
Custom Fields for the Price.
- Specified by:
getCustomin interfaceCustomizable<QueryPrice>- Specified by:
getCustomin interfaceQueryPrice- Returns:
- custom
-
getTiers
Price tier applied when the minimum quantity for the LineItem of a ProductVariant with the related Price is reached in a Cart.
If
discountedis specified, the tiered Price is ignored for a Product Variant.- Specified by:
getTiersin interfaceQueryPrice- Returns:
- tiers
-
setId
Description copied from interface:QueryPriceUnique identifier of the given Price.
- Specified by:
setIdin interfaceQueryPrice- Parameters:
id- value to be set
-
setValue
Description copied from interface:QueryPriceMoney value of the given Price.
- Specified by:
setValuein interfaceQueryPrice- Parameters:
value- value to be set
-
setCountry
Description copied from interface:QueryPriceCountry for which the given Price is valid.
- Specified by:
setCountryin interfaceQueryPrice- Parameters:
country- value to be set
-
setCustomerGroup
Description copied from interface:QueryPriceCustomerGroup for which the given Price is valid.
- Specified by:
setCustomerGroupin interfaceQueryPrice- Parameters:
customerGroup- value to be set
-
setChannel
Description copied from interface:QueryPriceProductDistributionChannel for which the given Price is valid.- Specified by:
setChannelin interfaceQueryPrice- Parameters:
channel- value to be set
-
setValidFrom
Description copied from interface:QueryPriceDate from which the given Price is valid.
- Specified by:
setValidFromin interfaceQueryPrice- Parameters:
validFrom- value to be set
-
setValidUntil
Description copied from interface:QueryPriceDate until which the given Price is valid.
- Specified by:
setValidUntilin interfaceQueryPrice- Parameters:
validUntil- value to be set
-
setDiscounted
Description copied from interface:QueryPriceDiscountedPrice you specify for the given Price.
- Specified by:
setDiscountedin interfaceQueryPrice- Parameters:
discounted- value to be set
-
setCustom
Description copied from interface:QueryPriceCustom Fields for the Price.
- Specified by:
setCustomin interfaceCustomizable<QueryPrice>- Specified by:
setCustomin interfaceQueryPrice- Parameters:
custom- value to be set
-
setTiers
Description copied from interface:QueryPricePrice tier applied when the minimum quantity for the LineItem of a ProductVariant with the related Price is reached in a Cart.
If
discountedis specified, the tiered Price is ignored for a Product Variant.- Specified by:
setTiersin interfaceQueryPrice- Parameters:
tiers- values to be set
-
setTiers
Description copied from interface:QueryPricePrice tier applied when the minimum quantity for the LineItem of a ProductVariant with the related Price is reached in a Cart.
If
discountedis specified, the tiered Price is ignored for a Product Variant.- Specified by:
setTiersin interfaceQueryPrice- Parameters:
tiers- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceQueryPrice
-