Class CustomObjectImpl
- All Implemented Interfaces:
BaseResource,CustomObject,CustomObjectMixin,DomainResource<CustomObject>,Identifiable<CustomObject>,Referencable<CustomObject>,Versioned<CustomObject>,io.vrap.rmf.base.client.ModelBase
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanNamespace to group CustomObjects.Date and time (UTC) the CustomObject was initially created.IDs and references that created the CustomObject.getId()Unique identifier of the CustomObject.getKey()User-defined unique identifier of the CustomObject within the definedcontainer.Date and time (UTC) the CustomObject was last updated.IDs and references that last modified the CustomObject.getValue()Can be any JSON standard type, such as number, string, boolean, array, object, or a common API data type.Current version of the CustomObject.inthashCode()voidsetContainer(String container) Namespace to group CustomObjects.voidsetCreatedAt(ZonedDateTime createdAt) Date and time (UTC) the CustomObject was initially created.voidsetCreatedBy(CreatedBy createdBy) IDs and references that created the CustomObject.voidUnique identifier of the CustomObject.voidUser-defined unique identifier of the CustomObject within the definedcontainer.voidsetLastModifiedAt(ZonedDateTime lastModifiedAt) Date and time (UTC) the CustomObject was last updated.voidsetLastModifiedBy(LastModifiedBy lastModifiedBy) IDs and references that last modified the CustomObject.voidCan be any JSON standard type, such as number, string, boolean, array, object, or a common API data type.voidsetVersion(Long version) Current version of the CustomObject.toString()Methods inherited from interface com.commercetools.api.models.common.BaseResource
withBaseResourceMethods inherited from interface com.commercetools.api.models.custom_object.CustomObject
withCustomObjectMethods inherited from interface com.commercetools.api.models.custom_object.CustomObjectMixin
toReferenceMethods inherited from interface com.commercetools.api.models.DomainResource
getMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
CustomObjectImpl
public CustomObjectImpl()create empty instance
-
-
Method Details
-
getId
Unique identifier of the CustomObject.
- Specified by:
getIdin interfaceBaseResource- Specified by:
getIdin interfaceCustomObject- Specified by:
getIdin interfaceDomainResource<CustomObject>- Specified by:
getIdin interfaceIdentifiable<CustomObject>- Specified by:
getIdin interfaceVersioned<CustomObject>- Returns:
- id
-
getVersion
Current version of the CustomObject.
- Specified by:
getVersionin interfaceBaseResource- Specified by:
getVersionin interfaceCustomObject- Specified by:
getVersionin interfaceDomainResource<CustomObject>- Specified by:
getVersionin interfaceVersioned<CustomObject>- Returns:
- version
-
getCreatedAt
Date and time (UTC) the CustomObject was initially created.
- Specified by:
getCreatedAtin interfaceBaseResource- Specified by:
getCreatedAtin interfaceCustomObject- Returns:
- createdAt
-
getLastModifiedAt
Date and time (UTC) the CustomObject was last updated.
- Specified by:
getLastModifiedAtin interfaceBaseResource- Specified by:
getLastModifiedAtin interfaceCustomObject- Returns:
- lastModifiedAt
-
getLastModifiedBy
IDs and references that last modified the CustomObject.
- Specified by:
getLastModifiedByin interfaceCustomObject- Returns:
- lastModifiedBy
-
getCreatedBy
IDs and references that created the CustomObject.
- Specified by:
getCreatedByin interfaceCustomObject- Returns:
- createdBy
-
getContainer
Namespace to group CustomObjects.
- Specified by:
getContainerin interfaceCustomObject- Returns:
- container
-
getKey
User-defined unique identifier of the CustomObject within the defined
container.- Specified by:
getKeyin interfaceCustomObject- Returns:
- key
-
getValue
Can be any JSON standard type, such as number, string, boolean, array, object, or a common API data type.
- For values of type Reference the integrity of the data is not guaranteed. If the referenced object is deleted, the API does not delete the corresponding reference to it and the
valuepoints to a non-existing object in such case.
- Specified by:
getValuein interfaceCustomObject- Returns:
- value
- For values of type Reference the integrity of the data is not guaranteed. If the referenced object is deleted, the API does not delete the corresponding reference to it and the
-
setId
Description copied from interface:CustomObjectUnique identifier of the CustomObject.
- Specified by:
setIdin interfaceBaseResource- Specified by:
setIdin interfaceCustomObject- Parameters:
id- value to be set
-
setVersion
Description copied from interface:CustomObjectCurrent version of the CustomObject.
- Specified by:
setVersionin interfaceBaseResource- Specified by:
setVersionin interfaceCustomObject- Parameters:
version- value to be set
-
setCreatedAt
Description copied from interface:CustomObjectDate and time (UTC) the CustomObject was initially created.
- Specified by:
setCreatedAtin interfaceBaseResource- Specified by:
setCreatedAtin interfaceCustomObject- Parameters:
createdAt- value to be set
-
setLastModifiedAt
Description copied from interface:CustomObjectDate and time (UTC) the CustomObject was last updated.
- Specified by:
setLastModifiedAtin interfaceBaseResource- Specified by:
setLastModifiedAtin interfaceCustomObject- Parameters:
lastModifiedAt- value to be set
-
setLastModifiedBy
Description copied from interface:CustomObjectIDs and references that last modified the CustomObject.
- Specified by:
setLastModifiedByin interfaceCustomObject- Parameters:
lastModifiedBy- value to be set
-
setCreatedBy
Description copied from interface:CustomObjectIDs and references that created the CustomObject.
- Specified by:
setCreatedByin interfaceCustomObject- Parameters:
createdBy- value to be set
-
setContainer
Description copied from interface:CustomObjectNamespace to group CustomObjects.
- Specified by:
setContainerin interfaceCustomObject- Parameters:
container- value to be set
-
setKey
Description copied from interface:CustomObjectUser-defined unique identifier of the CustomObject within the defined
container.- Specified by:
setKeyin interfaceCustomObject- Parameters:
key- value to be set
-
setValue
Description copied from interface:CustomObjectCan be any JSON standard type, such as number, string, boolean, array, object, or a common API data type.
- For values of type Reference the integrity of the data is not guaranteed. If the referenced object is deleted, the API does not delete the corresponding reference to it and the
valuepoints to a non-existing object in such case.
- Specified by:
setValuein interfaceCustomObject- Parameters:
value- value to be set
- For values of type Reference the integrity of the data is not guaranteed. If the referenced object is deleted, the API does not delete the corresponding reference to it and the
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceBaseResource- Specified by:
copyDeepin interfaceCustomObject
-