Class CustomObjectReferenceImpl
java.lang.Object
com.commercetools.api.models.custom_object.CustomObjectReferenceImpl
- All Implemented Interfaces:
Reference,ReferenceMixin,CustomObjectReference,Identifiable<CustomObject>,IdentifiableObjHolder<CustomObject>,io.vrap.rmf.base.client.ModelBase
public class CustomObjectReferenceImpl
extends Object
implements CustomObjectReference, io.vrap.rmf.base.client.ModelBase
Reference to a CustomObject.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.custom_object.CustomObjectReference
KEY_VALUE_DOCUMENT -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetId()Unique identifier of the referenced CustomObject.getObj()Contains the representation of the expanded CustomObject.Type of referenced resource.inthashCode()voidUnique identifier of the referenced CustomObject.voidsetObj(CustomObject obj) Contains the representation of the expanded CustomObject.toString()Methods inherited from interface com.commercetools.api.models.custom_object.CustomObjectReference
withCustomObjectReferenceMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.common.Reference
withReferenceMethods inherited from interface com.commercetools.api.models.common.ReferenceMixin
toResourceIdentifier
-
Constructor Details
-
CustomObjectReferenceImpl
public CustomObjectReferenceImpl()create empty instance
-
-
Method Details
-
getTypeId
Type of referenced resource.
- Specified by:
getTypeIdin interfaceReference- Specified by:
getTypeIdin interfaceReferenceMixin- Returns:
- typeId
-
getId
Unique identifier of the referenced CustomObject.
- Specified by:
getIdin interfaceCustomObjectReference- Specified by:
getIdin interfaceIdentifiable<CustomObject>- Specified by:
getIdin interfaceReference- Specified by:
getIdin interfaceReferenceMixin- Returns:
- id
-
getObj
Contains the representation of the expanded CustomObject. Only present in responses to requests with Reference Expansion for CustomObjects.
- Specified by:
getObjin interfaceCustomObjectReference- Specified by:
getObjin interfaceIdentifiableObjHolder<CustomObject>- Returns:
- obj
-
setId
Description copied from interface:CustomObjectReferenceUnique identifier of the referenced CustomObject.
- Specified by:
setIdin interfaceCustomObjectReference- Specified by:
setIdin interfaceReference- Parameters:
id- value to be set
-
setObj
Description copied from interface:CustomObjectReferenceContains the representation of the expanded CustomObject. Only present in responses to requests with Reference Expansion for CustomObjects.
- Specified by:
setObjin interfaceCustomObjectReference- Parameters:
obj- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceCustomObjectReference- Specified by:
copyDeepin interfaceReference
-