Class DiscountCodePagedQueryResponseImpl
- All Implemented Interfaces:
DiscountCodePagedQueryResponse,ResourcePagedQueryResponse<DiscountCode>,io.vrap.rmf.base.client.ModelBase
PagedQueryResult with results containing an array of DiscountCode.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCount()Actual number of results returned.getLimit()Number of results requested.Number of elements skipped.DiscountCodes matching the query.getTotal()Total number of results matching the query.inthashCode()voidActual number of results returned.voidNumber of results requested.voidNumber of elements skipped.voidsetResults(DiscountCode... results) DiscountCodes matching the query.voidsetResults(List<DiscountCode> results) DiscountCodes matching the query.voidTotal number of results matching the query.toString()Methods inherited from interface com.commercetools.api.models.discount_code.DiscountCodePagedQueryResponse
withDiscountCodePagedQueryResponseMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.ResourcePagedQueryResponse
getPageIndex, getTotalPages, head, isFirst, isLast
-
Constructor Details
-
DiscountCodePagedQueryResponseImpl
public DiscountCodePagedQueryResponseImpl()create empty instance
-
-
Method Details
-
getLimit
Number of results requested.
- Specified by:
getLimitin interfaceDiscountCodePagedQueryResponse- Specified by:
getLimitin interfaceResourcePagedQueryResponse<DiscountCode>- Returns:
- limit
-
getOffset
Number of elements skipped.
- Specified by:
getOffsetin interfaceDiscountCodePagedQueryResponse- Specified by:
getOffsetin interfaceResourcePagedQueryResponse<DiscountCode>- Returns:
- offset
-
getCount
Actual number of results returned.
- Specified by:
getCountin interfaceDiscountCodePagedQueryResponse- Specified by:
getCountin interfaceResourcePagedQueryResponse<DiscountCode>- Returns:
- count
-
getTotal
Total number of results matching the query. This number is an estimation that is not strongly consistent. This field is returned by default. For improved performance, calculating this field can be deactivated by using the query parameter
withTotal=false. When the results are filtered with a Query Predicate,totalis subject to a limit.- Specified by:
getTotalin interfaceDiscountCodePagedQueryResponse- Specified by:
getTotalin interfaceResourcePagedQueryResponse<DiscountCode>- Returns:
- total
-
getResults
DiscountCodes matching the query.
- Specified by:
getResultsin interfaceDiscountCodePagedQueryResponse- Specified by:
getResultsin interfaceResourcePagedQueryResponse<DiscountCode>- Returns:
- results
-
setLimit
Description copied from interface:DiscountCodePagedQueryResponseNumber of results requested.
- Specified by:
setLimitin interfaceDiscountCodePagedQueryResponse- Parameters:
limit- value to be set
-
setOffset
Description copied from interface:DiscountCodePagedQueryResponseNumber of elements skipped.
- Specified by:
setOffsetin interfaceDiscountCodePagedQueryResponse- Parameters:
offset- value to be set
-
setCount
Description copied from interface:DiscountCodePagedQueryResponseActual number of results returned.
- Specified by:
setCountin interfaceDiscountCodePagedQueryResponse- Parameters:
count- value to be set
-
setTotal
Description copied from interface:DiscountCodePagedQueryResponseTotal number of results matching the query. This number is an estimation that is not strongly consistent. This field is returned by default. For improved performance, calculating this field can be deactivated by using the query parameter
withTotal=false. When the results are filtered with a Query Predicate,totalis subject to a limit.- Specified by:
setTotalin interfaceDiscountCodePagedQueryResponse- Parameters:
total- value to be set
-
setResults
Description copied from interface:DiscountCodePagedQueryResponseDiscountCodes matching the query.
- Specified by:
setResultsin interfaceDiscountCodePagedQueryResponse- Parameters:
results- values to be set
-
setResults
Description copied from interface:DiscountCodePagedQueryResponseDiscountCodes matching the query.
- Specified by:
setResultsin interfaceDiscountCodePagedQueryResponse- Parameters:
results- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceDiscountCodePagedQueryResponse
-