Class DiscountCodeReferenceImpl
java.lang.Object
com.commercetools.api.models.discount_code.DiscountCodeReferenceImpl
- All Implemented Interfaces:
Reference,ReferenceMixin,DiscountCodeReference,Identifiable<DiscountCode>,IdentifiableObjHolder<DiscountCode>,io.vrap.rmf.base.client.ModelBase
public class DiscountCodeReferenceImpl
extends Object
implements DiscountCodeReference, io.vrap.rmf.base.client.ModelBase
Reference to a DiscountCode.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.discount_code.DiscountCodeReference
DISCOUNT_CODE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetId()Unique identifier of the referenced DiscountCode.getObj()Contains the representation of the expanded DiscountCode.Type of referenced resource.inthashCode()voidUnique identifier of the referenced DiscountCode.voidsetObj(DiscountCode obj) Contains the representation of the expanded DiscountCode.toString()Methods inherited from interface com.commercetools.api.models.discount_code.DiscountCodeReference
withDiscountCodeReferenceMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.common.Reference
withReferenceMethods inherited from interface com.commercetools.api.models.common.ReferenceMixin
toResourceIdentifier
-
Constructor Details
-
DiscountCodeReferenceImpl
public DiscountCodeReferenceImpl()create empty instance
-
-
Method Details
-
getTypeId
Type of referenced resource.
- Specified by:
getTypeIdin interfaceReference- Specified by:
getTypeIdin interfaceReferenceMixin- Returns:
- typeId
-
getId
Unique identifier of the referenced DiscountCode.
- Specified by:
getIdin interfaceDiscountCodeReference- Specified by:
getIdin interfaceIdentifiable<DiscountCode>- Specified by:
getIdin interfaceReference- Specified by:
getIdin interfaceReferenceMixin- Returns:
- id
-
getObj
Contains the representation of the expanded DiscountCode. Only present in responses to requests with Reference Expansion for DiscountCodes.
- Specified by:
getObjin interfaceDiscountCodeReference- Specified by:
getObjin interfaceIdentifiableObjHolder<DiscountCode>- Returns:
- obj
-
setId
Description copied from interface:DiscountCodeReferenceUnique identifier of the referenced DiscountCode.
- Specified by:
setIdin interfaceDiscountCodeReference- Specified by:
setIdin interfaceReference- Parameters:
id- value to be set
-
setObj
Description copied from interface:DiscountCodeReferenceContains the representation of the expanded DiscountCode. Only present in responses to requests with Reference Expansion for DiscountCodes.
- Specified by:
setObjin interfaceDiscountCodeReference- Parameters:
obj- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceDiscountCodeReference- Specified by:
copyDeepin interfaceReference
-