Class DiscountCodeSetCustomFieldActionImpl
java.lang.Object
com.commercetools.api.models.discount_code.DiscountCodeSetCustomFieldActionImpl
- All Implemented Interfaces:
DiscountCodeSetCustomFieldAction,DiscountCodeUpdateAction,ResourceUpdateAction<DiscountCodeUpdateAction>,io.vrap.rmf.base.client.ModelBase
public class DiscountCodeSetCustomFieldActionImpl
extends Object
implements DiscountCodeSetCustomFieldAction, io.vrap.rmf.base.client.ModelBase
DiscountCodeSetCustomFieldAction
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.discount_code.DiscountCodeSetCustomFieldAction
SET_CUSTOM_FIELD -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetName()Name of the Custom Field.getValue()Ifvalueis absent ornull, this field will be removed if it exists.inthashCode()voidName of the Custom Field.voidIfvalueis absent ornull, this field will be removed if it exists.toString()Methods inherited from interface com.commercetools.api.models.discount_code.DiscountCodeSetCustomFieldAction
withDiscountCodeSetCustomFieldActionMethods inherited from interface com.commercetools.api.models.discount_code.DiscountCodeUpdateAction
withDiscountCodeUpdateActionMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.ResourceUpdateAction
get
-
Constructor Details
-
DiscountCodeSetCustomFieldActionImpl
public DiscountCodeSetCustomFieldActionImpl()create empty instance
-
-
Method Details
-
getAction
- Specified by:
getActionin interfaceDiscountCodeUpdateAction- Specified by:
getActionin interfaceResourceUpdateAction<DiscountCodeUpdateAction>- Returns:
- action
-
getName
Name of the Custom Field.
- Specified by:
getNamein interfaceDiscountCodeSetCustomFieldAction- Returns:
- name
-
getValue
If
valueis absent ornull, this field will be removed if it exists. Removing a field that does not exist returns an InvalidOperation error. Ifvalueis provided, it is set for the field defined byname.- Specified by:
getValuein interfaceDiscountCodeSetCustomFieldAction- Returns:
- value
-
setName
Description copied from interface:DiscountCodeSetCustomFieldActionName of the Custom Field.
- Specified by:
setNamein interfaceDiscountCodeSetCustomFieldAction- Parameters:
name- value to be set
-
setValue
Description copied from interface:DiscountCodeSetCustomFieldActionIf
valueis absent ornull, this field will be removed if it exists. Removing a field that does not exist returns an InvalidOperation error. Ifvalueis provided, it is set for the field defined byname.- Specified by:
setValuein interfaceDiscountCodeSetCustomFieldAction- Parameters:
value- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceDiscountCodeSetCustomFieldAction- Specified by:
copyDeepin interfaceDiscountCodeUpdateAction
-