Class DiscountCodeSetMaxApplicationsPerCustomerActionImpl
java.lang.Object
com.commercetools.api.models.discount_code.DiscountCodeSetMaxApplicationsPerCustomerActionImpl
- All Implemented Interfaces:
DiscountCodeSetMaxApplicationsPerCustomerAction,DiscountCodeUpdateAction,ResourceUpdateAction<DiscountCodeUpdateAction>,io.vrap.rmf.base.client.ModelBase
public class DiscountCodeSetMaxApplicationsPerCustomerActionImpl
extends Object
implements DiscountCodeSetMaxApplicationsPerCustomerAction, io.vrap.rmf.base.client.ModelBase
DiscountCodeSetMaxApplicationsPerCustomerAction
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.discount_code.DiscountCodeSetMaxApplicationsPerCustomerAction
SET_MAX_APPLICATIONS_PER_CUSTOMER -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanValue to set.inthashCode()voidsetMaxApplicationsPerCustomer(Long maxApplicationsPerCustomer) Value to set.toString()Methods inherited from interface com.commercetools.api.models.discount_code.DiscountCodeSetMaxApplicationsPerCustomerAction
withDiscountCodeSetMaxApplicationsPerCustomerActionMethods inherited from interface com.commercetools.api.models.discount_code.DiscountCodeUpdateAction
withDiscountCodeUpdateActionMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.ResourceUpdateAction
get
-
Constructor Details
-
DiscountCodeSetMaxApplicationsPerCustomerActionImpl
public DiscountCodeSetMaxApplicationsPerCustomerActionImpl()create empty instance
-
-
Method Details
-
getAction
- Specified by:
getActionin interfaceDiscountCodeUpdateAction- Specified by:
getActionin interfaceResourceUpdateAction<DiscountCodeUpdateAction>- Returns:
- action
-
getMaxApplicationsPerCustomer
Value to set.
If empty, any existing value will be removed and the DiscountCode can be applied any number of times. This field does not limit discount applications for Orders created from a Recurring Order.
- Specified by:
getMaxApplicationsPerCustomerin interfaceDiscountCodeSetMaxApplicationsPerCustomerAction- Returns:
- maxApplicationsPerCustomer
-
setMaxApplicationsPerCustomer
Description copied from interface:DiscountCodeSetMaxApplicationsPerCustomerActionValue to set.
If empty, any existing value will be removed and the DiscountCode can be applied any number of times. This field does not limit discount applications for Orders created from a Recurring Order.
- Specified by:
setMaxApplicationsPerCustomerin interfaceDiscountCodeSetMaxApplicationsPerCustomerAction- Parameters:
maxApplicationsPerCustomer- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceDiscountCodeSetMaxApplicationsPerCustomerAction- Specified by:
copyDeepin interfaceDiscountCodeUpdateAction
-