Class AssociateMissingPermissionErrorImpl
- All Implemented Interfaces:
AssociateMissingPermissionError,ErrorObject,io.vrap.rmf.base.client.ModelBase
Returned when an Associate is missing a Permission on a B2B resource.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.AssociateMissingPermissionError
ASSOCIATE_MISSING_PERMISSION -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanResourceIdentifier to the Associate that tried to perform the action.ResourceIdentifier of the Associate on whose behalf the action is performed.ResourceIdentifier to the BusinessUnit.getCode()Error identifier.When an action is performed by an Associate:"Associate '$idOfAssociate' has no rights to $action in business-unit '$idOrKeyOfBusinessUnit'.The Permissions that the Associate performing the action lacks.inthashCode()voidsetAssociate(CustomerResourceIdentifier associate) ResourceIdentifier to the Associate that tried to perform the action.voidsetAssociateOnBehalf(CustomerResourceIdentifier associateOnBehalf) ResourceIdentifier of the Associate on whose behalf the action is performed.voidsetBusinessUnit(BusinessUnitResourceIdentifier businessUnit) ResourceIdentifier to the BusinessUnit.voidsetMessage(String message) When an action is performed by an Associate:"Associate '$idOfAssociate' has no rights to $action in business-unit '$idOrKeyOfBusinessUnit'.voidsetPermissions(Permission... permissions) The Permissions that the Associate performing the action lacks.voidsetPermissions(List<Permission> permissions) The Permissions that the Associate performing the action lacks.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.AssociateMissingPermissionError
withAssociateMissingPermissionErrorMethods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
AssociateMissingPermissionErrorImpl
public AssociateMissingPermissionErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceAssociateMissingPermissionError- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
- When an action is performed by an Associate:
"Associate '$idOfAssociate' has no rights to $action in business-unit '$idOrKeyOfBusinessUnit'. Needs '$requiredPermission'." - When an action is performed for another Associate, like viewing their Cart:
"Associate '$idOfAssociate' has no rights to $action for customer '$idOfCustomer' in business-unit '$idOrKeyOfBusinessUnit'. Needs '$requiredPermission'." - When viewing an entity:
"Associate '$idOfAssociate' has no rights to $action in business-unit '$idOrKeyOfBusinessUnit'. Needs '$requiredViewMyPermission' or '$requiredViewOthersPermission'."
- Specified by:
getMessagein interfaceAssociateMissingPermissionError- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
- When an action is performed by an Associate:
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getAssociate
ResourceIdentifier to the Associate that tried to perform the action.
- Specified by:
getAssociatein interfaceAssociateMissingPermissionError- Returns:
- associate
-
getBusinessUnit
ResourceIdentifier to the BusinessUnit.
- Specified by:
getBusinessUnitin interfaceAssociateMissingPermissionError- Returns:
- businessUnit
-
getAssociateOnBehalf
ResourceIdentifier of the Associate on whose behalf the action is performed.
- Specified by:
getAssociateOnBehalfin interfaceAssociateMissingPermissionError- Returns:
- associateOnBehalf
-
getPermissions
The Permissions that the Associate performing the action lacks. At least one of these Permissions is needed.
- Specified by:
getPermissionsin interfaceAssociateMissingPermissionError- Returns:
- permissions
-
setMessage
Description copied from interface:AssociateMissingPermissionError- When an action is performed by an Associate:
"Associate '$idOfAssociate' has no rights to $action in business-unit '$idOrKeyOfBusinessUnit'. Needs '$requiredPermission'." - When an action is performed for another Associate, like viewing their Cart:
"Associate '$idOfAssociate' has no rights to $action for customer '$idOfCustomer' in business-unit '$idOrKeyOfBusinessUnit'. Needs '$requiredPermission'." - When viewing an entity:
"Associate '$idOfAssociate' has no rights to $action in business-unit '$idOrKeyOfBusinessUnit'. Needs '$requiredViewMyPermission' or '$requiredViewOthersPermission'."
- Specified by:
setMessagein interfaceAssociateMissingPermissionError- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
- When an action is performed by an Associate:
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setAssociate
Description copied from interface:AssociateMissingPermissionErrorResourceIdentifier to the Associate that tried to perform the action.
- Specified by:
setAssociatein interfaceAssociateMissingPermissionError- Parameters:
associate- value to be set
-
setBusinessUnit
Description copied from interface:AssociateMissingPermissionErrorResourceIdentifier to the BusinessUnit.
- Specified by:
setBusinessUnitin interfaceAssociateMissingPermissionError- Parameters:
businessUnit- value to be set
-
setAssociateOnBehalf
Description copied from interface:AssociateMissingPermissionErrorResourceIdentifier of the Associate on whose behalf the action is performed.
- Specified by:
setAssociateOnBehalfin interfaceAssociateMissingPermissionError- Parameters:
associateOnBehalf- value to be set
-
setPermissions
Description copied from interface:AssociateMissingPermissionErrorThe Permissions that the Associate performing the action lacks. At least one of these Permissions is needed.
- Specified by:
setPermissionsin interfaceAssociateMissingPermissionError- Parameters:
permissions- values to be set
-
setPermissions
Description copied from interface:AssociateMissingPermissionErrorThe Permissions that the Associate performing the action lacks. At least one of these Permissions is needed.
- Specified by:
setPermissionsin interfaceAssociateMissingPermissionError- Parameters:
permissions- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceAssociateMissingPermissionError- Specified by:
copyDeepin interfaceErrorObject
-