Class AttributeDefinitionAlreadyExistsErrorImpl
- All Implemented Interfaces:
AttributeDefinitionAlreadyExistsError,ErrorObject,io.vrap.rmf.base.client.ModelBase
Returned when the name of the AttributeDefinition conflicts with an existing Attribute.
The error is returned as a failed response to the Create ProductType request or Change AttributeDefinition Name update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.AttributeDefinitionAlreadyExistsError
ATTRIBUTE_DEFINITION_ALREADY_EXISTS -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Name of the conflicting Attribute.Unique identifier of the Product Type containing the conflicting name.Name of the Product Type containing the conflicting name."An attribute definition with name $attributeName already exists on product type $productTypeName."inthashCode()voidsetConflictingAttributeName(String conflictingAttributeName) Name of the conflicting Attribute.voidsetConflictingProductTypeId(String conflictingProductTypeId) Unique identifier of the Product Type containing the conflicting name.voidsetConflictingProductTypeName(String conflictingProductTypeName) Name of the Product Type containing the conflicting name.voidsetMessage(String message) "An attribute definition with name $attributeName already exists on product type $productTypeName."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.AttributeDefinitionAlreadyExistsError
withAttributeDefinitionAlreadyExistsErrorMethods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
AttributeDefinitionAlreadyExistsErrorImpl
public AttributeDefinitionAlreadyExistsErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceAttributeDefinitionAlreadyExistsError- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
"An attribute definition with name $attributeName already exists on product type $productTypeName."- Specified by:
getMessagein interfaceAttributeDefinitionAlreadyExistsError- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getConflictingProductTypeId
Unique identifier of the Product Type containing the conflicting name.
- Specified by:
getConflictingProductTypeIdin interfaceAttributeDefinitionAlreadyExistsError- Returns:
- conflictingProductTypeId
-
getConflictingProductTypeName
Name of the Product Type containing the conflicting name.
- Specified by:
getConflictingProductTypeNamein interfaceAttributeDefinitionAlreadyExistsError- Returns:
- conflictingProductTypeName
-
getConflictingAttributeName
Name of the conflicting Attribute.
- Specified by:
getConflictingAttributeNamein interfaceAttributeDefinitionAlreadyExistsError- Returns:
- conflictingAttributeName
-
setMessage
Description copied from interface:AttributeDefinitionAlreadyExistsError"An attribute definition with name $attributeName already exists on product type $productTypeName."- Specified by:
setMessagein interfaceAttributeDefinitionAlreadyExistsError- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setConflictingProductTypeId
Description copied from interface:AttributeDefinitionAlreadyExistsErrorUnique identifier of the Product Type containing the conflicting name.
- Specified by:
setConflictingProductTypeIdin interfaceAttributeDefinitionAlreadyExistsError- Parameters:
conflictingProductTypeId- value to be set
-
setConflictingProductTypeName
Description copied from interface:AttributeDefinitionAlreadyExistsErrorName of the Product Type containing the conflicting name.
- Specified by:
setConflictingProductTypeNamein interfaceAttributeDefinitionAlreadyExistsError- Parameters:
conflictingProductTypeName- value to be set
-
setConflictingAttributeName
Description copied from interface:AttributeDefinitionAlreadyExistsErrorName of the conflicting Attribute.
- Specified by:
setConflictingAttributeNamein interfaceAttributeDefinitionAlreadyExistsError- Parameters:
conflictingAttributeName- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceAttributeDefinitionAlreadyExistsError- Specified by:
copyDeepin interfaceErrorObject
-