Class ConcurrentModificationErrorImpl
java.lang.Object
com.commercetools.api.models.error.ConcurrentModificationErrorImpl
- All Implemented Interfaces:
ConcurrentModificationError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class ConcurrentModificationErrorImpl
extends Object
implements ConcurrentModificationError, io.vrap.rmf.base.client.ModelBase
Returned when the request conflicts with the current state of the involved resources. Typically, the request attempts to modify a resource that is out of date (that is modified by another client since it was last retrieved). The client application should resolve the conflict (with or without involving the end user) before retrying the request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.ConcurrentModificationError
CONCURRENT_MODIFICATION -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Current version of the resource."Object $resourceId has a different version than expected.inthashCode()voidsetCurrentVersion(Long currentVersion) Current version of the resource.voidsetMessage(String message) "Object $resourceId has a different version than expected.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ConcurrentModificationError
withConcurrentModificationErrorMethods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
ConcurrentModificationErrorImpl
public ConcurrentModificationErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceConcurrentModificationError- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
"Object $resourceId has a different version than expected. Expected: $expectedVersion - Actual: $currentVersion."- Specified by:
getMessagein interfaceConcurrentModificationError- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getCurrentVersion
Current version of the resource.
- Specified by:
getCurrentVersionin interfaceConcurrentModificationError- Returns:
- currentVersion
-
setMessage
Description copied from interface:ConcurrentModificationError"Object $resourceId has a different version than expected. Expected: $expectedVersion - Actual: $currentVersion."- Specified by:
setMessagein interfaceConcurrentModificationError- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setCurrentVersion
Description copied from interface:ConcurrentModificationErrorCurrent version of the resource.
- Specified by:
setCurrentVersionin interfaceConcurrentModificationError- Parameters:
currentVersion- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceConcurrentModificationError- Specified by:
copyDeepin interfaceErrorObject
-