Class ContentTooLargeErrorImpl
java.lang.Object
com.commercetools.api.models.error.ContentTooLargeErrorImpl
- All Implemented Interfaces:
ContentTooLargeError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class ContentTooLargeErrorImpl
extends Object
implements ContentTooLargeError, io.vrap.rmf.base.client.ModelBase
Returned when the request results in too much data being returned from the API. Adjust the request query to reduce the size of the data returned.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.ContentTooLargeError
CONTENT_TOO_LARGE -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.ContentTooLargeError
withContentTooLargeErrorMethods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
ContentTooLargeErrorImpl
public ContentTooLargeErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceContentTooLargeError- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
"Content too large."- Specified by:
getMessagein interfaceContentTooLargeError- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:ContentTooLargeError"Content too large."- Specified by:
setMessagein interfaceContentTooLargeError- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceContentTooLargeError- Specified by:
copyDeepin interfaceErrorObject
-