Class CountryNotConfiguredInStoreErrorImpl

java.lang.Object
com.commercetools.api.models.error.CountryNotConfiguredInStoreErrorImpl
All Implemented Interfaces:
CountryNotConfiguredInStoreError, ErrorObject, io.vrap.rmf.base.client.ModelBase

public class CountryNotConfiguredInStoreErrorImpl extends Object implements CountryNotConfiguredInStoreError, io.vrap.rmf.base.client.ModelBase

Returned when a Cart or an Order in a Store references a country that is not included in the countries configured for the Store.

The error is returned as a failed response to: