Class DuplicateAttributeValueErrorImpl
java.lang.Object
com.commercetools.api.models.error.DuplicateAttributeValueErrorImpl
- All Implemented Interfaces:
DuplicateAttributeValueError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class DuplicateAttributeValueErrorImpl
extends Object
implements DuplicateAttributeValueError, io.vrap.rmf.base.client.ModelBase
Returned when the Unique AttributeConstraint criteria are not met during an Update Product request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.DuplicateAttributeValueError
DUPLICATE_ATTRIBUTE_VALUE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanConflicting Attributes.getCode()Error identifier."Attribute can't have the same value in a different variant."inthashCode()voidsetAttribute(Attribute attribute) Conflicting Attributes.voidsetMessage(String message) "Attribute can't have the same value in a different variant."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.DuplicateAttributeValueError
withDuplicateAttributeValueErrorMethods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
DuplicateAttributeValueErrorImpl
public DuplicateAttributeValueErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceDuplicateAttributeValueError- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
"Attribute can't have the same value in a different variant."- Specified by:
getMessagein interfaceDuplicateAttributeValueError- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getAttribute
Conflicting Attributes.
- Specified by:
getAttributein interfaceDuplicateAttributeValueError- Returns:
- attribute
-
setMessage
Description copied from interface:DuplicateAttributeValueError"Attribute can't have the same value in a different variant."- Specified by:
setMessagein interfaceDuplicateAttributeValueError- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setAttribute
Description copied from interface:DuplicateAttributeValueErrorConflicting Attributes.
- Specified by:
setAttributein interfaceDuplicateAttributeValueError- Parameters:
attribute- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceDuplicateAttributeValueError- Specified by:
copyDeepin interfaceErrorObject
-