Class DuplicateAttributeValuesErrorImpl
java.lang.Object
com.commercetools.api.models.error.DuplicateAttributeValuesErrorImpl
- All Implemented Interfaces:
DuplicateAttributeValuesError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class DuplicateAttributeValuesErrorImpl
extends Object
implements DuplicateAttributeValuesError, io.vrap.rmf.base.client.ModelBase
Returned when the CombinationUnique AttributeConstraint criteria are not met during an Update Product request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.DuplicateAttributeValuesError
DUPLICATE_ATTRIBUTE_VALUES -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanConflicting Attributes.getCode()Error identifier."The set of attributes must be unique across all variants."inthashCode()voidsetAttributes(Attribute... attributes) Conflicting Attributes.voidsetAttributes(List<Attribute> attributes) Conflicting Attributes.voidsetMessage(String message) "The set of attributes must be unique across all variants."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.DuplicateAttributeValuesError
withDuplicateAttributeValuesErrorMethods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
DuplicateAttributeValuesErrorImpl
public DuplicateAttributeValuesErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceDuplicateAttributeValuesError- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
"The set of attributes must be unique across all variants."- Specified by:
getMessagein interfaceDuplicateAttributeValuesError- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getAttributes
Conflicting Attributes.
- Specified by:
getAttributesin interfaceDuplicateAttributeValuesError- Returns:
- attributes
-
setMessage
Description copied from interface:DuplicateAttributeValuesError"The set of attributes must be unique across all variants."- Specified by:
setMessagein interfaceDuplicateAttributeValuesError- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setAttributes
Description copied from interface:DuplicateAttributeValuesErrorConflicting Attributes.
- Specified by:
setAttributesin interfaceDuplicateAttributeValuesError- Parameters:
attributes- values to be set
-
setAttributes
Description copied from interface:DuplicateAttributeValuesErrorConflicting Attributes.
- Specified by:
setAttributesin interfaceDuplicateAttributeValuesError- Parameters:
attributes- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceDuplicateAttributeValuesError- Specified by:
copyDeepin interfaceErrorObject
-