Class DuplicatePriceScopeErrorImpl
java.lang.Object
com.commercetools.api.models.error.DuplicatePriceScopeErrorImpl
- All Implemented Interfaces:
DuplicatePriceScopeError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class DuplicatePriceScopeErrorImpl
extends Object
implements DuplicatePriceScopeError, io.vrap.rmf.base.client.ModelBase
Returned when a Price scope conflicts with an existing one during an Update Product request.
Every Price of a Product Variant must have a distinct combination of currency, Customer Group, country, and Channel that constitute the scope of a Price.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.DuplicatePriceScopeError
DUPLICATE_PRICE_SCOPE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Conflicting Embedded Price."Duplicate price scope: $priceScope.inthashCode()voidsetConflictingPrice(Price conflictingPrice) Conflicting Embedded Price.voidsetMessage(String message) "Duplicate price scope: $priceScope.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.DuplicatePriceScopeError
withDuplicatePriceScopeErrorMethods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
DuplicatePriceScopeErrorImpl
public DuplicatePriceScopeErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceDuplicatePriceScopeError- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
"Duplicate price scope: $priceScope. The combination of currency, country, customerGroup and channel must be unique for each price of a product variant."- Specified by:
getMessagein interfaceDuplicatePriceScopeError- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getConflictingPrice
Conflicting Embedded Price.
- Specified by:
getConflictingPricein interfaceDuplicatePriceScopeError- Returns:
- conflictingPrice
-
setMessage
Description copied from interface:DuplicatePriceScopeError"Duplicate price scope: $priceScope. The combination of currency, country, customerGroup and channel must be unique for each price of a product variant."- Specified by:
setMessagein interfaceDuplicatePriceScopeError- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setConflictingPrice
Description copied from interface:DuplicatePriceScopeErrorConflicting Embedded Price.
- Specified by:
setConflictingPricein interfaceDuplicatePriceScopeError- Parameters:
conflictingPrice- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceDuplicatePriceScopeError- Specified by:
copyDeepin interfaceErrorObject
-