Class DuplicateVariantValuesErrorImpl
java.lang.Object
com.commercetools.api.models.error.DuplicateVariantValuesErrorImpl
- All Implemented Interfaces:
DuplicateVariantValuesError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class DuplicateVariantValuesErrorImpl
extends Object
implements DuplicateVariantValuesError, io.vrap.rmf.base.client.ModelBase
Returned when a Product Variant value conflicts with an existing one during an Update Product request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.DuplicateVariantValuesError
DUPLICATE_VARIANT_VALUES -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier."A duplicate combination of the variant values (sku, key, images, prices, attributes) exists."Every Product Variant must have a distinct combination of SKU, prices, and custom Attribute values.inthashCode()voidsetMessage(String message) "A duplicate combination of the variant values (sku, key, images, prices, attributes) exists."voidError-specific additional fields.voidsetVariantValues(VariantValues variantValues) Every Product Variant must have a distinct combination of SKU, prices, and custom Attribute values.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.DuplicateVariantValuesError
withDuplicateVariantValuesErrorMethods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
DuplicateVariantValuesErrorImpl
public DuplicateVariantValuesErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceDuplicateVariantValuesError- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
"A duplicate combination of the variant values (sku, key, images, prices, attributes) exists."- Specified by:
getMessagein interfaceDuplicateVariantValuesError- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getVariantValues
Every Product Variant must have a distinct combination of SKU, prices, and custom Attribute values.
- Specified by:
getVariantValuesin interfaceDuplicateVariantValuesError- Returns:
- variantValues
-
setMessage
Description copied from interface:DuplicateVariantValuesError"A duplicate combination of the variant values (sku, key, images, prices, attributes) exists."- Specified by:
setMessagein interfaceDuplicateVariantValuesError- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setVariantValues
Description copied from interface:DuplicateVariantValuesErrorEvery Product Variant must have a distinct combination of SKU, prices, and custom Attribute values.
- Specified by:
setVariantValuesin interfaceDuplicateVariantValuesError- Parameters:
variantValues- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceDuplicateVariantValuesError- Specified by:
copyDeepin interfaceErrorObject
-