Class EnumKeyAlreadyExistsErrorImpl
java.lang.Object
com.commercetools.api.models.error.EnumKeyAlreadyExistsErrorImpl
- All Implemented Interfaces:
EnumKeyAlreadyExistsError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class EnumKeyAlreadyExistsErrorImpl
extends Object
implements EnumKeyAlreadyExistsError, io.vrap.rmf.base.client.ModelBase
Returned when an AttributeEnumType or AttributeLocalizedEnumType contains a key that already exists.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.EnumKeyAlreadyExistsError
ENUM_KEY_ALREADY_EXISTS -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Name of the conflicting Attribute.Conflicting enum key."The $attributeName attribute definition already contains an enum value with the key $enumKey."inthashCode()voidsetConflictingAttributeName(String conflictingAttributeName) Name of the conflicting Attribute.voidsetConflictingEnumKey(String conflictingEnumKey) Conflicting enum key.voidsetMessage(String message) "The $attributeName attribute definition already contains an enum value with the key $enumKey."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.EnumKeyAlreadyExistsError
withEnumKeyAlreadyExistsErrorMethods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
EnumKeyAlreadyExistsErrorImpl
public EnumKeyAlreadyExistsErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceEnumKeyAlreadyExistsError- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
"The $attributeName attribute definition already contains an enum value with the key $enumKey."- Specified by:
getMessagein interfaceEnumKeyAlreadyExistsError- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getConflictingEnumKey
Conflicting enum key.
- Specified by:
getConflictingEnumKeyin interfaceEnumKeyAlreadyExistsError- Returns:
- conflictingEnumKey
-
getConflictingAttributeName
Name of the conflicting Attribute.
- Specified by:
getConflictingAttributeNamein interfaceEnumKeyAlreadyExistsError- Returns:
- conflictingAttributeName
-
setMessage
Description copied from interface:EnumKeyAlreadyExistsError"The $attributeName attribute definition already contains an enum value with the key $enumKey."- Specified by:
setMessagein interfaceEnumKeyAlreadyExistsError- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setConflictingEnumKey
Description copied from interface:EnumKeyAlreadyExistsErrorConflicting enum key.
- Specified by:
setConflictingEnumKeyin interfaceEnumKeyAlreadyExistsError- Parameters:
conflictingEnumKey- value to be set
-
setConflictingAttributeName
Description copied from interface:EnumKeyAlreadyExistsErrorName of the conflicting Attribute.
- Specified by:
setConflictingAttributeNamein interfaceEnumKeyAlreadyExistsError- Parameters:
conflictingAttributeName- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceEnumKeyAlreadyExistsError- Specified by:
copyDeepin interfaceErrorObject
-