Class EnumValueIsUsedErrorImpl
java.lang.Object
com.commercetools.api.models.error.EnumValueIsUsedErrorImpl
- All Implemented Interfaces:
EnumValueIsUsedError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class EnumValueIsUsedErrorImpl
extends Object
implements EnumValueIsUsedError, io.vrap.rmf.base.client.ModelBase
Returned when an enum value cannot be removed from an Attribute as it is being used by a Product.
The error is returned as a failed response to the Remove EnumValues from AttributeDefinition update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.EnumValueIsUsedError
ENUM_VALUE_IS_USED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier."$enumKeysTranscript is used by some products and cannot be deleted because the $attributeName attribute is required."inthashCode()voidsetMessage(String message) "$enumKeysTranscript is used by some products and cannot be deleted because the $attributeName attribute is required."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.EnumValueIsUsedError
withEnumValueIsUsedErrorMethods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
EnumValueIsUsedErrorImpl
public EnumValueIsUsedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceEnumValueIsUsedError- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
"$enumKeysTranscript is used by some products and cannot be deleted because the $attributeName attribute is required."- Specified by:
getMessagein interfaceEnumValueIsUsedError- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:EnumValueIsUsedError"$enumKeysTranscript is used by some products and cannot be deleted because the $attributeName attribute is required."- Specified by:
setMessagein interfaceEnumValueIsUsedError- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceEnumValueIsUsedError- Specified by:
copyDeepin interfaceErrorObject
-