Class EnumValuesMustMatchErrorImpl
java.lang.Object
com.commercetools.api.models.error.EnumValuesMustMatchErrorImpl
- All Implemented Interfaces:
EnumValuesMustMatchError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class EnumValuesMustMatchErrorImpl
extends Object
implements EnumValuesMustMatchError, io.vrap.rmf.base.client.ModelBase
Returned when during an order update of AttributeEnumType or AttributeLocalizedEnumType the new enum values do not match the existing ones.
The error is returned as a failed response to the Change the order of EnumValues and Change the order of LocalizedEnumValues update actions.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.EnumValuesMustMatchError
ENUM_VALUES_MUST_MATCH -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier."The given values must be equal to the existing enum values."inthashCode()voidsetMessage(String message) "The given values must be equal to the existing enum values."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.EnumValuesMustMatchError
withEnumValuesMustMatchErrorMethods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
EnumValuesMustMatchErrorImpl
public EnumValuesMustMatchErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceEnumValuesMustMatchError- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
"The given values must be equal to the existing enum values."- Specified by:
getMessagein interfaceEnumValuesMustMatchError- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:EnumValuesMustMatchError"The given values must be equal to the existing enum values."- Specified by:
setMessagein interfaceEnumValuesMustMatchError- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceEnumValuesMustMatchError- Specified by:
copyDeepin interfaceErrorObject
-