Class ExpiredCustomerEmailTokenErrorImpl

java.lang.Object
com.commercetools.api.models.error.ExpiredCustomerEmailTokenErrorImpl
All Implemented Interfaces:
ErrorObject, ExpiredCustomerEmailTokenError, io.vrap.rmf.base.client.ModelBase

public class ExpiredCustomerEmailTokenErrorImpl extends Object implements ExpiredCustomerEmailTokenError, io.vrap.rmf.base.client.ModelBase

Returned when the provided email token of the Customer has expired.

The error is returned as a failed response to: