Class ExpiredCustomerPasswordTokenErrorImpl

java.lang.Object
com.commercetools.api.models.error.ExpiredCustomerPasswordTokenErrorImpl
All Implemented Interfaces:
ErrorObject, ExpiredCustomerPasswordTokenError, io.vrap.rmf.base.client.ModelBase

public class ExpiredCustomerPasswordTokenErrorImpl extends Object implements ExpiredCustomerPasswordTokenError, io.vrap.rmf.base.client.ModelBase

Returned when the provided password token of the Customer has expired.

The error is returned as a failed response to: