Class ExtensionDependencyExistsErrorImpl
java.lang.Object
com.commercetools.api.models.error.ExtensionDependencyExistsErrorImpl
- All Implemented Interfaces:
ErrorObject,ExtensionDependencyExistsError,io.vrap.rmf.base.client.ModelBase
public class ExtensionDependencyExistsErrorImpl
extends Object
implements ExtensionDependencyExistsError, io.vrap.rmf.base.client.ModelBase
Returned when attempting to delete an Extension that is a prerequisite for other Extensions.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.ExtensionDependencyExistsError
EXTENSION_DEPENDENCY_EXISTS -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier."The extension cannot be deleted because it is a prerequisite for: [ext-2, ext-3]."inthashCode()voidsetMessage(String message) "The extension cannot be deleted because it is a prerequisite for: [ext-2, ext-3]."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.ExtensionDependencyExistsError
withExtensionDependencyExistsErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
ExtensionDependencyExistsErrorImpl
public ExtensionDependencyExistsErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceExtensionDependencyExistsError- Returns:
- code
-
getMessage
"The extension cannot be deleted because it is a prerequisite for: [ext-2, ext-3]."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceExtensionDependencyExistsError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:ExtensionDependencyExistsError"The extension cannot be deleted because it is a prerequisite for: [ext-2, ext-3]."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceExtensionDependencyExistsError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceExtensionDependencyExistsError
-