Class ExtensionUpdateActionsFailedErrorImpl
- All Implemented Interfaces:
ErrorObject,ExtensionUpdateActionsFailedError,io.vrap.rmf.base.client.ModelBase
Returned when update actions could not be applied to the resource (for example, because a referenced resource does not exist). This would result in a 400 Bad Request response if the same update action was sent from a regular client.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.ExtensionUpdateActionsFailedError
EXTENSION_UPDATE_ACTIONS_FAILED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Additional errors related to the API Extension.Any information that should be returned to the API caller.User-defined localized description of the error."The extension returned update actions that could not be executed."inthashCode()voidsetExtensionErrors(ExtensionError... extensionErrors) Additional errors related to the API Extension.voidsetExtensionErrors(List<ExtensionError> extensionErrors) Additional errors related to the API Extension.voidsetExtensionExtraInfo(Object extensionExtraInfo) Any information that should be returned to the API caller.voidsetLocalizedMessage(LocalizedString localizedMessage) User-defined localized description of the error.voidsetMessage(String message) "The extension returned update actions that could not be executed."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.ExtensionUpdateActionsFailedError
withExtensionUpdateActionsFailedErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
ExtensionUpdateActionsFailedErrorImpl
public ExtensionUpdateActionsFailedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceExtensionUpdateActionsFailedError- Returns:
- code
-
getMessage
"The extension returned update actions that could not be executed."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceExtensionUpdateActionsFailedError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getLocalizedMessage
User-defined localized description of the error.
- Specified by:
getLocalizedMessagein interfaceExtensionUpdateActionsFailedError- Returns:
- localizedMessage
-
getExtensionExtraInfo
Any information that should be returned to the API caller.
- Specified by:
getExtensionExtraInfoin interfaceExtensionUpdateActionsFailedError- Returns:
- extensionExtraInfo
-
getExtensionErrors
Additional errors related to the API Extension.
- Specified by:
getExtensionErrorsin interfaceExtensionUpdateActionsFailedError- Returns:
- extensionErrors
-
setMessage
Description copied from interface:ExtensionUpdateActionsFailedError"The extension returned update actions that could not be executed."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceExtensionUpdateActionsFailedError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setLocalizedMessage
Description copied from interface:ExtensionUpdateActionsFailedErrorUser-defined localized description of the error.
- Specified by:
setLocalizedMessagein interfaceExtensionUpdateActionsFailedError- Parameters:
localizedMessage- value to be set
-
setExtensionExtraInfo
Description copied from interface:ExtensionUpdateActionsFailedErrorAny information that should be returned to the API caller.
- Specified by:
setExtensionExtraInfoin interfaceExtensionUpdateActionsFailedError- Parameters:
extensionExtraInfo- value to be set
-
setExtensionErrors
Description copied from interface:ExtensionUpdateActionsFailedErrorAdditional errors related to the API Extension.
- Specified by:
setExtensionErrorsin interfaceExtensionUpdateActionsFailedError- Parameters:
extensionErrors- values to be set
-
setExtensionErrors
Description copied from interface:ExtensionUpdateActionsFailedErrorAdditional errors related to the API Extension.
- Specified by:
setExtensionErrorsin interfaceExtensionUpdateActionsFailedError- Parameters:
extensionErrors- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceExtensionUpdateActionsFailedError
-