Class GeneralErrorImpl

java.lang.Object
com.commercetools.api.models.error.GeneralErrorImpl
All Implemented Interfaces:
ErrorObject, GeneralError, io.vrap.rmf.base.client.ModelBase

public class GeneralErrorImpl extends Object implements GeneralError, io.vrap.rmf.base.client.ModelBase

Returned when a server-side problem occurs before or after data persistence. In some cases, the requested action may successfully complete after the error is returned. Therefore, it is recommended to verify the status of the requested resource after receiving a 500 error.

If you encounter this error, report it to the commercetools support team.

  • Nested Class Summary

    Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase

    io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle
  • Field Summary

    Fields inherited from interface com.commercetools.api.models.error.GeneralError

    GENERAL
  • Constructor Summary

    Constructors
    Constructor
    Description
    create empty instance
  • Method Summary

    Modifier and Type
    Method
    Description
     
    boolean
     
    Error identifier.
    Description about any known details of the problem, for example, "Write operations are temporarily unavailable".
    int
     
    void
    setMessage(String message)
    Description about any known details of the problem, for example, "Write operations are temporarily unavailable".
    void
    setValue(String key, Object value)
    Error-specific additional fields.
     
    Error-specific additional fields.

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait

    Methods inherited from interface com.commercetools.api.models.error.ErrorObject

    withErrorObject

    Methods inherited from interface com.commercetools.api.models.error.GeneralError

    withGeneralError

    Methods inherited from interface io.vrap.rmf.base.client.ModelBase

    reflectionString, reflectionString
  • Constructor Details

    • GeneralErrorImpl

      public GeneralErrorImpl()
      create empty instance
  • Method Details