Class GraphQLAssociateMissingPermissionErrorImpl
- All Implemented Interfaces:
GraphQLAssociateMissingPermissionError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
Returned when an Associate is missing a Permission on a B2B resource.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLAssociateMissingPermissionError
ASSOCIATE_MISSING_PERMISSION -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanResourceIdentifier to the Associate that tried to perform the action.ResourceIdentifier of the Associate on whose behalf the action is performed.ResourceIdentifier to the BusinessUnit.getCode()One of the error codes that is listed on the Errors page.The Permissions that the Associate performing the action lacks.inthashCode()voidsetAssociate(CustomerResourceIdentifier associate) ResourceIdentifier to the Associate that tried to perform the action.voidsetAssociateOnBehalf(CustomerResourceIdentifier associateOnBehalf) ResourceIdentifier of the Associate on whose behalf the action is performed.voidsetBusinessUnit(BusinessUnitResourceIdentifier businessUnit) ResourceIdentifier to the BusinessUnit.voidsetPermissions(Permission... permissions) The Permissions that the Associate performing the action lacks.voidsetPermissions(List<Permission> permissions) The Permissions that the Associate performing the action lacks.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLAssociateMissingPermissionError
withGraphQLAssociateMissingPermissionErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLAssociateMissingPermissionErrorImpl
public GraphQLAssociateMissingPermissionErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLAssociateMissingPermissionError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getAssociate
ResourceIdentifier to the Associate that tried to perform the action.
- Specified by:
getAssociatein interfaceGraphQLAssociateMissingPermissionError- Returns:
- associate
-
getBusinessUnit
ResourceIdentifier to the BusinessUnit.
- Specified by:
getBusinessUnitin interfaceGraphQLAssociateMissingPermissionError- Returns:
- businessUnit
-
getAssociateOnBehalf
ResourceIdentifier of the Associate on whose behalf the action is performed.
- Specified by:
getAssociateOnBehalfin interfaceGraphQLAssociateMissingPermissionError- Returns:
- associateOnBehalf
-
getPermissions
The Permissions that the Associate performing the action lacks. At least one of these Permissions is needed.
- Specified by:
getPermissionsin interfaceGraphQLAssociateMissingPermissionError- Returns:
- permissions
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setAssociate
Description copied from interface:GraphQLAssociateMissingPermissionErrorResourceIdentifier to the Associate that tried to perform the action.
- Specified by:
setAssociatein interfaceGraphQLAssociateMissingPermissionError- Parameters:
associate- value to be set
-
setBusinessUnit
Description copied from interface:GraphQLAssociateMissingPermissionErrorResourceIdentifier to the BusinessUnit.
- Specified by:
setBusinessUnitin interfaceGraphQLAssociateMissingPermissionError- Parameters:
businessUnit- value to be set
-
setAssociateOnBehalf
Description copied from interface:GraphQLAssociateMissingPermissionErrorResourceIdentifier of the Associate on whose behalf the action is performed.
- Specified by:
setAssociateOnBehalfin interfaceGraphQLAssociateMissingPermissionError- Parameters:
associateOnBehalf- value to be set
-
setPermissions
Description copied from interface:GraphQLAssociateMissingPermissionErrorThe Permissions that the Associate performing the action lacks. At least one of these Permissions is needed.
- Specified by:
setPermissionsin interfaceGraphQLAssociateMissingPermissionError- Parameters:
permissions- values to be set
-
setPermissions
Description copied from interface:GraphQLAssociateMissingPermissionErrorThe Permissions that the Associate performing the action lacks. At least one of these Permissions is needed.
- Specified by:
setPermissionsin interfaceGraphQLAssociateMissingPermissionError- Parameters:
permissions- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLAssociateMissingPermissionError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-