Class GraphQLAttributeDefinitionAlreadyExistsErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLAttributeDefinitionAlreadyExistsErrorImpl
- All Implemented Interfaces:
GraphQLAttributeDefinitionAlreadyExistsError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLAttributeDefinitionAlreadyExistsErrorImpl
extends Object
implements GraphQLAttributeDefinitionAlreadyExistsError, io.vrap.rmf.base.client.ModelBase
Returned when the name of the AttributeDefinition conflicts with an existing Attribute.
The error is returned as a failed response to the Create ProductType request or Change AttributeDefinition Name update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLAttributeDefinitionAlreadyExistsError
ATTRIBUTE_DEFINITION_ALREADY_EXISTS -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Name of the conflicting Attribute.Unique identifier of the Product Type containing the conflicting name.Name of the Product Type containing the conflicting name.inthashCode()voidsetConflictingAttributeName(String conflictingAttributeName) Name of the conflicting Attribute.voidsetConflictingProductTypeId(String conflictingProductTypeId) Unique identifier of the Product Type containing the conflicting name.voidsetConflictingProductTypeName(String conflictingProductTypeName) Name of the Product Type containing the conflicting name.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLAttributeDefinitionAlreadyExistsError
withGraphQLAttributeDefinitionAlreadyExistsErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLAttributeDefinitionAlreadyExistsErrorImpl
public GraphQLAttributeDefinitionAlreadyExistsErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLAttributeDefinitionAlreadyExistsError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getConflictingProductTypeId
Unique identifier of the Product Type containing the conflicting name.
- Specified by:
getConflictingProductTypeIdin interfaceGraphQLAttributeDefinitionAlreadyExistsError- Returns:
- conflictingProductTypeId
-
getConflictingProductTypeName
Name of the Product Type containing the conflicting name.
- Specified by:
getConflictingProductTypeNamein interfaceGraphQLAttributeDefinitionAlreadyExistsError- Returns:
- conflictingProductTypeName
-
getConflictingAttributeName
Name of the conflicting Attribute.
- Specified by:
getConflictingAttributeNamein interfaceGraphQLAttributeDefinitionAlreadyExistsError- Returns:
- conflictingAttributeName
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setConflictingProductTypeId
Description copied from interface:GraphQLAttributeDefinitionAlreadyExistsErrorUnique identifier of the Product Type containing the conflicting name.
- Specified by:
setConflictingProductTypeIdin interfaceGraphQLAttributeDefinitionAlreadyExistsError- Parameters:
conflictingProductTypeId- value to be set
-
setConflictingProductTypeName
Description copied from interface:GraphQLAttributeDefinitionAlreadyExistsErrorName of the Product Type containing the conflicting name.
- Specified by:
setConflictingProductTypeNamein interfaceGraphQLAttributeDefinitionAlreadyExistsError- Parameters:
conflictingProductTypeName- value to be set
-
setConflictingAttributeName
Description copied from interface:GraphQLAttributeDefinitionAlreadyExistsErrorName of the conflicting Attribute.
- Specified by:
setConflictingAttributeNamein interfaceGraphQLAttributeDefinitionAlreadyExistsError- Parameters:
conflictingAttributeName- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLAttributeDefinitionAlreadyExistsError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-