Class GraphQLAttributeNameDoesNotExistErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLAttributeNameDoesNotExistErrorImpl
- All Implemented Interfaces:
GraphQLAttributeNameDoesNotExistError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLAttributeNameDoesNotExistErrorImpl
extends Object
implements GraphQLAttributeNameDoesNotExistError, io.vrap.rmf.base.client.ModelBase
Returned when an AttributeDefinition does not exist for an Attribute name.
The error is returned as a failed response to the Change AttributeDefinition Name update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLAttributeNameDoesNotExistError
ATTRIBUTE_NAME_DOES_NOT_EXIST -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Non-existent Attribute name.inthashCode()voidsetInvalidAttributeName(String invalidAttributeName) Non-existent Attribute name.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLAttributeNameDoesNotExistError
withGraphQLAttributeNameDoesNotExistErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLAttributeNameDoesNotExistErrorImpl
public GraphQLAttributeNameDoesNotExistErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLAttributeNameDoesNotExistError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getInvalidAttributeName
Non-existent Attribute name.
- Specified by:
getInvalidAttributeNamein interfaceGraphQLAttributeNameDoesNotExistError- Returns:
- invalidAttributeName
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setInvalidAttributeName
Description copied from interface:GraphQLAttributeNameDoesNotExistErrorNon-existent Attribute name.
- Specified by:
setInvalidAttributeNamein interfaceGraphQLAttributeNameDoesNotExistError- Parameters:
invalidAttributeName- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLAttributeNameDoesNotExistError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-