Interface GraphQLCircularDependencyError

All Superinterfaces:
GraphQLErrorObject
All Known Implementing Classes:
GraphQLCircularDependencyErrorImpl

public interface GraphQLCircularDependencyError extends GraphQLErrorObject

Returned when a circular reference is detected among Extension dependencies.


Example to create an instance using the builder pattern

     GraphQLCircularDependencyError graphQLCircularDependencyError = GraphQLCircularDependencyError.builder()
             .build()