Class GraphQLConcurrentModificationErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLConcurrentModificationErrorImpl
- All Implemented Interfaces:
GraphQLConcurrentModificationError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLConcurrentModificationErrorImpl
extends Object
implements GraphQLConcurrentModificationError, io.vrap.rmf.base.client.ModelBase
Returned when the request conflicts with the current state of the involved resources. Typically, the request attempts to modify a resource that is out of date (that is modified by another client since it was last retrieved). The client application should resolve the conflict (with or without involving the end user) before retrying the request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLConcurrentModificationError
CONCURRENT_MODIFICATION -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Current version of the resource.inthashCode()voidsetCurrentVersion(Long currentVersion) Current version of the resource.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLConcurrentModificationError
withGraphQLConcurrentModificationErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLConcurrentModificationErrorImpl
public GraphQLConcurrentModificationErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLConcurrentModificationError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getCurrentVersion
Current version of the resource.
- Specified by:
getCurrentVersionin interfaceGraphQLConcurrentModificationError- Returns:
- currentVersion
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setCurrentVersion
Description copied from interface:GraphQLConcurrentModificationErrorCurrent version of the resource.
- Specified by:
setCurrentVersionin interfaceGraphQLConcurrentModificationError- Parameters:
currentVersion- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLConcurrentModificationError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-