Class GraphQLContentTooLargeErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLContentTooLargeErrorImpl
- All Implemented Interfaces:
GraphQLContentTooLargeError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLContentTooLargeErrorImpl
extends Object
implements GraphQLContentTooLargeError, io.vrap.rmf.base.client.ModelBase
Returned when the request results in too much data being returned from the API. Adjust the request query to reduce the size of the data returned.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLContentTooLargeError
CONTENT_TOO_LARGE -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLContentTooLargeError
withGraphQLContentTooLargeErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLContentTooLargeErrorImpl
public GraphQLContentTooLargeErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLContentTooLargeError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLContentTooLargeError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-