Class GraphQLCountryNotConfiguredInStoreErrorImpl

java.lang.Object
com.commercetools.api.models.error.GraphQLCountryNotConfiguredInStoreErrorImpl
All Implemented Interfaces:
GraphQLCountryNotConfiguredInStoreError, GraphQLErrorObject, io.vrap.rmf.base.client.ModelBase

public class GraphQLCountryNotConfiguredInStoreErrorImpl extends Object implements GraphQLCountryNotConfiguredInStoreError, io.vrap.rmf.base.client.ModelBase

Returned when a Cart or an Order in a Store references a country that is not included in the countries configured for the Store.

The error is returned as a failed response to: