Class GraphQLDiscountCodeNonApplicableErrorImpl
- All Implemented Interfaces:
GraphQLDiscountCodeNonApplicableError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
Returned when the Cart contains a Discount Code with a DiscountCodeState other than MatchesCart or ApplicationStoppedByGroupBestDeal.
The error is returned as a failed response to:
- Create Cart and Create Cart in Store requests.
- Create Cart and Create Cart in Store requests.
- Create Cart in BusinessUnit request on Associate Carts.
- Create Order from Cart and Create Order in Store from Cart requests on Orders.
- Create Order from Cart and Create Order in Store from Cart requests on My Orders.
- Add DiscountCode update action on Carts, if the associated Cart Discounts are inactive or invalid, or belongs to a different Store than the Cart.
- Add DiscountCode update action on My Carts, if the associated Cart Discounts are inactive or invalid, or belongs to a different Store than the Cart.
- Add DiscountCode update action on Order Edits, if the associated Cart Discounts are inactive or invalid, or belongs to a different Store than the Order.
- Create Order from Cart in BusinessUnit request on Associate Orders.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLDiscountCodeNonApplicableError
DISCOUNT_CODE_NON_APPLICABLE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Discount Code passed to the Cart.Unique identifier of the Discount Code."DoesNotExist"or"TimeRangeNonApplicable"Date and time (UTC) from which the Discount Code is valid.Date and time (UTC) the Discount Code validity check was last performed.Date and time (UTC) until which the Discount Code is valid.inthashCode()voidsetDiscountCode(String discountCode) Discount Code passed to the Cart.voidsetDiscountCodeId(String discountCodeId) Unique identifier of the Discount Code.void"DoesNotExist"or"TimeRangeNonApplicable"voidsetValidFrom(ZonedDateTime validFrom) Date and time (UTC) from which the Discount Code is valid.voidsetValidityCheckTime(ZonedDateTime validityCheckTime) Date and time (UTC) the Discount Code validity check was last performed.voidsetValidUntil(ZonedDateTime validUntil) Date and time (UTC) until which the Discount Code is valid.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLDiscountCodeNonApplicableError
withGraphQLDiscountCodeNonApplicableErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLDiscountCodeNonApplicableErrorImpl
public GraphQLDiscountCodeNonApplicableErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLDiscountCodeNonApplicableError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getDiscountCode
Discount Code passed to the Cart.
- Specified by:
getDiscountCodein interfaceGraphQLDiscountCodeNonApplicableError- Returns:
- discountCode
-
getReason
"DoesNotExist"or"TimeRangeNonApplicable"- Specified by:
getReasonin interfaceGraphQLDiscountCodeNonApplicableError- Returns:
- reason
-
getDiscountCodeId
Unique identifier of the Discount Code.
- Specified by:
getDiscountCodeIdin interfaceGraphQLDiscountCodeNonApplicableError- Returns:
- discountCodeId
-
getValidFrom
Date and time (UTC) from which the Discount Code is valid.
- Specified by:
getValidFromin interfaceGraphQLDiscountCodeNonApplicableError- Returns:
- validFrom
-
getValidUntil
Date and time (UTC) until which the Discount Code is valid.
- Specified by:
getValidUntilin interfaceGraphQLDiscountCodeNonApplicableError- Returns:
- validUntil
-
getValidityCheckTime
Date and time (UTC) the Discount Code validity check was last performed.
- Specified by:
getValidityCheckTimein interfaceGraphQLDiscountCodeNonApplicableError- Returns:
- validityCheckTime
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setDiscountCode
Description copied from interface:GraphQLDiscountCodeNonApplicableErrorDiscount Code passed to the Cart.
- Specified by:
setDiscountCodein interfaceGraphQLDiscountCodeNonApplicableError- Parameters:
discountCode- value to be set
-
setReason
Description copied from interface:GraphQLDiscountCodeNonApplicableError"DoesNotExist"or"TimeRangeNonApplicable"- Specified by:
setReasonin interfaceGraphQLDiscountCodeNonApplicableError- Parameters:
reason- value to be set
-
setDiscountCodeId
Description copied from interface:GraphQLDiscountCodeNonApplicableErrorUnique identifier of the Discount Code.
- Specified by:
setDiscountCodeIdin interfaceGraphQLDiscountCodeNonApplicableError- Parameters:
discountCodeId- value to be set
-
setValidFrom
Description copied from interface:GraphQLDiscountCodeNonApplicableErrorDate and time (UTC) from which the Discount Code is valid.
- Specified by:
setValidFromin interfaceGraphQLDiscountCodeNonApplicableError- Parameters:
validFrom- value to be set
-
setValidUntil
Description copied from interface:GraphQLDiscountCodeNonApplicableErrorDate and time (UTC) until which the Discount Code is valid.
- Specified by:
setValidUntilin interfaceGraphQLDiscountCodeNonApplicableError- Parameters:
validUntil- value to be set
-
setValidityCheckTime
Description copied from interface:GraphQLDiscountCodeNonApplicableErrorDate and time (UTC) the Discount Code validity check was last performed.
- Specified by:
setValidityCheckTimein interfaceGraphQLDiscountCodeNonApplicableError- Parameters:
validityCheckTime- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLDiscountCodeNonApplicableError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-