Class GraphQLDuplicateAttributeValueErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLDuplicateAttributeValueErrorImpl
- All Implemented Interfaces:
GraphQLDuplicateAttributeValueError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLDuplicateAttributeValueErrorImpl
extends Object
implements GraphQLDuplicateAttributeValueError, io.vrap.rmf.base.client.ModelBase
Returned when the Unique AttributeConstraint criteria are not met during an Update Product request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLDuplicateAttributeValueError
DUPLICATE_ATTRIBUTE_VALUE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanConflicting Attributes.getCode()One of the error codes that is listed on the Errors page.inthashCode()voidsetAttribute(Attribute attribute) Conflicting Attributes.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLDuplicateAttributeValueError
withGraphQLDuplicateAttributeValueErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLDuplicateAttributeValueErrorImpl
public GraphQLDuplicateAttributeValueErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLDuplicateAttributeValueError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getAttribute
Conflicting Attributes.
- Specified by:
getAttributein interfaceGraphQLDuplicateAttributeValueError- Returns:
- attribute
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setAttribute
Description copied from interface:GraphQLDuplicateAttributeValueErrorConflicting Attributes.
- Specified by:
setAttributein interfaceGraphQLDuplicateAttributeValueError- Parameters:
attribute- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLDuplicateAttributeValueError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-