Class GraphQLDuplicateAttributeValuesErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLDuplicateAttributeValuesErrorImpl
- All Implemented Interfaces:
GraphQLDuplicateAttributeValuesError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLDuplicateAttributeValuesErrorImpl
extends Object
implements GraphQLDuplicateAttributeValuesError, io.vrap.rmf.base.client.ModelBase
Returned when the CombinationUnique AttributeConstraint criteria are not met during an Update Product request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLDuplicateAttributeValuesError
DUPLICATE_ATTRIBUTE_VALUES -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanConflicting Attributes.getCode()One of the error codes that is listed on the Errors page.inthashCode()voidsetAttributes(Attribute... attributes) Conflicting Attributes.voidsetAttributes(List<Attribute> attributes) Conflicting Attributes.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLDuplicateAttributeValuesError
withGraphQLDuplicateAttributeValuesErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLDuplicateAttributeValuesErrorImpl
public GraphQLDuplicateAttributeValuesErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLDuplicateAttributeValuesError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getAttributes
Conflicting Attributes.
- Specified by:
getAttributesin interfaceGraphQLDuplicateAttributeValuesError- Returns:
- attributes
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setAttributes
Description copied from interface:GraphQLDuplicateAttributeValuesErrorConflicting Attributes.
- Specified by:
setAttributesin interfaceGraphQLDuplicateAttributeValuesError- Parameters:
attributes- values to be set
-
setAttributes
Description copied from interface:GraphQLDuplicateAttributeValuesErrorConflicting Attributes.
- Specified by:
setAttributesin interfaceGraphQLDuplicateAttributeValuesError- Parameters:
attributes- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLDuplicateAttributeValuesError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-