Class GraphQLDuplicateFieldErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLDuplicateFieldErrorImpl
- All Implemented Interfaces:
GraphQLDuplicateFieldError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLDuplicateFieldErrorImpl
extends Object
implements GraphQLDuplicateFieldError, io.vrap.rmf.base.client.ModelBase
Returned when a field value conflicts with an existing value causing a duplicate.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLDuplicateFieldError
DUPLICATE_FIELD -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Conflicting duplicate value.getField()Name of the conflicting field.inthashCode()voidsetDuplicateValue(Object duplicateValue) Conflicting duplicate value.voidName of the conflicting field.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLDuplicateFieldError
withGraphQLDuplicateFieldErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLDuplicateFieldErrorImpl
public GraphQLDuplicateFieldErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLDuplicateFieldError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getField
Name of the conflicting field.
- Specified by:
getFieldin interfaceGraphQLDuplicateFieldError- Returns:
- field
-
getDuplicateValue
Conflicting duplicate value.
- Specified by:
getDuplicateValuein interfaceGraphQLDuplicateFieldError- Returns:
- duplicateValue
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setField
Description copied from interface:GraphQLDuplicateFieldErrorName of the conflicting field.
- Specified by:
setFieldin interfaceGraphQLDuplicateFieldError- Parameters:
field- value to be set
-
setDuplicateValue
Description copied from interface:GraphQLDuplicateFieldErrorConflicting duplicate value.
- Specified by:
setDuplicateValuein interfaceGraphQLDuplicateFieldError- Parameters:
duplicateValue- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLDuplicateFieldError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-