Class GraphQLDuplicateFieldWithConflictingResourceErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLDuplicateFieldWithConflictingResourceErrorImpl
- All Implemented Interfaces:
GraphQLDuplicateFieldWithConflictingResourceError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLDuplicateFieldWithConflictingResourceErrorImpl
extends Object
implements GraphQLDuplicateFieldWithConflictingResourceError, io.vrap.rmf.base.client.ModelBase
Returned when a field value conflicts with an existing value stored in a particular resource causing a duplicate.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLDuplicateFieldWithConflictingResourceError
DUPLICATE_FIELD_WITH_CONFLICTING_RESOURCE -
Constructor Summary
ConstructorsConstructorDescriptioncreate empty instance -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Reference to the resource that has the conflicting value.Conflicting duplicate value.getField()Name of the conflicting field.inthashCode()voidsetConflictingResource(Reference conflictingResource) Reference to the resource that has the conflicting value.voidsetDuplicateValue(Object duplicateValue) Conflicting duplicate value.voidName of the conflicting field.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLDuplicateFieldWithConflictingResourceError
withGraphQLDuplicateFieldWithConflictingResourceErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLDuplicateFieldWithConflictingResourceErrorImpl
public GraphQLDuplicateFieldWithConflictingResourceErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLDuplicateFieldWithConflictingResourceError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getField
Name of the conflicting field.
- Specified by:
getFieldin interfaceGraphQLDuplicateFieldWithConflictingResourceError- Returns:
- field
-
getDuplicateValue
Conflicting duplicate value.
- Specified by:
getDuplicateValuein interfaceGraphQLDuplicateFieldWithConflictingResourceError- Returns:
- duplicateValue
-
getConflictingResource
Reference to the resource that has the conflicting value.
- Specified by:
getConflictingResourcein interfaceGraphQLDuplicateFieldWithConflictingResourceError- Returns:
- conflictingResource
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setField
Description copied from interface:GraphQLDuplicateFieldWithConflictingResourceErrorName of the conflicting field.
- Specified by:
setFieldin interfaceGraphQLDuplicateFieldWithConflictingResourceError- Parameters:
field- value to be set
-
setDuplicateValue
Description copied from interface:GraphQLDuplicateFieldWithConflictingResourceErrorConflicting duplicate value.
- Specified by:
setDuplicateValuein interfaceGraphQLDuplicateFieldWithConflictingResourceError- Parameters:
duplicateValue- value to be set
-
setConflictingResource
Description copied from interface:GraphQLDuplicateFieldWithConflictingResourceErrorReference to the resource that has the conflicting value.
- Specified by:
setConflictingResourcein interfaceGraphQLDuplicateFieldWithConflictingResourceError- Parameters:
conflictingResource- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLDuplicateFieldWithConflictingResourceError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-