Class GraphQLDuplicatePriceKeyErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLDuplicatePriceKeyErrorImpl
- All Implemented Interfaces:
GraphQLDuplicatePriceKeyError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLDuplicatePriceKeyErrorImpl
extends Object
implements GraphQLDuplicatePriceKeyError, io.vrap.rmf.base.client.ModelBase
Returned when a Price key conflicts with an existing key.
Keys of Embedded Prices must be unique per ProductVariant.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLDuplicatePriceKeyError
DUPLICATE_PRICE_KEY -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Conflicting Embedded Price.inthashCode()voidsetConflictingPrice(Price conflictingPrice) Conflicting Embedded Price.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLDuplicatePriceKeyError
withGraphQLDuplicatePriceKeyErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLDuplicatePriceKeyErrorImpl
public GraphQLDuplicatePriceKeyErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLDuplicatePriceKeyError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getConflictingPrice
Conflicting Embedded Price.
- Specified by:
getConflictingPricein interfaceGraphQLDuplicatePriceKeyError- Returns:
- conflictingPrice
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setConflictingPrice
Description copied from interface:GraphQLDuplicatePriceKeyErrorConflicting Embedded Price.
- Specified by:
setConflictingPricein interfaceGraphQLDuplicatePriceKeyError- Parameters:
conflictingPrice- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLDuplicatePriceKeyError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-