Class GraphQLDuplicatePriceScopeErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLDuplicatePriceScopeErrorImpl
- All Implemented Interfaces:
GraphQLDuplicatePriceScopeError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLDuplicatePriceScopeErrorImpl
extends Object
implements GraphQLDuplicatePriceScopeError, io.vrap.rmf.base.client.ModelBase
Returned when a Price scope conflicts with an existing one during an Update Product request.
Every Price of a Product Variant must have a distinct combination of currency, Customer Group, country, and Channel that constitute the scope of a Price.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLDuplicatePriceScopeError
DUPLICATE_PRICE_SCOPE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Conflicting Embedded Price.inthashCode()voidsetConflictingPrice(Price conflictingPrice) Conflicting Embedded Price.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLDuplicatePriceScopeError
withGraphQLDuplicatePriceScopeErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLDuplicatePriceScopeErrorImpl
public GraphQLDuplicatePriceScopeErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLDuplicatePriceScopeError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getConflictingPrice
Conflicting Embedded Price.
- Specified by:
getConflictingPricein interfaceGraphQLDuplicatePriceScopeError- Returns:
- conflictingPrice
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setConflictingPrice
Description copied from interface:GraphQLDuplicatePriceScopeErrorConflicting Embedded Price.
- Specified by:
setConflictingPricein interfaceGraphQLDuplicatePriceScopeError- Parameters:
conflictingPrice- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLDuplicatePriceScopeError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-