Class GraphQLDuplicateStandalonePriceScopeErrorImpl
- All Implemented Interfaces:
GraphQLDuplicateStandalonePriceScopeError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
Returned when the given Price scope conflicts with the Price scope of an existing Standalone Price. Every Standalone Price associated with the same SKU must have a distinct combination of currency, country, Customer Group, Channel, and validity periods (validFrom and validUntil).
The error is returned as a failed response to the Create StandalonePrice request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLDuplicateStandalonePriceScopeError
DUPLICATE_STANDALONE_PRICE_SCOPE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanChannel for which the Standalone Price is valid.getCode()One of the error codes that is listed on the Errors page.Reference to the conflicting Standalone Price.Country code of the geographic location.Currency code of the country.CustomerGroup for which the Standalone Price is valid.getSku()SKU of the ProductVariant to which the conflicting Standalone Price is associated.Date and time (UTC) from which the Standalone Price is valid.Date and time (UTC) until which the Standalone Price is valid.inthashCode()voidsetChannel(ChannelResourceIdentifier channel) Channel for which the Standalone Price is valid.voidsetConflictingStandalonePrice(StandalonePriceReference conflictingStandalonePrice) Reference to the conflicting Standalone Price.voidsetCountry(String country) Country code of the geographic location.voidsetCurrency(String currency) Currency code of the country.voidsetCustomerGroup(CustomerGroupResourceIdentifier customerGroup) CustomerGroup for which the Standalone Price is valid.voidSKU of the ProductVariant to which the conflicting Standalone Price is associated.voidsetValidFrom(ZonedDateTime validFrom) Date and time (UTC) from which the Standalone Price is valid.voidsetValidUntil(ZonedDateTime validUntil) Date and time (UTC) until which the Standalone Price is valid.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLDuplicateStandalonePriceScopeError
withGraphQLDuplicateStandalonePriceScopeErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLDuplicateStandalonePriceScopeErrorImpl
public GraphQLDuplicateStandalonePriceScopeErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLDuplicateStandalonePriceScopeError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getConflictingStandalonePrice
Reference to the conflicting Standalone Price.
- Specified by:
getConflictingStandalonePricein interfaceGraphQLDuplicateStandalonePriceScopeError- Returns:
- conflictingStandalonePrice
-
getSku
SKU of the ProductVariant to which the conflicting Standalone Price is associated.
- Specified by:
getSkuin interfaceGraphQLDuplicateStandalonePriceScopeError- Returns:
- sku
-
getCurrency
Currency code of the country.
- Specified by:
getCurrencyin interfaceGraphQLDuplicateStandalonePriceScopeError- Returns:
- currency
-
getCountry
Country code of the geographic location.
- Specified by:
getCountryin interfaceGraphQLDuplicateStandalonePriceScopeError- Returns:
- country
-
getCustomerGroup
CustomerGroup for which the Standalone Price is valid.
- Specified by:
getCustomerGroupin interfaceGraphQLDuplicateStandalonePriceScopeError- Returns:
- customerGroup
-
getChannel
Channel for which the Standalone Price is valid.
- Specified by:
getChannelin interfaceGraphQLDuplicateStandalonePriceScopeError- Returns:
- channel
-
getValidFrom
Date and time (UTC) from which the Standalone Price is valid.
- Specified by:
getValidFromin interfaceGraphQLDuplicateStandalonePriceScopeError- Returns:
- validFrom
-
getValidUntil
Date and time (UTC) until which the Standalone Price is valid.
- Specified by:
getValidUntilin interfaceGraphQLDuplicateStandalonePriceScopeError- Returns:
- validUntil
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setConflictingStandalonePrice
Description copied from interface:GraphQLDuplicateStandalonePriceScopeErrorReference to the conflicting Standalone Price.
- Specified by:
setConflictingStandalonePricein interfaceGraphQLDuplicateStandalonePriceScopeError- Parameters:
conflictingStandalonePrice- value to be set
-
setSku
Description copied from interface:GraphQLDuplicateStandalonePriceScopeErrorSKU of the ProductVariant to which the conflicting Standalone Price is associated.
- Specified by:
setSkuin interfaceGraphQLDuplicateStandalonePriceScopeError- Parameters:
sku- value to be set
-
setCurrency
Description copied from interface:GraphQLDuplicateStandalonePriceScopeErrorCurrency code of the country.
- Specified by:
setCurrencyin interfaceGraphQLDuplicateStandalonePriceScopeError- Parameters:
currency- value to be set
-
setCountry
Description copied from interface:GraphQLDuplicateStandalonePriceScopeErrorCountry code of the geographic location.
- Specified by:
setCountryin interfaceGraphQLDuplicateStandalonePriceScopeError- Parameters:
country- value to be set
-
setCustomerGroup
Description copied from interface:GraphQLDuplicateStandalonePriceScopeErrorCustomerGroup for which the Standalone Price is valid.
- Specified by:
setCustomerGroupin interfaceGraphQLDuplicateStandalonePriceScopeError- Parameters:
customerGroup- value to be set
-
setChannel
Description copied from interface:GraphQLDuplicateStandalonePriceScopeErrorChannel for which the Standalone Price is valid.
- Specified by:
setChannelin interfaceGraphQLDuplicateStandalonePriceScopeError- Parameters:
channel- value to be set
-
setValidFrom
Description copied from interface:GraphQLDuplicateStandalonePriceScopeErrorDate and time (UTC) from which the Standalone Price is valid.
- Specified by:
setValidFromin interfaceGraphQLDuplicateStandalonePriceScopeError- Parameters:
validFrom- value to be set
-
setValidUntil
Description copied from interface:GraphQLDuplicateStandalonePriceScopeErrorDate and time (UTC) until which the Standalone Price is valid.
- Specified by:
setValidUntilin interfaceGraphQLDuplicateStandalonePriceScopeError- Parameters:
validUntil- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLDuplicateStandalonePriceScopeError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-