Class GraphQLDuplicateVariantValuesErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLDuplicateVariantValuesErrorImpl
- All Implemented Interfaces:
GraphQLDuplicateVariantValuesError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLDuplicateVariantValuesErrorImpl
extends Object
implements GraphQLDuplicateVariantValuesError, io.vrap.rmf.base.client.ModelBase
Returned when a Product Variant value conflicts with an existing one during an Update Product request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLDuplicateVariantValuesError
DUPLICATE_VARIANT_VALUES -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Every Product Variant must have a distinct combination of SKU, prices, and custom Attribute values.inthashCode()voidError-specific additional fields.voidsetVariantValues(VariantValues variantValues) Every Product Variant must have a distinct combination of SKU, prices, and custom Attribute values.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLDuplicateVariantValuesError
withGraphQLDuplicateVariantValuesErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLDuplicateVariantValuesErrorImpl
public GraphQLDuplicateVariantValuesErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLDuplicateVariantValuesError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getVariantValues
Every Product Variant must have a distinct combination of SKU, prices, and custom Attribute values.
- Specified by:
getVariantValuesin interfaceGraphQLDuplicateVariantValuesError- Returns:
- variantValues
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setVariantValues
Description copied from interface:GraphQLDuplicateVariantValuesErrorEvery Product Variant must have a distinct combination of SKU, prices, and custom Attribute values.
- Specified by:
setVariantValuesin interfaceGraphQLDuplicateVariantValuesError- Parameters:
variantValues- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLDuplicateVariantValuesError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-