Class GraphQLEditPreviewFailedErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLEditPreviewFailedErrorImpl
- All Implemented Interfaces:
GraphQLEditPreviewFailedError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLEditPreviewFailedErrorImpl
extends Object
implements GraphQLEditPreviewFailedError, io.vrap.rmf.base.client.ModelBase
Returned when a preview to find an appropriate Shipping Method for an OrderEdit could not be generated.
The error is returned as a failed response to the Get Shipping Methods for an OrderEdit request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLEditPreviewFailedError
EDIT_PREVIEW_FAILED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.State of the OrderEdit where thestagedActionscannot be applied to the Order.inthashCode()voidsetResult(OrderEditPreviewFailure result) State of the OrderEdit where thestagedActionscannot be applied to the Order.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLEditPreviewFailedError
withGraphQLEditPreviewFailedErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLEditPreviewFailedErrorImpl
public GraphQLEditPreviewFailedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLEditPreviewFailedError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getResult
State of the OrderEdit where the
stagedActionscannot be applied to the Order.- Specified by:
getResultin interfaceGraphQLEditPreviewFailedError- Returns:
- result
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setResult
Description copied from interface:GraphQLEditPreviewFailedErrorState of the OrderEdit where the
stagedActionscannot be applied to the Order.- Specified by:
setResultin interfaceGraphQLEditPreviewFailedError- Parameters:
result- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLEditPreviewFailedError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-