Class GraphQLEnumKeyAlreadyExistsErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLEnumKeyAlreadyExistsErrorImpl
- All Implemented Interfaces:
GraphQLEnumKeyAlreadyExistsError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLEnumKeyAlreadyExistsErrorImpl
extends Object
implements GraphQLEnumKeyAlreadyExistsError, io.vrap.rmf.base.client.ModelBase
Returned when an AttributeEnumType or AttributeLocalizedEnumType contains a key that already exists.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLEnumKeyAlreadyExistsError
ENUM_KEY_ALREADY_EXISTS -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Name of the conflicting Attribute.Conflicting enum key.inthashCode()voidsetConflictingAttributeName(String conflictingAttributeName) Name of the conflicting Attribute.voidsetConflictingEnumKey(String conflictingEnumKey) Conflicting enum key.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLEnumKeyAlreadyExistsError
withGraphQLEnumKeyAlreadyExistsErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLEnumKeyAlreadyExistsErrorImpl
public GraphQLEnumKeyAlreadyExistsErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLEnumKeyAlreadyExistsError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getConflictingEnumKey
Conflicting enum key.
- Specified by:
getConflictingEnumKeyin interfaceGraphQLEnumKeyAlreadyExistsError- Returns:
- conflictingEnumKey
-
getConflictingAttributeName
Name of the conflicting Attribute.
- Specified by:
getConflictingAttributeNamein interfaceGraphQLEnumKeyAlreadyExistsError- Returns:
- conflictingAttributeName
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setConflictingEnumKey
Description copied from interface:GraphQLEnumKeyAlreadyExistsErrorConflicting enum key.
- Specified by:
setConflictingEnumKeyin interfaceGraphQLEnumKeyAlreadyExistsError- Parameters:
conflictingEnumKey- value to be set
-
setConflictingAttributeName
Description copied from interface:GraphQLEnumKeyAlreadyExistsErrorName of the conflicting Attribute.
- Specified by:
setConflictingAttributeNamein interfaceGraphQLEnumKeyAlreadyExistsError- Parameters:
conflictingAttributeName- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLEnumKeyAlreadyExistsError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-