Class GraphQLEnumKeyDoesNotExistErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLEnumKeyDoesNotExistErrorImpl
- All Implemented Interfaces:
GraphQLEnumKeyDoesNotExistError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLEnumKeyDoesNotExistErrorImpl
extends Object
implements GraphQLEnumKeyDoesNotExistError, io.vrap.rmf.base.client.ModelBase
Returned when an AttributeEnumType or AttributeLocalizedEnumType already contains a value with the given key.
The error is returned as a failed response to the Change the key of an EnumValue update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLEnumKeyDoesNotExistError
ENUM_KEY_DOES_NOT_EXIST -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Name of the conflicting Attribute.Conflicting enum key.inthashCode()voidsetConflictingAttributeName(String conflictingAttributeName) Name of the conflicting Attribute.voidsetConflictingEnumKey(String conflictingEnumKey) Conflicting enum key.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLEnumKeyDoesNotExistError
withGraphQLEnumKeyDoesNotExistErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLEnumKeyDoesNotExistErrorImpl
public GraphQLEnumKeyDoesNotExistErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLEnumKeyDoesNotExistError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getConflictingEnumKey
Conflicting enum key.
- Specified by:
getConflictingEnumKeyin interfaceGraphQLEnumKeyDoesNotExistError- Returns:
- conflictingEnumKey
-
getConflictingAttributeName
Name of the conflicting Attribute.
- Specified by:
getConflictingAttributeNamein interfaceGraphQLEnumKeyDoesNotExistError- Returns:
- conflictingAttributeName
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setConflictingEnumKey
Description copied from interface:GraphQLEnumKeyDoesNotExistErrorConflicting enum key.
- Specified by:
setConflictingEnumKeyin interfaceGraphQLEnumKeyDoesNotExistError- Parameters:
conflictingEnumKey- value to be set
-
setConflictingAttributeName
Description copied from interface:GraphQLEnumKeyDoesNotExistErrorName of the conflicting Attribute.
- Specified by:
setConflictingAttributeNamein interfaceGraphQLEnumKeyDoesNotExistError- Parameters:
conflictingAttributeName- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLEnumKeyDoesNotExistError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-