Class GraphQLEnumValueIsUsedErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLEnumValueIsUsedErrorImpl
- All Implemented Interfaces:
GraphQLEnumValueIsUsedError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLEnumValueIsUsedErrorImpl
extends Object
implements GraphQLEnumValueIsUsedError, io.vrap.rmf.base.client.ModelBase
Returned when an enum value cannot be removed from an Attribute as it is being used by a Product.
The error is returned as a failed response to the Remove EnumValues from AttributeDefinition update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLEnumValueIsUsedError
ENUM_VALUE_IS_USED -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLEnumValueIsUsedError
withGraphQLEnumValueIsUsedErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLEnumValueIsUsedErrorImpl
public GraphQLEnumValueIsUsedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLEnumValueIsUsedError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLEnumValueIsUsedError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-