Class GraphQLEnumValuesMustMatchErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLEnumValuesMustMatchErrorImpl
- All Implemented Interfaces:
GraphQLEnumValuesMustMatchError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLEnumValuesMustMatchErrorImpl
extends Object
implements GraphQLEnumValuesMustMatchError, io.vrap.rmf.base.client.ModelBase
Returned when during an order update of AttributeEnumType or AttributeLocalizedEnumType the new enum values do not match the existing ones.
The error is returned as a failed response to the Change the order of EnumValues and Change the order of LocalizedEnumValues update actions.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLEnumValuesMustMatchError
ENUM_VALUES_MUST_MATCH -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLEnumValuesMustMatchError
withGraphQLEnumValuesMustMatchErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLEnumValuesMustMatchErrorImpl
public GraphQLEnumValuesMustMatchErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLEnumValuesMustMatchError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLEnumValuesMustMatchError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-