Class GraphQLExactLockConflictErrorImpl

java.lang.Object
com.commercetools.api.models.error.GraphQLExactLockConflictErrorImpl
All Implemented Interfaces:
GraphQLErrorObject, GraphQLExactLockConflictError, io.vrap.rmf.base.client.ModelBase

public class GraphQLExactLockConflictErrorImpl extends Object implements GraphQLExactLockConflictError, io.vrap.rmf.base.client.ModelBase

Returned when a modification is already in progress for the exact combination of SKU and price scope fields for a Standalone Price. Retry the same request after 300 ms.

The error is returned as a failed response to: