Class GraphQLExpiredCustomerEmailTokenErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLExpiredCustomerEmailTokenErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLExpiredCustomerEmailTokenError,io.vrap.rmf.base.client.ModelBase
public class GraphQLExpiredCustomerEmailTokenErrorImpl
extends Object
implements GraphQLExpiredCustomerEmailTokenError, io.vrap.rmf.base.client.ModelBase
Returned when the provided email token of the Customer has expired.
The error is returned as a failed response to:
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLExpiredCustomerEmailTokenError
EXPIRED_CUSTOMER_EMAIL_TOKEN -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLExpiredCustomerEmailTokenError
withGraphQLExpiredCustomerEmailTokenErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLExpiredCustomerEmailTokenErrorImpl
public GraphQLExpiredCustomerEmailTokenErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLExpiredCustomerEmailTokenError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLExpiredCustomerEmailTokenError
-