Class GraphQLExpiredCustomerPasswordTokenErrorImpl

java.lang.Object
com.commercetools.api.models.error.GraphQLExpiredCustomerPasswordTokenErrorImpl
All Implemented Interfaces:
GraphQLErrorObject, GraphQLExpiredCustomerPasswordTokenError, io.vrap.rmf.base.client.ModelBase

public class GraphQLExpiredCustomerPasswordTokenErrorImpl extends Object implements GraphQLExpiredCustomerPasswordTokenError, io.vrap.rmf.base.client.ModelBase

Returned when the provided password token of the Customer has expired.

The error is returned as a failed response to: