Class GraphQLExtensionBadResponseErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLExtensionBadResponseError,io.vrap.rmf.base.client.ModelBase
Returned when the response from the API Extension could not be parsed successfully (such as a 500 HTTP status code, or an invalid JSON response).
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLExtensionBadResponseError
EXTENSION_BAD_RESPONSE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.The response body returned by the Extension.Additional errors related to the API Extension.Any information that should be returned to the API caller.Unique identifier of the Extension.User-defined unique identifier of the Extension.Http status code returned by the Extension.User-defined localized description of the error.inthashCode()voidsetExtensionBody(String extensionBody) The response body returned by the Extension.voidsetExtensionErrors(ExtensionError... extensionErrors) Additional errors related to the API Extension.voidsetExtensionErrors(List<ExtensionError> extensionErrors) Additional errors related to the API Extension.voidsetExtensionExtraInfo(Object extensionExtraInfo) Any information that should be returned to the API caller.voidsetExtensionId(String extensionId) Unique identifier of the Extension.voidsetExtensionKey(String extensionKey) User-defined unique identifier of the Extension.voidsetExtensionStatusCode(Integer extensionStatusCode) Http status code returned by the Extension.voidsetLocalizedMessage(LocalizedString localizedMessage) User-defined localized description of the error.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLExtensionBadResponseError
withGraphQLExtensionBadResponseErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLExtensionBadResponseErrorImpl
public GraphQLExtensionBadResponseErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLExtensionBadResponseError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getLocalizedMessage
User-defined localized description of the error.
- Specified by:
getLocalizedMessagein interfaceGraphQLExtensionBadResponseError- Returns:
- localizedMessage
-
getExtensionExtraInfo
Any information that should be returned to the API caller.
- Specified by:
getExtensionExtraInfoin interfaceGraphQLExtensionBadResponseError- Returns:
- extensionExtraInfo
-
getExtensionErrors
Additional errors related to the API Extension.
- Specified by:
getExtensionErrorsin interfaceGraphQLExtensionBadResponseError- Returns:
- extensionErrors
-
getExtensionBody
The response body returned by the Extension.
- Specified by:
getExtensionBodyin interfaceGraphQLExtensionBadResponseError- Returns:
- extensionBody
-
getExtensionStatusCode
Http status code returned by the Extension.
- Specified by:
getExtensionStatusCodein interfaceGraphQLExtensionBadResponseError- Returns:
- extensionStatusCode
-
getExtensionId
Unique identifier of the Extension.
- Specified by:
getExtensionIdin interfaceGraphQLExtensionBadResponseError- Returns:
- extensionId
-
getExtensionKey
User-defined unique identifier of the Extension.
- Specified by:
getExtensionKeyin interfaceGraphQLExtensionBadResponseError- Returns:
- extensionKey
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setLocalizedMessage
Description copied from interface:GraphQLExtensionBadResponseErrorUser-defined localized description of the error.
- Specified by:
setLocalizedMessagein interfaceGraphQLExtensionBadResponseError- Parameters:
localizedMessage- value to be set
-
setExtensionExtraInfo
Description copied from interface:GraphQLExtensionBadResponseErrorAny information that should be returned to the API caller.
- Specified by:
setExtensionExtraInfoin interfaceGraphQLExtensionBadResponseError- Parameters:
extensionExtraInfo- value to be set
-
setExtensionErrors
Description copied from interface:GraphQLExtensionBadResponseErrorAdditional errors related to the API Extension.
- Specified by:
setExtensionErrorsin interfaceGraphQLExtensionBadResponseError- Parameters:
extensionErrors- values to be set
-
setExtensionErrors
Description copied from interface:GraphQLExtensionBadResponseErrorAdditional errors related to the API Extension.
- Specified by:
setExtensionErrorsin interfaceGraphQLExtensionBadResponseError- Parameters:
extensionErrors- values to be set
-
setExtensionBody
Description copied from interface:GraphQLExtensionBadResponseErrorThe response body returned by the Extension.
- Specified by:
setExtensionBodyin interfaceGraphQLExtensionBadResponseError- Parameters:
extensionBody- value to be set
-
setExtensionStatusCode
Description copied from interface:GraphQLExtensionBadResponseErrorHttp status code returned by the Extension.
- Specified by:
setExtensionStatusCodein interfaceGraphQLExtensionBadResponseError- Parameters:
extensionStatusCode- value to be set
-
setExtensionId
Description copied from interface:GraphQLExtensionBadResponseErrorUnique identifier of the Extension.
- Specified by:
setExtensionIdin interfaceGraphQLExtensionBadResponseError- Parameters:
extensionId- value to be set
-
setExtensionKey
Description copied from interface:GraphQLExtensionBadResponseErrorUser-defined unique identifier of the Extension.
- Specified by:
setExtensionKeyin interfaceGraphQLExtensionBadResponseError- Parameters:
extensionKey- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLExtensionBadResponseError
-