Class GraphQLExtensionDependencyExistsErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLExtensionDependencyExistsErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLExtensionDependencyExistsError,io.vrap.rmf.base.client.ModelBase
public class GraphQLExtensionDependencyExistsErrorImpl
extends Object
implements GraphQLExtensionDependencyExistsError, io.vrap.rmf.base.client.ModelBase
Returned when attempting to delete an Extension that is a prerequisite for other Extensions.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLExtensionDependencyExistsError
EXTENSION_DEPENDENCY_EXISTS -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLExtensionDependencyExistsError
withGraphQLExtensionDependencyExistsErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLExtensionDependencyExistsErrorImpl
public GraphQLExtensionDependencyExistsErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLExtensionDependencyExistsError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLExtensionDependencyExistsError
-