Class GraphQLExtensionNoResponseErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLExtensionNoResponseErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLExtensionNoResponseError,io.vrap.rmf.base.client.ModelBase
public class GraphQLExtensionNoResponseErrorImpl
extends Object
implements GraphQLExtensionNoResponseError, io.vrap.rmf.base.client.ModelBase
Returned when the API Extension does not respond within the time limit, or could not be reached.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLExtensionNoResponseError
EXTENSION_NO_RESPONSE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Unique identifier of the API Extension.User-defined unique identifier of the API Extension, if available.inthashCode()voidsetExtensionId(String extensionId) Unique identifier of the API Extension.voidsetExtensionKey(String extensionKey) User-defined unique identifier of the API Extension, if available.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLExtensionNoResponseError
withGraphQLExtensionNoResponseErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLExtensionNoResponseErrorImpl
public GraphQLExtensionNoResponseErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLExtensionNoResponseError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getExtensionId
Unique identifier of the API Extension.
- Specified by:
getExtensionIdin interfaceGraphQLExtensionNoResponseError- Returns:
- extensionId
-
getExtensionKey
User-defined unique identifier of the API Extension, if available.
- Specified by:
getExtensionKeyin interfaceGraphQLExtensionNoResponseError- Returns:
- extensionKey
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setExtensionId
Description copied from interface:GraphQLExtensionNoResponseErrorUnique identifier of the API Extension.
- Specified by:
setExtensionIdin interfaceGraphQLExtensionNoResponseError- Parameters:
extensionId- value to be set
-
setExtensionKey
Description copied from interface:GraphQLExtensionNoResponseErrorUser-defined unique identifier of the API Extension, if available.
- Specified by:
setExtensionKeyin interfaceGraphQLExtensionNoResponseError- Parameters:
extensionKey- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLExtensionNoResponseError
-