Class GraphQLExtensionUpdateActionsFailedErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLExtensionUpdateActionsFailedErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLExtensionUpdateActionsFailedError,io.vrap.rmf.base.client.ModelBase
public class GraphQLExtensionUpdateActionsFailedErrorImpl
extends Object
implements GraphQLExtensionUpdateActionsFailedError, io.vrap.rmf.base.client.ModelBase
Returned when update actions could not be applied to the resource (for example, because a referenced resource does not exist). This would result in a 400 Bad Request response if the same update action was sent from a regular client.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLExtensionUpdateActionsFailedError
EXTENSION_UPDATE_ACTIONS_FAILED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Additional errors related to the API Extension.Any information that should be returned to the API caller.User-defined localized description of the error.inthashCode()voidsetExtensionErrors(ExtensionError... extensionErrors) Additional errors related to the API Extension.voidsetExtensionErrors(List<ExtensionError> extensionErrors) Additional errors related to the API Extension.voidsetExtensionExtraInfo(Object extensionExtraInfo) Any information that should be returned to the API caller.voidsetLocalizedMessage(LocalizedString localizedMessage) User-defined localized description of the error.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLExtensionUpdateActionsFailedError
withGraphQLExtensionUpdateActionsFailedErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLExtensionUpdateActionsFailedErrorImpl
public GraphQLExtensionUpdateActionsFailedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLExtensionUpdateActionsFailedError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getLocalizedMessage
User-defined localized description of the error.
- Specified by:
getLocalizedMessagein interfaceGraphQLExtensionUpdateActionsFailedError- Returns:
- localizedMessage
-
getExtensionExtraInfo
Any information that should be returned to the API caller.
- Specified by:
getExtensionExtraInfoin interfaceGraphQLExtensionUpdateActionsFailedError- Returns:
- extensionExtraInfo
-
getExtensionErrors
Additional errors related to the API Extension.
- Specified by:
getExtensionErrorsin interfaceGraphQLExtensionUpdateActionsFailedError- Returns:
- extensionErrors
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setLocalizedMessage
Description copied from interface:GraphQLExtensionUpdateActionsFailedErrorUser-defined localized description of the error.
- Specified by:
setLocalizedMessagein interfaceGraphQLExtensionUpdateActionsFailedError- Parameters:
localizedMessage- value to be set
-
setExtensionExtraInfo
Description copied from interface:GraphQLExtensionUpdateActionsFailedErrorAny information that should be returned to the API caller.
- Specified by:
setExtensionExtraInfoin interfaceGraphQLExtensionUpdateActionsFailedError- Parameters:
extensionExtraInfo- value to be set
-
setExtensionErrors
Description copied from interface:GraphQLExtensionUpdateActionsFailedErrorAdditional errors related to the API Extension.
- Specified by:
setExtensionErrorsin interfaceGraphQLExtensionUpdateActionsFailedError- Parameters:
extensionErrors- values to be set
-
setExtensionErrors
Description copied from interface:GraphQLExtensionUpdateActionsFailedErrorAdditional errors related to the API Extension.
- Specified by:
setExtensionErrorsin interfaceGraphQLExtensionUpdateActionsFailedError- Parameters:
extensionErrors- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLExtensionUpdateActionsFailedError
-