Class GraphQLExternalOAuthFailedErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLExternalOAuthFailedErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLExternalOAuthFailedError,io.vrap.rmf.base.client.ModelBase
public class GraphQLExternalOAuthFailedErrorImpl
extends Object
implements GraphQLExternalOAuthFailedError, io.vrap.rmf.base.client.ModelBase
Returned when an external OAuth Introspection endpoint does not return a response within the time limit, or the response isn't compliant with RFC 7662 (for example, an HTTP status code like 500).
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLExternalOAuthFailedError
EXTERNAL_O_AUTH_FAILED -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLExternalOAuthFailedError
withGraphQLExternalOAuthFailedErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLExternalOAuthFailedErrorImpl
public GraphQLExternalOAuthFailedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLExternalOAuthFailedError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLExternalOAuthFailedError
-