Class GraphQLGeneralErrorImpl

java.lang.Object
com.commercetools.api.models.error.GraphQLGeneralErrorImpl
All Implemented Interfaces:
GraphQLErrorObject, GraphQLGeneralError, io.vrap.rmf.base.client.ModelBase

public class GraphQLGeneralErrorImpl extends Object implements GraphQLGeneralError, io.vrap.rmf.base.client.ModelBase

Returned when a server-side problem occurs before or after data persistence. In some cases, the requested action may successfully complete after the error is returned. Therefore, it is recommended to verify the status of the requested resource after receiving a 500 error.

If you encounter this error, report it to the Composable Commerce support team.