Class GraphQLInternalConstraintViolatedErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLInternalConstraintViolatedErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLInternalConstraintViolatedError,io.vrap.rmf.base.client.ModelBase
public class GraphQLInternalConstraintViolatedErrorImpl
extends Object
implements GraphQLInternalConstraintViolatedError, io.vrap.rmf.base.client.ModelBase
Returned when certain API-specific constraints were not met. For example, the specified Discount Code was never applied and cannot be updated.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLInternalConstraintViolatedError
INTERNAL_CONSTRAINT_VIOLATED -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLInternalConstraintViolatedError
withGraphQLInternalConstraintViolatedErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLInternalConstraintViolatedErrorImpl
public GraphQLInternalConstraintViolatedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLInternalConstraintViolatedError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLInternalConstraintViolatedError
-