Class GraphQLInvalidCredentialsErrorImpl

java.lang.Object
com.commercetools.api.models.error.GraphQLInvalidCredentialsErrorImpl
All Implemented Interfaces:
GraphQLErrorObject, GraphQLInvalidCredentialsError, io.vrap.rmf.base.client.ModelBase

public class GraphQLInvalidCredentialsErrorImpl extends Object implements GraphQLInvalidCredentialsError, io.vrap.rmf.base.client.ModelBase

Returned when a Customer with the given credentials (matching the given email/password pair) is not found and authentication fails.

The error is returned as a failed response to: