Class GraphQLInvalidCurrentPasswordErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLInvalidCurrentPasswordErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLInvalidCurrentPasswordError,io.vrap.rmf.base.client.ModelBase
public class GraphQLInvalidCurrentPasswordErrorImpl
extends Object
implements GraphQLInvalidCurrentPasswordError, io.vrap.rmf.base.client.ModelBase
Returned when the current password of the Customer does not match.
The error is returned as a failed response to:
- Change Customer Password and Change Customer Password in a Store requests on Customers.
- Change Customer Password and Change Customer Password in a Store requests on My Customer Profile.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLInvalidCurrentPasswordError
INVALID_CURRENT_PASSWORD -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLInvalidCurrentPasswordError
withGraphQLInvalidCurrentPasswordErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLInvalidCurrentPasswordErrorImpl
public GraphQLInvalidCurrentPasswordErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLInvalidCurrentPasswordError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLInvalidCurrentPasswordError
-