Class GraphQLInvalidFieldErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLInvalidFieldErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLInvalidFieldError,io.vrap.rmf.base.client.ModelBase
public class GraphQLInvalidFieldErrorImpl
extends Object
implements GraphQLInvalidFieldError, io.vrap.rmf.base.client.ModelBase
Returned when a field has an invalid value.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLInvalidFieldError
INVALID_FIELD -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanFixed set of allowed values for the field, if any.getCode()One of the error codes that is listed on the Errors page.getField()Name of the field with the invalid value.Value invalid for the field.inthashCode()voidsetAllowedValues(Object... allowedValues) Fixed set of allowed values for the field, if any.voidsetAllowedValues(List<Object> allowedValues) Fixed set of allowed values for the field, if any.voidName of the field with the invalid value.voidsetInvalidValue(Object invalidValue) Value invalid for the field.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLInvalidFieldError
withGraphQLInvalidFieldErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLInvalidFieldErrorImpl
public GraphQLInvalidFieldErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLInvalidFieldError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getField
Name of the field with the invalid value.
- Specified by:
getFieldin interfaceGraphQLInvalidFieldError- Returns:
- field
-
getInvalidValue
Value invalid for the field.
- Specified by:
getInvalidValuein interfaceGraphQLInvalidFieldError- Returns:
- invalidValue
-
getAllowedValues
Fixed set of allowed values for the field, if any.
- Specified by:
getAllowedValuesin interfaceGraphQLInvalidFieldError- Returns:
- allowedValues
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setField
Description copied from interface:GraphQLInvalidFieldErrorName of the field with the invalid value.
- Specified by:
setFieldin interfaceGraphQLInvalidFieldError- Parameters:
field- value to be set
-
setInvalidValue
Description copied from interface:GraphQLInvalidFieldErrorValue invalid for the field.
- Specified by:
setInvalidValuein interfaceGraphQLInvalidFieldError- Parameters:
invalidValue- value to be set
-
setAllowedValues
Description copied from interface:GraphQLInvalidFieldErrorFixed set of allowed values for the field, if any.
- Specified by:
setAllowedValuesin interfaceGraphQLInvalidFieldError- Parameters:
allowedValues- values to be set
-
setAllowedValues
Description copied from interface:GraphQLInvalidFieldErrorFixed set of allowed values for the field, if any.
- Specified by:
setAllowedValuesin interfaceGraphQLInvalidFieldError- Parameters:
allowedValues- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLInvalidFieldError
-