Class GraphQLInvalidItemShippingDetailsErrorImpl

java.lang.Object
com.commercetools.api.models.error.GraphQLInvalidItemShippingDetailsErrorImpl
All Implemented Interfaces:
GraphQLErrorObject, GraphQLInvalidItemShippingDetailsError, io.vrap.rmf.base.client.ModelBase

public class GraphQLInvalidItemShippingDetailsErrorImpl extends Object implements GraphQLInvalidItemShippingDetailsError, io.vrap.rmf.base.client.ModelBase

Returned when Line Item or Custom Line Item quantities set under ItemShippingDetails do not match the sum of the quantities in their respective shipping details.

When a Cart is frozen, the error can be returned as a failed response to all update actions on Carts and My Carts.

The error is also returned as a failed response to: