Class GraphQLInvalidJsonInputErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLInvalidJsonInputErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLInvalidJsonInputError,io.vrap.rmf.base.client.ModelBase
public class GraphQLInvalidJsonInputErrorImpl
extends Object
implements GraphQLInvalidJsonInputError, io.vrap.rmf.base.client.ModelBase
Returned when an invalid JSON input has been sent. Either the JSON is syntactically incorrect or does not conform to the expected shape (for example is missing a required field).
The client application should validate the input according to the constraints described in the error message before sending the request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLInvalidJsonInputError
INVALID_JSON_INPUT -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Further explanation about why the JSON is invalid.inthashCode()voidsetDetailedErrorMessage(String detailedErrorMessage) Further explanation about why the JSON is invalid.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLInvalidJsonInputError
withGraphQLInvalidJsonInputErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLInvalidJsonInputErrorImpl
public GraphQLInvalidJsonInputErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLInvalidJsonInputError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getDetailedErrorMessage
Further explanation about why the JSON is invalid.
- Specified by:
getDetailedErrorMessagein interfaceGraphQLInvalidJsonInputError- Returns:
- detailedErrorMessage
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setDetailedErrorMessage
Description copied from interface:GraphQLInvalidJsonInputErrorFurther explanation about why the JSON is invalid.
- Specified by:
setDetailedErrorMessagein interfaceGraphQLInvalidJsonInputError- Parameters:
detailedErrorMessage- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLInvalidJsonInputError
-