Class GraphQLLanguageUsedInStoresErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLLanguageUsedInStoresErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLLanguageUsedInStoresError,io.vrap.rmf.base.client.ModelBase
public class GraphQLLanguageUsedInStoresErrorImpl
extends Object
implements GraphQLLanguageUsedInStoresError, io.vrap.rmf.base.client.ModelBase
Returned when a language cannot be removed from a Project as it is being used by a Store.
The error is returned as a failed response to the Change Languages update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLLanguageUsedInStoresError
LANGUAGE_USED_IN_STORES -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLLanguageUsedInStoresError
withGraphQLLanguageUsedInStoresErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLLanguageUsedInStoresErrorImpl
public GraphQLLanguageUsedInStoresErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLLanguageUsedInStoresError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLLanguageUsedInStoresError
-