Class GraphQLLockedFieldErrorImpl

java.lang.Object
com.commercetools.api.models.error.GraphQLLockedFieldErrorImpl
All Implemented Interfaces:
GraphQLErrorObject, GraphQLLockedFieldError, io.vrap.rmf.base.client.ModelBase

public class GraphQLLockedFieldErrorImpl extends Object implements GraphQLLockedFieldError, io.vrap.rmf.base.client.ModelBase

Returned when two Customers are simultaneously created or updated with the same email address.

To confirm if the operation was successful, repeat the request.