Class GraphQLMatchingPriceNotFoundErrorImpl

java.lang.Object
com.commercetools.api.models.error.GraphQLMatchingPriceNotFoundErrorImpl
All Implemented Interfaces:
GraphQLErrorObject, GraphQLMatchingPriceNotFoundError, io.vrap.rmf.base.client.ModelBase

public class GraphQLMatchingPriceNotFoundErrorImpl extends Object implements GraphQLMatchingPriceNotFoundError, io.vrap.rmf.base.client.ModelBase

Returned when the Product Variant does not have a Price according to the Product priceMode value for a selected currency, country, Customer Group, or Channel.

The error can be returned as a failed response to all update actions on Carts and Staged Orders.

The error is also returned as a failed response to: