Class GraphQLMaxDiscountGroupsReachedErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLMaxDiscountGroupsReachedErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLMaxDiscountGroupsReachedError,io.vrap.rmf.base.client.ModelBase
public class GraphQLMaxDiscountGroupsReachedErrorImpl
extends Object
implements GraphQLMaxDiscountGroupsReachedError, io.vrap.rmf.base.client.ModelBase
Returned when a Discount Group cannot be created or activated as the limit for active Discount Groups has been reached.
The error is returned as a failed response to:
- Create DiscountGroup request
- Set IsActive update action
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLMaxDiscountGroupsReachedError
MAX_DISCOUNT_GROUPS_REACHED -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLMaxDiscountGroupsReachedError
withGraphQLMaxDiscountGroupsReachedErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLMaxDiscountGroupsReachedErrorImpl
public GraphQLMaxDiscountGroupsReachedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLMaxDiscountGroupsReachedError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLMaxDiscountGroupsReachedError
-