Class GraphQLMaxResourceLimitExceededErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLMaxResourceLimitExceededErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLMaxResourceLimitExceededError,io.vrap.rmf.base.client.ModelBase
public class GraphQLMaxResourceLimitExceededErrorImpl
extends Object
implements GraphQLMaxResourceLimitExceededError, io.vrap.rmf.base.client.ModelBase
Returned when a resource type cannot be created as it has reached its limits.
The limits must be adjusted for this resource before sending the request again.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLMaxResourceLimitExceededError
MAX_RESOURCE_LIMIT_EXCEEDED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Resource type that reached its maximum limit of configured elements (for example, 100 Zones per Project).inthashCode()voidsetExceededResource(ReferenceTypeId exceededResource) Resource type that reached its maximum limit of configured elements (for example, 100 Zones per Project).voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLMaxResourceLimitExceededError
withGraphQLMaxResourceLimitExceededErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLMaxResourceLimitExceededErrorImpl
public GraphQLMaxResourceLimitExceededErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLMaxResourceLimitExceededError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getExceededResource
Resource type that reached its maximum limit of configured elements (for example, 100 Zones per Project).
- Specified by:
getExceededResourcein interfaceGraphQLMaxResourceLimitExceededError- Returns:
- exceededResource
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setExceededResource
Description copied from interface:GraphQLMaxResourceLimitExceededErrorResource type that reached its maximum limit of configured elements (for example, 100 Zones per Project).
- Specified by:
setExceededResourcein interfaceGraphQLMaxResourceLimitExceededError- Parameters:
exceededResource- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLMaxResourceLimitExceededError
-