Class GraphQLMaxStoreReferencesReachedErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLMaxStoreReferencesReachedErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLMaxStoreReferencesReachedError,io.vrap.rmf.base.client.ModelBase
public class GraphQLMaxStoreReferencesReachedErrorImpl
extends Object
implements GraphQLMaxStoreReferencesReachedError, io.vrap.rmf.base.client.ModelBase
Returned when a Store cannot be added to a Cart Discount as the limit for Stores configured for a Cart Discount has been reached.
The error is returned as a failed response to:
- Create CartDiscount and Create CartDiscount in Store requests
- Add Store and Set Store update actions
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLMaxStoreReferencesReachedError
MAX_STORE_REFERENCES_REACHED -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLMaxStoreReferencesReachedError
withGraphQLMaxStoreReferencesReachedErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLMaxStoreReferencesReachedErrorImpl
public GraphQLMaxStoreReferencesReachedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLMaxStoreReferencesReachedError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLMaxStoreReferencesReachedError
-