Class GraphQLMissingRoleOnChannelErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLMissingRoleOnChannelErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLMissingRoleOnChannelError,io.vrap.rmf.base.client.ModelBase
public class GraphQLMissingRoleOnChannelErrorImpl
extends Object
implements GraphQLMissingRoleOnChannelError, io.vrap.rmf.base.client.ModelBase
Returned when one of the following states occur:
- Channel is added or set on a Store with missing Channel
roles. - Standalone Price references a Channel that does not contain the
ProductDistributionrole.
The error is returned as a failed response to:
- Add Distribution Channel, Set Distribution Channel, Add Supply Channel, and Set Supply Channel update actions.
- Create StandalonePrice request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLMissingRoleOnChannelError
MISSING_ROLE_ON_CHANNEL -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanResourceIdentifier to a given Channel.getCode()One of the error codes that is listed on the Errors page.ProductDistributionfor Product Distribution Channels allowed for the Store.inthashCode()voidsetChannel(ChannelResourceIdentifier channel) ResourceIdentifier to a given Channel.voidsetMissingRole(ChannelRoleEnum missingRole) ProductDistributionfor Product Distribution Channels allowed for the Store.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLMissingRoleOnChannelError
withGraphQLMissingRoleOnChannelErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLMissingRoleOnChannelErrorImpl
public GraphQLMissingRoleOnChannelErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLMissingRoleOnChannelError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getChannel
ResourceIdentifier to a given Channel.
- Specified by:
getChannelin interfaceGraphQLMissingRoleOnChannelError- Returns:
- channel
-
getMissingRole
ProductDistributionfor Product Distribution Channels allowed for the Store. Also required for Standalone Prices.InventorySupplyfor Inventory Supply Channels allowed for the Store.
- Specified by:
getMissingRolein interfaceGraphQLMissingRoleOnChannelError- Returns:
- missingRole
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setChannel
Description copied from interface:GraphQLMissingRoleOnChannelErrorResourceIdentifier to a given Channel.
- Specified by:
setChannelin interfaceGraphQLMissingRoleOnChannelError- Parameters:
channel- value to be set
-
setMissingRole
Description copied from interface:GraphQLMissingRoleOnChannelErrorProductDistributionfor Product Distribution Channels allowed for the Store. Also required for Standalone Prices.InventorySupplyfor Inventory Supply Channels allowed for the Store.
- Specified by:
setMissingRolein interfaceGraphQLMissingRoleOnChannelError- Parameters:
missingRole- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLMissingRoleOnChannelError
-