Class GraphQLMissingTaxRateForCountryErrorImpl

java.lang.Object
com.commercetools.api.models.error.GraphQLMissingTaxRateForCountryErrorImpl
All Implemented Interfaces:
GraphQLErrorObject, GraphQLMissingTaxRateForCountryError, io.vrap.rmf.base.client.ModelBase

public class GraphQLMissingTaxRateForCountryErrorImpl extends Object implements GraphQLMissingTaxRateForCountryError, io.vrap.rmf.base.client.ModelBase

Returned when the Tax Category of at least one of the lineItems, customLineItems, or shippingInfo in the Cart is missing the TaxRate matching country and state given in the shippingAddress of that Cart.

The error can be returned as a failed response to all update actions on Carts and Staged Orders.

The error is also returned as a failed response to: