Class GraphQLNoMatchingProductDiscountFoundErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLNoMatchingProductDiscountFoundErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLNoMatchingProductDiscountFoundError,io.vrap.rmf.base.client.ModelBase
public class GraphQLNoMatchingProductDiscountFoundErrorImpl
extends Object
implements GraphQLNoMatchingProductDiscountFoundError, io.vrap.rmf.base.client.ModelBase
Returned when a Product Discount could not be found that could be applied to the Price of a Product Variant.
The error is returned as a failed response to the Get Matching ProductDiscount request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLNoMatchingProductDiscountFoundError
NO_MATCHING_PRODUCT_DISCOUNT_FOUND -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLNoMatchingProductDiscountFoundError
withGraphQLNoMatchingProductDiscountFoundErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLNoMatchingProductDiscountFoundErrorImpl
public GraphQLNoMatchingProductDiscountFoundErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLNoMatchingProductDiscountFoundError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLNoMatchingProductDiscountFoundError
-