Class GraphQLObjectNotFoundErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLObjectNotFoundErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLObjectNotFoundError,io.vrap.rmf.base.client.ModelBase
public class GraphQLObjectNotFoundErrorImpl
extends Object
implements GraphQLObjectNotFoundError, io.vrap.rmf.base.client.ModelBase
Returned if the requested resource was not found or the Product Search index is inactive.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLObjectNotFoundError
OBJECT_NOT_FOUND -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLObjectNotFoundError
withGraphQLObjectNotFoundErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLObjectNotFoundErrorImpl
public GraphQLObjectNotFoundErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLObjectNotFoundError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLObjectNotFoundError
-