Class GraphQLOutOfStockErrorImpl

java.lang.Object
com.commercetools.api.models.error.GraphQLOutOfStockErrorImpl
All Implemented Interfaces:
GraphQLErrorObject, GraphQLOutOfStockError, io.vrap.rmf.base.client.ModelBase

public class GraphQLOutOfStockErrorImpl extends Object implements GraphQLOutOfStockError, io.vrap.rmf.base.client.ModelBase

Returned when some of the Line Items are out of stock at the time of placing an Order.

The error is returned as a failed response to: