Class GraphQLOverCapacityErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLOverCapacityErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLOverCapacityError,io.vrap.rmf.base.client.ModelBase
public class GraphQLOverCapacityErrorImpl
extends Object
implements GraphQLOverCapacityError, io.vrap.rmf.base.client.ModelBase
Returned when the service is having trouble handling the load.
The client application should retry the request with exponential backoff up to a point where further delay is unacceptable.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLOverCapacityError
OVER_CAPACITY -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLOverCapacityError
withGraphQLOverCapacityErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLOverCapacityErrorImpl
public GraphQLOverCapacityErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLOverCapacityError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLOverCapacityError
-