Class GraphQLOverlappingStandalonePriceValidityErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLOverlappingStandalonePriceValidityError,io.vrap.rmf.base.client.ModelBase
Returned when a given Price validity period conflicts with an existing one. Every Standalone Price associated with the same SKU and with the same combination of currency, country, Customer Group, and Channel, must have non-overlapping validity periods (validFrom and validUntil).
The error is returned as a failed response to the Create StandalonePrice request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLOverlappingStandalonePriceValidityError
OVERLAPPING_STANDALONE_PRICE_VALIDITY -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanChannel for which the Standalone Price is valid.getCode()One of the error codes that is listed on the Errors page.Reference to the conflicting Standalone Price.Date and time (UTC) from which the conflicting Standalone Price is valid.Date and time (UTC) until which the conflicting Standalone Price is valid.Country code of the geographic location.Currency code of the country.CustomerGroup for which the Standalone Price is valid.getSku()SKU of the ProductVariant to which the conflicting Standalone Price is associated.Date and time (UTC) from which the Standalone Price is valid.Date and time (UTC) until which the Standalone Price is valid.inthashCode()voidsetChannel(ChannelResourceIdentifier channel) Channel for which the Standalone Price is valid.voidsetConflictingStandalonePrice(StandalonePriceReference conflictingStandalonePrice) Reference to the conflicting Standalone Price.voidsetConflictingValidFrom(ZonedDateTime conflictingValidFrom) Date and time (UTC) from which the conflicting Standalone Price is valid.voidsetConflictingValidUntil(ZonedDateTime conflictingValidUntil) Date and time (UTC) until which the conflicting Standalone Price is valid.voidsetCountry(String country) Country code of the geographic location.voidsetCurrency(String currency) Currency code of the country.voidsetCustomerGroup(CustomerGroupResourceIdentifier customerGroup) CustomerGroup for which the Standalone Price is valid.voidSKU of the ProductVariant to which the conflicting Standalone Price is associated.voidsetValidFrom(ZonedDateTime validFrom) Date and time (UTC) from which the Standalone Price is valid.voidsetValidUntil(ZonedDateTime validUntil) Date and time (UTC) until which the Standalone Price is valid.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLOverlappingStandalonePriceValidityError
withGraphQLOverlappingStandalonePriceValidityErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLOverlappingStandalonePriceValidityErrorImpl
public GraphQLOverlappingStandalonePriceValidityErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLOverlappingStandalonePriceValidityError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getConflictingStandalonePrice
Reference to the conflicting Standalone Price.
- Specified by:
getConflictingStandalonePricein interfaceGraphQLOverlappingStandalonePriceValidityError- Returns:
- conflictingStandalonePrice
-
getSku
SKU of the ProductVariant to which the conflicting Standalone Price is associated.
- Specified by:
getSkuin interfaceGraphQLOverlappingStandalonePriceValidityError- Returns:
- sku
-
getCurrency
Currency code of the country.
- Specified by:
getCurrencyin interfaceGraphQLOverlappingStandalonePriceValidityError- Returns:
- currency
-
getCountry
Country code of the geographic location.
- Specified by:
getCountryin interfaceGraphQLOverlappingStandalonePriceValidityError- Returns:
- country
-
getCustomerGroup
CustomerGroup for which the Standalone Price is valid.
- Specified by:
getCustomerGroupin interfaceGraphQLOverlappingStandalonePriceValidityError- Returns:
- customerGroup
-
getChannel
Channel for which the Standalone Price is valid.
- Specified by:
getChannelin interfaceGraphQLOverlappingStandalonePriceValidityError- Returns:
- channel
-
getValidFrom
Date and time (UTC) from which the Standalone Price is valid.
- Specified by:
getValidFromin interfaceGraphQLOverlappingStandalonePriceValidityError- Returns:
- validFrom
-
getValidUntil
Date and time (UTC) until which the Standalone Price is valid.
- Specified by:
getValidUntilin interfaceGraphQLOverlappingStandalonePriceValidityError- Returns:
- validUntil
-
getConflictingValidFrom
Date and time (UTC) from which the conflicting Standalone Price is valid.
- Specified by:
getConflictingValidFromin interfaceGraphQLOverlappingStandalonePriceValidityError- Returns:
- conflictingValidFrom
-
getConflictingValidUntil
Date and time (UTC) until which the conflicting Standalone Price is valid.
- Specified by:
getConflictingValidUntilin interfaceGraphQLOverlappingStandalonePriceValidityError- Returns:
- conflictingValidUntil
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setConflictingStandalonePrice
Description copied from interface:GraphQLOverlappingStandalonePriceValidityErrorReference to the conflicting Standalone Price.
- Specified by:
setConflictingStandalonePricein interfaceGraphQLOverlappingStandalonePriceValidityError- Parameters:
conflictingStandalonePrice- value to be set
-
setSku
Description copied from interface:GraphQLOverlappingStandalonePriceValidityErrorSKU of the ProductVariant to which the conflicting Standalone Price is associated.
- Specified by:
setSkuin interfaceGraphQLOverlappingStandalonePriceValidityError- Parameters:
sku- value to be set
-
setCurrency
Description copied from interface:GraphQLOverlappingStandalonePriceValidityErrorCurrency code of the country.
- Specified by:
setCurrencyin interfaceGraphQLOverlappingStandalonePriceValidityError- Parameters:
currency- value to be set
-
setCountry
Description copied from interface:GraphQLOverlappingStandalonePriceValidityErrorCountry code of the geographic location.
- Specified by:
setCountryin interfaceGraphQLOverlappingStandalonePriceValidityError- Parameters:
country- value to be set
-
setCustomerGroup
Description copied from interface:GraphQLOverlappingStandalonePriceValidityErrorCustomerGroup for which the Standalone Price is valid.
- Specified by:
setCustomerGroupin interfaceGraphQLOverlappingStandalonePriceValidityError- Parameters:
customerGroup- value to be set
-
setChannel
Description copied from interface:GraphQLOverlappingStandalonePriceValidityErrorChannel for which the Standalone Price is valid.
- Specified by:
setChannelin interfaceGraphQLOverlappingStandalonePriceValidityError- Parameters:
channel- value to be set
-
setValidFrom
Description copied from interface:GraphQLOverlappingStandalonePriceValidityErrorDate and time (UTC) from which the Standalone Price is valid.
- Specified by:
setValidFromin interfaceGraphQLOverlappingStandalonePriceValidityError- Parameters:
validFrom- value to be set
-
setValidUntil
Description copied from interface:GraphQLOverlappingStandalonePriceValidityErrorDate and time (UTC) until which the Standalone Price is valid.
- Specified by:
setValidUntilin interfaceGraphQLOverlappingStandalonePriceValidityError- Parameters:
validUntil- value to be set
-
setConflictingValidFrom
Description copied from interface:GraphQLOverlappingStandalonePriceValidityErrorDate and time (UTC) from which the conflicting Standalone Price is valid.
- Specified by:
setConflictingValidFromin interfaceGraphQLOverlappingStandalonePriceValidityError- Parameters:
conflictingValidFrom- value to be set
-
setConflictingValidUntil
Description copied from interface:GraphQLOverlappingStandalonePriceValidityErrorDate and time (UTC) until which the conflicting Standalone Price is valid.
- Specified by:
setConflictingValidUntilin interfaceGraphQLOverlappingStandalonePriceValidityError- Parameters:
conflictingValidUntil- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLOverlappingStandalonePriceValidityError
-