Class GraphQLPriceChangedErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLPriceChangedErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLPriceChangedError,io.vrap.rmf.base.client.ModelBase
public class GraphQLPriceChangedErrorImpl
extends Object
implements GraphQLPriceChangedError, io.vrap.rmf.base.client.ModelBase
Returned when the Price or Tax Rate of some Line Items or Shipping Rate of some Shipping Methods changed since they were last added to the Cart.
When a Cart is frozen, the error can be returned as a failed response to all update actions on Carts and My Carts.
The error is also returned as a failed response to:
- Create Order from Cart and Create Order in Store from Cart requests on Orders.
- Create Order from Cart and Create Order in Store from Cart requests on My Orders.
- Create Order from Cart in BusinessUnit request on Associate Orders.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLPriceChangedError
PRICE_CHANGED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Unique identifiers of the Line Items for which the Price or TaxRate has changed.trueif the ShippingRate has changed.inthashCode()voidsetLineItems(String... lineItems) Unique identifiers of the Line Items for which the Price or TaxRate has changed.voidsetLineItems(List<String> lineItems) Unique identifiers of the Line Items for which the Price or TaxRate has changed.voidsetShipping(Boolean shipping) trueif the ShippingRate has changed.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLPriceChangedError
withGraphQLPriceChangedErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLPriceChangedErrorImpl
public GraphQLPriceChangedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLPriceChangedError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getLineItems
Unique identifiers of the Line Items for which the Price or TaxRate has changed.
- Specified by:
getLineItemsin interfaceGraphQLPriceChangedError- Returns:
- lineItems
-
getShipping
trueif the ShippingRate has changed.- Specified by:
getShippingin interfaceGraphQLPriceChangedError- Returns:
- shipping
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setLineItems
Description copied from interface:GraphQLPriceChangedErrorUnique identifiers of the Line Items for which the Price or TaxRate has changed.
- Specified by:
setLineItemsin interfaceGraphQLPriceChangedError- Parameters:
lineItems- values to be set
-
setLineItems
Description copied from interface:GraphQLPriceChangedErrorUnique identifiers of the Line Items for which the Price or TaxRate has changed.
- Specified by:
setLineItemsin interfaceGraphQLPriceChangedError- Parameters:
lineItems- values to be set
-
setShipping
Description copied from interface:GraphQLPriceChangedErrortrueif the ShippingRate has changed.- Specified by:
setShippingin interfaceGraphQLPriceChangedError- Parameters:
shipping- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLPriceChangedError
-