Class GraphQLProductAssignmentMissingErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLProductAssignmentMissingErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLProductAssignmentMissingError,io.vrap.rmf.base.client.ModelBase
public class GraphQLProductAssignmentMissingErrorImpl
extends Object
implements GraphQLProductAssignmentMissingError, io.vrap.rmf.base.client.ModelBase
Returned when a Product is not assigned to the Product Selection. The error is returned as a failed response either to the Set Variant Selection or to the Set Variant Exclusion update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLProductAssignmentMissingError
PRODUCT_ASSIGNMENT_MISSING -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.inthashCode()voidsetProduct(ProductReference product) voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLProductAssignmentMissingError
withGraphQLProductAssignmentMissingErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLProductAssignmentMissingErrorImpl
public GraphQLProductAssignmentMissingErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLProductAssignmentMissingError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getProduct
- Specified by:
getProductin interfaceGraphQLProductAssignmentMissingError- Returns:
- product
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setProduct
Description copied from interface:GraphQLProductAssignmentMissingError- Specified by:
setProductin interfaceGraphQLProductAssignmentMissingError- Parameters:
product- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLProductAssignmentMissingError
-