Class GraphQLProductPresentWithDifferentVariantSelectionErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLProductPresentWithDifferentVariantSelectionErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLProductPresentWithDifferentVariantSelectionError,io.vrap.rmf.base.client.ModelBase
public class GraphQLProductPresentWithDifferentVariantSelectionErrorImpl
extends Object
implements GraphQLProductPresentWithDifferentVariantSelectionError, io.vrap.rmf.base.client.ModelBase
Returned when a Product is already assigned to a Product Selection, but the Product Selection has either a different Product Variant Selection or a different Product Variant Exclusion.
The error is returned as a failed response either to the Add Product or to the Exclude Product update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLProductPresentWithDifferentVariantSelectionError
PRODUCT_PRESENT_WITH_DIFFERENT_VARIANT_SELECTION -
Constructor Summary
ConstructorsConstructorDescriptioncreate empty instance -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Existing Product Variant Selection or Exclusion for the Product in the Product Selection.inthashCode()voidsetExistingVariantSelection(ProductVariantSelection existingVariantSelection) Existing Product Variant Selection or Exclusion for the Product in the Product Selection.voidsetProduct(ProductReference product) voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLProductPresentWithDifferentVariantSelectionError
withGraphQLProductPresentWithDifferentVariantSelectionErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLProductPresentWithDifferentVariantSelectionErrorImpl
public GraphQLProductPresentWithDifferentVariantSelectionErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLProductPresentWithDifferentVariantSelectionError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getProduct
- Specified by:
getProductin interfaceGraphQLProductPresentWithDifferentVariantSelectionError- Returns:
- product
-
getExistingVariantSelection
Existing Product Variant Selection or Exclusion for the Product in the Product Selection.
- Specified by:
getExistingVariantSelectionin interfaceGraphQLProductPresentWithDifferentVariantSelectionError- Returns:
- existingVariantSelection
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setProduct
Description copied from interface:GraphQLProductPresentWithDifferentVariantSelectionError- Specified by:
setProductin interfaceGraphQLProductPresentWithDifferentVariantSelectionError- Parameters:
product- value to be set
-
setExistingVariantSelection
Description copied from interface:GraphQLProductPresentWithDifferentVariantSelectionErrorExisting Product Variant Selection or Exclusion for the Product in the Product Selection.
- Specified by:
setExistingVariantSelectionin interfaceGraphQLProductPresentWithDifferentVariantSelectionError- Parameters:
existingVariantSelection- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLProductPresentWithDifferentVariantSelectionError
-