Class GraphQLProjectNotConfiguredForLanguagesErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLProjectNotConfiguredForLanguagesErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLProjectNotConfiguredForLanguagesError,io.vrap.rmf.base.client.ModelBase
public class GraphQLProjectNotConfiguredForLanguagesErrorImpl
extends Object
implements GraphQLProjectNotConfiguredForLanguagesError, io.vrap.rmf.base.client.ModelBase
Returned when the languages set for a Store are not supported by the Project.
The error is returned as a failed response to the Set Languages update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLProjectNotConfiguredForLanguagesError
PROJECT_NOT_CONFIGURED_FOR_LANGUAGES -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Languages configured for the Store.inthashCode()voidsetLanguages(String... languages) Languages configured for the Store.voidsetLanguages(List<String> languages) Languages configured for the Store.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLProjectNotConfiguredForLanguagesError
withGraphQLProjectNotConfiguredForLanguagesErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLProjectNotConfiguredForLanguagesErrorImpl
public GraphQLProjectNotConfiguredForLanguagesErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLProjectNotConfiguredForLanguagesError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getLanguages
Languages configured for the Store.
- Specified by:
getLanguagesin interfaceGraphQLProjectNotConfiguredForLanguagesError- Returns:
- languages
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setLanguages
Description copied from interface:GraphQLProjectNotConfiguredForLanguagesErrorLanguages configured for the Store.
- Specified by:
setLanguagesin interfaceGraphQLProjectNotConfiguredForLanguagesError- Parameters:
languages- values to be set
-
setLanguages
Description copied from interface:GraphQLProjectNotConfiguredForLanguagesErrorLanguages configured for the Store.
- Specified by:
setLanguagesin interfaceGraphQLProjectNotConfiguredForLanguagesError- Parameters:
languages- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLProjectNotConfiguredForLanguagesError
-