Class GraphQLRecurringOrderFailureErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLRecurringOrderFailureErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLRecurringOrderFailureError,io.vrap.rmf.base.client.ModelBase
public class GraphQLRecurringOrderFailureErrorImpl
extends Object
implements GraphQLRecurringOrderFailureError, io.vrap.rmf.base.client.ModelBase
Returned when a subsequent Order for a Recurring Order could not be processed.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLRecurringOrderFailureError
RECURRING_ORDER_FAILURE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Details about the error's cause and the entities involved.inthashCode()voidsetDetails(Object details) Details about the error's cause and the entities involved.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLRecurringOrderFailureError
withGraphQLRecurringOrderFailureErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLRecurringOrderFailureErrorImpl
public GraphQLRecurringOrderFailureErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLRecurringOrderFailureError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getDetails
Details about the error's cause and the entities involved.
- Specified by:
getDetailsin interfaceGraphQLRecurringOrderFailureError- Returns:
- details
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setDetails
Description copied from interface:GraphQLRecurringOrderFailureErrorDetails about the error's cause and the entities involved.
- Specified by:
setDetailsin interfaceGraphQLRecurringOrderFailureError- Parameters:
details- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLRecurringOrderFailureError
-