Class GraphQLReferenceExistsErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLReferenceExistsErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLReferenceExistsError,io.vrap.rmf.base.client.ModelBase
public class GraphQLReferenceExistsErrorImpl
extends Object
implements GraphQLReferenceExistsError, io.vrap.rmf.base.client.ModelBase
Returned when a resource cannot be deleted because it is being referenced by another resource.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLReferenceExistsError
REFERENCE_EXISTS -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Type of referenced resource.inthashCode()voidsetReferencedBy(ReferenceTypeId referencedBy) Type of referenced resource.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLReferenceExistsError
withGraphQLReferenceExistsErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLReferenceExistsErrorImpl
public GraphQLReferenceExistsErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLReferenceExistsError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getReferencedBy
Type of referenced resource.
- Specified by:
getReferencedByin interfaceGraphQLReferenceExistsError- Returns:
- referencedBy
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setReferencedBy
Description copied from interface:GraphQLReferenceExistsErrorType of referenced resource.
- Specified by:
setReferencedByin interfaceGraphQLReferenceExistsError- Parameters:
referencedBy- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLReferenceExistsError
-