Class GraphQLRequiredFieldErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLRequiredFieldErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLRequiredFieldError,io.vrap.rmf.base.client.ModelBase
public class GraphQLRequiredFieldErrorImpl
extends Object
implements GraphQLRequiredFieldError, io.vrap.rmf.base.client.ModelBase
Returned when a value is not defined for a required field.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLRequiredFieldError
REQUIRED_FIELD -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.getField()Name of the field missing the value.inthashCode()voidName of the field missing the value.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLRequiredFieldError
withGraphQLRequiredFieldErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLRequiredFieldErrorImpl
public GraphQLRequiredFieldErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLRequiredFieldError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getField
Name of the field missing the value.
- Specified by:
getFieldin interfaceGraphQLRequiredFieldError- Returns:
- field
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setField
Description copied from interface:GraphQLRequiredFieldErrorName of the field missing the value.
- Specified by:
setFieldin interfaceGraphQLRequiredFieldError- Parameters:
field- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLRequiredFieldError
-