Class GraphQLSearchDeactivatedErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLSearchDeactivatedErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLSearchDeactivatedError,io.vrap.rmf.base.client.ModelBase
public class GraphQLSearchDeactivatedErrorImpl
extends Object
implements GraphQLSearchDeactivatedError, io.vrap.rmf.base.client.ModelBase
Returned when the indexing of Product information is deactivated in a Project.
To activate indexing, call Change Product Search Indexing Enabled and set enabled to true.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLSearchDeactivatedError
SEARCH_DEACTIVATED -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLSearchDeactivatedError
withGraphQLSearchDeactivatedErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLSearchDeactivatedErrorImpl
public GraphQLSearchDeactivatedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLSearchDeactivatedError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLSearchDeactivatedError
-