Class GraphQLSearchExecutionFailureErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLSearchExecutionFailureErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLSearchExecutionFailureError,io.vrap.rmf.base.client.ModelBase
public class GraphQLSearchExecutionFailureErrorImpl
extends Object
implements GraphQLSearchExecutionFailureError, io.vrap.rmf.base.client.ModelBase
Returned when a search query could not be completed due to an unexpected failure.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLSearchExecutionFailureError
SEARCH_EXECUTION_FAILURE -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLSearchExecutionFailureError
withGraphQLSearchExecutionFailureErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLSearchExecutionFailureErrorImpl
public GraphQLSearchExecutionFailureErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLSearchExecutionFailureError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLSearchExecutionFailureError
-