Interface GraphQLSearchIndexingInProgressError

All Superinterfaces:
GraphQLErrorObject
All Known Implementing Classes:
GraphQLSearchIndexingInProgressErrorImpl

public interface GraphQLSearchIndexingInProgressError extends GraphQLErrorObject

Returned when the indexing of Product information is still in progress for Projects that have indexing activated.


Example to create an instance using the builder pattern

     GraphQLSearchIndexingInProgressError graphQLSearchIndexingInProgressError = GraphQLSearchIndexingInProgressError.builder()
             .build()