Interface GraphQLSearchNotReadyError

All Superinterfaces:
GraphQLErrorObject
All Known Implementing Classes:
GraphQLSearchNotReadyErrorImpl

public interface GraphQLSearchNotReadyError extends GraphQLErrorObject

Returned if the requested search service is not ready. The search might be deactivated or indexing is in progress.


Example to create an instance using the builder pattern

     GraphQLSearchNotReadyError graphQLSearchNotReadyError = GraphQLSearchNotReadyError.builder()
             .build()