Class GraphQLSearchNotReadyErrorImpl

java.lang.Object
com.commercetools.api.models.error.GraphQLSearchNotReadyErrorImpl
All Implemented Interfaces:
GraphQLErrorObject, GraphQLSearchNotReadyError, io.vrap.rmf.base.client.ModelBase

public class GraphQLSearchNotReadyErrorImpl extends Object implements GraphQLSearchNotReadyError, io.vrap.rmf.base.client.ModelBase

Returned if the requested search service is not ready. The search might be deactivated or indexing is in progress.