Class GraphQLShippingMethodDoesNotMatchCartErrorImpl

java.lang.Object
com.commercetools.api.models.error.GraphQLShippingMethodDoesNotMatchCartErrorImpl
All Implemented Interfaces:
GraphQLErrorObject, GraphQLShippingMethodDoesNotMatchCartError, io.vrap.rmf.base.client.ModelBase

public class GraphQLShippingMethodDoesNotMatchCartErrorImpl extends Object implements GraphQLShippingMethodDoesNotMatchCartError, io.vrap.rmf.base.client.ModelBase

Returned when the Cart contains a ShippingMethod that is not allowed for the Cart. In this case, the ShippingMethodState value is DoesNotMatchCart.

When a Cart is frozen, the error can be returned as a failed response to all update actions on Carts and My Carts.

The error is also returned as a failed response to: