Class GraphQLStoreCartDiscountsLimitReachedErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLStoreCartDiscountsLimitReachedErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLStoreCartDiscountsLimitReachedError,io.vrap.rmf.base.client.ModelBase
public class GraphQLStoreCartDiscountsLimitReachedErrorImpl
extends Object
implements GraphQLStoreCartDiscountsLimitReachedError, io.vrap.rmf.base.client.ModelBase
Returned when a Cart Discount cannot be created or assigned to a Store as the limit for active Cart Discounts in a Store has been reached for one or more Stores in the request.
The error is returned as a failed response to:
- Create CartDiscount and Create CartDiscount in Store requests
- Add Store and Set Store update actions
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLStoreCartDiscountsLimitReachedError
STORE_CART_DISCOUNTS_LIMIT_REACHED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Stores for which the limit for active Cart Discounts that can exist has been reached.inthashCode()voidsetStores(StoreKeyReference... stores) Stores for which the limit for active Cart Discounts that can exist has been reached.voidsetStores(List<StoreKeyReference> stores) Stores for which the limit for active Cart Discounts that can exist has been reached.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLStoreCartDiscountsLimitReachedError
withGraphQLStoreCartDiscountsLimitReachedErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLStoreCartDiscountsLimitReachedErrorImpl
public GraphQLStoreCartDiscountsLimitReachedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLStoreCartDiscountsLimitReachedError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getStores
Stores for which the limit for active Cart Discounts that can exist has been reached.
- Specified by:
getStoresin interfaceGraphQLStoreCartDiscountsLimitReachedError- Returns:
- stores
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setStores
Description copied from interface:GraphQLStoreCartDiscountsLimitReachedErrorStores for which the limit for active Cart Discounts that can exist has been reached.
- Specified by:
setStoresin interfaceGraphQLStoreCartDiscountsLimitReachedError- Parameters:
stores- values to be set
-
setStores
Description copied from interface:GraphQLStoreCartDiscountsLimitReachedErrorStores for which the limit for active Cart Discounts that can exist has been reached.
- Specified by:
setStoresin interfaceGraphQLStoreCartDiscountsLimitReachedError- Parameters:
stores- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLStoreCartDiscountsLimitReachedError
-