Class GraphQLSyntaxErrorErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLSyntaxErrorErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLSyntaxErrorError,io.vrap.rmf.base.client.ModelBase
public class GraphQLSyntaxErrorErrorImpl
extends Object
implements GraphQLSyntaxErrorError, io.vrap.rmf.base.client.ModelBase
Returned when a Discount predicate, API Extension predicate, or search query does not have the correct syntax.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLSyntaxErrorError
SYNTAX_ERROR -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLSyntaxErrorError
withGraphQLSyntaxErrorErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLSyntaxErrorErrorImpl
public GraphQLSyntaxErrorErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLSyntaxErrorError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLSyntaxErrorError
-