Class GraphQLValidityLockConflictErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLValidityLockConflictError,io.vrap.rmf.base.client.ModelBase
Returned when a modification is already in progress for the combination of SKU and price scope fields (but potentially different validity period) for a Standalone Price. Retry the same request after 300 ms.
The error is returned as a failed response to:
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLValidityLockConflictError
VALIDITY_LOCK_CONFLICT -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanChannel for which the Standalone Price is valid.getCode()One of the error codes that is listed on the Errors page.Country code of the geographic location.Currency code of the Standalone Price.CustomerGroup for which the Standalone Price is valid.RecurrencePolicy for which the Standalone Price is valid.getSku()SKU for which the modification conflict occurred.inthashCode()voidsetChannel(ChannelResourceIdentifier channel) Channel for which the Standalone Price is valid.voidsetCountry(String country) Country code of the geographic location.voidsetCurrency(String currency) Currency code of the Standalone Price.voidsetCustomerGroup(CustomerGroupResourceIdentifier customerGroup) CustomerGroup for which the Standalone Price is valid.voidsetRecurrencePolicy(RecurrencePolicyResourceIdentifier recurrencePolicy) RecurrencePolicy for which the Standalone Price is valid.voidSKU for which the modification conflict occurred.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLValidityLockConflictError
withGraphQLValidityLockConflictErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLValidityLockConflictErrorImpl
public GraphQLValidityLockConflictErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLValidityLockConflictError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getSku
SKU for which the modification conflict occurred.
- Specified by:
getSkuin interfaceGraphQLValidityLockConflictError- Returns:
- sku
-
getCurrency
Currency code of the Standalone Price.
- Specified by:
getCurrencyin interfaceGraphQLValidityLockConflictError- Returns:
- currency
-
getCountry
Country code of the geographic location.
- Specified by:
getCountryin interfaceGraphQLValidityLockConflictError- Returns:
- country
-
getCustomerGroup
CustomerGroup for which the Standalone Price is valid.
- Specified by:
getCustomerGroupin interfaceGraphQLValidityLockConflictError- Returns:
- customerGroup
-
getChannel
Channel for which the Standalone Price is valid.
- Specified by:
getChannelin interfaceGraphQLValidityLockConflictError- Returns:
- channel
-
getRecurrencePolicy
RecurrencePolicy for which the Standalone Price is valid.
- Specified by:
getRecurrencePolicyin interfaceGraphQLValidityLockConflictError- Returns:
- recurrencePolicy
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setSku
Description copied from interface:GraphQLValidityLockConflictErrorSKU for which the modification conflict occurred.
- Specified by:
setSkuin interfaceGraphQLValidityLockConflictError- Parameters:
sku- value to be set
-
setCurrency
Description copied from interface:GraphQLValidityLockConflictErrorCurrency code of the Standalone Price.
- Specified by:
setCurrencyin interfaceGraphQLValidityLockConflictError- Parameters:
currency- value to be set
-
setCountry
Description copied from interface:GraphQLValidityLockConflictErrorCountry code of the geographic location.
- Specified by:
setCountryin interfaceGraphQLValidityLockConflictError- Parameters:
country- value to be set
-
setCustomerGroup
Description copied from interface:GraphQLValidityLockConflictErrorCustomerGroup for which the Standalone Price is valid.
- Specified by:
setCustomerGroupin interfaceGraphQLValidityLockConflictError- Parameters:
customerGroup- value to be set
-
setChannel
Description copied from interface:GraphQLValidityLockConflictErrorChannel for which the Standalone Price is valid.
- Specified by:
setChannelin interfaceGraphQLValidityLockConflictError- Parameters:
channel- value to be set
-
setRecurrencePolicy
Description copied from interface:GraphQLValidityLockConflictErrorRecurrencePolicy for which the Standalone Price is valid.
- Specified by:
setRecurrencePolicyin interfaceGraphQLValidityLockConflictError- Parameters:
recurrencePolicy- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLValidityLockConflictError
-