Class InvalidCredentialsErrorImpl
java.lang.Object
com.commercetools.api.models.error.InvalidCredentialsErrorImpl
- All Implemented Interfaces:
ErrorObject,InvalidCredentialsError,io.vrap.rmf.base.client.ModelBase
public class InvalidCredentialsErrorImpl
extends Object
implements InvalidCredentialsError, io.vrap.rmf.base.client.ModelBase
Returned when a Customer with the given credentials (matching the given email/password pair) is not found and authentication fails.
The error is returned as a failed response to:
- Authenticate (sign in) Customer and Authenticate (sign in) Customer in Store requests on Customers.
- Authenticate (sign in) Customer and Authenticate (sign in) Customer in Store requests on My Customer Profile.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.InvalidCredentialsError
INVALID_CREDENTIALS -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier."Account with the given credentials not found."inthashCode()voidsetMessage(String message) "Account with the given credentials not found."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.InvalidCredentialsError
withInvalidCredentialsErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
InvalidCredentialsErrorImpl
public InvalidCredentialsErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceInvalidCredentialsError- Returns:
- code
-
getMessage
"Account with the given credentials not found."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceInvalidCredentialsError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:InvalidCredentialsError"Account with the given credentials not found."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceInvalidCredentialsError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceInvalidCredentialsError
-