Class InvalidCurrentPasswordErrorImpl
java.lang.Object
com.commercetools.api.models.error.InvalidCurrentPasswordErrorImpl
- All Implemented Interfaces:
ErrorObject,InvalidCurrentPasswordError,io.vrap.rmf.base.client.ModelBase
public class InvalidCurrentPasswordErrorImpl
extends Object
implements InvalidCurrentPasswordError, io.vrap.rmf.base.client.ModelBase
Returned when the current password of the Customer does not match.
The error is returned as a failed response to:
- Change Customer Password and Change Customer Password in a Store requests on Customers.
- Change Customer Password and Change Customer Password in a Store requests on My Customer Profile.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.InvalidCurrentPasswordError
INVALID_CURRENT_PASSWORD -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier."The given current password does not match."inthashCode()voidsetMessage(String message) "The given current password does not match."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.InvalidCurrentPasswordError
withInvalidCurrentPasswordErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
InvalidCurrentPasswordErrorImpl
public InvalidCurrentPasswordErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceInvalidCurrentPasswordError- Returns:
- code
-
getMessage
"The given current password does not match."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceInvalidCurrentPasswordError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:InvalidCurrentPasswordError"The given current password does not match."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceInvalidCurrentPasswordError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceInvalidCurrentPasswordError
-