Class InvalidFieldErrorImpl
java.lang.Object
com.commercetools.api.models.error.InvalidFieldErrorImpl
- All Implemented Interfaces:
ErrorObject,InvalidFieldError,io.vrap.rmf.base.client.ModelBase
public class InvalidFieldErrorImpl
extends Object
implements InvalidFieldError, io.vrap.rmf.base.client.ModelBase
Returned when a field has an invalid value.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.InvalidFieldError
INVALID_FIELD -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanFixed set of allowed values for the field, if any.getCode()Error identifier.getField()Name of the field with the invalid value.Value invalid for the field."The value $invalidValue is not valid for field $field."inthashCode()voidsetAllowedValues(Object... allowedValues) Fixed set of allowed values for the field, if any.voidsetAllowedValues(List<Object> allowedValues) Fixed set of allowed values for the field, if any.voidName of the field with the invalid value.voidsetInvalidValue(Object invalidValue) Value invalid for the field.voidsetMessage(String message) "The value $invalidValue is not valid for field $field."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.InvalidFieldError
withInvalidFieldErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
InvalidFieldErrorImpl
public InvalidFieldErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceInvalidFieldError- Returns:
- code
-
getMessage
"The value $invalidValue is not valid for field $field."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceInvalidFieldError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getField
Name of the field with the invalid value.
- Specified by:
getFieldin interfaceInvalidFieldError- Returns:
- field
-
getInvalidValue
Value invalid for the field.
- Specified by:
getInvalidValuein interfaceInvalidFieldError- Returns:
- invalidValue
-
getAllowedValues
Fixed set of allowed values for the field, if any.
- Specified by:
getAllowedValuesin interfaceInvalidFieldError- Returns:
- allowedValues
-
setMessage
Description copied from interface:InvalidFieldError"The value $invalidValue is not valid for field $field."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceInvalidFieldError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setField
Description copied from interface:InvalidFieldErrorName of the field with the invalid value.
- Specified by:
setFieldin interfaceInvalidFieldError- Parameters:
field- value to be set
-
setInvalidValue
Description copied from interface:InvalidFieldErrorValue invalid for the field.
- Specified by:
setInvalidValuein interfaceInvalidFieldError- Parameters:
invalidValue- value to be set
-
setAllowedValues
Description copied from interface:InvalidFieldErrorFixed set of allowed values for the field, if any.
- Specified by:
setAllowedValuesin interfaceInvalidFieldError- Parameters:
allowedValues- values to be set
-
setAllowedValues
Description copied from interface:InvalidFieldErrorFixed set of allowed values for the field, if any.
- Specified by:
setAllowedValuesin interfaceInvalidFieldError- Parameters:
allowedValues- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceInvalidFieldError
-