Class InvalidInputErrorImpl
java.lang.Object
com.commercetools.api.models.error.InvalidInputErrorImpl
- All Implemented Interfaces:
ErrorObject,InvalidInputError,io.vrap.rmf.base.client.ModelBase
public class InvalidInputErrorImpl
extends Object
implements InvalidInputError, io.vrap.rmf.base.client.ModelBase
Returned when an invalid input has been sent.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.InvalidInputError
INVALID_INPUT -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Description of the constraints that are not met by the request.inthashCode()voidsetMessage(String message) Description of the constraints that are not met by the request.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.InvalidInputError
withInvalidInputErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
InvalidInputErrorImpl
public InvalidInputErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceInvalidInputError- Returns:
- code
-
getMessage
Description of the constraints that are not met by the request. For example,
"Invalid $propertyName. It may be a non-empty string up to $maxLength".- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceInvalidInputError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:InvalidInputErrorDescription of the constraints that are not met by the request. For example,
"Invalid $propertyName. It may be a non-empty string up to $maxLength".- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceInvalidInputError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceInvalidInputError
-