Class InvalidJsonInputErrorImpl
java.lang.Object
com.commercetools.api.models.error.InvalidJsonInputErrorImpl
- All Implemented Interfaces:
ErrorObject,InvalidJsonInputError,io.vrap.rmf.base.client.ModelBase
public class InvalidJsonInputErrorImpl
extends Object
implements InvalidJsonInputError, io.vrap.rmf.base.client.ModelBase
Returned when an invalid JSON input has been sent. Either the JSON is syntactically incorrect or does not conform to the expected shape (for example is missing a required field).
The client application should validate the input according to the constraints described in the error message before sending the request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.InvalidJsonInputError
INVALID_JSON_INPUT -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Further explanation about why the JSON is invalid."Request body does not contain valid JSON."inthashCode()voidsetDetailedErrorMessage(String detailedErrorMessage) Further explanation about why the JSON is invalid.voidsetMessage(String message) "Request body does not contain valid JSON."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.InvalidJsonInputError
withInvalidJsonInputErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
InvalidJsonInputErrorImpl
public InvalidJsonInputErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceInvalidJsonInputError- Returns:
- code
-
getMessage
"Request body does not contain valid JSON."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceInvalidJsonInputError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getDetailedErrorMessage
Further explanation about why the JSON is invalid.
- Specified by:
getDetailedErrorMessagein interfaceInvalidJsonInputError- Returns:
- detailedErrorMessage
-
setMessage
Description copied from interface:InvalidJsonInputError"Request body does not contain valid JSON."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceInvalidJsonInputError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setDetailedErrorMessage
Description copied from interface:InvalidJsonInputErrorFurther explanation about why the JSON is invalid.
- Specified by:
setDetailedErrorMessagein interfaceInvalidJsonInputError- Parameters:
detailedErrorMessage- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceInvalidJsonInputError
-