Class InvalidSubjectErrorImpl
java.lang.Object
com.commercetools.api.models.error.InvalidSubjectErrorImpl
- All Implemented Interfaces:
ErrorObject,InvalidSubjectError,io.vrap.rmf.base.client.ModelBase
public class InvalidSubjectErrorImpl
extends Object
implements InvalidSubjectError, io.vrap.rmf.base.client.ModelBase
InvalidSubjectError
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.InvalidSubjectError
INVALID_SUBJECT -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Plain text description of the cause of the error.inthashCode()voidsetMessage(String message) Plain text description of the cause of the error.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.InvalidSubjectError
withInvalidSubjectErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
InvalidSubjectErrorImpl
public InvalidSubjectErrorImpl()create empty instance
-
-
Method Details
-
getCode
Error identifier.
- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
Plain text description of the cause of the error.
- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:ErrorObjectPlain text description of the cause of the error.
- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceInvalidSubjectError
-