Class LanguageUsedInStoresErrorImpl
java.lang.Object
com.commercetools.api.models.error.LanguageUsedInStoresErrorImpl
- All Implemented Interfaces:
ErrorObject,LanguageUsedInStoresError,io.vrap.rmf.base.client.ModelBase
public class LanguageUsedInStoresErrorImpl
extends Object
implements LanguageUsedInStoresError, io.vrap.rmf.base.client.ModelBase
Returned when a language cannot be removed from a Project as it is being used by a Store.
The error is returned as a failed response to the Change Languages update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.LanguageUsedInStoresError
LANGUAGE_USED_IN_STORES -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier."Language(s) in use by a store cannot be deleted.inthashCode()voidsetMessage(String message) "Language(s) in use by a store cannot be deleted.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.LanguageUsedInStoresError
withLanguageUsedInStoresErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
LanguageUsedInStoresErrorImpl
public LanguageUsedInStoresErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceLanguageUsedInStoresError- Returns:
- code
-
getMessage
"Language(s) in use by a store cannot be deleted. Remove them in all the stores of this project first."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceLanguageUsedInStoresError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:LanguageUsedInStoresError"Language(s) in use by a store cannot be deleted. Remove them in all the stores of this project first."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceLanguageUsedInStoresError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceLanguageUsedInStoresError
-