Class LineItemQuantityBelowLimitErrorImpl

java.lang.Object
com.commercetools.api.models.error.LineItemQuantityBelowLimitErrorImpl
All Implemented Interfaces:
ErrorObject, LineItemQuantityBelowLimitError, io.vrap.rmf.base.client.ModelBase

public class LineItemQuantityBelowLimitErrorImpl extends Object implements LineItemQuantityBelowLimitError, io.vrap.rmf.base.client.ModelBase

Returned when attempting to create or update a Cart with a Line Item whose quantity is below the minCartQuantity limit defined in the InventoryEntry for that Line Item's SKU.