Class LockedFieldErrorImpl
java.lang.Object
com.commercetools.api.models.error.LockedFieldErrorImpl
- All Implemented Interfaces:
ErrorObject,LockedFieldError,io.vrap.rmf.base.client.ModelBase
public class LockedFieldErrorImpl
extends Object
implements LockedFieldError, io.vrap.rmf.base.client.ModelBase
Returned when two Customers are simultaneously created or updated with the same email address.
To confirm if the operation was successful, repeat the request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.LockedFieldError
LOCKED_FIELD -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.getField()Field that is currently locked."'$field' is locked by another request.inthashCode()voidField that is currently locked.voidsetMessage(String message) "'$field' is locked by another request.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.LockedFieldError
withLockedFieldErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
LockedFieldErrorImpl
public LockedFieldErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceLockedFieldError- Returns:
- code
-
getMessage
"'$field' is locked by another request. Please try again later."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceLockedFieldError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getField
Field that is currently locked.
- Specified by:
getFieldin interfaceLockedFieldError- Returns:
- field
-
setMessage
Description copied from interface:LockedFieldError"'$field' is locked by another request. Please try again later."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceLockedFieldError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setField
Description copied from interface:LockedFieldErrorField that is currently locked.
- Specified by:
setFieldin interfaceLockedFieldError- Parameters:
field- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceLockedFieldError
-