Class MatchingPriceNotFoundErrorImpl

java.lang.Object
com.commercetools.api.models.error.MatchingPriceNotFoundErrorImpl
All Implemented Interfaces:
ErrorObject, MatchingPriceNotFoundError, io.vrap.rmf.base.client.ModelBase

public class MatchingPriceNotFoundErrorImpl extends Object implements MatchingPriceNotFoundError, io.vrap.rmf.base.client.ModelBase

Returned when the Product Variant does not have a Price according to the Product priceMode value for a selected currency, country, Customer Group, or Channel.

The error can be returned as a failed response to all update actions on Carts and Staged Orders.

The error is also returned as a failed response to: