Class MaxResourceLimitExceededErrorImpl
java.lang.Object
com.commercetools.api.models.error.MaxResourceLimitExceededErrorImpl
- All Implemented Interfaces:
ErrorObject,MaxResourceLimitExceededError,io.vrap.rmf.base.client.ModelBase
public class MaxResourceLimitExceededErrorImpl
extends Object
implements MaxResourceLimitExceededError, io.vrap.rmf.base.client.ModelBase
Returned when a resource type cannot be created as it has reached its limits.
The limits must be adjusted for this resource before sending the request again.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.MaxResourceLimitExceededError
MAX_RESOURCE_LIMIT_EXCEEDED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Resource type that reached its maximum limit of configured elements (for example, 100 Zones per Project)."You have exceeded the limit of $limit resources of type $resourceTypeId."inthashCode()voidsetExceededResource(ReferenceTypeId exceededResource) Resource type that reached its maximum limit of configured elements (for example, 100 Zones per Project).voidsetMessage(String message) "You have exceeded the limit of $limit resources of type $resourceTypeId."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.MaxResourceLimitExceededError
withMaxResourceLimitExceededErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
MaxResourceLimitExceededErrorImpl
public MaxResourceLimitExceededErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceMaxResourceLimitExceededError- Returns:
- code
-
getMessage
"You have exceeded the limit of $limit resources of type $resourceTypeId."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceMaxResourceLimitExceededError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getExceededResource
Resource type that reached its maximum limit of configured elements (for example, 100 Zones per Project).
- Specified by:
getExceededResourcein interfaceMaxResourceLimitExceededError- Returns:
- exceededResource
-
setMessage
Description copied from interface:MaxResourceLimitExceededError"You have exceeded the limit of $limit resources of type $resourceTypeId."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceMaxResourceLimitExceededError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setExceededResource
Description copied from interface:MaxResourceLimitExceededErrorResource type that reached its maximum limit of configured elements (for example, 100 Zones per Project).
- Specified by:
setExceededResourcein interfaceMaxResourceLimitExceededError- Parameters:
exceededResource- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceMaxResourceLimitExceededError
-