Class MaxStoreReferencesReachedErrorImpl
java.lang.Object
com.commercetools.api.models.error.MaxStoreReferencesReachedErrorImpl
- All Implemented Interfaces:
ErrorObject,MaxStoreReferencesReachedError,io.vrap.rmf.base.client.ModelBase
public class MaxStoreReferencesReachedErrorImpl
extends Object
implements MaxStoreReferencesReachedError, io.vrap.rmf.base.client.ModelBase
Returned when a Store cannot be added to a Cart Discount as the limit for Stores configured for a Cart Discount has been reached.
The error is returned as a failed response to:
- Create CartDiscount and Create CartDiscount in Store requests
- Add Store and Set Store update actions
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.MaxStoreReferencesReachedError
MAX_STORE_REFERENCES_REACHED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier."Maximum number of store discounts on a single cart discount reached $max".inthashCode()voidsetMessage(String message) "Maximum number of store discounts on a single cart discount reached $max".voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.MaxStoreReferencesReachedError
withMaxStoreReferencesReachedErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
MaxStoreReferencesReachedErrorImpl
public MaxStoreReferencesReachedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceMaxStoreReferencesReachedError- Returns:
- code
-
getMessage
"Maximum number of store discounts on a single cart discount reached $max".- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceMaxStoreReferencesReachedError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:MaxStoreReferencesReachedError"Maximum number of store discounts on a single cart discount reached $max".- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceMaxStoreReferencesReachedError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceMaxStoreReferencesReachedError
-