Class MissingRoleOnChannelErrorImpl

java.lang.Object
com.commercetools.api.models.error.MissingRoleOnChannelErrorImpl
All Implemented Interfaces:
ErrorObject, MissingRoleOnChannelError, io.vrap.rmf.base.client.ModelBase

public class MissingRoleOnChannelErrorImpl extends Object implements MissingRoleOnChannelError, io.vrap.rmf.base.client.ModelBase

Returned when one of the following states occur:

  • Channel is added or set on a Store with missing Channel roles.
  • Standalone Price references a Channel that does not contain the ProductDistribution role.

The error is returned as a failed response to: