Class OutOfStockErrorImpl

java.lang.Object
com.commercetools.api.models.error.OutOfStockErrorImpl
All Implemented Interfaces:
ErrorObject, OutOfStockError, io.vrap.rmf.base.client.ModelBase

public class OutOfStockErrorImpl extends Object implements OutOfStockError, io.vrap.rmf.base.client.ModelBase

Returned when some of the Line Items are out of stock at the time of placing an Order.

The error is returned as a failed response to: