Class OverCapacityErrorImpl
java.lang.Object
com.commercetools.api.models.error.OverCapacityErrorImpl
- All Implemented Interfaces:
ErrorObject,OverCapacityError,io.vrap.rmf.base.client.ModelBase
public class OverCapacityErrorImpl
extends Object
implements OverCapacityError, io.vrap.rmf.base.client.ModelBase
Returned when the service is having trouble handling the load.
The client application should retry the request with exponential backoff up to a point where further delay is unacceptable.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.OverCapacityError
OVER_CAPACITY -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.OverCapacityError
withOverCapacityError
-
Constructor Details
-
OverCapacityErrorImpl
public OverCapacityErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceOverCapacityError- Returns:
- code
-
getMessage
Plain text description of the error.
- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceOverCapacityError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:OverCapacityErrorPlain text description of the error.
- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceOverCapacityError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceOverCapacityError
-