Class PendingOperationErrorImpl
java.lang.Object
com.commercetools.api.models.error.PendingOperationErrorImpl
- All Implemented Interfaces:
ErrorObject,PendingOperationError,io.vrap.rmf.base.client.ModelBase
public class PendingOperationErrorImpl
extends Object
implements PendingOperationError, io.vrap.rmf.base.client.ModelBase
Returned when a previous conflicting operation is still pending and needs to finish before the request can succeed.
The client application should retry the request with exponential backoff up to a point where further delay is unacceptable. If the error persists, report it to the commercetools support team.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.PendingOperationError
PENDING_OPERATION -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.PendingOperationError
withPendingOperationError
-
Constructor Details
-
PendingOperationErrorImpl
public PendingOperationErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfacePendingOperationError- Returns:
- code
-
getMessage
Plain text description of the error.
- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfacePendingOperationError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:PendingOperationErrorPlain text description of the error.
- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfacePendingOperationError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfacePendingOperationError
-