Class PriceChangedErrorImpl

java.lang.Object
com.commercetools.api.models.error.PriceChangedErrorImpl
All Implemented Interfaces:
ErrorObject, PriceChangedError, io.vrap.rmf.base.client.ModelBase

public class PriceChangedErrorImpl extends Object implements PriceChangedError, io.vrap.rmf.base.client.ModelBase

Returned when the Price or Tax Rate of some Line Items or Shipping Rate of some Shipping Methods changed since they were last added to the Cart.

When a Cart is frozen, the error can be returned as a failed response to all update actions on Carts and My Carts.

The error is also returned as a failed response to: