Class ProductAssignmentMissingErrorImpl

java.lang.Object
com.commercetools.api.models.error.ProductAssignmentMissingErrorImpl
All Implemented Interfaces:
ErrorObject, ProductAssignmentMissingError, io.vrap.rmf.base.client.ModelBase

public class ProductAssignmentMissingErrorImpl extends Object implements ProductAssignmentMissingError, io.vrap.rmf.base.client.ModelBase

Returned when a Product is not assigned to the Product Selection. The error is returned as a failed response either to the Set Variant Selection or to the Set Variant Exclusion update action.