Class ProductPresentWithDifferentVariantSelectionErrorImpl
java.lang.Object
com.commercetools.api.models.error.ProductPresentWithDifferentVariantSelectionErrorImpl
- All Implemented Interfaces:
ErrorObject,ProductPresentWithDifferentVariantSelectionError,io.vrap.rmf.base.client.ModelBase
public class ProductPresentWithDifferentVariantSelectionErrorImpl
extends Object
implements ProductPresentWithDifferentVariantSelectionError, io.vrap.rmf.base.client.ModelBase
Returned when a Product is already assigned to a Product Selection, but the Product Selection has either a different Product Variant Selection or a different Product Variant Exclusion.
The error is returned as a failed response either to the Add Product or to the Exclude Product update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.ProductPresentWithDifferentVariantSelectionError
PRODUCT_PRESENT_WITH_DIFFERENT_VARIANT_SELECTION -
Constructor Summary
ConstructorsConstructorDescriptioncreate empty instance -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Existing Product Variant Selection or Exclusion for the Product in the Product Selection."Product is already present with the following different $variantSelections."inthashCode()voidsetExistingVariantSelection(ProductVariantSelection existingVariantSelection) Existing Product Variant Selection or Exclusion for the Product in the Product Selection.voidsetMessage(String message) "Product is already present with the following different $variantSelections."voidsetProduct(ProductReference product) voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.ProductPresentWithDifferentVariantSelectionError
withProductPresentWithDifferentVariantSelectionError
-
Constructor Details
-
ProductPresentWithDifferentVariantSelectionErrorImpl
public ProductPresentWithDifferentVariantSelectionErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceProductPresentWithDifferentVariantSelectionError- Returns:
- code
-
getMessage
"Product is already present with the following different $variantSelections."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceProductPresentWithDifferentVariantSelectionError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getProduct
- Specified by:
getProductin interfaceProductPresentWithDifferentVariantSelectionError- Returns:
- product
-
getExistingVariantSelection
Existing Product Variant Selection or Exclusion for the Product in the Product Selection.
- Specified by:
getExistingVariantSelectionin interfaceProductPresentWithDifferentVariantSelectionError- Returns:
- existingVariantSelection
-
setMessage
Description copied from interface:ProductPresentWithDifferentVariantSelectionError"Product is already present with the following different $variantSelections."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceProductPresentWithDifferentVariantSelectionError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setProduct
Description copied from interface:ProductPresentWithDifferentVariantSelectionError- Specified by:
setProductin interfaceProductPresentWithDifferentVariantSelectionError- Parameters:
product- value to be set
-
setExistingVariantSelection
Description copied from interface:ProductPresentWithDifferentVariantSelectionErrorExisting Product Variant Selection or Exclusion for the Product in the Product Selection.
- Specified by:
setExistingVariantSelectionin interfaceProductPresentWithDifferentVariantSelectionError- Parameters:
existingVariantSelection- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceProductPresentWithDifferentVariantSelectionError
-