Class ProjectNotConfiguredForLanguagesErrorImpl
java.lang.Object
com.commercetools.api.models.error.ProjectNotConfiguredForLanguagesErrorImpl
- All Implemented Interfaces:
ErrorObject,ProjectNotConfiguredForLanguagesError,io.vrap.rmf.base.client.ModelBase
public class ProjectNotConfiguredForLanguagesErrorImpl
extends Object
implements ProjectNotConfiguredForLanguagesError, io.vrap.rmf.base.client.ModelBase
Returned when the languages set for a Store are not supported by the Project.
The error is returned as a failed response to the Set Languages update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.ProjectNotConfiguredForLanguagesError
PROJECT_NOT_CONFIGURED_FOR_LANGUAGES -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Languages configured for the Store."The project is not configured for given languages."inthashCode()voidsetLanguages(String... languages) Languages configured for the Store.voidsetLanguages(List<String> languages) Languages configured for the Store.voidsetMessage(String message) "The project is not configured for given languages."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.ProjectNotConfiguredForLanguagesError
withProjectNotConfiguredForLanguagesError
-
Constructor Details
-
ProjectNotConfiguredForLanguagesErrorImpl
public ProjectNotConfiguredForLanguagesErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceProjectNotConfiguredForLanguagesError- Returns:
- code
-
getMessage
"The project is not configured for given languages."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceProjectNotConfiguredForLanguagesError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getLanguages
Languages configured for the Store.
- Specified by:
getLanguagesin interfaceProjectNotConfiguredForLanguagesError- Returns:
- languages
-
setMessage
Description copied from interface:ProjectNotConfiguredForLanguagesError"The project is not configured for given languages."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceProjectNotConfiguredForLanguagesError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setLanguages
Description copied from interface:ProjectNotConfiguredForLanguagesErrorLanguages configured for the Store.
- Specified by:
setLanguagesin interfaceProjectNotConfiguredForLanguagesError- Parameters:
languages- values to be set
-
setLanguages
Description copied from interface:ProjectNotConfiguredForLanguagesErrorLanguages configured for the Store.
- Specified by:
setLanguagesin interfaceProjectNotConfiguredForLanguagesError- Parameters:
languages- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceProjectNotConfiguredForLanguagesError
-