Class QueryTimedOutErrorImpl
java.lang.Object
com.commercetools.api.models.error.QueryTimedOutErrorImpl
- All Implemented Interfaces:
ErrorObject,QueryTimedOutError,io.vrap.rmf.base.client.ModelBase
public class QueryTimedOutErrorImpl
extends Object
implements QueryTimedOutError, io.vrap.rmf.base.client.ModelBase
Returned when the query times out.
If a query constantly times out, please check if it follows the performance best practices.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.QueryTimedOutError
QUERY_TIMED_OUT -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.QueryTimedOutError
withQueryTimedOutError
-
Constructor Details
-
QueryTimedOutErrorImpl
public QueryTimedOutErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceQueryTimedOutError- Returns:
- code
-
getMessage
"The query timed out. If your query constantly times out, please check that it follows the performance best practices (see https://docs.commercetools.com/api/predicates/query#performance-considerations)."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceQueryTimedOutError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:QueryTimedOutError"The query timed out. If your query constantly times out, please check that it follows the performance best practices (see https://docs.commercetools.com/api/predicates/query#performance-considerations)."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceQueryTimedOutError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceQueryTimedOutError
-