Class ReferencedResourceNotFoundErrorImpl
- All Implemented Interfaces:
ErrorObject,ReferencedResourceNotFoundError,io.vrap.rmf.base.client.ModelBase
Returned when a resource referenced by a Reference or a ResourceIdentifier could not be found.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.ReferencedResourceNotFoundError
REFERENCED_RESOURCE_NOT_FOUND -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.getId()Unique identifier of the referenced resource, if known.getKey()User-defined unique identifier of the referenced resource, if known."The referenced object of type $typeId $predicate was not found.Type of referenced resource.inthashCode()voidUnique identifier of the referenced resource, if known.voidUser-defined unique identifier of the referenced resource, if known.voidsetMessage(String message) "The referenced object of type $typeId $predicate was not found.voidsetTypeId(ReferenceTypeId typeId) Type of referenced resource.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.ReferencedResourceNotFoundError
withReferencedResourceNotFoundError
-
Constructor Details
-
ReferencedResourceNotFoundErrorImpl
public ReferencedResourceNotFoundErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceReferencedResourceNotFoundError- Returns:
- code
-
getMessage
"The referenced object of type $typeId $predicate was not found. It either doesn't exist, or it can't be accessed from this endpoint (e.g., if the endpoint filters by store or customer account)."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceReferencedResourceNotFoundError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getTypeId
Type of referenced resource.
- Specified by:
getTypeIdin interfaceReferencedResourceNotFoundError- Returns:
- typeId
-
getId
Unique identifier of the referenced resource, if known.
- Specified by:
getIdin interfaceReferencedResourceNotFoundError- Returns:
- id
-
getKey
User-defined unique identifier of the referenced resource, if known.
- Specified by:
getKeyin interfaceReferencedResourceNotFoundError- Returns:
- key
-
setMessage
Description copied from interface:ReferencedResourceNotFoundError"The referenced object of type $typeId $predicate was not found. It either doesn't exist, or it can't be accessed from this endpoint (e.g., if the endpoint filters by store or customer account)."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceReferencedResourceNotFoundError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setTypeId
Description copied from interface:ReferencedResourceNotFoundErrorType of referenced resource.
- Specified by:
setTypeIdin interfaceReferencedResourceNotFoundError- Parameters:
typeId- value to be set
-
setId
Description copied from interface:ReferencedResourceNotFoundErrorUnique identifier of the referenced resource, if known.
- Specified by:
setIdin interfaceReferencedResourceNotFoundError- Parameters:
id- value to be set
-
setKey
Description copied from interface:ReferencedResourceNotFoundErrorUser-defined unique identifier of the referenced resource, if known.
- Specified by:
setKeyin interfaceReferencedResourceNotFoundError- Parameters:
key- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceReferencedResourceNotFoundError
-