Class SearchDeactivatedErrorImpl
java.lang.Object
com.commercetools.api.models.error.SearchDeactivatedErrorImpl
- All Implemented Interfaces:
ErrorObject,SearchDeactivatedError,io.vrap.rmf.base.client.ModelBase
public class SearchDeactivatedErrorImpl
extends Object
implements SearchDeactivatedError, io.vrap.rmf.base.client.ModelBase
Returned when the indexing of Product information is deactivated in a Project.
To activate indexing, call Change Product Search Indexing Enabled and set enabled to true.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.SearchDeactivatedError
SEARCH_DEACTIVATED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier."The endpoint is deactivated for this project.inthashCode()voidsetMessage(String message) "The endpoint is deactivated for this project.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.SearchDeactivatedError
withSearchDeactivatedError
-
Constructor Details
-
SearchDeactivatedErrorImpl
public SearchDeactivatedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceSearchDeactivatedError- Returns:
- code
-
getMessage
"The endpoint is deactivated for this project. Please enable it via the Project endpoint, via the Merchant Center in the Project settings, or reach out to Support to enable it."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceSearchDeactivatedError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:SearchDeactivatedError"The endpoint is deactivated for this project. Please enable it via the Project endpoint, via the Merchant Center in the Project settings, or reach out to Support to enable it."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceSearchDeactivatedError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceSearchDeactivatedError
-