Class SearchExecutionFailureErrorImpl
java.lang.Object
com.commercetools.api.models.error.SearchExecutionFailureErrorImpl
- All Implemented Interfaces:
ErrorObject,SearchExecutionFailureError,io.vrap.rmf.base.client.ModelBase
public class SearchExecutionFailureErrorImpl
extends Object
implements SearchExecutionFailureError, io.vrap.rmf.base.client.ModelBase
Returned when a search query could not be completed due to an unexpected failure.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.SearchExecutionFailureError
SEARCH_EXECUTION_FAILURE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier."Something went wrong during the search query execution.inthashCode()voidsetMessage(String message) "Something went wrong during the search query execution.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.SearchExecutionFailureError
withSearchExecutionFailureError
-
Constructor Details
-
SearchExecutionFailureErrorImpl
public SearchExecutionFailureErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceSearchExecutionFailureError- Returns:
- code
-
getMessage
"Something went wrong during the search query execution. In most case this happens due to usage of non-existing fields and custom product attributes. Please verify all filters and facets in your search query and make sure that all paths are correct."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceSearchExecutionFailureError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:SearchExecutionFailureError"Something went wrong during the search query execution. In most case this happens due to usage of non-existing fields and custom product attributes. Please verify all filters and facets in your search query and make sure that all paths are correct."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceSearchExecutionFailureError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceSearchExecutionFailureError
-