Class SearchIndexingInProgressErrorImpl
java.lang.Object
com.commercetools.api.models.error.SearchIndexingInProgressErrorImpl
- All Implemented Interfaces:
ErrorObject,SearchIndexingInProgressError,io.vrap.rmf.base.client.ModelBase
public class SearchIndexingInProgressErrorImpl
extends Object
implements SearchIndexingInProgressError, io.vrap.rmf.base.client.ModelBase
Returned when the indexing of Product information is still in progress for Projects that have indexing activated.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.SearchIndexingInProgressError
SEARCH_INDEXING_IN_PROGRESS -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier."The indexing is currently in progress.inthashCode()voidsetMessage(String message) "The indexing is currently in progress.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.SearchIndexingInProgressError
withSearchIndexingInProgressError
-
Constructor Details
-
SearchIndexingInProgressErrorImpl
public SearchIndexingInProgressErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceSearchIndexingInProgressError- Returns:
- code
-
getMessage
"The indexing is currently in progress. Please wait until the status is "Activated" to execute search requests."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceSearchIndexingInProgressError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:SearchIndexingInProgressError"The indexing is currently in progress. Please wait until the status is "Activated" to execute search requests."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceSearchIndexingInProgressError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceSearchIndexingInProgressError
-