Class SearchNotReadyErrorImpl

java.lang.Object
com.commercetools.api.models.error.SearchNotReadyErrorImpl
All Implemented Interfaces:
ErrorObject, SearchNotReadyError, io.vrap.rmf.base.client.ModelBase

public class SearchNotReadyErrorImpl extends Object implements SearchNotReadyError, io.vrap.rmf.base.client.ModelBase

Returned if the requested search service is not ready. The search might be deactivated or indexing is in progress.