Class SemanticErrorErrorImpl
java.lang.Object
com.commercetools.api.models.error.SemanticErrorErrorImpl
- All Implemented Interfaces:
ErrorObject,SemanticErrorError,io.vrap.rmf.base.client.ModelBase
public class SemanticErrorErrorImpl
extends Object
implements SemanticErrorError, io.vrap.rmf.base.client.ModelBase
Returned when a Discount predicate or API Extension predicate is not semantically correct.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.SemanticErrorError
SEMANTIC_ERROR -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Plain text description of the error concerning the predicate.inthashCode()voidsetMessage(String message) Plain text description of the error concerning the predicate.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.SemanticErrorError
withSemanticErrorError
-
Constructor Details
-
SemanticErrorErrorImpl
public SemanticErrorErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceSemanticErrorError- Returns:
- code
-
getMessage
Plain text description of the error concerning the predicate. For example,
"Invalid country code $countryCode provided for the field $fieldDefinition.".- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceSemanticErrorError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:SemanticErrorErrorPlain text description of the error concerning the predicate. For example,
"Invalid country code $countryCode provided for the field $fieldDefinition.".- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceSemanticErrorError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceSemanticErrorError
-