Class ShippingMethodDoesNotMatchCartErrorImpl
java.lang.Object
com.commercetools.api.models.error.ShippingMethodDoesNotMatchCartErrorImpl
- All Implemented Interfaces:
ErrorObject,ShippingMethodDoesNotMatchCartError,io.vrap.rmf.base.client.ModelBase
public class ShippingMethodDoesNotMatchCartErrorImpl
extends Object
implements ShippingMethodDoesNotMatchCartError, io.vrap.rmf.base.client.ModelBase
Returned when the Cart contains a ShippingMethod that is not allowed for the Cart. In this case, the ShippingMethodState value is DoesNotMatchCart.
When a Cart is frozen, the error can be returned as a failed response to all update actions on Carts and My Carts.
The error is also returned as a failed response to:
- Create Order from Cart and Create Order in Store from Cart requests on Orders.
- Create Order from Cart and Create Order in Store from Cart requests on My Orders.
- Create Order from Cart in BusinessUnit request on Associate Orders.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.ShippingMethodDoesNotMatchCartError
SHIPPING_METHOD_DOES_NOT_MATCH_CART -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier."The predicate does not match the cart."inthashCode()voidsetMessage(String message) "The predicate does not match the cart."voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.ShippingMethodDoesNotMatchCartError
withShippingMethodDoesNotMatchCartError
-
Constructor Details
-
ShippingMethodDoesNotMatchCartErrorImpl
public ShippingMethodDoesNotMatchCartErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceShippingMethodDoesNotMatchCartError- Returns:
- code
-
getMessage
"The predicate does not match the cart."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceShippingMethodDoesNotMatchCartError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:ShippingMethodDoesNotMatchCartError"The predicate does not match the cart."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceShippingMethodDoesNotMatchCartError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceShippingMethodDoesNotMatchCartError
-