Class ValidityLockConflictErrorImpl

java.lang.Object
com.commercetools.api.models.error.ValidityLockConflictErrorImpl
All Implemented Interfaces:
ErrorObject, ValidityLockConflictError, io.vrap.rmf.base.client.ModelBase

public class ValidityLockConflictErrorImpl extends Object implements ValidityLockConflictError, io.vrap.rmf.base.client.ModelBase

Returned when a modification is already in progress for the combination of SKU and price scope fields (but potentially different validity period) for a Standalone Price. Retry the same request after 300 ms.

The error is returned as a failed response to: