Class BusinessUnitAddressCustomFieldAddedMessageImpl

java.lang.Object
com.commercetools.api.models.message.BusinessUnitAddressCustomFieldAddedMessageImpl
All Implemented Interfaces:
BaseResource, DomainResource<Message>, Identifiable<Message>, BusinessUnitAddressCustomFieldAddedMessage, Message, Versioned<Message>, io.vrap.rmf.base.client.ModelBase

public class BusinessUnitAddressCustomFieldAddedMessageImpl extends Object implements BusinessUnitAddressCustomFieldAddedMessage, io.vrap.rmf.base.client.ModelBase

Generated after adding a Custom Field to an address of a Business Unit using the Set Address CustomField update action. If a Custom Field already exists with the same name, a BusinessUnitAddressCustomFieldChanged Message is generated instead.