Class BusinessUnitAddressCustomFieldRemovedMessageImpl

java.lang.Object
com.commercetools.api.models.message.BusinessUnitAddressCustomFieldRemovedMessageImpl
All Implemented Interfaces:
BaseResource, DomainResource<Message>, Identifiable<Message>, BusinessUnitAddressCustomFieldRemovedMessage, Message, Versioned<Message>, io.vrap.rmf.base.client.ModelBase

public class BusinessUnitAddressCustomFieldRemovedMessageImpl extends Object implements BusinessUnitAddressCustomFieldRemovedMessage, io.vrap.rmf.base.client.ModelBase

Generated after removing a Custom Field from an address of a Business Unit using the Set Address CustomField update action.