Class CustomLineItemStateTransitionMessageImpl
- All Implemented Interfaces:
BaseResource,DomainResource<Message>,Identifiable<Message>,CustomLineItemStateTransitionMessage,Message,OrderMessage,Versioned<Message>,io.vrap.rmf.base.client.ModelBase
Generated after a successful Transition CustomLineItem State update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.message.CustomLineItemStateTransitionMessage
CUSTOM_LINE_ITEM_STATE_TRANSITION -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanDate and time (UTC) the Message was generated.IDs and references that created the Message.Unique identifier of the Custom Line Item.User-defined unique identifier of the Custom Line Item.State the Custom Line Item was transitioned from.getId()Unique identifier of the Message.Value ofcreatedAt.IDs and references that last modified the Message.Number of Custom Line Items for which the State was transitioned.Reference to the resource on which the change or action was performed.User-provided identifiers of the resource, such askeyorexternalId.Version of the resource on which the change or action was performed.Message number in relation to other Messages for a given resource.State the Custom Line Item was transitioned to.Date and time (UTC) the transition of the Custom Line Item State was performed.getType()Message Type of the Message.Version of a resource.inthashCode()voidsetCreatedAt(ZonedDateTime createdAt) Date and time (UTC) the Message was generated.voidsetCreatedBy(CreatedBy createdBy) IDs and references that created the Message.voidsetCustomLineItemId(String customLineItemId) Unique identifier of the Custom Line Item.voidsetCustomLineItemKey(String customLineItemKey) User-defined unique identifier of the Custom Line Item.voidsetFromState(StateReference fromState) State the Custom Line Item was transitioned from.voidUnique identifier of the Message.voidsetLastModifiedAt(ZonedDateTime lastModifiedAt) Value ofcreatedAt.voidsetLastModifiedBy(LastModifiedBy lastModifiedBy) IDs and references that last modified the Message.voidsetQuantity(Long quantity) Number of Custom Line Items for which the State was transitioned.voidsetResource(Reference resource) Reference to the resource on which the change or action was performed.voidsetResourceUserProvidedIdentifiers(UserProvidedIdentifiers resourceUserProvidedIdentifiers) User-provided identifiers of the resource, such askeyorexternalId.voidsetResourceVersion(Long resourceVersion) Version of the resource on which the change or action was performed.voidsetSequenceNumber(Long sequenceNumber) Message number in relation to other Messages for a given resource.voidsetToState(StateReference toState) State the Custom Line Item was transitioned to.voidsetTransitionDate(ZonedDateTime transitionDate) Date and time (UTC) the transition of the Custom Line Item State was performed.voidsetVersion(Long version) Version of a resource.toString()Methods inherited from interface com.commercetools.api.models.common.BaseResource
withBaseResourceMethods inherited from interface com.commercetools.api.models.message.CustomLineItemStateTransitionMessage
withCustomLineItemStateTransitionMessageMethods inherited from interface com.commercetools.api.models.DomainResource
getMethods inherited from interface com.commercetools.api.models.message.Message
withMessageMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.message.OrderMessage
withOrderMessage
-
Constructor Details
-
CustomLineItemStateTransitionMessageImpl
public CustomLineItemStateTransitionMessageImpl()create empty instance
-
-
Method Details
-
getId
Unique identifier of the Message. Can be used to track which Messages have been processed.
- Specified by:
getIdin interfaceBaseResource- Specified by:
getIdin interfaceDomainResource<Message>- Specified by:
getIdin interfaceIdentifiable<Message>- Specified by:
getIdin interfaceMessage- Specified by:
getIdin interfaceVersioned<Message>- Returns:
- id
-
getVersion
Version of a resource. In case of Messages, this is always
1.- Specified by:
getVersionin interfaceBaseResource- Specified by:
getVersionin interfaceDomainResource<Message>- Specified by:
getVersionin interfaceMessage- Specified by:
getVersionin interfaceVersioned<Message>- Returns:
- version
-
getCreatedAt
Date and time (UTC) the Message was generated.
- Specified by:
getCreatedAtin interfaceBaseResource- Specified by:
getCreatedAtin interfaceMessage- Returns:
- createdAt
-
getLastModifiedAt
Value of
createdAt.- Specified by:
getLastModifiedAtin interfaceBaseResource- Specified by:
getLastModifiedAtin interfaceMessage- Returns:
- lastModifiedAt
-
getLastModifiedBy
IDs and references that last modified the Message.
- Specified by:
getLastModifiedByin interfaceMessage- Returns:
- lastModifiedBy
-
getCreatedBy
IDs and references that created the Message.
- Specified by:
getCreatedByin interfaceMessage- Returns:
- createdBy
-
getSequenceNumber
Message number in relation to other Messages for a given resource. The
sequenceNumberof the next Message for the resource is the successor of thesequenceNumberof the current Message. Meaning, thesequenceNumberof the next Message equals thesequenceNumberof the current Message + 1.sequenceNumbercan be used to ensure that Messages are processed in the correct order for a particular resource.- Specified by:
getSequenceNumberin interfaceMessage- Returns:
- sequenceNumber
-
getResource
Reference to the resource on which the change or action was performed.
- Specified by:
getResourcein interfaceMessage- Returns:
- resource
-
getResourceVersion
Version of the resource on which the change or action was performed.
- Specified by:
getResourceVersionin interfaceMessage- Returns:
- resourceVersion
-
getType
Message Type of the Message.
-
getResourceUserProvidedIdentifiers
User-provided identifiers of the resource, such as
keyorexternalId. Only present if the resource has such identifiers.- Specified by:
getResourceUserProvidedIdentifiersin interfaceMessage- Returns:
- resourceUserProvidedIdentifiers
-
getCustomLineItemId
Unique identifier of the Custom Line Item.
- Specified by:
getCustomLineItemIdin interfaceCustomLineItemStateTransitionMessage- Returns:
- customLineItemId
-
getCustomLineItemKey
User-defined unique identifier of the Custom Line Item.
- Specified by:
getCustomLineItemKeyin interfaceCustomLineItemStateTransitionMessage- Returns:
- customLineItemKey
-
getTransitionDate
Date and time (UTC) the transition of the Custom Line Item State was performed.
- Specified by:
getTransitionDatein interfaceCustomLineItemStateTransitionMessage- Returns:
- transitionDate
-
getQuantity
Number of Custom Line Items for which the State was transitioned.
- Specified by:
getQuantityin interfaceCustomLineItemStateTransitionMessage- Returns:
- quantity
-
getFromState
State the Custom Line Item was transitioned from.
- Specified by:
getFromStatein interfaceCustomLineItemStateTransitionMessage- Returns:
- fromState
-
getToState
State the Custom Line Item was transitioned to.
- Specified by:
getToStatein interfaceCustomLineItemStateTransitionMessage- Returns:
- toState
-
setId
Description copied from interface:MessageUnique identifier of the Message. Can be used to track which Messages have been processed.
- Specified by:
setIdin interfaceBaseResource- Specified by:
setIdin interfaceMessage- Parameters:
id- value to be set
-
setVersion
Description copied from interface:MessageVersion of a resource. In case of Messages, this is always
1.- Specified by:
setVersionin interfaceBaseResource- Specified by:
setVersionin interfaceMessage- Parameters:
version- value to be set
-
setCreatedAt
Description copied from interface:MessageDate and time (UTC) the Message was generated.
- Specified by:
setCreatedAtin interfaceBaseResource- Specified by:
setCreatedAtin interfaceMessage- Parameters:
createdAt- value to be set
-
setLastModifiedAt
Description copied from interface:MessageValue of
createdAt.- Specified by:
setLastModifiedAtin interfaceBaseResource- Specified by:
setLastModifiedAtin interfaceMessage- Parameters:
lastModifiedAt- value to be set
-
setLastModifiedBy
Description copied from interface:MessageIDs and references that last modified the Message.
- Specified by:
setLastModifiedByin interfaceMessage- Parameters:
lastModifiedBy- value to be set
-
setCreatedBy
Description copied from interface:MessageIDs and references that created the Message.
- Specified by:
setCreatedByin interfaceMessage- Parameters:
createdBy- value to be set
-
setSequenceNumber
Description copied from interface:MessageMessage number in relation to other Messages for a given resource. The
sequenceNumberof the next Message for the resource is the successor of thesequenceNumberof the current Message. Meaning, thesequenceNumberof the next Message equals thesequenceNumberof the current Message + 1.sequenceNumbercan be used to ensure that Messages are processed in the correct order for a particular resource.- Specified by:
setSequenceNumberin interfaceMessage- Parameters:
sequenceNumber- value to be set
-
setResource
Description copied from interface:MessageReference to the resource on which the change or action was performed.
- Specified by:
setResourcein interfaceMessage- Parameters:
resource- value to be set
-
setResourceVersion
Description copied from interface:MessageVersion of the resource on which the change or action was performed.
- Specified by:
setResourceVersionin interfaceMessage- Parameters:
resourceVersion- value to be set
-
setResourceUserProvidedIdentifiers
public void setResourceUserProvidedIdentifiers(UserProvidedIdentifiers resourceUserProvidedIdentifiers) Description copied from interface:MessageUser-provided identifiers of the resource, such as
keyorexternalId. Only present if the resource has such identifiers.- Specified by:
setResourceUserProvidedIdentifiersin interfaceMessage- Parameters:
resourceUserProvidedIdentifiers- value to be set
-
setCustomLineItemId
Description copied from interface:CustomLineItemStateTransitionMessageUnique identifier of the Custom Line Item.
- Specified by:
setCustomLineItemIdin interfaceCustomLineItemStateTransitionMessage- Parameters:
customLineItemId- value to be set
-
setCustomLineItemKey
Description copied from interface:CustomLineItemStateTransitionMessageUser-defined unique identifier of the Custom Line Item.
- Specified by:
setCustomLineItemKeyin interfaceCustomLineItemStateTransitionMessage- Parameters:
customLineItemKey- value to be set
-
setTransitionDate
Description copied from interface:CustomLineItemStateTransitionMessageDate and time (UTC) the transition of the Custom Line Item State was performed.
- Specified by:
setTransitionDatein interfaceCustomLineItemStateTransitionMessage- Parameters:
transitionDate- value to be set
-
setQuantity
Description copied from interface:CustomLineItemStateTransitionMessageNumber of Custom Line Items for which the State was transitioned.
- Specified by:
setQuantityin interfaceCustomLineItemStateTransitionMessage- Parameters:
quantity- value to be set
-
setFromState
Description copied from interface:CustomLineItemStateTransitionMessageState the Custom Line Item was transitioned from.
- Specified by:
setFromStatein interfaceCustomLineItemStateTransitionMessage- Parameters:
fromState- value to be set
-
setToState
Description copied from interface:CustomLineItemStateTransitionMessageState the Custom Line Item was transitioned to.
- Specified by:
setToStatein interfaceCustomLineItemStateTransitionMessage- Parameters:
toState- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceBaseResource- Specified by:
copyDeepin interfaceCustomLineItemStateTransitionMessage- Specified by:
copyDeepin interfaceMessage- Specified by:
copyDeepin interfaceOrderMessage
-