Class CustomerAddressCustomFieldRemovedMessagePayloadImpl
java.lang.Object
com.commercetools.api.models.message.CustomerAddressCustomFieldRemovedMessagePayloadImpl
- All Implemented Interfaces:
CustomerAddressCustomFieldRemovedMessagePayload,MessagePayload,MessagePayloadMixin,io.vrap.rmf.base.client.ModelBase
public class CustomerAddressCustomFieldRemovedMessagePayloadImpl
extends Object
implements CustomerAddressCustomFieldRemovedMessagePayload, io.vrap.rmf.base.client.ModelBase
Generated after removing a Custom Field from an Address of a Customer using the Set CustomField in Address update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.message.CustomerAddressCustomFieldRemovedMessagePayload
CUSTOMER_ADDRESS_CUSTOM_FIELD_REMOVED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanidof the Address from which the Custom Field was removed.getName()Name of the Custom Field that was removed.getType()inthashCode()voidsetAddressId(String addressId) idof the Address from which the Custom Field was removed.voidName of the Custom Field that was removed.toString()Methods inherited from interface com.commercetools.api.models.message.CustomerAddressCustomFieldRemovedMessagePayload
withCustomerAddressCustomFieldRemovedMessagePayloadMethods inherited from interface com.commercetools.api.models.message.MessagePayload
withMessagePayloadMethods inherited from interface com.commercetools.api.models.message.MessagePayloadMixin
asMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
CustomerAddressCustomFieldRemovedMessagePayloadImpl
public CustomerAddressCustomFieldRemovedMessagePayloadImpl()create empty instance
-
-
Method Details
-
getType
- Specified by:
getTypein interfaceMessagePayload- Returns:
- type
-
getName
Name of the Custom Field that was removed.
- Specified by:
getNamein interfaceCustomerAddressCustomFieldRemovedMessagePayload- Returns:
- name
-
getAddressId
idof the Address from which the Custom Field was removed.- Specified by:
getAddressIdin interfaceCustomerAddressCustomFieldRemovedMessagePayload- Returns:
- addressId
-
setName
Description copied from interface:CustomerAddressCustomFieldRemovedMessagePayloadName of the Custom Field that was removed.
- Specified by:
setNamein interfaceCustomerAddressCustomFieldRemovedMessagePayload- Parameters:
name- value to be set
-
setAddressId
Description copied from interface:CustomerAddressCustomFieldRemovedMessagePayloadidof the Address from which the Custom Field was removed.- Specified by:
setAddressIdin interfaceCustomerAddressCustomFieldRemovedMessagePayload- Parameters:
addressId- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceCustomerAddressCustomFieldRemovedMessagePayload- Specified by:
copyDeepin interfaceMessagePayload
-