Class DeliveryCustomFieldChangedMessageImpl
- All Implemented Interfaces:
BaseResource,DomainResource<Message>,Identifiable<Message>,DeliveryCustomFieldChangedMessage,Message,OrderMessage,Versioned<Message>,io.vrap.rmf.base.client.ModelBase
Generated when an existing Custom Field on a Delivery has been changed using the Set CustomField update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.message.DeliveryCustomFieldChangedMessage
DELIVERY_CUSTOM_FIELD_CHANGED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanDate and time (UTC) the Message was generated.IDs and references that created the Message.Unique identifier of the Delivery.getId()Unique identifier of the Message.Value ofcreatedAt.IDs and references that last modified the Message.getName()Name of the Custom Field that changed.Reference to the resource on which the change or action was performed.User-provided identifiers of the resource, such askeyorexternalId.Version of the resource on which the change or action was performed.Message number in relation to other Messages for a given resource.getType()Message Type of the Message.getValue()Version of a resource.inthashCode()voidsetCreatedAt(ZonedDateTime createdAt) Date and time (UTC) the Message was generated.voidsetCreatedBy(CreatedBy createdBy) IDs and references that created the Message.voidsetDeliveryId(String deliveryId) Unique identifier of the Delivery.voidUnique identifier of the Message.voidsetLastModifiedAt(ZonedDateTime lastModifiedAt) Value ofcreatedAt.voidsetLastModifiedBy(LastModifiedBy lastModifiedBy) IDs and references that last modified the Message.voidName of the Custom Field that changed.voidsetPreviousValue(Object previousValue) voidsetResource(Reference resource) Reference to the resource on which the change or action was performed.voidsetResourceUserProvidedIdentifiers(UserProvidedIdentifiers resourceUserProvidedIdentifiers) User-provided identifiers of the resource, such askeyorexternalId.voidsetResourceVersion(Long resourceVersion) Version of the resource on which the change or action was performed.voidsetSequenceNumber(Long sequenceNumber) Message number in relation to other Messages for a given resource.voidvoidsetVersion(Long version) Version of a resource.toString()Methods inherited from interface com.commercetools.api.models.common.BaseResource
withBaseResourceMethods inherited from interface com.commercetools.api.models.message.DeliveryCustomFieldChangedMessage
withDeliveryCustomFieldChangedMessageMethods inherited from interface com.commercetools.api.models.DomainResource
getMethods inherited from interface com.commercetools.api.models.message.Message
withMessageMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.message.OrderMessage
withOrderMessage
-
Constructor Details
-
DeliveryCustomFieldChangedMessageImpl
public DeliveryCustomFieldChangedMessageImpl()create empty instance
-
-
Method Details
-
getId
Unique identifier of the Message. Can be used to track which Messages have been processed.
- Specified by:
getIdin interfaceBaseResource- Specified by:
getIdin interfaceDomainResource<Message>- Specified by:
getIdin interfaceIdentifiable<Message>- Specified by:
getIdin interfaceMessage- Specified by:
getIdin interfaceVersioned<Message>- Returns:
- id
-
getVersion
Version of a resource. In case of Messages, this is always
1.- Specified by:
getVersionin interfaceBaseResource- Specified by:
getVersionin interfaceDomainResource<Message>- Specified by:
getVersionin interfaceMessage- Specified by:
getVersionin interfaceVersioned<Message>- Returns:
- version
-
getCreatedAt
Date and time (UTC) the Message was generated.
- Specified by:
getCreatedAtin interfaceBaseResource- Specified by:
getCreatedAtin interfaceMessage- Returns:
- createdAt
-
getLastModifiedAt
Value of
createdAt.- Specified by:
getLastModifiedAtin interfaceBaseResource- Specified by:
getLastModifiedAtin interfaceMessage- Returns:
- lastModifiedAt
-
getLastModifiedBy
IDs and references that last modified the Message.
- Specified by:
getLastModifiedByin interfaceMessage- Returns:
- lastModifiedBy
-
getCreatedBy
IDs and references that created the Message.
- Specified by:
getCreatedByin interfaceMessage- Returns:
- createdBy
-
getSequenceNumber
Message number in relation to other Messages for a given resource. The
sequenceNumberof the next Message for the resource is the successor of thesequenceNumberof the current Message. Meaning, thesequenceNumberof the next Message equals thesequenceNumberof the current Message + 1.sequenceNumbercan be used to ensure that Messages are processed in the correct order for a particular resource.- Specified by:
getSequenceNumberin interfaceMessage- Returns:
- sequenceNumber
-
getResource
Reference to the resource on which the change or action was performed.
- Specified by:
getResourcein interfaceMessage- Returns:
- resource
-
getResourceVersion
Version of the resource on which the change or action was performed.
- Specified by:
getResourceVersionin interfaceMessage- Returns:
- resourceVersion
-
getType
Message Type of the Message.
-
getResourceUserProvidedIdentifiers
User-provided identifiers of the resource, such as
keyorexternalId. Only present if the resource has such identifiers.- Specified by:
getResourceUserProvidedIdentifiersin interfaceMessage- Returns:
- resourceUserProvidedIdentifiers
-
getName
Name of the Custom Field that changed.
- Specified by:
getNamein interfaceDeliveryCustomFieldChangedMessage- Returns:
- name
-
getValue
CustomFieldValue based on the FieldType after the Set CustomField update action.
- Specified by:
getValuein interfaceDeliveryCustomFieldChangedMessage- Returns:
- value
-
getPreviousValue
CustomFieldValue based on the FieldType before the Set CustomField update action. When there has not been a Custom Field with the
nameon the Delivery before, a Delivery Custom Field Added Message is generated instead.- Specified by:
getPreviousValuein interfaceDeliveryCustomFieldChangedMessage- Returns:
- previousValue
-
getDeliveryId
Unique identifier of the Delivery.
- Specified by:
getDeliveryIdin interfaceDeliveryCustomFieldChangedMessage- Returns:
- deliveryId
-
setId
Description copied from interface:MessageUnique identifier of the Message. Can be used to track which Messages have been processed.
- Specified by:
setIdin interfaceBaseResource- Specified by:
setIdin interfaceMessage- Parameters:
id- value to be set
-
setVersion
Description copied from interface:MessageVersion of a resource. In case of Messages, this is always
1.- Specified by:
setVersionin interfaceBaseResource- Specified by:
setVersionin interfaceMessage- Parameters:
version- value to be set
-
setCreatedAt
Description copied from interface:MessageDate and time (UTC) the Message was generated.
- Specified by:
setCreatedAtin interfaceBaseResource- Specified by:
setCreatedAtin interfaceMessage- Parameters:
createdAt- value to be set
-
setLastModifiedAt
Description copied from interface:MessageValue of
createdAt.- Specified by:
setLastModifiedAtin interfaceBaseResource- Specified by:
setLastModifiedAtin interfaceMessage- Parameters:
lastModifiedAt- value to be set
-
setLastModifiedBy
Description copied from interface:MessageIDs and references that last modified the Message.
- Specified by:
setLastModifiedByin interfaceMessage- Parameters:
lastModifiedBy- value to be set
-
setCreatedBy
Description copied from interface:MessageIDs and references that created the Message.
- Specified by:
setCreatedByin interfaceMessage- Parameters:
createdBy- value to be set
-
setSequenceNumber
Description copied from interface:MessageMessage number in relation to other Messages for a given resource. The
sequenceNumberof the next Message for the resource is the successor of thesequenceNumberof the current Message. Meaning, thesequenceNumberof the next Message equals thesequenceNumberof the current Message + 1.sequenceNumbercan be used to ensure that Messages are processed in the correct order for a particular resource.- Specified by:
setSequenceNumberin interfaceMessage- Parameters:
sequenceNumber- value to be set
-
setResource
Description copied from interface:MessageReference to the resource on which the change or action was performed.
- Specified by:
setResourcein interfaceMessage- Parameters:
resource- value to be set
-
setResourceVersion
Description copied from interface:MessageVersion of the resource on which the change or action was performed.
- Specified by:
setResourceVersionin interfaceMessage- Parameters:
resourceVersion- value to be set
-
setResourceUserProvidedIdentifiers
public void setResourceUserProvidedIdentifiers(UserProvidedIdentifiers resourceUserProvidedIdentifiers) Description copied from interface:MessageUser-provided identifiers of the resource, such as
keyorexternalId. Only present if the resource has such identifiers.- Specified by:
setResourceUserProvidedIdentifiersin interfaceMessage- Parameters:
resourceUserProvidedIdentifiers- value to be set
-
setName
Description copied from interface:DeliveryCustomFieldChangedMessageName of the Custom Field that changed.
- Specified by:
setNamein interfaceDeliveryCustomFieldChangedMessage- Parameters:
name- value to be set
-
setValue
Description copied from interface:DeliveryCustomFieldChangedMessageCustomFieldValue based on the FieldType after the Set CustomField update action.
- Specified by:
setValuein interfaceDeliveryCustomFieldChangedMessage- Parameters:
value- value to be set
-
setPreviousValue
Description copied from interface:DeliveryCustomFieldChangedMessageCustomFieldValue based on the FieldType before the Set CustomField update action. When there has not been a Custom Field with the
nameon the Delivery before, a Delivery Custom Field Added Message is generated instead.- Specified by:
setPreviousValuein interfaceDeliveryCustomFieldChangedMessage- Parameters:
previousValue- value to be set
-
setDeliveryId
Description copied from interface:DeliveryCustomFieldChangedMessageUnique identifier of the Delivery.
- Specified by:
setDeliveryIdin interfaceDeliveryCustomFieldChangedMessage- Parameters:
deliveryId- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceBaseResource- Specified by:
copyDeepin interfaceDeliveryCustomFieldChangedMessage- Specified by:
copyDeepin interfaceMessage- Specified by:
copyDeepin interfaceOrderMessage
-