Interface Message

All Superinterfaces:
BaseResource, DomainResource<Message>, Identifiable<Message>, Versioned<Message>
All Known Subinterfaces:
ApprovalFlowApprovedMessage, ApprovalFlowCompletedMessage, ApprovalFlowCreatedMessage, ApprovalFlowRejectedMessage, ApprovalRuleApproversSetMessage, ApprovalRuleCreatedMessage, ApprovalRuleDescriptionSetMessage, ApprovalRuleKeySetMessage, ApprovalRuleNameSetMessage, ApprovalRulePredicateSetMessage, ApprovalRuleRequestersSetMessage, ApprovalRuleStatusSetMessage, AssociateRoleBuyerAssignableChangedMessage, AssociateRoleCreatedMessage, AssociateRoleDeletedMessage, AssociateRoleNameSetMessage, AssociateRolePermissionAddedMessage, AssociateRolePermissionRemovedMessage, AssociateRolePermissionsSetMessage, BusinessUnitAddressAddedMessage, BusinessUnitAddressChangedMessage, BusinessUnitAddressCustomFieldAddedMessage, BusinessUnitAddressCustomFieldChangedMessage, BusinessUnitAddressCustomFieldRemovedMessage, BusinessUnitAddressCustomTypeRemovedMessage, BusinessUnitAddressCustomTypeSetMessage, BusinessUnitAddressRemovedMessage, BusinessUnitApprovalRuleModeChangedMessage, BusinessUnitAssociateAddedMessage, BusinessUnitAssociateChangedMessage, BusinessUnitAssociateModeChangedMessage, BusinessUnitAssociateRemovedMessage, BusinessUnitAssociatesSetMessage, BusinessUnitBillingAddressAddedMessage, BusinessUnitBillingAddressRemovedMessage, BusinessUnitContactEmailSetMessage, BusinessUnitCreatedMessage, BusinessUnitCustomerGroupAssignmentAddedMessage, BusinessUnitCustomerGroupAssignmentRemovedMessage, BusinessUnitCustomerGroupAssignmentsSetMessage, BusinessUnitCustomFieldAddedMessage, BusinessUnitCustomFieldChangedMessage, BusinessUnitCustomFieldRemovedMessage, BusinessUnitCustomTypeRemovedMessage, BusinessUnitCustomTypeSetMessage, BusinessUnitDefaultBillingAddressSetMessage, BusinessUnitDefaultShippingAddressSetMessage, BusinessUnitDeletedMessage, BusinessUnitNameChangedMessage, BusinessUnitParentChangedMessage, BusinessUnitShippingAddressAddedMessage, BusinessUnitShippingAddressRemovedMessage, BusinessUnitStatusChangedMessage, BusinessUnitStoreAddedMessage, BusinessUnitStoreModeChangedMessage, BusinessUnitStoreRemovedMessage, BusinessUnitStoresSetMessage, BusinessUnitTopLevelUnitSetMessage, BusinessUnitTypeSetMessage, CartDiscountCreatedMessage, CartDiscountDeletedMessage, CartDiscountStoreAddedMessage, CartDiscountStoreRemovedMessage, CartDiscountStoresSetMessage, CartFrozenMessage, CartPurchaseOrderNumberSetMessage, CartUnfrozenMessage, CategoryCreatedMessage, CategorySlugChangedMessage, CustomerAddressAddedMessage, CustomerAddressChangedMessage, CustomerAddressCustomFieldAddedMessage, CustomerAddressCustomFieldChangedMessage, CustomerAddressCustomFieldRemovedMessage, CustomerAddressCustomTypeRemovedMessage, CustomerAddressCustomTypeSetMessage, CustomerAddressRemovedMessage, CustomerBillingAddressAddedMessage, CustomerBillingAddressRemovedMessage, CustomerCompanyNameSetMessage, CustomerCreatedMessage, CustomerCustomFieldAddedMessage, CustomerCustomFieldChangedMessage, CustomerCustomFieldRemovedMessage, CustomerCustomTypeRemovedMessage, CustomerCustomTypeSetMessage, CustomerDateOfBirthSetMessage, CustomerDefaultBillingAddressSetMessage, CustomerDefaultShippingAddressSetMessage, CustomerDeletedMessage, CustomerEmailChangedMessage, CustomerEmailTokenCreatedMessage, CustomerEmailVerifiedMessage, CustomerExternalIdSetMessage, CustomerFirstNameSetMessage, CustomerGroupAssignmentAddedMessage, CustomerGroupAssignmentRemovedMessage, CustomerGroupAssignmentsSetMessage, CustomerGroupCustomFieldAddedMessage, CustomerGroupCustomFieldChangedMessage, CustomerGroupCustomFieldRemovedMessage, CustomerGroupCustomTypeRemovedMessage, CustomerGroupCustomTypeSetMessage, CustomerGroupSetMessage, CustomerLastNameSetMessage, CustomerPasswordTokenCreatedMessage, CustomerPasswordUpdatedMessage, CustomerShippingAddressAddedMessage, CustomerShippingAddressRemovedMessage, CustomerStoresSetMessage, CustomerTitleSetMessage, CustomLineItemStateTransitionMessage, DeliveryAddedMessage, DeliveryAddressSetMessage, DeliveryCustomFieldAddedMessage, DeliveryCustomFieldChangedMessage, DeliveryCustomFieldRemovedMessage, DeliveryCustomTypeRemovedMessage, DeliveryCustomTypeSetMessage, DeliveryItemsUpdatedMessage, DeliveryRemovedMessage, DiscountCodeCreatedMessage, DiscountCodeDeletedMessage, DiscountCodeKeySetMessage, DiscountGroupCreatedMessage, DiscountGroupDeletedMessage, DiscountGroupIsActiveSetMessage, DiscountGroupKeySetMessage, DiscountGroupSortOrderSetMessage, InventoryEntryCreatedMessage, InventoryEntryDeletedMessage, InventoryEntryQuantitySetMessage, LineItemStateTransitionMessage, OrderBillingAddressSetMessage, OrderBusinessUnitSetMessage, OrderCreatedFromRecurringOrderMessage, OrderCreatedMessage, OrderCustomerEmailSetMessage, OrderCustomerGroupSetMessage, OrderCustomerSetMessage, OrderCustomFieldAddedMessage, OrderCustomFieldChangedMessage, OrderCustomFieldRemovedMessage, OrderCustomLineItemAddedMessage, OrderCustomLineItemDiscountSetMessage, OrderCustomLineItemQuantityChangedMessage, OrderCustomLineItemRemovedMessage, OrderCustomTypeRemovedMessage, OrderCustomTypeSetMessage, OrderDeletedMessage, OrderDiscountCodeAddedMessage, OrderDiscountCodeRemovedMessage, OrderDiscountCodeStateSetMessage, OrderEditAppliedMessage, OrderImportedMessage, OrderLineItemAddedMessage, OrderLineItemDiscountSetMessage, OrderLineItemDistributionChannelSetMessage, OrderLineItemRemovedMessage, OrderMessage, OrderPaymentAddedMessage, OrderPaymentRemovedMessage, OrderPaymentStateChangedMessage, OrderPurchaseOrderNumberSetMessage, OrderReturnShipmentStateChangedMessage, OrderShipmentStateChangedMessage, OrderShippingAddressSetMessage, OrderShippingInfoSetMessage, OrderShippingRateInputSetMessage, OrderStateChangedMessage, OrderStateTransitionMessage, OrderStoreSetMessage, ParcelAddedToDeliveryMessage, ParcelItemsUpdatedMessage, ParcelMeasurementsUpdatedMessage, ParcelRemovedFromDeliveryMessage, ParcelTrackingDataUpdatedMessage, PaymentCreatedMessage, PaymentInteractionAddedMessage, PaymentInterfaceIdSetMessage, PaymentMethodCreatedMessage, PaymentMethodCustomFieldAddedMessage, PaymentMethodCustomFieldChangedMessage, PaymentMethodCustomFieldRemovedMessage, PaymentMethodCustomTypeRemovedMessage, PaymentMethodCustomTypeSetMessage, PaymentMethodDefaultSetMessage, PaymentMethodDeletedMessage, PaymentMethodInfoCustomFieldAddedMessage, PaymentMethodInfoCustomFieldChangedMessage, PaymentMethodInfoCustomFieldRemovedMessage, PaymentMethodInfoCustomTypeRemovedMessage, PaymentMethodInfoCustomTypeSetMessage, PaymentMethodInfoInterfaceAccountSetMessage, PaymentMethodInfoInterfaceSetMessage, PaymentMethodInfoMethodSetMessage, PaymentMethodInfoNameSetMessage, PaymentMethodInfoTokenSetMessage, PaymentMethodInterfaceAccountSetMessage, PaymentMethodKeySetMessage, PaymentMethodMethodSetMessage, PaymentMethodNameSetMessage, PaymentMethodPaymentInterfaceSetMessage, PaymentMethodPaymentMethodStatusSetMessage, PaymentStatusInterfaceCodeSetMessage, PaymentStatusStateTransitionMessage, PaymentTransactionAddedMessage, PaymentTransactionInterfaceIdSetMessage, PaymentTransactionStateChangedMessage, ProductAddedToCategoryMessage, ProductCreatedMessage, ProductDeletedMessage, ProductImageAddedMessage, ProductPriceAddedMessage, ProductPriceChangedMessage, ProductPriceCustomFieldAddedMessage, ProductPriceCustomFieldChangedMessage, ProductPriceCustomFieldRemovedMessage, ProductPriceCustomFieldsRemovedMessage, ProductPriceCustomFieldsSetMessage, ProductPriceDiscountsSetMessage, ProductPriceExternalDiscountSetMessage, ProductPriceKeySetMessage, ProductPriceModeSetMessage, ProductPriceRemovedMessage, ProductPricesSetMessage, ProductPublishedMessage, ProductRemovedFromCategoryMessage, ProductRevertedStagedChangesMessage, ProductSelectionCreatedMessage, ProductSelectionDeletedMessage, ProductSelectionProductAddedMessage, ProductSelectionProductExcludedMessage, ProductSelectionProductRemovedMessage, ProductSelectionVariantExclusionChangedMessage, ProductSelectionVariantSelectionChangedMessage, ProductSlugChangedMessage, ProductStateTransitionMessage, ProductTailoringCreatedMessage, ProductTailoringDeletedMessage, ProductTailoringDescriptionSetMessage, ProductTailoringImageAddedMessage, ProductTailoringImagesSetMessage, ProductTailoringNameSetMessage, ProductTailoringPublishedMessage, ProductTailoringSlugSetMessage, ProductTailoringUnpublishedMessage, ProductUnpublishedMessage, ProductVariantAddedMessage, ProductVariantDeletedMessage, ProductVariantTailoringAddedMessage, ProductVariantTailoringRemovedMessage, QuoteCreatedMessage, QuoteCustomerChangedMessage, QuoteDeletedMessage, QuoteRenegotiationRequestedMessage, QuoteRequestCreatedMessage, QuoteRequestCustomerChangedMessage, QuoteRequestDeletedMessage, QuoteRequestStateChangedMessage, QuoteRequestStateTransitionMessage, QuoteStateChangedMessage, QuoteStateTransitionMessage, RecurringOrderCreatedMessage, RecurringOrderCustomFieldAddedMessage, RecurringOrderCustomFieldChangedMessage, RecurringOrderCustomFieldRemovedMessage, RecurringOrderCustomTypeRemovedMessage, RecurringOrderCustomTypeSetMessage, RecurringOrderDeletedMessage, RecurringOrderExpiresAtSetMessage, RecurringOrderFailedMessage, RecurringOrderKeySetMessage, RecurringOrderScheduleSetMessage, RecurringOrderStartsAtSetMessage, RecurringOrderStateChangedMessage, RecurringOrderStateTransitionMessage, ReturnInfoAddedMessage, ReturnInfoSetMessage, ReviewCreatedMessage, ReviewRatingSetMessage, ReviewStateTransitionMessage, ShoppingListLineItemAddedMessage, ShoppingListLineItemRemovedMessage, ShoppingListMessage, StagedQuoteCreatedMessage, StagedQuoteDeletedMessage, StagedQuoteSellerCommentSetMessage, StagedQuoteStateChangedMessage, StagedQuoteStateTransitionMessage, StagedQuoteValidToSetMessage, StandalonePriceActiveChangedMessage, StandalonePriceCreatedMessage, StandalonePriceDeletedMessage, StandalonePriceDiscountSetMessage, StandalonePriceExternalDiscountSetMessage, StandalonePriceKeySetMessage, StandalonePriceStagedChangesAppliedMessage, StandalonePriceStagedChangesRemovedMessage, StandalonePriceTierAddedMessage, StandalonePriceTierRemovedMessage, StandalonePriceTiersSetMessage, StandalonePriceValidFromAndUntilSetMessage, StandalonePriceValidFromSetMessage, StandalonePriceValidUntilSetMessage, StandalonePriceValueChangedMessage, StoreCountriesChangedMessage, StoreCreatedMessage, StoreDeletedMessage, StoreDistributionChannelsChangedMessage, StoreLanguagesChangedMessage, StoreNameSetMessage, StoreProductSelectionsChangedMessage, StoreSupplyChannelsChangedMessage
All Known Implementing Classes:
ApprovalFlowApprovedMessageImpl, ApprovalFlowCompletedMessageImpl, ApprovalFlowCreatedMessageImpl, ApprovalFlowRejectedMessageImpl, ApprovalRuleApproversSetMessageImpl, ApprovalRuleCreatedMessageImpl, ApprovalRuleDescriptionSetMessageImpl, ApprovalRuleKeySetMessageImpl, ApprovalRuleNameSetMessageImpl, ApprovalRulePredicateSetMessageImpl, ApprovalRuleRequestersSetMessageImpl, ApprovalRuleStatusSetMessageImpl, AssociateRoleBuyerAssignableChangedMessageImpl, AssociateRoleCreatedMessageImpl, AssociateRoleDeletedMessageImpl, AssociateRoleNameSetMessageImpl, AssociateRolePermissionAddedMessageImpl, AssociateRolePermissionRemovedMessageImpl, AssociateRolePermissionsSetMessageImpl, BusinessUnitAddressAddedMessageImpl, BusinessUnitAddressChangedMessageImpl, BusinessUnitAddressCustomFieldAddedMessageImpl, BusinessUnitAddressCustomFieldChangedMessageImpl, BusinessUnitAddressCustomFieldRemovedMessageImpl, BusinessUnitAddressCustomTypeRemovedMessageImpl, BusinessUnitAddressCustomTypeSetMessageImpl, BusinessUnitAddressRemovedMessageImpl, BusinessUnitApprovalRuleModeChangedMessageImpl, BusinessUnitAssociateAddedMessageImpl, BusinessUnitAssociateChangedMessageImpl, BusinessUnitAssociateModeChangedMessageImpl, BusinessUnitAssociateRemovedMessageImpl, BusinessUnitAssociatesSetMessageImpl, BusinessUnitBillingAddressAddedMessageImpl, BusinessUnitBillingAddressRemovedMessageImpl, BusinessUnitContactEmailSetMessageImpl, BusinessUnitCreatedMessageImpl, BusinessUnitCustomerGroupAssignmentAddedMessageImpl, BusinessUnitCustomerGroupAssignmentRemovedMessageImpl, BusinessUnitCustomerGroupAssignmentsSetMessageImpl, BusinessUnitCustomFieldAddedMessageImpl, BusinessUnitCustomFieldChangedMessageImpl, BusinessUnitCustomFieldRemovedMessageImpl, BusinessUnitCustomTypeRemovedMessageImpl, BusinessUnitCustomTypeSetMessageImpl, BusinessUnitDefaultBillingAddressSetMessageImpl, BusinessUnitDefaultShippingAddressSetMessageImpl, BusinessUnitDeletedMessageImpl, BusinessUnitNameChangedMessageImpl, BusinessUnitParentChangedMessageImpl, BusinessUnitShippingAddressAddedMessageImpl, BusinessUnitShippingAddressRemovedMessageImpl, BusinessUnitStatusChangedMessageImpl, BusinessUnitStoreAddedMessageImpl, BusinessUnitStoreModeChangedMessageImpl, BusinessUnitStoreRemovedMessageImpl, BusinessUnitStoresSetMessageImpl, BusinessUnitTopLevelUnitSetMessageImpl, BusinessUnitTypeSetMessageImpl, CartDiscountCreatedMessageImpl, CartDiscountDeletedMessageImpl, CartDiscountStoreAddedMessageImpl, CartDiscountStoreRemovedMessageImpl, CartDiscountStoresSetMessageImpl, CartFrozenMessageImpl, CartPurchaseOrderNumberSetMessageImpl, CartUnfrozenMessageImpl, CategoryCreatedMessageImpl, CategorySlugChangedMessageImpl, CustomerAddressAddedMessageImpl, CustomerAddressChangedMessageImpl, CustomerAddressCustomFieldAddedMessageImpl, CustomerAddressCustomFieldChangedMessageImpl, CustomerAddressCustomFieldRemovedMessageImpl, CustomerAddressCustomTypeRemovedMessageImpl, CustomerAddressCustomTypeSetMessageImpl, CustomerAddressRemovedMessageImpl, CustomerBillingAddressAddedMessageImpl, CustomerBillingAddressRemovedMessageImpl, CustomerCompanyNameSetMessageImpl, CustomerCreatedMessageImpl, CustomerCustomFieldAddedMessageImpl, CustomerCustomFieldChangedMessageImpl, CustomerCustomFieldRemovedMessageImpl, CustomerCustomTypeRemovedMessageImpl, CustomerCustomTypeSetMessageImpl, CustomerDateOfBirthSetMessageImpl, CustomerDefaultBillingAddressSetMessageImpl, CustomerDefaultShippingAddressSetMessageImpl, CustomerDeletedMessageImpl, CustomerEmailChangedMessageImpl, CustomerEmailTokenCreatedMessageImpl, CustomerEmailVerifiedMessageImpl, CustomerExternalIdSetMessageImpl, CustomerFirstNameSetMessageImpl, CustomerGroupAssignmentAddedMessageImpl, CustomerGroupAssignmentRemovedMessageImpl, CustomerGroupAssignmentsSetMessageImpl, CustomerGroupCustomFieldAddedMessageImpl, CustomerGroupCustomFieldChangedMessageImpl, CustomerGroupCustomFieldRemovedMessageImpl, CustomerGroupCustomTypeRemovedMessageImpl, CustomerGroupCustomTypeSetMessageImpl, CustomerGroupSetMessageImpl, CustomerLastNameSetMessageImpl, CustomerPasswordTokenCreatedMessageImpl, CustomerPasswordUpdatedMessageImpl, CustomerShippingAddressAddedMessageImpl, CustomerShippingAddressRemovedMessageImpl, CustomerStoresSetMessageImpl, CustomerTitleSetMessageImpl, CustomLineItemStateTransitionMessageImpl, DeliveryAddedMessageImpl, DeliveryAddressSetMessageImpl, DeliveryCustomFieldAddedMessageImpl, DeliveryCustomFieldChangedMessageImpl, DeliveryCustomFieldRemovedMessageImpl, DeliveryCustomTypeRemovedMessageImpl, DeliveryCustomTypeSetMessageImpl, DeliveryItemsUpdatedMessageImpl, DeliveryRemovedMessageImpl, DiscountCodeCreatedMessageImpl, DiscountCodeDeletedMessageImpl, DiscountCodeKeySetMessageImpl, DiscountGroupCreatedMessageImpl, DiscountGroupDeletedMessageImpl, DiscountGroupIsActiveSetMessageImpl, DiscountGroupKeySetMessageImpl, DiscountGroupSortOrderSetMessageImpl, InventoryEntryCreatedMessageImpl, InventoryEntryDeletedMessageImpl, InventoryEntryQuantitySetMessageImpl, LineItemStateTransitionMessageImpl, MessageImpl, OrderBillingAddressSetMessageImpl, OrderBusinessUnitSetMessageImpl, OrderCreatedFromRecurringOrderMessageImpl, OrderCreatedMessageImpl, OrderCustomerEmailSetMessageImpl, OrderCustomerGroupSetMessageImpl, OrderCustomerSetMessageImpl, OrderCustomFieldAddedMessageImpl, OrderCustomFieldChangedMessageImpl, OrderCustomFieldRemovedMessageImpl, OrderCustomLineItemAddedMessageImpl, OrderCustomLineItemDiscountSetMessageImpl, OrderCustomLineItemQuantityChangedMessageImpl, OrderCustomLineItemRemovedMessageImpl, OrderCustomTypeRemovedMessageImpl, OrderCustomTypeSetMessageImpl, OrderDeletedMessageImpl, OrderDiscountCodeAddedMessageImpl, OrderDiscountCodeRemovedMessageImpl, OrderDiscountCodeStateSetMessageImpl, OrderEditAppliedMessageImpl, OrderImportedMessageImpl, OrderLineItemAddedMessageImpl, OrderLineItemDiscountSetMessageImpl, OrderLineItemDistributionChannelSetMessageImpl, OrderLineItemRemovedMessageImpl, OrderMessageImpl, OrderPaymentAddedMessageImpl, OrderPaymentRemovedMessageImpl, OrderPaymentStateChangedMessageImpl, OrderPurchaseOrderNumberSetMessageImpl, OrderReturnShipmentStateChangedMessageImpl, OrderShipmentStateChangedMessageImpl, OrderShippingAddressSetMessageImpl, OrderShippingInfoSetMessageImpl, OrderShippingRateInputSetMessageImpl, OrderStateChangedMessageImpl, OrderStateTransitionMessageImpl, OrderStoreSetMessageImpl, ParcelAddedToDeliveryMessageImpl, ParcelItemsUpdatedMessageImpl, ParcelMeasurementsUpdatedMessageImpl, ParcelRemovedFromDeliveryMessageImpl, ParcelTrackingDataUpdatedMessageImpl, PaymentCreatedMessageImpl, PaymentInteractionAddedMessageImpl, PaymentInterfaceIdSetMessageImpl, PaymentMethodCreatedMessageImpl, PaymentMethodCustomFieldAddedMessageImpl, PaymentMethodCustomFieldChangedMessageImpl, PaymentMethodCustomFieldRemovedMessageImpl, PaymentMethodCustomTypeRemovedMessageImpl, PaymentMethodCustomTypeSetMessageImpl, PaymentMethodDefaultSetMessageImpl, PaymentMethodDeletedMessageImpl, PaymentMethodInfoCustomFieldAddedMessageImpl, PaymentMethodInfoCustomFieldChangedMessageImpl, PaymentMethodInfoCustomFieldRemovedMessageImpl, PaymentMethodInfoCustomTypeRemovedMessageImpl, PaymentMethodInfoCustomTypeSetMessageImpl, PaymentMethodInfoInterfaceAccountSetMessageImpl, PaymentMethodInfoInterfaceSetMessageImpl, PaymentMethodInfoMethodSetMessageImpl, PaymentMethodInfoNameSetMessageImpl, PaymentMethodInfoTokenSetMessageImpl, PaymentMethodInterfaceAccountSetMessageImpl, PaymentMethodKeySetMessageImpl, PaymentMethodMethodSetMessageImpl, PaymentMethodNameSetMessageImpl, PaymentMethodPaymentInterfaceSetMessageImpl, PaymentMethodPaymentMethodStatusSetMessageImpl, PaymentStatusInterfaceCodeSetMessageImpl, PaymentStatusStateTransitionMessageImpl, PaymentTransactionAddedMessageImpl, PaymentTransactionInterfaceIdSetMessageImpl, PaymentTransactionStateChangedMessageImpl, ProductAddedToCategoryMessageImpl, ProductCreatedMessageImpl, ProductDeletedMessageImpl, ProductImageAddedMessageImpl, ProductPriceAddedMessageImpl, ProductPriceChangedMessageImpl, ProductPriceCustomFieldAddedMessageImpl, ProductPriceCustomFieldChangedMessageImpl, ProductPriceCustomFieldRemovedMessageImpl, ProductPriceCustomFieldsRemovedMessageImpl, ProductPriceCustomFieldsSetMessageImpl, ProductPriceDiscountsSetMessageImpl, ProductPriceExternalDiscountSetMessageImpl, ProductPriceKeySetMessageImpl, ProductPriceModeSetMessageImpl, ProductPriceRemovedMessageImpl, ProductPricesSetMessageImpl, ProductPublishedMessageImpl, ProductRemovedFromCategoryMessageImpl, ProductRevertedStagedChangesMessageImpl, ProductSelectionCreatedMessageImpl, ProductSelectionDeletedMessageImpl, ProductSelectionProductAddedMessageImpl, ProductSelectionProductExcludedMessageImpl, ProductSelectionProductRemovedMessageImpl, ProductSelectionVariantExclusionChangedMessageImpl, ProductSelectionVariantSelectionChangedMessageImpl, ProductSlugChangedMessageImpl, ProductStateTransitionMessageImpl, ProductTailoringCreatedMessageImpl, ProductTailoringDeletedMessageImpl, ProductTailoringDescriptionSetMessageImpl, ProductTailoringImageAddedMessageImpl, ProductTailoringImagesSetMessageImpl, ProductTailoringNameSetMessageImpl, ProductTailoringPublishedMessageImpl, ProductTailoringSlugSetMessageImpl, ProductTailoringUnpublishedMessageImpl, ProductUnpublishedMessageImpl, ProductVariantAddedMessageImpl, ProductVariantDeletedMessageImpl, ProductVariantTailoringAddedMessageImpl, ProductVariantTailoringRemovedMessageImpl, QuoteCreatedMessageImpl, QuoteCustomerChangedMessageImpl, QuoteDeletedMessageImpl, QuoteRenegotiationRequestedMessageImpl, QuoteRequestCreatedMessageImpl, QuoteRequestCustomerChangedMessageImpl, QuoteRequestDeletedMessageImpl, QuoteRequestStateChangedMessageImpl, QuoteRequestStateTransitionMessageImpl, QuoteStateChangedMessageImpl, QuoteStateTransitionMessageImpl, RecurringOrderCreatedMessageImpl, RecurringOrderCustomFieldAddedMessageImpl, RecurringOrderCustomFieldChangedMessageImpl, RecurringOrderCustomFieldRemovedMessageImpl, RecurringOrderCustomTypeRemovedMessageImpl, RecurringOrderCustomTypeSetMessageImpl, RecurringOrderDeletedMessageImpl, RecurringOrderExpiresAtSetMessageImpl, RecurringOrderFailedMessageImpl, RecurringOrderKeySetMessageImpl, RecurringOrderScheduleSetMessageImpl, RecurringOrderStartsAtSetMessageImpl, RecurringOrderStateChangedMessageImpl, RecurringOrderStateTransitionMessageImpl, ReturnInfoAddedMessageImpl, ReturnInfoSetMessageImpl, ReviewCreatedMessageImpl, ReviewRatingSetMessageImpl, ReviewStateTransitionMessageImpl, ShoppingListLineItemAddedMessageImpl, ShoppingListLineItemRemovedMessageImpl, ShoppingListMessageImpl, StagedQuoteCreatedMessageImpl, StagedQuoteDeletedMessageImpl, StagedQuoteSellerCommentSetMessageImpl, StagedQuoteStateChangedMessageImpl, StagedQuoteStateTransitionMessageImpl, StagedQuoteValidToSetMessageImpl, StandalonePriceActiveChangedMessageImpl, StandalonePriceCreatedMessageImpl, StandalonePriceDeletedMessageImpl, StandalonePriceDiscountSetMessageImpl, StandalonePriceExternalDiscountSetMessageImpl, StandalonePriceKeySetMessageImpl, StandalonePriceStagedChangesAppliedMessageImpl, StandalonePriceStagedChangesRemovedMessageImpl, StandalonePriceTierAddedMessageImpl, StandalonePriceTierRemovedMessageImpl, StandalonePriceTiersSetMessageImpl, StandalonePriceValidFromAndUntilSetMessageImpl, StandalonePriceValidFromSetMessageImpl, StandalonePriceValidUntilSetMessageImpl, StandalonePriceValueChangedMessageImpl, StoreCountriesChangedMessageImpl, StoreCreatedMessageImpl, StoreDeletedMessageImpl, StoreDistributionChannelsChangedMessageImpl, StoreLanguagesChangedMessageImpl, StoreNameSetMessageImpl, StoreProductSelectionsChangedMessageImpl, StoreSupplyChannelsChangedMessageImpl

public interface Message extends BaseResource, DomainResource<Message>

Base representation of a Message containing common fields to all Message Types.


Example to create a subtype instance using the builder pattern

     Message message = Message.approvalFlowApprovedBuilder()
             id("{id}")
             version(0.3)
             createdAt(ZonedDateTime.parse("2022-01-01T12:00:00.301Z"))
             lastModifiedAt(ZonedDateTime.parse("2022-01-01T12:00:00.301Z"))
             sequenceNumber(0.3)
             resource(resourceBuilder -> resourceBuilder)
             resourceVersion(0.3)
             associate(associateBuilder -> associateBuilder)
             order(orderBuilder -> orderBuilder)
             .build()