Class MessagePagedQueryResponseImpl
- All Implemented Interfaces:
MessagePagedQueryResponse,ResourcePagedQueryResponse<Message>,io.vrap.rmf.base.client.ModelBase
PagedQueryResult with results containing an array of Message.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCount()Actual number of results returned.getLimit()Number of results requested.Number of elements skipped.Messages matching the query.getTotal()Total number of results matching the query.inthashCode()voidActual number of results returned.voidNumber of results requested.voidNumber of elements skipped.voidsetResults(Message... results) Messages matching the query.voidsetResults(List<Message> results) Messages matching the query.voidTotal number of results matching the query.toString()Methods inherited from interface com.commercetools.api.models.message.MessagePagedQueryResponse
withMessagePagedQueryResponseMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.ResourcePagedQueryResponse
getPageIndex, getTotalPages, head, isFirst, isLast
-
Constructor Details
-
MessagePagedQueryResponseImpl
public MessagePagedQueryResponseImpl()create empty instance
-
-
Method Details
-
getLimit
Number of results requested.
- Specified by:
getLimitin interfaceMessagePagedQueryResponse- Specified by:
getLimitin interfaceResourcePagedQueryResponse<Message>- Returns:
- limit
-
getCount
Actual number of results returned.
- Specified by:
getCountin interfaceMessagePagedQueryResponse- Specified by:
getCountin interfaceResourcePagedQueryResponse<Message>- Returns:
- count
-
getTotal
Total number of results matching the query. This number is an estimation that is not strongly consistent. This field is returned by default. For improved performance, calculating this field can be deactivated by using the query parameter
withTotal=false. When the results are filtered with a Query Predicate,totalis subject to a limit.- Specified by:
getTotalin interfaceMessagePagedQueryResponse- Specified by:
getTotalin interfaceResourcePagedQueryResponse<Message>- Returns:
- total
-
getOffset
Number of elements skipped.
- Specified by:
getOffsetin interfaceMessagePagedQueryResponse- Specified by:
getOffsetin interfaceResourcePagedQueryResponse<Message>- Returns:
- offset
-
getResults
Messages matching the query.
- Specified by:
getResultsin interfaceMessagePagedQueryResponse- Specified by:
getResultsin interfaceResourcePagedQueryResponse<Message>- Returns:
- results
-
setLimit
Description copied from interface:MessagePagedQueryResponseNumber of results requested.
- Specified by:
setLimitin interfaceMessagePagedQueryResponse- Parameters:
limit- value to be set
-
setCount
Description copied from interface:MessagePagedQueryResponseActual number of results returned.
- Specified by:
setCountin interfaceMessagePagedQueryResponse- Parameters:
count- value to be set
-
setTotal
Description copied from interface:MessagePagedQueryResponseTotal number of results matching the query. This number is an estimation that is not strongly consistent. This field is returned by default. For improved performance, calculating this field can be deactivated by using the query parameter
withTotal=false. When the results are filtered with a Query Predicate,totalis subject to a limit.- Specified by:
setTotalin interfaceMessagePagedQueryResponse- Parameters:
total- value to be set
-
setOffset
Description copied from interface:MessagePagedQueryResponseNumber of elements skipped.
- Specified by:
setOffsetin interfaceMessagePagedQueryResponse- Parameters:
offset- value to be set
-
setResults
Description copied from interface:MessagePagedQueryResponseMessages matching the query.
- Specified by:
setResultsin interfaceMessagePagedQueryResponse- Parameters:
results- values to be set
-
setResults
Description copied from interface:MessagePagedQueryResponseMessages matching the query.
- Specified by:
setResultsin interfaceMessagePagedQueryResponse- Parameters:
results- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceMessagePagedQueryResponse
-