Class OrderCustomFieldChangedMessagePayloadImpl
- All Implemented Interfaces:
MessagePayload,MessagePayloadMixin,OrderCustomFieldChangedMessagePayload,OrderMessagePayload,io.vrap.rmf.base.client.ModelBase
Generated when an existing Custom Field has been changed using the Set CustomField action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.message.OrderCustomFieldChangedMessagePayload
ORDER_CUSTOM_FIELD_CHANGED -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.message.MessagePayload
withMessagePayloadMethods inherited from interface com.commercetools.api.models.message.MessagePayloadMixin
asMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.message.OrderCustomFieldChangedMessagePayload
withOrderCustomFieldChangedMessagePayloadMethods inherited from interface com.commercetools.api.models.message.OrderMessagePayload
withOrderMessagePayload
-
Constructor Details
-
OrderCustomFieldChangedMessagePayloadImpl
public OrderCustomFieldChangedMessagePayloadImpl()create empty instance
-
-
Method Details
-
getType
- Specified by:
getTypein interfaceMessagePayload- Returns:
- type
-
getName
Name of the Custom Field that changed.
- Specified by:
getNamein interfaceOrderCustomFieldChangedMessagePayload- Returns:
- name
-
getValue
CustomFieldValue based on the FieldType after the Set CustomField update action.
- Specified by:
getValuein interfaceOrderCustomFieldChangedMessagePayload- Returns:
- value
-
getPreviousValue
CustomFieldValue based on the FieldType before the Set CustomField update action. When there has not been a Custom Field with the
nameon the Order before, an Order Custom Field Added Message is generated instead.- Specified by:
getPreviousValuein interfaceOrderCustomFieldChangedMessagePayload- Returns:
- previousValue
-
setName
Description copied from interface:OrderCustomFieldChangedMessagePayloadName of the Custom Field that changed.
- Specified by:
setNamein interfaceOrderCustomFieldChangedMessagePayload- Parameters:
name- value to be set
-
setValue
Description copied from interface:OrderCustomFieldChangedMessagePayloadCustomFieldValue based on the FieldType after the Set CustomField update action.
- Specified by:
setValuein interfaceOrderCustomFieldChangedMessagePayload- Parameters:
value- value to be set
-
setPreviousValue
Description copied from interface:OrderCustomFieldChangedMessagePayloadCustomFieldValue based on the FieldType before the Set CustomField update action. When there has not been a Custom Field with the
nameon the Order before, an Order Custom Field Added Message is generated instead.- Specified by:
setPreviousValuein interfaceOrderCustomFieldChangedMessagePayload- Parameters:
previousValue- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceMessagePayload- Specified by:
copyDeepin interfaceOrderCustomFieldChangedMessagePayload- Specified by:
copyDeepin interfaceOrderMessagePayload
-