Class OrderCustomLineItemDiscountSetMessageImpl
- All Implemented Interfaces:
BaseResource,DomainResource<Message>,Identifiable<Message>,Message,OrderCustomLineItemDiscountSetMessage,OrderMessage,Versioned<Message>,io.vrap.rmf.base.client.ModelBase
Generated after a successful recalculation of a Discount on a Custom Line Item.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.message.OrderCustomLineItemDiscountSetMessage
ORDER_CUSTOM_LINE_ITEM_DISCOUNT_SET -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanDate and time (UTC) the Message was generated.IDs and references that created the Message.Unique identifier for the Custom Line Item.User-defined unique identifier of the Custom Line Item.Array of DiscountedLineItemPriceForQuantity after the Discount recalculation.getId()Unique identifier of the Message.Value ofcreatedAt.IDs and references that last modified the Message.Reference to the resource on which the change or action was performed.User-provided identifiers of the resource, such askeyorexternalId.Version of the resource on which the change or action was performed.Message number in relation to other Messages for a given resource.TaxedItemPrice of the Custom Line Item after the Discount recalculation.getType()Message Type of the Message.Version of a resource.inthashCode()voidsetCreatedAt(ZonedDateTime createdAt) Date and time (UTC) the Message was generated.voidsetCreatedBy(CreatedBy createdBy) IDs and references that created the Message.voidsetCustomLineItemId(String customLineItemId) Unique identifier for the Custom Line Item.voidsetCustomLineItemKey(String customLineItemKey) User-defined unique identifier of the Custom Line Item.voidsetDiscountedPricePerQuantity(DiscountedLineItemPriceForQuantity... discountedPricePerQuantity) Array of DiscountedLineItemPriceForQuantity after the Discount recalculation.voidsetDiscountedPricePerQuantity(List<DiscountedLineItemPriceForQuantity> discountedPricePerQuantity) Array of DiscountedLineItemPriceForQuantity after the Discount recalculation.voidUnique identifier of the Message.voidsetLastModifiedAt(ZonedDateTime lastModifiedAt) Value ofcreatedAt.voidsetLastModifiedBy(LastModifiedBy lastModifiedBy) IDs and references that last modified the Message.voidsetResource(Reference resource) Reference to the resource on which the change or action was performed.voidsetResourceUserProvidedIdentifiers(UserProvidedIdentifiers resourceUserProvidedIdentifiers) User-provided identifiers of the resource, such askeyorexternalId.voidsetResourceVersion(Long resourceVersion) Version of the resource on which the change or action was performed.voidsetSequenceNumber(Long sequenceNumber) Message number in relation to other Messages for a given resource.voidsetTaxedPrice(TaxedItemPrice taxedPrice) TaxedItemPrice of the Custom Line Item after the Discount recalculation.voidsetVersion(Long version) Version of a resource.toString()Methods inherited from interface com.commercetools.api.models.common.BaseResource
withBaseResourceMethods inherited from interface com.commercetools.api.models.DomainResource
getMethods inherited from interface com.commercetools.api.models.message.Message
withMessageMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.message.OrderCustomLineItemDiscountSetMessage
withOrderCustomLineItemDiscountSetMessageMethods inherited from interface com.commercetools.api.models.message.OrderMessage
withOrderMessage
-
Constructor Details
-
OrderCustomLineItemDiscountSetMessageImpl
public OrderCustomLineItemDiscountSetMessageImpl()create empty instance
-
-
Method Details
-
getId
Unique identifier of the Message. Can be used to track which Messages have been processed.
- Specified by:
getIdin interfaceBaseResource- Specified by:
getIdin interfaceDomainResource<Message>- Specified by:
getIdin interfaceIdentifiable<Message>- Specified by:
getIdin interfaceMessage- Specified by:
getIdin interfaceVersioned<Message>- Returns:
- id
-
getVersion
Version of a resource. In case of Messages, this is always
1.- Specified by:
getVersionin interfaceBaseResource- Specified by:
getVersionin interfaceDomainResource<Message>- Specified by:
getVersionin interfaceMessage- Specified by:
getVersionin interfaceVersioned<Message>- Returns:
- version
-
getCreatedAt
Date and time (UTC) the Message was generated.
- Specified by:
getCreatedAtin interfaceBaseResource- Specified by:
getCreatedAtin interfaceMessage- Returns:
- createdAt
-
getLastModifiedAt
Value of
createdAt.- Specified by:
getLastModifiedAtin interfaceBaseResource- Specified by:
getLastModifiedAtin interfaceMessage- Returns:
- lastModifiedAt
-
getLastModifiedBy
IDs and references that last modified the Message.
- Specified by:
getLastModifiedByin interfaceMessage- Returns:
- lastModifiedBy
-
getCreatedBy
IDs and references that created the Message.
- Specified by:
getCreatedByin interfaceMessage- Returns:
- createdBy
-
getSequenceNumber
Message number in relation to other Messages for a given resource. The
sequenceNumberof the next Message for the resource is the successor of thesequenceNumberof the current Message. Meaning, thesequenceNumberof the next Message equals thesequenceNumberof the current Message + 1.sequenceNumbercan be used to ensure that Messages are processed in the correct order for a particular resource.- Specified by:
getSequenceNumberin interfaceMessage- Returns:
- sequenceNumber
-
getResource
Reference to the resource on which the change or action was performed.
- Specified by:
getResourcein interfaceMessage- Returns:
- resource
-
getResourceVersion
Version of the resource on which the change or action was performed.
- Specified by:
getResourceVersionin interfaceMessage- Returns:
- resourceVersion
-
getType
Message Type of the Message.
-
getResourceUserProvidedIdentifiers
User-provided identifiers of the resource, such as
keyorexternalId. Only present if the resource has such identifiers.- Specified by:
getResourceUserProvidedIdentifiersin interfaceMessage- Returns:
- resourceUserProvidedIdentifiers
-
getCustomLineItemId
Unique identifier for the Custom Line Item.
- Specified by:
getCustomLineItemIdin interfaceOrderCustomLineItemDiscountSetMessage- Returns:
- customLineItemId
-
getCustomLineItemKey
User-defined unique identifier of the Custom Line Item.
- Specified by:
getCustomLineItemKeyin interfaceOrderCustomLineItemDiscountSetMessage- Returns:
- customLineItemKey
-
getDiscountedPricePerQuantity
Array of DiscountedLineItemPriceForQuantity after the Discount recalculation.
- Specified by:
getDiscountedPricePerQuantityin interfaceOrderCustomLineItemDiscountSetMessage- Returns:
- discountedPricePerQuantity
-
getTaxedPrice
TaxedItemPrice of the Custom Line Item after the Discount recalculation.
- Specified by:
getTaxedPricein interfaceOrderCustomLineItemDiscountSetMessage- Returns:
- taxedPrice
-
setId
Description copied from interface:MessageUnique identifier of the Message. Can be used to track which Messages have been processed.
- Specified by:
setIdin interfaceBaseResource- Specified by:
setIdin interfaceMessage- Parameters:
id- value to be set
-
setVersion
Description copied from interface:MessageVersion of a resource. In case of Messages, this is always
1.- Specified by:
setVersionin interfaceBaseResource- Specified by:
setVersionin interfaceMessage- Parameters:
version- value to be set
-
setCreatedAt
Description copied from interface:MessageDate and time (UTC) the Message was generated.
- Specified by:
setCreatedAtin interfaceBaseResource- Specified by:
setCreatedAtin interfaceMessage- Parameters:
createdAt- value to be set
-
setLastModifiedAt
Description copied from interface:MessageValue of
createdAt.- Specified by:
setLastModifiedAtin interfaceBaseResource- Specified by:
setLastModifiedAtin interfaceMessage- Parameters:
lastModifiedAt- value to be set
-
setLastModifiedBy
Description copied from interface:MessageIDs and references that last modified the Message.
- Specified by:
setLastModifiedByin interfaceMessage- Parameters:
lastModifiedBy- value to be set
-
setCreatedBy
Description copied from interface:MessageIDs and references that created the Message.
- Specified by:
setCreatedByin interfaceMessage- Parameters:
createdBy- value to be set
-
setSequenceNumber
Description copied from interface:MessageMessage number in relation to other Messages for a given resource. The
sequenceNumberof the next Message for the resource is the successor of thesequenceNumberof the current Message. Meaning, thesequenceNumberof the next Message equals thesequenceNumberof the current Message + 1.sequenceNumbercan be used to ensure that Messages are processed in the correct order for a particular resource.- Specified by:
setSequenceNumberin interfaceMessage- Parameters:
sequenceNumber- value to be set
-
setResource
Description copied from interface:MessageReference to the resource on which the change or action was performed.
- Specified by:
setResourcein interfaceMessage- Parameters:
resource- value to be set
-
setResourceVersion
Description copied from interface:MessageVersion of the resource on which the change or action was performed.
- Specified by:
setResourceVersionin interfaceMessage- Parameters:
resourceVersion- value to be set
-
setResourceUserProvidedIdentifiers
public void setResourceUserProvidedIdentifiers(UserProvidedIdentifiers resourceUserProvidedIdentifiers) Description copied from interface:MessageUser-provided identifiers of the resource, such as
keyorexternalId. Only present if the resource has such identifiers.- Specified by:
setResourceUserProvidedIdentifiersin interfaceMessage- Parameters:
resourceUserProvidedIdentifiers- value to be set
-
setCustomLineItemId
Description copied from interface:OrderCustomLineItemDiscountSetMessageUnique identifier for the Custom Line Item.
- Specified by:
setCustomLineItemIdin interfaceOrderCustomLineItemDiscountSetMessage- Parameters:
customLineItemId- value to be set
-
setCustomLineItemKey
Description copied from interface:OrderCustomLineItemDiscountSetMessageUser-defined unique identifier of the Custom Line Item.
- Specified by:
setCustomLineItemKeyin interfaceOrderCustomLineItemDiscountSetMessage- Parameters:
customLineItemKey- value to be set
-
setDiscountedPricePerQuantity
public void setDiscountedPricePerQuantity(DiscountedLineItemPriceForQuantity... discountedPricePerQuantity) Description copied from interface:OrderCustomLineItemDiscountSetMessageArray of DiscountedLineItemPriceForQuantity after the Discount recalculation.
- Specified by:
setDiscountedPricePerQuantityin interfaceOrderCustomLineItemDiscountSetMessage- Parameters:
discountedPricePerQuantity- values to be set
-
setDiscountedPricePerQuantity
public void setDiscountedPricePerQuantity(List<DiscountedLineItemPriceForQuantity> discountedPricePerQuantity) Description copied from interface:OrderCustomLineItemDiscountSetMessageArray of DiscountedLineItemPriceForQuantity after the Discount recalculation.
- Specified by:
setDiscountedPricePerQuantityin interfaceOrderCustomLineItemDiscountSetMessage- Parameters:
discountedPricePerQuantity- values to be set
-
setTaxedPrice
Description copied from interface:OrderCustomLineItemDiscountSetMessageTaxedItemPrice of the Custom Line Item after the Discount recalculation.
- Specified by:
setTaxedPricein interfaceOrderCustomLineItemDiscountSetMessage- Parameters:
taxedPrice- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceBaseResource- Specified by:
copyDeepin interfaceMessage- Specified by:
copyDeepin interfaceOrderCustomLineItemDiscountSetMessage- Specified by:
copyDeepin interfaceOrderMessage
-