Class OrderCustomerGroupSetMessagePayloadImpl
java.lang.Object
com.commercetools.api.models.message.OrderCustomerGroupSetMessagePayloadImpl
- All Implemented Interfaces:
MessagePayload,MessagePayloadMixin,OrderCustomerGroupSetMessagePayload,OrderMessagePayload,io.vrap.rmf.base.client.ModelBase
public class OrderCustomerGroupSetMessagePayloadImpl
extends Object
implements OrderCustomerGroupSetMessagePayload, io.vrap.rmf.base.client.ModelBase
Generated after a successful Set Customer Group update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.message.OrderCustomerGroupSetMessagePayload
ORDER_CUSTOMER_GROUP_SET -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetType()inthashCode()voidsetCustomerGroup(CustomerGroupReference customerGroup) voidsetOldCustomerGroup(CustomerGroupReference oldCustomerGroup) toString()Methods inherited from interface com.commercetools.api.models.message.MessagePayload
withMessagePayloadMethods inherited from interface com.commercetools.api.models.message.MessagePayloadMixin
asMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.message.OrderCustomerGroupSetMessagePayload
withOrderCustomerGroupSetMessagePayloadMethods inherited from interface com.commercetools.api.models.message.OrderMessagePayload
withOrderMessagePayload
-
Constructor Details
-
OrderCustomerGroupSetMessagePayloadImpl
public OrderCustomerGroupSetMessagePayloadImpl()create empty instance
-
-
Method Details
-
getType
- Specified by:
getTypein interfaceMessagePayload- Returns:
- type
-
getCustomerGroup
CustomerGroup on the Order after the Set Customer Group update action.
- Specified by:
getCustomerGroupin interfaceOrderCustomerGroupSetMessagePayload- Returns:
- customerGroup
-
getOldCustomerGroup
CustomerGroup on the Order before the Set Customer Group update action.
- Specified by:
getOldCustomerGroupin interfaceOrderCustomerGroupSetMessagePayload- Returns:
- oldCustomerGroup
-
setCustomerGroup
Description copied from interface:OrderCustomerGroupSetMessagePayloadCustomerGroup on the Order after the Set Customer Group update action.
- Specified by:
setCustomerGroupin interfaceOrderCustomerGroupSetMessagePayload- Parameters:
customerGroup- value to be set
-
setOldCustomerGroup
Description copied from interface:OrderCustomerGroupSetMessagePayloadCustomerGroup on the Order before the Set Customer Group update action.
- Specified by:
setOldCustomerGroupin interfaceOrderCustomerGroupSetMessagePayload- Parameters:
oldCustomerGroup- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceMessagePayload- Specified by:
copyDeepin interfaceOrderCustomerGroupSetMessagePayload- Specified by:
copyDeepin interfaceOrderMessagePayload
-