Class OrderCustomerSetMessageImpl
- All Implemented Interfaces:
BaseResource,DomainResource<Message>,Identifiable<Message>,Message,OrderCustomerSetMessage,OrderMessage,Versioned<Message>,io.vrap.rmf.base.client.ModelBase
Generated after a successful Set Customer ID update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.message.OrderCustomerSetMessage
ORDER_CUSTOMER_SET -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanDate and time (UTC) the Message was generated.IDs and references that created the Message.getId()Unique identifier of the Message.Value ofcreatedAt.IDs and references that last modified the Message.Reference to the resource on which the change or action was performed.User-provided identifiers of the resource, such askeyorexternalId.Version of the resource on which the change or action was performed.Message number in relation to other Messages for a given resource.getType()Message Type of the Message.Version of a resource.inthashCode()voidsetCreatedAt(ZonedDateTime createdAt) Date and time (UTC) the Message was generated.voidsetCreatedBy(CreatedBy createdBy) IDs and references that created the Message.voidsetCustomer(CustomerReference customer) voidsetCustomerGroup(CustomerGroupReference customerGroup) voidUnique identifier of the Message.voidsetLastModifiedAt(ZonedDateTime lastModifiedAt) Value ofcreatedAt.voidsetLastModifiedBy(LastModifiedBy lastModifiedBy) IDs and references that last modified the Message.voidsetOldCustomer(CustomerReference oldCustomer) voidsetOldCustomerGroup(CustomerGroupReference oldCustomerGroup) voidsetResource(Reference resource) Reference to the resource on which the change or action was performed.voidsetResourceUserProvidedIdentifiers(UserProvidedIdentifiers resourceUserProvidedIdentifiers) User-provided identifiers of the resource, such askeyorexternalId.voidsetResourceVersion(Long resourceVersion) Version of the resource on which the change or action was performed.voidsetSequenceNumber(Long sequenceNumber) Message number in relation to other Messages for a given resource.voidsetVersion(Long version) Version of a resource.toString()Methods inherited from interface com.commercetools.api.models.common.BaseResource
withBaseResourceMethods inherited from interface com.commercetools.api.models.DomainResource
getMethods inherited from interface com.commercetools.api.models.message.Message
withMessageMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.message.OrderCustomerSetMessage
withOrderCustomerSetMessageMethods inherited from interface com.commercetools.api.models.message.OrderMessage
withOrderMessage
-
Constructor Details
-
OrderCustomerSetMessageImpl
public OrderCustomerSetMessageImpl()create empty instance
-
-
Method Details
-
getId
Unique identifier of the Message. Can be used to track which Messages have been processed.
- Specified by:
getIdin interfaceBaseResource- Specified by:
getIdin interfaceDomainResource<Message>- Specified by:
getIdin interfaceIdentifiable<Message>- Specified by:
getIdin interfaceMessage- Specified by:
getIdin interfaceVersioned<Message>- Returns:
- id
-
getVersion
Version of a resource. In case of Messages, this is always
1.- Specified by:
getVersionin interfaceBaseResource- Specified by:
getVersionin interfaceDomainResource<Message>- Specified by:
getVersionin interfaceMessage- Specified by:
getVersionin interfaceVersioned<Message>- Returns:
- version
-
getCreatedAt
Date and time (UTC) the Message was generated.
- Specified by:
getCreatedAtin interfaceBaseResource- Specified by:
getCreatedAtin interfaceMessage- Returns:
- createdAt
-
getLastModifiedAt
Value of
createdAt.- Specified by:
getLastModifiedAtin interfaceBaseResource- Specified by:
getLastModifiedAtin interfaceMessage- Returns:
- lastModifiedAt
-
getLastModifiedBy
IDs and references that last modified the Message.
- Specified by:
getLastModifiedByin interfaceMessage- Returns:
- lastModifiedBy
-
getCreatedBy
IDs and references that created the Message.
- Specified by:
getCreatedByin interfaceMessage- Returns:
- createdBy
-
getSequenceNumber
Message number in relation to other Messages for a given resource. The
sequenceNumberof the next Message for the resource is the successor of thesequenceNumberof the current Message. Meaning, thesequenceNumberof the next Message equals thesequenceNumberof the current Message + 1.sequenceNumbercan be used to ensure that Messages are processed in the correct order for a particular resource.- Specified by:
getSequenceNumberin interfaceMessage- Returns:
- sequenceNumber
-
getResource
Reference to the resource on which the change or action was performed.
- Specified by:
getResourcein interfaceMessage- Returns:
- resource
-
getResourceVersion
Version of the resource on which the change or action was performed.
- Specified by:
getResourceVersionin interfaceMessage- Returns:
- resourceVersion
-
getType
Message Type of the Message.
-
getResourceUserProvidedIdentifiers
User-provided identifiers of the resource, such as
keyorexternalId. Only present if the resource has such identifiers.- Specified by:
getResourceUserProvidedIdentifiersin interfaceMessage- Returns:
- resourceUserProvidedIdentifiers
-
getCustomer
Customer on the Order after the Set Customer ID update action.
- Specified by:
getCustomerin interfaceOrderCustomerSetMessage- Returns:
- customer
-
getCustomerGroup
CustomerGroup on the Order after the Set Customer ID update action.
- Specified by:
getCustomerGroupin interfaceOrderCustomerSetMessage- Returns:
- customerGroup
-
getOldCustomer
Customer on the Order before the Set Customer ID update action.
- Specified by:
getOldCustomerin interfaceOrderCustomerSetMessage- Returns:
- oldCustomer
-
getOldCustomerGroup
CustomerGroup on the Order before the Set Customer ID update action.
- Specified by:
getOldCustomerGroupin interfaceOrderCustomerSetMessage- Returns:
- oldCustomerGroup
-
setId
Description copied from interface:MessageUnique identifier of the Message. Can be used to track which Messages have been processed.
- Specified by:
setIdin interfaceBaseResource- Specified by:
setIdin interfaceMessage- Parameters:
id- value to be set
-
setVersion
Description copied from interface:MessageVersion of a resource. In case of Messages, this is always
1.- Specified by:
setVersionin interfaceBaseResource- Specified by:
setVersionin interfaceMessage- Parameters:
version- value to be set
-
setCreatedAt
Description copied from interface:MessageDate and time (UTC) the Message was generated.
- Specified by:
setCreatedAtin interfaceBaseResource- Specified by:
setCreatedAtin interfaceMessage- Parameters:
createdAt- value to be set
-
setLastModifiedAt
Description copied from interface:MessageValue of
createdAt.- Specified by:
setLastModifiedAtin interfaceBaseResource- Specified by:
setLastModifiedAtin interfaceMessage- Parameters:
lastModifiedAt- value to be set
-
setLastModifiedBy
Description copied from interface:MessageIDs and references that last modified the Message.
- Specified by:
setLastModifiedByin interfaceMessage- Parameters:
lastModifiedBy- value to be set
-
setCreatedBy
Description copied from interface:MessageIDs and references that created the Message.
- Specified by:
setCreatedByin interfaceMessage- Parameters:
createdBy- value to be set
-
setSequenceNumber
Description copied from interface:MessageMessage number in relation to other Messages for a given resource. The
sequenceNumberof the next Message for the resource is the successor of thesequenceNumberof the current Message. Meaning, thesequenceNumberof the next Message equals thesequenceNumberof the current Message + 1.sequenceNumbercan be used to ensure that Messages are processed in the correct order for a particular resource.- Specified by:
setSequenceNumberin interfaceMessage- Parameters:
sequenceNumber- value to be set
-
setResource
Description copied from interface:MessageReference to the resource on which the change or action was performed.
- Specified by:
setResourcein interfaceMessage- Parameters:
resource- value to be set
-
setResourceVersion
Description copied from interface:MessageVersion of the resource on which the change or action was performed.
- Specified by:
setResourceVersionin interfaceMessage- Parameters:
resourceVersion- value to be set
-
setResourceUserProvidedIdentifiers
public void setResourceUserProvidedIdentifiers(UserProvidedIdentifiers resourceUserProvidedIdentifiers) Description copied from interface:MessageUser-provided identifiers of the resource, such as
keyorexternalId. Only present if the resource has such identifiers.- Specified by:
setResourceUserProvidedIdentifiersin interfaceMessage- Parameters:
resourceUserProvidedIdentifiers- value to be set
-
setCustomer
Description copied from interface:OrderCustomerSetMessageCustomer on the Order after the Set Customer ID update action.
- Specified by:
setCustomerin interfaceOrderCustomerSetMessage- Parameters:
customer- value to be set
-
setCustomerGroup
Description copied from interface:OrderCustomerSetMessageCustomerGroup on the Order after the Set Customer ID update action.
- Specified by:
setCustomerGroupin interfaceOrderCustomerSetMessage- Parameters:
customerGroup- value to be set
-
setOldCustomer
Description copied from interface:OrderCustomerSetMessageCustomer on the Order before the Set Customer ID update action.
- Specified by:
setOldCustomerin interfaceOrderCustomerSetMessage- Parameters:
oldCustomer- value to be set
-
setOldCustomerGroup
Description copied from interface:OrderCustomerSetMessageCustomerGroup on the Order before the Set Customer ID update action.
- Specified by:
setOldCustomerGroupin interfaceOrderCustomerSetMessage- Parameters:
oldCustomerGroup- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceBaseResource- Specified by:
copyDeepin interfaceMessage- Specified by:
copyDeepin interfaceOrderCustomerSetMessage- Specified by:
copyDeepin interfaceOrderMessage
-