Class OrderShippingAddressSetMessagePayloadImpl
java.lang.Object
com.commercetools.api.models.message.OrderShippingAddressSetMessagePayloadImpl
- All Implemented Interfaces:
MessagePayload,MessagePayloadMixin,OrderMessagePayload,OrderShippingAddressSetMessagePayload,io.vrap.rmf.base.client.ModelBase
public class OrderShippingAddressSetMessagePayloadImpl
extends Object
implements OrderShippingAddressSetMessagePayload, io.vrap.rmf.base.client.ModelBase
Generated after a successful Set Shipping Address update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.message.OrderShippingAddressSetMessagePayload
ORDER_SHIPPING_ADDRESS_SET -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanShipping address on the Order after the Set Shipping Address update action.Shipping address on the Order before the Set Shipping Address update action.getType()inthashCode()voidsetAddress(Address address) Shipping address on the Order after the Set Shipping Address update action.voidsetOldAddress(Address oldAddress) Shipping address on the Order before the Set Shipping Address update action.toString()Methods inherited from interface com.commercetools.api.models.message.MessagePayload
withMessagePayloadMethods inherited from interface com.commercetools.api.models.message.MessagePayloadMixin
asMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.message.OrderMessagePayload
withOrderMessagePayloadMethods inherited from interface com.commercetools.api.models.message.OrderShippingAddressSetMessagePayload
withOrderShippingAddressSetMessagePayload
-
Constructor Details
-
OrderShippingAddressSetMessagePayloadImpl
public OrderShippingAddressSetMessagePayloadImpl()create empty instance
-
-
Method Details
-
getType
- Specified by:
getTypein interfaceMessagePayload- Returns:
- type
-
getAddress
Shipping address on the Order after the Set Shipping Address update action.
- Specified by:
getAddressin interfaceOrderShippingAddressSetMessagePayload- Returns:
- address
-
getOldAddress
Shipping address on the Order before the Set Shipping Address update action.
- Specified by:
getOldAddressin interfaceOrderShippingAddressSetMessagePayload- Returns:
- oldAddress
-
setAddress
Description copied from interface:OrderShippingAddressSetMessagePayloadShipping address on the Order after the Set Shipping Address update action.
- Specified by:
setAddressin interfaceOrderShippingAddressSetMessagePayload- Parameters:
address- value to be set
-
setOldAddress
Description copied from interface:OrderShippingAddressSetMessagePayloadShipping address on the Order before the Set Shipping Address update action.
- Specified by:
setOldAddressin interfaceOrderShippingAddressSetMessagePayload- Parameters:
oldAddress- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceMessagePayload- Specified by:
copyDeepin interfaceOrderMessagePayload- Specified by:
copyDeepin interfaceOrderShippingAddressSetMessagePayload
-