Class PaymentMethodCustomFieldAddedMessageImpl

java.lang.Object
com.commercetools.api.models.message.PaymentMethodCustomFieldAddedMessageImpl
All Implemented Interfaces:
BaseResource, DomainResource<Message>, Identifiable<Message>, Message, PaymentMethodCustomFieldAddedMessage, Versioned<Message>, io.vrap.rmf.base.client.ModelBase

public class PaymentMethodCustomFieldAddedMessageImpl extends Object implements PaymentMethodCustomFieldAddedMessage, io.vrap.rmf.base.client.ModelBase

Generated after adding a Custom Field to a Payment Method using the Set CustomField update action. If a Custom Field already exists with the same name, a PaymentMethodCustomFieldChanged Message is generated instead.