Class PaymentMethodInfoCustomFieldAddedMessageImpl

java.lang.Object
com.commercetools.api.models.message.PaymentMethodInfoCustomFieldAddedMessageImpl
All Implemented Interfaces:
BaseResource, DomainResource<Message>, Identifiable<Message>, Message, PaymentMethodInfoCustomFieldAddedMessage, Versioned<Message>, io.vrap.rmf.base.client.ModelBase

public class PaymentMethodInfoCustomFieldAddedMessageImpl extends Object implements PaymentMethodInfoCustomFieldAddedMessage, io.vrap.rmf.base.client.ModelBase

Generated after adding a Custom Field to a PaymentMethodInfo using the Set MethodInfo CustomField update action on Payments and the Set MethodInfo CustomField update action on My Payments. If a Custom Field already exists with the same name, a PaymentMethodInfoCustomFieldChanged Message is generated instead.