Class PaymentMethodInterfaceAccountSetMessagePayloadImpl
java.lang.Object
com.commercetools.api.models.message.PaymentMethodInterfaceAccountSetMessagePayloadImpl
- All Implemented Interfaces:
MessagePayload,MessagePayloadMixin,PaymentMethodInterfaceAccountSetMessagePayload,io.vrap.rmf.base.client.ModelBase
public class PaymentMethodInterfaceAccountSetMessagePayloadImpl
extends Object
implements PaymentMethodInterfaceAccountSetMessagePayload, io.vrap.rmf.base.client.ModelBase
Generated after a successful Set InterfaceAccount update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.message.PaymentMethodInterfaceAccountSetMessagePayload
PAYMENT_METHOD_INTERFACE_ACCOUNT_SET -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanInterface account of the Payment Method after the Set InterfaceAccount update action.Interface account of the Payment Method before the Set InterfaceAccount update action.getType()inthashCode()voidsetInterfaceAccount(String interfaceAccount) Interface account of the Payment Method after the Set InterfaceAccount update action.voidsetOldInterfaceAccount(String oldInterfaceAccount) Interface account of the Payment Method before the Set InterfaceAccount update action.toString()Methods inherited from interface com.commercetools.api.models.message.MessagePayload
withMessagePayloadMethods inherited from interface com.commercetools.api.models.message.MessagePayloadMixin
asMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.message.PaymentMethodInterfaceAccountSetMessagePayload
withPaymentMethodInterfaceAccountSetMessagePayload
-
Constructor Details
-
PaymentMethodInterfaceAccountSetMessagePayloadImpl
public PaymentMethodInterfaceAccountSetMessagePayloadImpl()create empty instance
-
-
Method Details
-
getType
- Specified by:
getTypein interfaceMessagePayload- Returns:
- type
-
getInterfaceAccount
Interface account of the Payment Method after the Set InterfaceAccount update action.
- Specified by:
getInterfaceAccountin interfacePaymentMethodInterfaceAccountSetMessagePayload- Returns:
- interfaceAccount
-
getOldInterfaceAccount
Interface account of the Payment Method before the Set InterfaceAccount update action.
- Specified by:
getOldInterfaceAccountin interfacePaymentMethodInterfaceAccountSetMessagePayload- Returns:
- oldInterfaceAccount
-
setInterfaceAccount
Description copied from interface:PaymentMethodInterfaceAccountSetMessagePayloadInterface account of the Payment Method after the Set InterfaceAccount update action.
- Specified by:
setInterfaceAccountin interfacePaymentMethodInterfaceAccountSetMessagePayload- Parameters:
interfaceAccount- value to be set
-
setOldInterfaceAccount
Description copied from interface:PaymentMethodInterfaceAccountSetMessagePayloadInterface account of the Payment Method before the Set InterfaceAccount update action.
- Specified by:
setOldInterfaceAccountin interfacePaymentMethodInterfaceAccountSetMessagePayload- Parameters:
oldInterfaceAccount- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceMessagePayload- Specified by:
copyDeepin interfacePaymentMethodInterfaceAccountSetMessagePayload
-