Class StoreCreatedMessageImpl
- All Implemented Interfaces:
BaseResource,DomainResource<Message>,Identifiable<Message>,Message,StoreCreatedMessage,Versioned<Message>,io.vrap.rmf.base.client.ModelBase
Generated after a successful Create Store request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.message.StoreCreatedMessage
STORE_CREATED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanDate and time (UTC) the Message was generated.IDs and references that created the Message.Custom Fields on the Store that was created.Distribution Channels of the Store that was created.getId()Unique identifier of the Message.Languages of the Store that was created.Value ofcreatedAt.IDs and references that last modified the Message.getName()Thenameof the Store that was created.ProductSelectionSettings of the Store that was created.Reference to the resource on which the change or action was performed.User-provided identifiers of the resource, such askeyorexternalId.Version of the resource on which the change or action was performed.Message number in relation to other Messages for a given resource.Supply Channels of the Store that was created.getType()Message Type of the Message.Version of a resource.inthashCode()voidsetCountries(StoreCountry... countries) voidsetCountries(List<StoreCountry> countries) voidsetCreatedAt(ZonedDateTime createdAt) Date and time (UTC) the Message was generated.voidsetCreatedBy(CreatedBy createdBy) IDs and references that created the Message.voidsetCustom(CustomFields custom) Custom Fields on the Store that was created.voidsetDistributionChannels(ChannelReference... distributionChannels) Distribution Channels of the Store that was created.voidsetDistributionChannels(List<ChannelReference> distributionChannels) Distribution Channels of the Store that was created.voidUnique identifier of the Message.voidsetLanguages(String... languages) Languages of the Store that was created.voidsetLanguages(List<String> languages) Languages of the Store that was created.voidsetLastModifiedAt(ZonedDateTime lastModifiedAt) Value ofcreatedAt.voidsetLastModifiedBy(LastModifiedBy lastModifiedBy) IDs and references that last modified the Message.voidsetName(LocalizedString name) Thenameof the Store that was created.voidsetProductSelections(ProductSelectionSetting... productSelections) ProductSelectionSettings of the Store that was created.voidsetProductSelections(List<ProductSelectionSetting> productSelections) ProductSelectionSettings of the Store that was created.voidsetResource(Reference resource) Reference to the resource on which the change or action was performed.voidsetResourceUserProvidedIdentifiers(UserProvidedIdentifiers resourceUserProvidedIdentifiers) User-provided identifiers of the resource, such askeyorexternalId.voidsetResourceVersion(Long resourceVersion) Version of the resource on which the change or action was performed.voidsetSequenceNumber(Long sequenceNumber) Message number in relation to other Messages for a given resource.voidsetSupplyChannels(ChannelReference... supplyChannels) Supply Channels of the Store that was created.voidsetSupplyChannels(List<ChannelReference> supplyChannels) Supply Channels of the Store that was created.voidsetVersion(Long version) Version of a resource.toString()Methods inherited from interface com.commercetools.api.models.common.BaseResource
withBaseResourceMethods inherited from interface com.commercetools.api.models.DomainResource
getMethods inherited from interface com.commercetools.api.models.message.Message
withMessageMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.message.StoreCreatedMessage
withStoreCreatedMessage
-
Constructor Details
-
StoreCreatedMessageImpl
public StoreCreatedMessageImpl()create empty instance
-
-
Method Details
-
getId
Unique identifier of the Message. Can be used to track which Messages have been processed.
- Specified by:
getIdin interfaceBaseResource- Specified by:
getIdin interfaceDomainResource<Message>- Specified by:
getIdin interfaceIdentifiable<Message>- Specified by:
getIdin interfaceMessage- Specified by:
getIdin interfaceVersioned<Message>- Returns:
- id
-
getVersion
Version of a resource. In case of Messages, this is always
1.- Specified by:
getVersionin interfaceBaseResource- Specified by:
getVersionin interfaceDomainResource<Message>- Specified by:
getVersionin interfaceMessage- Specified by:
getVersionin interfaceVersioned<Message>- Returns:
- version
-
getCreatedAt
Date and time (UTC) the Message was generated.
- Specified by:
getCreatedAtin interfaceBaseResource- Specified by:
getCreatedAtin interfaceMessage- Returns:
- createdAt
-
getLastModifiedAt
Value of
createdAt.- Specified by:
getLastModifiedAtin interfaceBaseResource- Specified by:
getLastModifiedAtin interfaceMessage- Returns:
- lastModifiedAt
-
getLastModifiedBy
IDs and references that last modified the Message.
- Specified by:
getLastModifiedByin interfaceMessage- Returns:
- lastModifiedBy
-
getCreatedBy
IDs and references that created the Message.
- Specified by:
getCreatedByin interfaceMessage- Returns:
- createdBy
-
getSequenceNumber
Message number in relation to other Messages for a given resource. The
sequenceNumberof the next Message for the resource is the successor of thesequenceNumberof the current Message. Meaning, thesequenceNumberof the next Message equals thesequenceNumberof the current Message + 1.sequenceNumbercan be used to ensure that Messages are processed in the correct order for a particular resource.- Specified by:
getSequenceNumberin interfaceMessage- Returns:
- sequenceNumber
-
getResource
Reference to the resource on which the change or action was performed.
- Specified by:
getResourcein interfaceMessage- Returns:
- resource
-
getResourceVersion
Version of the resource on which the change or action was performed.
- Specified by:
getResourceVersionin interfaceMessage- Returns:
- resourceVersion
-
getType
Message Type of the Message.
-
getResourceUserProvidedIdentifiers
User-provided identifiers of the resource, such as
keyorexternalId. Only present if the resource has such identifiers.- Specified by:
getResourceUserProvidedIdentifiersin interfaceMessage- Returns:
- resourceUserProvidedIdentifiers
-
getName
The
nameof the Store that was created.- Specified by:
getNamein interfaceStoreCreatedMessage- Returns:
- name
-
getLanguages
Languages of the Store that was created. Languages are represented as IETF language tags.
- Specified by:
getLanguagesin interfaceStoreCreatedMessage- Returns:
- languages
-
getCountries
- Specified by:
getCountriesin interfaceStoreCreatedMessage- Returns:
- countries
-
getDistributionChannels
Distribution Channels of the Store that was created.
- Specified by:
getDistributionChannelsin interfaceStoreCreatedMessage- Returns:
- distributionChannels
-
getSupplyChannels
Supply Channels of the Store that was created.
- Specified by:
getSupplyChannelsin interfaceStoreCreatedMessage- Returns:
- supplyChannels
-
getProductSelections
ProductSelectionSettings of the Store that was created.
- Specified by:
getProductSelectionsin interfaceStoreCreatedMessage- Returns:
- productSelections
-
getCustom
Custom Fields on the Store that was created.
- Specified by:
getCustomin interfaceStoreCreatedMessage- Returns:
- custom
-
setId
Description copied from interface:MessageUnique identifier of the Message. Can be used to track which Messages have been processed.
- Specified by:
setIdin interfaceBaseResource- Specified by:
setIdin interfaceMessage- Parameters:
id- value to be set
-
setVersion
Description copied from interface:MessageVersion of a resource. In case of Messages, this is always
1.- Specified by:
setVersionin interfaceBaseResource- Specified by:
setVersionin interfaceMessage- Parameters:
version- value to be set
-
setCreatedAt
Description copied from interface:MessageDate and time (UTC) the Message was generated.
- Specified by:
setCreatedAtin interfaceBaseResource- Specified by:
setCreatedAtin interfaceMessage- Parameters:
createdAt- value to be set
-
setLastModifiedAt
Description copied from interface:MessageValue of
createdAt.- Specified by:
setLastModifiedAtin interfaceBaseResource- Specified by:
setLastModifiedAtin interfaceMessage- Parameters:
lastModifiedAt- value to be set
-
setLastModifiedBy
Description copied from interface:MessageIDs and references that last modified the Message.
- Specified by:
setLastModifiedByin interfaceMessage- Parameters:
lastModifiedBy- value to be set
-
setCreatedBy
Description copied from interface:MessageIDs and references that created the Message.
- Specified by:
setCreatedByin interfaceMessage- Parameters:
createdBy- value to be set
-
setSequenceNumber
Description copied from interface:MessageMessage number in relation to other Messages for a given resource. The
sequenceNumberof the next Message for the resource is the successor of thesequenceNumberof the current Message. Meaning, thesequenceNumberof the next Message equals thesequenceNumberof the current Message + 1.sequenceNumbercan be used to ensure that Messages are processed in the correct order for a particular resource.- Specified by:
setSequenceNumberin interfaceMessage- Parameters:
sequenceNumber- value to be set
-
setResource
Description copied from interface:MessageReference to the resource on which the change or action was performed.
- Specified by:
setResourcein interfaceMessage- Parameters:
resource- value to be set
-
setResourceVersion
Description copied from interface:MessageVersion of the resource on which the change or action was performed.
- Specified by:
setResourceVersionin interfaceMessage- Parameters:
resourceVersion- value to be set
-
setResourceUserProvidedIdentifiers
public void setResourceUserProvidedIdentifiers(UserProvidedIdentifiers resourceUserProvidedIdentifiers) Description copied from interface:MessageUser-provided identifiers of the resource, such as
keyorexternalId. Only present if the resource has such identifiers.- Specified by:
setResourceUserProvidedIdentifiersin interfaceMessage- Parameters:
resourceUserProvidedIdentifiers- value to be set
-
setName
Description copied from interface:StoreCreatedMessageThe
nameof the Store that was created.- Specified by:
setNamein interfaceStoreCreatedMessage- Parameters:
name- value to be set
-
setLanguages
Description copied from interface:StoreCreatedMessageLanguages of the Store that was created. Languages are represented as IETF language tags.
- Specified by:
setLanguagesin interfaceStoreCreatedMessage- Parameters:
languages- values to be set
-
setLanguages
Description copied from interface:StoreCreatedMessageLanguages of the Store that was created. Languages are represented as IETF language tags.
- Specified by:
setLanguagesin interfaceStoreCreatedMessage- Parameters:
languages- values to be set
-
setCountries
Description copied from interface:StoreCreatedMessage- Specified by:
setCountriesin interfaceStoreCreatedMessage- Parameters:
countries- values to be set
-
setCountries
Description copied from interface:StoreCreatedMessage- Specified by:
setCountriesin interfaceStoreCreatedMessage- Parameters:
countries- values to be set
-
setDistributionChannels
Description copied from interface:StoreCreatedMessageDistribution Channels of the Store that was created.
- Specified by:
setDistributionChannelsin interfaceStoreCreatedMessage- Parameters:
distributionChannels- values to be set
-
setDistributionChannels
Description copied from interface:StoreCreatedMessageDistribution Channels of the Store that was created.
- Specified by:
setDistributionChannelsin interfaceStoreCreatedMessage- Parameters:
distributionChannels- values to be set
-
setSupplyChannels
Description copied from interface:StoreCreatedMessageSupply Channels of the Store that was created.
- Specified by:
setSupplyChannelsin interfaceStoreCreatedMessage- Parameters:
supplyChannels- values to be set
-
setSupplyChannels
Description copied from interface:StoreCreatedMessageSupply Channels of the Store that was created.
- Specified by:
setSupplyChannelsin interfaceStoreCreatedMessage- Parameters:
supplyChannels- values to be set
-
setProductSelections
Description copied from interface:StoreCreatedMessageProductSelectionSettings of the Store that was created.
- Specified by:
setProductSelectionsin interfaceStoreCreatedMessage- Parameters:
productSelections- values to be set
-
setProductSelections
Description copied from interface:StoreCreatedMessageProductSelectionSettings of the Store that was created.
- Specified by:
setProductSelectionsin interfaceStoreCreatedMessage- Parameters:
productSelections- values to be set
-
setCustom
Description copied from interface:StoreCreatedMessageCustom Fields on the Store that was created.
- Specified by:
setCustomin interfaceStoreCreatedMessage- Parameters:
custom- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceBaseResource- Specified by:
copyDeepin interfaceMessage- Specified by:
copyDeepin interfaceStoreCreatedMessage
-