Class OrderSetCustomLineItemCustomFieldActionImpl
- All Implemented Interfaces:
OrderSetCustomLineItemCustomFieldAction,OrderUpdateAction,ResourceUpdateAction<OrderUpdateAction>,io.vrap.rmf.base.client.ModelBase
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.order.OrderSetCustomLineItemCustomFieldAction
SET_CUSTOM_LINE_ITEM_CUSTOM_FIELD -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanidof the CustomLineItem to update.keyof the CustomLineItem to update.getName()Name of the Custom Field.getValue()Ifvalueis absent ornull, this field will be removed if it exists.inthashCode()voidsetCustomLineItemId(String customLineItemId) idof the CustomLineItem to update.voidsetCustomLineItemKey(String customLineItemKey) keyof the CustomLineItem to update.voidName of the Custom Field.voidIfvalueis absent ornull, this field will be removed if it exists.toString()Methods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.order.OrderSetCustomLineItemCustomFieldAction
withOrderSetCustomLineItemCustomFieldActionMethods inherited from interface com.commercetools.api.models.order.OrderUpdateAction
withOrderUpdateActionMethods inherited from interface com.commercetools.api.models.ResourceUpdateAction
get
-
Constructor Details
-
OrderSetCustomLineItemCustomFieldActionImpl
public OrderSetCustomLineItemCustomFieldActionImpl()create empty instance
-
-
Method Details
-
getAction
- Specified by:
getActionin interfaceOrderUpdateAction- Specified by:
getActionin interfaceResourceUpdateAction<OrderUpdateAction>- Returns:
- action
-
getCustomLineItemId
idof the CustomLineItem to update. EithercustomLineItemIdorcustomLineItemKeyis required.- Specified by:
getCustomLineItemIdin interfaceOrderSetCustomLineItemCustomFieldAction- Returns:
- customLineItemId
-
getCustomLineItemKey
keyof the CustomLineItem to update. EithercustomLineItemIdorcustomLineItemKeyis required.- Specified by:
getCustomLineItemKeyin interfaceOrderSetCustomLineItemCustomFieldAction- Returns:
- customLineItemKey
-
getName
Name of the Custom Field.
- Specified by:
getNamein interfaceOrderSetCustomLineItemCustomFieldAction- Returns:
- name
-
getValue
If
valueis absent ornull, this field will be removed if it exists. Removing a field that does not exist returns an InvalidOperation error. Ifvalueis provided, it is set for the field defined byname.- Specified by:
getValuein interfaceOrderSetCustomLineItemCustomFieldAction- Returns:
- value
-
setCustomLineItemId
Description copied from interface:OrderSetCustomLineItemCustomFieldActionidof the CustomLineItem to update. EithercustomLineItemIdorcustomLineItemKeyis required.- Specified by:
setCustomLineItemIdin interfaceOrderSetCustomLineItemCustomFieldAction- Parameters:
customLineItemId- value to be set
-
setCustomLineItemKey
Description copied from interface:OrderSetCustomLineItemCustomFieldActionkeyof the CustomLineItem to update. EithercustomLineItemIdorcustomLineItemKeyis required.- Specified by:
setCustomLineItemKeyin interfaceOrderSetCustomLineItemCustomFieldAction- Parameters:
customLineItemKey- value to be set
-
setName
Description copied from interface:OrderSetCustomLineItemCustomFieldActionName of the Custom Field.
- Specified by:
setNamein interfaceOrderSetCustomLineItemCustomFieldAction- Parameters:
name- value to be set
-
setValue
Description copied from interface:OrderSetCustomLineItemCustomFieldActionIf
valueis absent ornull, this field will be removed if it exists. Removing a field that does not exist returns an InvalidOperation error. Ifvalueis provided, it is set for the field defined byname.- Specified by:
setValuein interfaceOrderSetCustomLineItemCustomFieldAction- Parameters:
value- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceOrderSetCustomLineItemCustomFieldAction- Specified by:
copyDeepin interfaceOrderUpdateAction
-