Class ProjectImpl
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanHolds configuration specific to Business Units.getCarts()Holds the configuration for the Carts feature.Country code of the geographic location.Date and time (UTC) the Project was initially created.Currency code of the country.Holds configuration specific to discounts, including how Product and Cart Discounts are combined in every Cart of the Project.Represents a RFC 7662 compliant OAuth 2.0 Token Introspection endpoint.getKey()User-defined unique identifier of the Project.Language of the country.Holds the configuration for the Messages Query feature.getName()Name of the Project.Controls indexing of resources to be provided on high performance read-only search endpoints.Holds the configuration for the tiered shipping rates feature.Holds the configuration for the Shopping Lists feature.Date in YYYY-MM format specifying when the trial period for the Project ends.Current version of the Project.inthashCode()voidsetBusinessUnits(BusinessUnitConfiguration businessUnits) Holds configuration specific to Business Units.voidsetCarts(CartsConfiguration carts) Holds the configuration for the Carts feature.voidsetCountries(String... countries) Country code of the geographic location.voidsetCountries(List<String> countries) Country code of the geographic location.voidsetCreatedAt(ZonedDateTime createdAt) Date and time (UTC) the Project was initially created.voidsetCurrencies(String... currencies) Currency code of the country.voidsetCurrencies(List<String> currencies) Currency code of the country.voidsetDiscounts(DiscountsConfiguration discounts) Holds configuration specific to discounts, including how Product and Cart Discounts are combined in every Cart of the Project.voidsetExternalOAuth(ExternalOAuth externalOAuth) Represents a RFC 7662 compliant OAuth 2.0 Token Introspection endpoint.voidUser-defined unique identifier of the Project.voidsetLanguages(String... languages) Language of the country.voidsetLanguages(List<String> languages) Language of the country.voidsetMessages(MessagesConfiguration messages) Holds the configuration for the Messages Query feature.voidName of the Project.voidsetSearchIndexing(SearchIndexingConfiguration searchIndexing) Controls indexing of resources to be provided on high performance read-only search endpoints.voidsetShippingRateInputType(ShippingRateInputType shippingRateInputType) Holds the configuration for the tiered shipping rates feature.voidsetShoppingLists(ShoppingListsConfiguration shoppingLists) Holds the configuration for the Shopping Lists feature.voidsetTrialUntil(String trialUntil) Date in YYYY-MM format specifying when the trial period for the Project ends.voidsetVersion(Long version) Current version of the Project.toString()Methods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.project.Project
withProject
-
Constructor Details
-
ProjectImpl
public ProjectImpl()create empty instance
-
-
Method Details
-
getVersion
Current version of the Project.
- Specified by:
getVersionin interfaceProject- Returns:
- version
-
getKey
User-defined unique identifier of the Project.
-
getName
Name of the Project.
-
getCountries
Country code of the geographic location.
- Specified by:
getCountriesin interfaceProject- Returns:
- countries
-
getCurrencies
Currency code of the country. A Project must have at least one currency.
- Specified by:
getCurrenciesin interfaceProject- Returns:
- currencies
-
getLanguages
Language of the country. A Project must have at least one language.
- Specified by:
getLanguagesin interfaceProject- Returns:
- languages
-
getCreatedAt
Date and time (UTC) the Project was initially created.
- Specified by:
getCreatedAtin interfaceProject- Returns:
- createdAt
-
getTrialUntil
Date in YYYY-MM format specifying when the trial period for the Project ends. Only present on Projects in trial period.
- Specified by:
getTrialUntilin interfaceProject- Returns:
- trialUntil
-
getMessages
Holds the configuration for the Messages Query feature.
- Specified by:
getMessagesin interfaceProject- Returns:
- messages
-
getCarts
Holds the configuration for the Carts feature.
-
getShoppingLists
Holds the configuration for the Shopping Lists feature.
- Specified by:
getShoppingListsin interfaceProject- Returns:
- shoppingLists
-
getShippingRateInputType
Holds the configuration for the tiered shipping rates feature.
- Specified by:
getShippingRateInputTypein interfaceProject- Returns:
- shippingRateInputType
-
getExternalOAuth
Represents a RFC 7662 compliant OAuth 2.0 Token Introspection endpoint.
- Specified by:
getExternalOAuthin interfaceProject- Returns:
- externalOAuth
-
getSearchIndexing
Controls indexing of resources to be provided on high performance read-only search endpoints.
- Specified by:
getSearchIndexingin interfaceProject- Returns:
- searchIndexing
-
getBusinessUnits
Holds configuration specific to Business Units.
- Specified by:
getBusinessUnitsin interfaceProject- Returns:
- businessUnits
-
getDiscounts
Holds configuration specific to discounts, including how Product and Cart Discounts are combined in every Cart of the Project.
- Specified by:
getDiscountsin interfaceProject- Returns:
- discounts
-
setVersion
Description copied from interface:ProjectCurrent version of the Project.
- Specified by:
setVersionin interfaceProject- Parameters:
version- value to be set
-
setKey
Description copied from interface:ProjectUser-defined unique identifier of the Project.
-
setName
Description copied from interface:ProjectName of the Project.
-
setCountries
Description copied from interface:ProjectCountry code of the geographic location.
- Specified by:
setCountriesin interfaceProject- Parameters:
countries- values to be set
-
setCountries
Description copied from interface:ProjectCountry code of the geographic location.
- Specified by:
setCountriesin interfaceProject- Parameters:
countries- values to be set
-
setCurrencies
Description copied from interface:ProjectCurrency code of the country. A Project must have at least one currency.
- Specified by:
setCurrenciesin interfaceProject- Parameters:
currencies- values to be set
-
setCurrencies
Description copied from interface:ProjectCurrency code of the country. A Project must have at least one currency.
- Specified by:
setCurrenciesin interfaceProject- Parameters:
currencies- values to be set
-
setLanguages
Description copied from interface:ProjectLanguage of the country. A Project must have at least one language.
- Specified by:
setLanguagesin interfaceProject- Parameters:
languages- values to be set
-
setLanguages
Description copied from interface:ProjectLanguage of the country. A Project must have at least one language.
- Specified by:
setLanguagesin interfaceProject- Parameters:
languages- values to be set
-
setCreatedAt
Description copied from interface:ProjectDate and time (UTC) the Project was initially created.
- Specified by:
setCreatedAtin interfaceProject- Parameters:
createdAt- value to be set
-
setTrialUntil
Description copied from interface:ProjectDate in YYYY-MM format specifying when the trial period for the Project ends. Only present on Projects in trial period.
- Specified by:
setTrialUntilin interfaceProject- Parameters:
trialUntil- value to be set
-
setMessages
Description copied from interface:ProjectHolds the configuration for the Messages Query feature.
- Specified by:
setMessagesin interfaceProject- Parameters:
messages- value to be set
-
setCarts
Description copied from interface:ProjectHolds the configuration for the Carts feature.
-
setShoppingLists
Description copied from interface:ProjectHolds the configuration for the Shopping Lists feature.
- Specified by:
setShoppingListsin interfaceProject- Parameters:
shoppingLists- value to be set
-
setShippingRateInputType
Description copied from interface:ProjectHolds the configuration for the tiered shipping rates feature.
- Specified by:
setShippingRateInputTypein interfaceProject- Parameters:
shippingRateInputType- value to be set
-
setExternalOAuth
Description copied from interface:ProjectRepresents a RFC 7662 compliant OAuth 2.0 Token Introspection endpoint.
- Specified by:
setExternalOAuthin interfaceProject- Parameters:
externalOAuth- value to be set
-
setSearchIndexing
Description copied from interface:ProjectControls indexing of resources to be provided on high performance read-only search endpoints.
- Specified by:
setSearchIndexingin interfaceProject- Parameters:
searchIndexing- value to be set
-
setBusinessUnits
Description copied from interface:ProjectHolds configuration specific to Business Units.
- Specified by:
setBusinessUnitsin interfaceProject- Parameters:
businessUnits- value to be set
-
setDiscounts
Description copied from interface:ProjectHolds configuration specific to discounts, including how Product and Cart Discounts are combined in every Cart of the Project.
- Specified by:
setDiscountsin interfaceProject- Parameters:
discounts- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
-