Class ProjectSetDiscountsConfigurationActionImpl
java.lang.Object
com.commercetools.api.models.project.ProjectSetDiscountsConfigurationActionImpl
- All Implemented Interfaces:
ProjectSetDiscountsConfigurationAction,ProjectUpdateAction,ResourceUpdateAction<ProjectUpdateAction>,io.vrap.rmf.base.client.ModelBase
public class ProjectSetDiscountsConfigurationActionImpl
extends Object
implements ProjectSetDiscountsConfigurationAction, io.vrap.rmf.base.client.ModelBase
ProjectSetDiscountsConfigurationAction
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.project.ProjectSetDiscountsConfigurationAction
SET_DISCOUNTS_CONFIGURATION -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanConfiguration for the behavior of Cart and Product Discounts in the Project.inthashCode()voidsetDiscountsConfiguration(DiscountsConfiguration discountsConfiguration) Configuration for the behavior of Cart and Product Discounts in the Project.toString()Methods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.project.ProjectSetDiscountsConfigurationAction
withProjectSetDiscountsConfigurationActionMethods inherited from interface com.commercetools.api.models.project.ProjectUpdateAction
withProjectUpdateActionMethods inherited from interface com.commercetools.api.models.ResourceUpdateAction
get
-
Constructor Details
-
ProjectSetDiscountsConfigurationActionImpl
public ProjectSetDiscountsConfigurationActionImpl()create empty instance
-
-
Method Details
-
getAction
- Specified by:
getActionin interfaceProjectUpdateAction- Specified by:
getActionin interfaceResourceUpdateAction<ProjectUpdateAction>- Returns:
- action
-
getDiscountsConfiguration
Configuration for the behavior of Cart and Product Discounts in the Project.
- Specified by:
getDiscountsConfigurationin interfaceProjectSetDiscountsConfigurationAction- Returns:
- discountsConfiguration
-
setDiscountsConfiguration
Description copied from interface:ProjectSetDiscountsConfigurationActionConfiguration for the behavior of Cart and Product Discounts in the Project.
- Specified by:
setDiscountsConfigurationin interfaceProjectSetDiscountsConfigurationAction- Parameters:
discountsConfiguration- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceProjectSetDiscountsConfigurationAction- Specified by:
copyDeepin interfaceProjectUpdateAction
-