Class StatePagedQueryResponseImpl
- All Implemented Interfaces:
ResourcePagedQueryResponse<State>,StatePagedQueryResponse,io.vrap.rmf.base.client.ModelBase
PagedQueryResult with results containing an array of State.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCount()Actual number of results returned.getLimit()Number of results requested.Number of elements skipped.States matching the query.getTotal()Total number of results matching the query.inthashCode()voidActual number of results returned.voidNumber of results requested.voidNumber of elements skipped.voidsetResults(State... results) States matching the query.voidsetResults(List<State> results) States matching the query.voidTotal number of results matching the query.toString()Methods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.ResourcePagedQueryResponse
getPageIndex, getTotalPages, head, isFirst, isLastMethods inherited from interface com.commercetools.api.models.state.StatePagedQueryResponse
withStatePagedQueryResponse
-
Constructor Details
-
StatePagedQueryResponseImpl
public StatePagedQueryResponseImpl()create empty instance
-
-
Method Details
-
getLimit
Number of results requested.
- Specified by:
getLimitin interfaceResourcePagedQueryResponse<State>- Specified by:
getLimitin interfaceStatePagedQueryResponse- Returns:
- limit
-
getOffset
Number of elements skipped.
- Specified by:
getOffsetin interfaceResourcePagedQueryResponse<State>- Specified by:
getOffsetin interfaceStatePagedQueryResponse- Returns:
- offset
-
getCount
Actual number of results returned.
- Specified by:
getCountin interfaceResourcePagedQueryResponse<State>- Specified by:
getCountin interfaceStatePagedQueryResponse- Returns:
- count
-
getTotal
Total number of results matching the query. This number is an estimation that is not strongly consistent. This field is returned by default. For improved performance, calculating this field can be deactivated by using the query parameter
withTotal=false. When the results are filtered with a Query Predicate,totalis subject to a limit.- Specified by:
getTotalin interfaceResourcePagedQueryResponse<State>- Specified by:
getTotalin interfaceStatePagedQueryResponse- Returns:
- total
-
getResults
States matching the query.
- Specified by:
getResultsin interfaceResourcePagedQueryResponse<State>- Specified by:
getResultsin interfaceStatePagedQueryResponse- Returns:
- results
-
setLimit
Description copied from interface:StatePagedQueryResponseNumber of results requested.
- Specified by:
setLimitin interfaceStatePagedQueryResponse- Parameters:
limit- value to be set
-
setOffset
Description copied from interface:StatePagedQueryResponseNumber of elements skipped.
- Specified by:
setOffsetin interfaceStatePagedQueryResponse- Parameters:
offset- value to be set
-
setCount
Description copied from interface:StatePagedQueryResponseActual number of results returned.
- Specified by:
setCountin interfaceStatePagedQueryResponse- Parameters:
count- value to be set
-
setTotal
Description copied from interface:StatePagedQueryResponseTotal number of results matching the query. This number is an estimation that is not strongly consistent. This field is returned by default. For improved performance, calculating this field can be deactivated by using the query parameter
withTotal=false. When the results are filtered with a Query Predicate,totalis subject to a limit.- Specified by:
setTotalin interfaceStatePagedQueryResponse- Parameters:
total- value to be set
-
setResults
Description copied from interface:StatePagedQueryResponseStates matching the query.
- Specified by:
setResultsin interfaceStatePagedQueryResponse- Parameters:
results- values to be set
-
setResults
Description copied from interface:StatePagedQueryResponseStates matching the query.
- Specified by:
setResultsin interfaceStatePagedQueryResponse- Parameters:
results- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceStatePagedQueryResponse
-