Class ApiClientImpl
- All Implemented Interfaces:
ApiClient,Identifiable<ApiClient>,io.vrap.rmf.base.client.ModelBase
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanExpiration time in seconds for each access token obtained by the APIClient.Date and time (UTC) the APIClient was initially created.If set, the Client will be deleted on (or shortly after) this point in time.getId()The OAuth2client_idthat can be used to obtain an access token.Date of the last day this APIClient was used to obtain an access token.getName()Name of the APIClient.Inactivity expiration time in seconds for each refresh token obtained by the APIClient.getScope()Whitespace-separated list of OAuth scopes that can be used when obtaining an access token.Only shown once in the response of creating the APIClient.inthashCode()voidsetAccessTokenValiditySeconds(Integer accessTokenValiditySeconds) Expiration time in seconds for each access token obtained by the APIClient.voidsetCreatedAt(ZonedDateTime createdAt) Date and time (UTC) the APIClient was initially created.voidsetDeleteAt(ZonedDateTime deleteAt) If set, the Client will be deleted on (or shortly after) this point in time.voidThe OAuth2client_idthat can be used to obtain an access token.voidsetLastUsedAt(LocalDate lastUsedAt) Date of the last day this APIClient was used to obtain an access token.voidName of the APIClient.voidsetRefreshTokenValiditySeconds(Integer refreshTokenValiditySeconds) Inactivity expiration time in seconds for each refresh token obtained by the APIClient.voidWhitespace-separated list of OAuth scopes that can be used when obtaining an access token.voidOnly shown once in the response of creating the APIClient.toString()Methods inherited from interface com.commercetools.api.models.api_client.ApiClient
withApiClientMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
ApiClientImpl
public ApiClientImpl()create empty instance
-
-
Method Details
-
getId
The OAuth2
client_idthat can be used to obtain an access token.- Specified by:
getIdin interfaceApiClient- Specified by:
getIdin interfaceIdentifiable<ApiClient>- Returns:
- id
-
getName
Name of the APIClient.
-
getScope
Whitespace-separated list of OAuth scopes that can be used when obtaining an access token.
-
getSecret
Only shown once in the response of creating the APIClient. This is the OAuth2
client_secretthat can be used to obtain an access token. -
getLastUsedAt
Date of the last day this APIClient was used to obtain an access token.
- Specified by:
getLastUsedAtin interfaceApiClient- Returns:
- lastUsedAt
-
getDeleteAt
If set, the Client will be deleted on (or shortly after) this point in time.
- Specified by:
getDeleteAtin interfaceApiClient- Returns:
- deleteAt
-
getCreatedAt
Date and time (UTC) the APIClient was initially created.
- Specified by:
getCreatedAtin interfaceApiClient- Returns:
- createdAt
-
getAccessTokenValiditySeconds
Expiration time in seconds for each access token obtained by the APIClient. Only present when set with the APIClientDraft. If not present the default value applies.
- Specified by:
getAccessTokenValiditySecondsin interfaceApiClient- Returns:
- accessTokenValiditySeconds
-
getRefreshTokenValiditySeconds
Inactivity expiration time in seconds for each refresh token obtained by the APIClient. Only present when set with the APIClientDraft. If not present the default value applies.
- Specified by:
getRefreshTokenValiditySecondsin interfaceApiClient- Returns:
- refreshTokenValiditySeconds
-
setId
Description copied from interface:ApiClientThe OAuth2
client_idthat can be used to obtain an access token. -
setName
Description copied from interface:ApiClientName of the APIClient.
-
setScope
Description copied from interface:ApiClientWhitespace-separated list of OAuth scopes that can be used when obtaining an access token.
-
setSecret
Description copied from interface:ApiClientOnly shown once in the response of creating the APIClient. This is the OAuth2
client_secretthat can be used to obtain an access token. -
setLastUsedAt
Description copied from interface:ApiClientDate of the last day this APIClient was used to obtain an access token.
- Specified by:
setLastUsedAtin interfaceApiClient- Parameters:
lastUsedAt- value to be set
-
setDeleteAt
Description copied from interface:ApiClientIf set, the Client will be deleted on (or shortly after) this point in time.
- Specified by:
setDeleteAtin interfaceApiClient- Parameters:
deleteAt- value to be set
-
setCreatedAt
Description copied from interface:ApiClientDate and time (UTC) the APIClient was initially created.
- Specified by:
setCreatedAtin interfaceApiClient- Parameters:
createdAt- value to be set
-
setAccessTokenValiditySeconds
Description copied from interface:ApiClientExpiration time in seconds for each access token obtained by the APIClient. Only present when set with the APIClientDraft. If not present the default value applies.
- Specified by:
setAccessTokenValiditySecondsin interfaceApiClient- Parameters:
accessTokenValiditySeconds- value to be set
-
setRefreshTokenValiditySeconds
Description copied from interface:ApiClientInactivity expiration time in seconds for each refresh token obtained by the APIClient. Only present when set with the APIClientDraft. If not present the default value applies.
- Specified by:
setRefreshTokenValiditySecondsin interfaceApiClient- Parameters:
refreshTokenValiditySeconds- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
-