Class CountryNotConfiguredInStoreErrorImpl
java.lang.Object
com.commercetools.api.models.error.CountryNotConfiguredInStoreErrorImpl
- All Implemented Interfaces:
CountryNotConfiguredInStoreError,ErrorObject,io.vrap.rmf.base.client.ModelBase
public class CountryNotConfiguredInStoreErrorImpl
extends Object
implements CountryNotConfiguredInStoreError, io.vrap.rmf.base.client.ModelBase
Returned when a Cart or an Order in a Store references a country that is not included in the countries configured for the Store.
The error is returned as a failed response to:
- Create Cart in Store request and Set Country update action on Carts.
- Create Cart in Store request and Set Country update action on My Carts.
- Create Order in Store from Cart and Create Order from Quote requests on Orders.
- Create Order in Store from Cart and Create Order from Quote requests on My Orders.
- Create Order by Import request on Order Import.
- Set Country update action on Order Edits.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.CountryNotConfiguredInStoreError
COUNTRY_NOT_CONFIGURED_IN_STORE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.The country that is not configured for the Store but referenced on the Cart or Order."The country $country is not configured for the store $store."Countries configured for the Store.inthashCode()voidsetCountry(String country) The country that is not configured for the Store but referenced on the Cart or Order.voidsetMessage(String message) "The country $country is not configured for the store $store."voidsetStoreCountries(String... storeCountries) Countries configured for the Store.voidsetStoreCountries(List<String> storeCountries) Countries configured for the Store.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.CountryNotConfiguredInStoreError
withCountryNotConfiguredInStoreErrorMethods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
CountryNotConfiguredInStoreErrorImpl
public CountryNotConfiguredInStoreErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceCountryNotConfiguredInStoreError- Specified by:
getCodein interfaceErrorObject- Returns:
- code
-
getMessage
"The country $country is not configured for the store $store."- Specified by:
getMessagein interfaceCountryNotConfiguredInStoreError- Specified by:
getMessagein interfaceErrorObject- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getStoreCountries
Countries configured for the Store.
- Specified by:
getStoreCountriesin interfaceCountryNotConfiguredInStoreError- Returns:
- storeCountries
-
getCountry
The country that is not configured for the Store but referenced on the Cart or Order.
- Specified by:
getCountryin interfaceCountryNotConfiguredInStoreError- Returns:
- country
-
setMessage
Description copied from interface:CountryNotConfiguredInStoreError"The country $country is not configured for the store $store."- Specified by:
setMessagein interfaceCountryNotConfiguredInStoreError- Specified by:
setMessagein interfaceErrorObject- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setStoreCountries
Description copied from interface:CountryNotConfiguredInStoreErrorCountries configured for the Store.
- Specified by:
setStoreCountriesin interfaceCountryNotConfiguredInStoreError- Parameters:
storeCountries- values to be set
-
setStoreCountries
Description copied from interface:CountryNotConfiguredInStoreErrorCountries configured for the Store.
- Specified by:
setStoreCountriesin interfaceCountryNotConfiguredInStoreError- Parameters:
storeCountries- values to be set
-
setCountry
Description copied from interface:CountryNotConfiguredInStoreErrorThe country that is not configured for the Store but referenced on the Cart or Order.
- Specified by:
setCountryin interfaceCountryNotConfiguredInStoreError- Parameters:
country- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceCountryNotConfiguredInStoreError- Specified by:
copyDeepin interfaceErrorObject
-