Class ExpiredCustomerEmailTokenErrorImpl
java.lang.Object
com.commercetools.api.models.error.ExpiredCustomerEmailTokenErrorImpl
- All Implemented Interfaces:
ErrorObject,ExpiredCustomerEmailTokenError,io.vrap.rmf.base.client.ModelBase
public class ExpiredCustomerEmailTokenErrorImpl
extends Object
implements ExpiredCustomerEmailTokenError, io.vrap.rmf.base.client.ModelBase
Returned when the provided email token of the Customer has expired.
The error is returned as a failed response to:
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.ExpiredCustomerEmailTokenError
EXPIRED_CUSTOMER_EMAIL_TOKEN -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.ExpiredCustomerEmailTokenError
withExpiredCustomerEmailTokenErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
ExpiredCustomerEmailTokenErrorImpl
public ExpiredCustomerEmailTokenErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceExpiredCustomerEmailTokenError- Returns:
- code
-
getMessage
"The given email token has expired."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceExpiredCustomerEmailTokenError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:ExpiredCustomerEmailTokenError"The given email token has expired."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceExpiredCustomerEmailTokenError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceExpiredCustomerEmailTokenError
-