Class GeneralErrorImpl
java.lang.Object
com.commercetools.api.models.error.GeneralErrorImpl
- All Implemented Interfaces:
ErrorObject,GeneralError,io.vrap.rmf.base.client.ModelBase
public class GeneralErrorImpl
extends Object
implements GeneralError, io.vrap.rmf.base.client.ModelBase
Returned when a server-side problem occurs before or after data persistence. In some cases, the requested action may successfully complete after the error is returned. Therefore, it is recommended to verify the status of the requested resource after receiving a 500 error.
If you encounter this error, report it to the commercetools support team.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GeneralError
GENERAL -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Description about any known details of the problem, for example,"Write operations are temporarily unavailable".inthashCode()voidsetMessage(String message) Description about any known details of the problem, for example,"Write operations are temporarily unavailable".voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.GeneralError
withGeneralErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GeneralErrorImpl
public GeneralErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceGeneralError- Returns:
- code
-
getMessage
Description about any known details of the problem, for example,
"Write operations are temporarily unavailable".- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceGeneralError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:GeneralErrorDescription about any known details of the problem, for example,
"Write operations are temporarily unavailable".- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceGeneralError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceGeneralError
-