Class GraphQLCountryNotConfiguredInStoreErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLCountryNotConfiguredInStoreErrorImpl
- All Implemented Interfaces:
GraphQLCountryNotConfiguredInStoreError,GraphQLErrorObject,io.vrap.rmf.base.client.ModelBase
public class GraphQLCountryNotConfiguredInStoreErrorImpl
extends Object
implements GraphQLCountryNotConfiguredInStoreError, io.vrap.rmf.base.client.ModelBase
Returned when a Cart or an Order in a Store references a country that is not included in the countries configured for the Store.
The error is returned as a failed response to:
- Create Cart in Store request and Set Country update action on Carts.
- Create Cart in Store request and Set Country update action on My Carts.
- Create Order in Store from Cart and Create Order from Quote requests on Orders.
- Create Order in Store from Cart and Create Order from Quote requests on My Orders.
- Create Order by Import request on Order Import.
- Set Country update action on Order Edits.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLCountryNotConfiguredInStoreError
COUNTRY_NOT_CONFIGURED_IN_STORE -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.The country that is not configured for the Store but referenced on the Cart or Order.Countries configured for the Store.inthashCode()voidsetCountry(String country) The country that is not configured for the Store but referenced on the Cart or Order.voidsetStoreCountries(String... storeCountries) Countries configured for the Store.voidsetStoreCountries(List<String> storeCountries) Countries configured for the Store.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLCountryNotConfiguredInStoreError
withGraphQLCountryNotConfiguredInStoreErrorMethods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLCountryNotConfiguredInStoreErrorImpl
public GraphQLCountryNotConfiguredInStoreErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLCountryNotConfiguredInStoreError- Specified by:
getCodein interfaceGraphQLErrorObject- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getStoreCountries
Countries configured for the Store.
- Specified by:
getStoreCountriesin interfaceGraphQLCountryNotConfiguredInStoreError- Returns:
- storeCountries
-
getCountry
The country that is not configured for the Store but referenced on the Cart or Order.
- Specified by:
getCountryin interfaceGraphQLCountryNotConfiguredInStoreError- Returns:
- country
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setStoreCountries
Description copied from interface:GraphQLCountryNotConfiguredInStoreErrorCountries configured for the Store.
- Specified by:
setStoreCountriesin interfaceGraphQLCountryNotConfiguredInStoreError- Parameters:
storeCountries- values to be set
-
setStoreCountries
Description copied from interface:GraphQLCountryNotConfiguredInStoreErrorCountries configured for the Store.
- Specified by:
setStoreCountriesin interfaceGraphQLCountryNotConfiguredInStoreError- Parameters:
storeCountries- values to be set
-
setCountry
Description copied from interface:GraphQLCountryNotConfiguredInStoreErrorThe country that is not configured for the Store but referenced on the Cart or Order.
- Specified by:
setCountryin interfaceGraphQLCountryNotConfiguredInStoreError- Parameters:
country- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLCountryNotConfiguredInStoreError- Specified by:
copyDeepin interfaceGraphQLErrorObject
-