Class GraphQLExactLockConflictErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLExactLockConflictError,io.vrap.rmf.base.client.ModelBase
Returned when a modification is already in progress for the exact combination of SKU and price scope fields for a Standalone Price. Retry the same request after 300 ms.
The error is returned as a failed response to:
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLExactLockConflictError
EXACT_LOCK_CONFLICT -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanChannel for which the Standalone Price is valid.getCode()One of the error codes that is listed on the Errors page.Country code of the geographic location.Currency code of the Standalone Price.CustomerGroup for which the Standalone Price is valid.RecurrencePolicy that applies to the Standalone Price.getSku()SKU for which the modification conflict occurred.Date and time (UTC) from which the Standalone Price is valid.Date and time (UTC) until which the Standalone Price is valid.inthashCode()voidsetChannel(ChannelResourceIdentifier channel) Channel for which the Standalone Price is valid.voidsetCountry(String country) Country code of the geographic location.voidsetCurrency(String currency) Currency code of the Standalone Price.voidsetCustomerGroup(CustomerGroupResourceIdentifier customerGroup) CustomerGroup for which the Standalone Price is valid.voidsetRecurrencePolicy(RecurrencePolicyReference recurrencePolicy) RecurrencePolicy that applies to the Standalone Price.voidSKU for which the modification conflict occurred.voidsetValidFrom(ZonedDateTime validFrom) Date and time (UTC) from which the Standalone Price is valid.voidsetValidUntil(ZonedDateTime validUntil) Date and time (UTC) until which the Standalone Price is valid.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLExactLockConflictError
withGraphQLExactLockConflictErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLExactLockConflictErrorImpl
public GraphQLExactLockConflictErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLExactLockConflictError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getSku
SKU for which the modification conflict occurred.
- Specified by:
getSkuin interfaceGraphQLExactLockConflictError- Returns:
- sku
-
getCurrency
Currency code of the Standalone Price.
- Specified by:
getCurrencyin interfaceGraphQLExactLockConflictError- Returns:
- currency
-
getCountry
Country code of the geographic location.
- Specified by:
getCountryin interfaceGraphQLExactLockConflictError- Returns:
- country
-
getCustomerGroup
CustomerGroup for which the Standalone Price is valid.
- Specified by:
getCustomerGroupin interfaceGraphQLExactLockConflictError- Returns:
- customerGroup
-
getChannel
Channel for which the Standalone Price is valid.
- Specified by:
getChannelin interfaceGraphQLExactLockConflictError- Returns:
- channel
-
getValidFrom
Date and time (UTC) from which the Standalone Price is valid.
- Specified by:
getValidFromin interfaceGraphQLExactLockConflictError- Returns:
- validFrom
-
getValidUntil
Date and time (UTC) until which the Standalone Price is valid.
- Specified by:
getValidUntilin interfaceGraphQLExactLockConflictError- Returns:
- validUntil
-
getRecurrencePolicy
RecurrencePolicy that applies to the Standalone Price.
- Specified by:
getRecurrencePolicyin interfaceGraphQLExactLockConflictError- Returns:
- recurrencePolicy
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setSku
Description copied from interface:GraphQLExactLockConflictErrorSKU for which the modification conflict occurred.
- Specified by:
setSkuin interfaceGraphQLExactLockConflictError- Parameters:
sku- value to be set
-
setCurrency
Description copied from interface:GraphQLExactLockConflictErrorCurrency code of the Standalone Price.
- Specified by:
setCurrencyin interfaceGraphQLExactLockConflictError- Parameters:
currency- value to be set
-
setCountry
Description copied from interface:GraphQLExactLockConflictErrorCountry code of the geographic location.
- Specified by:
setCountryin interfaceGraphQLExactLockConflictError- Parameters:
country- value to be set
-
setCustomerGroup
Description copied from interface:GraphQLExactLockConflictErrorCustomerGroup for which the Standalone Price is valid.
- Specified by:
setCustomerGroupin interfaceGraphQLExactLockConflictError- Parameters:
customerGroup- value to be set
-
setChannel
Description copied from interface:GraphQLExactLockConflictErrorChannel for which the Standalone Price is valid.
- Specified by:
setChannelin interfaceGraphQLExactLockConflictError- Parameters:
channel- value to be set
-
setValidFrom
Description copied from interface:GraphQLExactLockConflictErrorDate and time (UTC) from which the Standalone Price is valid.
- Specified by:
setValidFromin interfaceGraphQLExactLockConflictError- Parameters:
validFrom- value to be set
-
setValidUntil
Description copied from interface:GraphQLExactLockConflictErrorDate and time (UTC) until which the Standalone Price is valid.
- Specified by:
setValidUntilin interfaceGraphQLExactLockConflictError- Parameters:
validUntil- value to be set
-
setRecurrencePolicy
Description copied from interface:GraphQLExactLockConflictErrorRecurrencePolicy that applies to the Standalone Price.
- Specified by:
setRecurrencePolicyin interfaceGraphQLExactLockConflictError- Parameters:
recurrencePolicy- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLExactLockConflictError
-