Class GraphQLExpiredCustomerPasswordTokenErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLExpiredCustomerPasswordTokenErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLExpiredCustomerPasswordTokenError,io.vrap.rmf.base.client.ModelBase
public class GraphQLExpiredCustomerPasswordTokenErrorImpl
extends Object
implements GraphQLExpiredCustomerPasswordTokenError, io.vrap.rmf.base.client.ModelBase
Returned when the provided password token of the Customer has expired.
The error is returned as a failed response to:
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLExpiredCustomerPasswordTokenError
EXPIRED_CUSTOMER_PASSWORD_TOKEN -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLExpiredCustomerPasswordTokenError
withGraphQLExpiredCustomerPasswordTokenErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLExpiredCustomerPasswordTokenErrorImpl
public GraphQLExpiredCustomerPasswordTokenErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLExpiredCustomerPasswordTokenError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLExpiredCustomerPasswordTokenError
-