Class GraphQLInvalidItemShippingDetailsErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLInvalidItemShippingDetailsErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLInvalidItemShippingDetailsError,io.vrap.rmf.base.client.ModelBase
public class GraphQLInvalidItemShippingDetailsErrorImpl
extends Object
implements GraphQLInvalidItemShippingDetailsError, io.vrap.rmf.base.client.ModelBase
Returned when Line Item or Custom Line Item quantities set under ItemShippingDetails do not match the sum of the quantities in their respective shipping details.
When a Cart is frozen, the error can be returned as a failed response to all update actions on Carts and My Carts.
The error is also returned as a failed response to:
- Create Cart and Create Cart in Store requests and Add LineItem, Add CustomLineItem, Set LineItem ShippingDetails, Set CustomLineItem ShippingDetails, Add Shopping List, and Remove LineItem update actions on Carts.
- Create Cart and Create Cart in Store requests, and Add LineItem, Set LineItem ShippingDetails, and Remove LineItem update actions on My Carts.
- Create Cart in BusinessUnit request on Associate Carts.
- Create Order from Cart, Create Order in Store from Cart, Create Order from Quote, and Create Order by Import requests on Orders.
- Create Order from Cart, Create Order in Store from Cart, and Create Order from Quote requests on My Orders.
- Add LineItem, Add CustomLineItem, Set LineItem ShippingDetails, Set CustomLineItem ShippingDetails, Add Shopping List, and Remove LineItem update actions on Order Edits.
- Create Order from Cart in BusinessUnit and Create Order from Quote in BusinessUnit requests on Associate Orders.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLInvalidItemShippingDetailsError
INVALID_ITEM_SHIPPING_DETAILS -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Unique identifier of the Line Item or Custom Line Item."LineItem"or"CustomLineItem"inthashCode()voidUnique identifier of the Line Item or Custom Line Item.voidsetSubject(String subject) "LineItem"or"CustomLineItem"voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLInvalidItemShippingDetailsError
withGraphQLInvalidItemShippingDetailsErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLInvalidItemShippingDetailsErrorImpl
public GraphQLInvalidItemShippingDetailsErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLInvalidItemShippingDetailsError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getSubject
"LineItem"or"CustomLineItem"- Specified by:
getSubjectin interfaceGraphQLInvalidItemShippingDetailsError- Returns:
- subject
-
getItemId
Unique identifier of the Line Item or Custom Line Item.
- Specified by:
getItemIdin interfaceGraphQLInvalidItemShippingDetailsError- Returns:
- itemId
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setSubject
Description copied from interface:GraphQLInvalidItemShippingDetailsError"LineItem"or"CustomLineItem"- Specified by:
setSubjectin interfaceGraphQLInvalidItemShippingDetailsError- Parameters:
subject- value to be set
-
setItemId
Description copied from interface:GraphQLInvalidItemShippingDetailsErrorUnique identifier of the Line Item or Custom Line Item.
- Specified by:
setItemIdin interfaceGraphQLInvalidItemShippingDetailsError- Parameters:
itemId- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLInvalidItemShippingDetailsError
-