Class GraphQLLockedFieldErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLLockedFieldErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLLockedFieldError,io.vrap.rmf.base.client.ModelBase
public class GraphQLLockedFieldErrorImpl
extends Object
implements GraphQLLockedFieldError, io.vrap.rmf.base.client.ModelBase
Returned when two Customers are simultaneously created or updated with the same email address.
To confirm if the operation was successful, repeat the request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLLockedFieldError
LOCKED_FIELD -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.getField()Field that is currently locked.inthashCode()voidField that is currently locked.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLLockedFieldError
withGraphQLLockedFieldErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLLockedFieldErrorImpl
public GraphQLLockedFieldErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLLockedFieldError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getField
Field that is currently locked.
- Specified by:
getFieldin interfaceGraphQLLockedFieldError- Returns:
- field
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setField
Description copied from interface:GraphQLLockedFieldErrorField that is currently locked.
- Specified by:
setFieldin interfaceGraphQLLockedFieldError- Parameters:
field- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLLockedFieldError
-