Class GraphQLMatchingPriceNotFoundErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLMatchingPriceNotFoundError,io.vrap.rmf.base.client.ModelBase
Returned when the Product Variant does not have a Price according to the Product priceMode value for a selected currency, country, Customer Group, or Channel.
The error can be returned as a failed response to all update actions on Carts and Staged Orders.
The error is also returned as a failed response to:
- Authenticate (sign in) Customer and Authenticate (sign in) Customer in Store requests and Set CustomerGroup update action on Customers.
- Authenticate (sign in) Customer and Authenticate (sign in) Customer in Store requests on My Customer Profile.
- Create Cart, Create Cart in Store, Replicate Cart, and Replicate Cart in Store requests on Carts.
- Create Cart and Create Cart in Store and Replicate My Cart requests on My Carts.
- Create Cart in BusinessUnit and Replicate Cart in Business Unit requests on Associate Carts.
- Create Order from Cart and Create Order in Store from Cart requests on Orders.
- Create Order from Cart and Create Order in Store from Cart requests on My Orders.
- Create Order from Cart in BusinessUnit request on Associate Orders.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLMatchingPriceNotFoundError
MATCHING_PRICE_NOT_FOUND -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanChannel associated with the Price.getCode()One of the error codes that is listed on the Errors page.Country code of the geographic location.Currency code of the country.Customer Group associated with the Price.Unique identifier of a Product.Unique identifier of a ProductVariant in the Product.inthashCode()voidsetChannel(ChannelReference channel) Channel associated with the Price.voidsetCountry(String country) Country code of the geographic location.voidsetCurrency(String currency) Currency code of the country.voidsetCustomerGroup(CustomerGroupReference customerGroup) Customer Group associated with the Price.voidsetProductId(String productId) Unique identifier of a Product.voidError-specific additional fields.voidsetVariantId(Integer variantId) Unique identifier of a ProductVariant in the Product.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLMatchingPriceNotFoundError
withGraphQLMatchingPriceNotFoundErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLMatchingPriceNotFoundErrorImpl
public GraphQLMatchingPriceNotFoundErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLMatchingPriceNotFoundError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getProductId
Unique identifier of a Product.
- Specified by:
getProductIdin interfaceGraphQLMatchingPriceNotFoundError- Returns:
- productId
-
getVariantId
Unique identifier of a ProductVariant in the Product.
- Specified by:
getVariantIdin interfaceGraphQLMatchingPriceNotFoundError- Returns:
- variantId
-
getCurrency
Currency code of the country.
- Specified by:
getCurrencyin interfaceGraphQLMatchingPriceNotFoundError- Returns:
- currency
-
getCountry
Country code of the geographic location.
- Specified by:
getCountryin interfaceGraphQLMatchingPriceNotFoundError- Returns:
- country
-
getCustomerGroup
Customer Group associated with the Price.
- Specified by:
getCustomerGroupin interfaceGraphQLMatchingPriceNotFoundError- Returns:
- customerGroup
-
getChannel
Channel associated with the Price.
- Specified by:
getChannelin interfaceGraphQLMatchingPriceNotFoundError- Returns:
- channel
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setProductId
Description copied from interface:GraphQLMatchingPriceNotFoundErrorUnique identifier of a Product.
- Specified by:
setProductIdin interfaceGraphQLMatchingPriceNotFoundError- Parameters:
productId- value to be set
-
setVariantId
Description copied from interface:GraphQLMatchingPriceNotFoundErrorUnique identifier of a ProductVariant in the Product.
- Specified by:
setVariantIdin interfaceGraphQLMatchingPriceNotFoundError- Parameters:
variantId- value to be set
-
setCurrency
Description copied from interface:GraphQLMatchingPriceNotFoundErrorCurrency code of the country.
- Specified by:
setCurrencyin interfaceGraphQLMatchingPriceNotFoundError- Parameters:
currency- value to be set
-
setCountry
Description copied from interface:GraphQLMatchingPriceNotFoundErrorCountry code of the geographic location.
- Specified by:
setCountryin interfaceGraphQLMatchingPriceNotFoundError- Parameters:
country- value to be set
-
setCustomerGroup
Description copied from interface:GraphQLMatchingPriceNotFoundErrorCustomer Group associated with the Price.
- Specified by:
setCustomerGroupin interfaceGraphQLMatchingPriceNotFoundError- Parameters:
customerGroup- value to be set
-
setChannel
Description copied from interface:GraphQLMatchingPriceNotFoundErrorChannel associated with the Price.
- Specified by:
setChannelin interfaceGraphQLMatchingPriceNotFoundError- Parameters:
channel- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLMatchingPriceNotFoundError
-