Class GraphQLMissingTaxRateForCountryErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLMissingTaxRateForCountryErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLMissingTaxRateForCountryError,io.vrap.rmf.base.client.ModelBase
public class GraphQLMissingTaxRateForCountryErrorImpl
extends Object
implements GraphQLMissingTaxRateForCountryError, io.vrap.rmf.base.client.ModelBase
Returned when the Tax Category of at least one of the lineItems, customLineItems, or shippingInfo in the Cart is missing the TaxRate matching country and state given in the shippingAddress of that Cart.
The error can be returned as a failed response to all update actions on Carts and Staged Orders.
The error is also returned as a failed response to:
- Authenticate (sign in) Customer and Authenticate (sign in) Customer in Store requests and Set CustomerGroup update action on Customers.
- Authenticate (sign in) Customer and Authenticate (sign in) Customer in Store on My Customer Profile.
- Create Cart, Create Cart in Store, Replicate Cart, and Replicate Cart in Store requests on Carts.
- Create Cart and Create Cart in Store and Replicate My Cart requests on My Carts.
- Create Cart in BusinessUnit and Replicate Cart in Business Unit requests on Associate Carts.
- Create Order from Cart and Create Order in Store from Cart requests on Orders.
- Create Order from Cart and Create Order in Store from Cart requests on My Orders.
- Create Order from Cart in BusinessUnit requests on Associate Orders.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLMissingTaxRateForCountryError
MISSING_TAX_RATE_FOR_COUNTRY -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Country code of the geographic location.getState()State within the country, such as Texas in the United States.Unique identifier of the TaxCategory.inthashCode()voidsetCountry(String country) Country code of the geographic location.voidState within the country, such as Texas in the United States.voidsetTaxCategoryId(String taxCategoryId) Unique identifier of the TaxCategory.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLMissingTaxRateForCountryError
withGraphQLMissingTaxRateForCountryErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLMissingTaxRateForCountryErrorImpl
public GraphQLMissingTaxRateForCountryErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLMissingTaxRateForCountryError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getTaxCategoryId
Unique identifier of the TaxCategory.
- Specified by:
getTaxCategoryIdin interfaceGraphQLMissingTaxRateForCountryError- Returns:
- taxCategoryId
-
getCountry
Country code of the geographic location.
- Specified by:
getCountryin interfaceGraphQLMissingTaxRateForCountryError- Returns:
- country
-
getState
State within the country, such as Texas in the United States.
- Specified by:
getStatein interfaceGraphQLMissingTaxRateForCountryError- Returns:
- state
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setTaxCategoryId
Description copied from interface:GraphQLMissingTaxRateForCountryErrorUnique identifier of the TaxCategory.
- Specified by:
setTaxCategoryIdin interfaceGraphQLMissingTaxRateForCountryError- Parameters:
taxCategoryId- value to be set
-
setCountry
Description copied from interface:GraphQLMissingTaxRateForCountryErrorCountry code of the geographic location.
- Specified by:
setCountryin interfaceGraphQLMissingTaxRateForCountryError- Parameters:
country- value to be set
-
setState
Description copied from interface:GraphQLMissingTaxRateForCountryErrorState within the country, such as Texas in the United States.
- Specified by:
setStatein interfaceGraphQLMissingTaxRateForCountryError- Parameters:
state- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLMissingTaxRateForCountryError
-