Class GraphQLOutOfStockErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLOutOfStockErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLOutOfStockError,io.vrap.rmf.base.client.ModelBase
public class GraphQLOutOfStockErrorImpl
extends Object
implements GraphQLOutOfStockError, io.vrap.rmf.base.client.ModelBase
Returned when some of the Line Items are out of stock at the time of placing an Order.
The error is returned as a failed response to:
- Create Order from Cart, Create Order in Store from Cart, Create Order from Quote, and Create Order by Import requests on Orders.
- Create Order from Cart, Create Order in Store from Cart, and Create Order from Quote requests on My Orders.
- Create Order from Cart in BusinessUnit and Create Order from Quote in BusinessUnit requests on Associate Orders.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLOutOfStockError
OUT_OF_STOCK -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()One of the error codes that is listed on the Errors page.Unique identifiers of the Line Items that are out of stock.getSkus()SKUs of the Line Items that are out of stock.inthashCode()voidsetLineItems(String... lineItems) Unique identifiers of the Line Items that are out of stock.voidsetLineItems(List<String> lineItems) Unique identifiers of the Line Items that are out of stock.voidSKUs of the Line Items that are out of stock.voidSKUs of the Line Items that are out of stock.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLOutOfStockError
withGraphQLOutOfStockErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLOutOfStockErrorImpl
public GraphQLOutOfStockErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLOutOfStockError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
getLineItems
Unique identifiers of the Line Items that are out of stock.
- Specified by:
getLineItemsin interfaceGraphQLOutOfStockError- Returns:
- lineItems
-
getSkus
SKUs of the Line Items that are out of stock.
- Specified by:
getSkusin interfaceGraphQLOutOfStockError- Returns:
- skus
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
setLineItems
Description copied from interface:GraphQLOutOfStockErrorUnique identifiers of the Line Items that are out of stock.
- Specified by:
setLineItemsin interfaceGraphQLOutOfStockError- Parameters:
lineItems- values to be set
-
setLineItems
Description copied from interface:GraphQLOutOfStockErrorUnique identifiers of the Line Items that are out of stock.
- Specified by:
setLineItemsin interfaceGraphQLOutOfStockError- Parameters:
lineItems- values to be set
-
setSkus
Description copied from interface:GraphQLOutOfStockErrorSKUs of the Line Items that are out of stock.
- Specified by:
setSkusin interfaceGraphQLOutOfStockError- Parameters:
skus- values to be set
-
setSkus
Description copied from interface:GraphQLOutOfStockErrorSKUs of the Line Items that are out of stock.
- Specified by:
setSkusin interfaceGraphQLOutOfStockError- Parameters:
skus- values to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLOutOfStockError
-