Class GraphQLSearchNotReadyErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLSearchNotReadyErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLSearchNotReadyError,io.vrap.rmf.base.client.ModelBase
public class GraphQLSearchNotReadyErrorImpl
extends Object
implements GraphQLSearchNotReadyError, io.vrap.rmf.base.client.ModelBase
Returned if the requested search service is not ready. The search might be deactivated or indexing is in progress.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLSearchNotReadyError
SEARCH_NOT_READY -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLSearchNotReadyError
withGraphQLSearchNotReadyErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLSearchNotReadyErrorImpl
public GraphQLSearchNotReadyErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLSearchNotReadyError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLSearchNotReadyError
-