Class GraphQLShippingMethodDoesNotMatchCartErrorImpl
java.lang.Object
com.commercetools.api.models.error.GraphQLShippingMethodDoesNotMatchCartErrorImpl
- All Implemented Interfaces:
GraphQLErrorObject,GraphQLShippingMethodDoesNotMatchCartError,io.vrap.rmf.base.client.ModelBase
public class GraphQLShippingMethodDoesNotMatchCartErrorImpl
extends Object
implements GraphQLShippingMethodDoesNotMatchCartError, io.vrap.rmf.base.client.ModelBase
Returned when the Cart contains a ShippingMethod that is not allowed for the Cart. In this case, the ShippingMethodState value is DoesNotMatchCart.
When a Cart is frozen, the error can be returned as a failed response to all update actions on Carts and My Carts.
The error is also returned as a failed response to:
- Create Order from Cart and Create Order in Store from Cart requests on Orders.
- Create Order from Cart and Create Order in Store from Cart requests on My Orders.
- Create Order from Cart in BusinessUnit request on Associate Orders.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.GraphQLShippingMethodDoesNotMatchCartError
SHIPPING_METHOD_DOES_NOT_MATCH_CART -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.GraphQLErrorObject
withGraphQLErrorObjectMethods inherited from interface com.commercetools.api.models.error.GraphQLShippingMethodDoesNotMatchCartError
withGraphQLShippingMethodDoesNotMatchCartErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
GraphQLShippingMethodDoesNotMatchCartErrorImpl
public GraphQLShippingMethodDoesNotMatchCartErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:GraphQLErrorObjectOne of the error codes that is listed on the Errors page.
- Specified by:
getCodein interfaceGraphQLErrorObject- Specified by:
getCodein interfaceGraphQLShippingMethodDoesNotMatchCartError- Returns:
- code
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceGraphQLErrorObject- Returns:
- map of the pattern property values
-
setValue
Description copied from interface:GraphQLErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceGraphQLErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceGraphQLErrorObject- Specified by:
copyDeepin interfaceGraphQLShippingMethodDoesNotMatchCartError
-