Class LineItemQuantityBelowLimitErrorImpl
java.lang.Object
com.commercetools.api.models.error.LineItemQuantityBelowLimitErrorImpl
- All Implemented Interfaces:
ErrorObject,LineItemQuantityBelowLimitError,io.vrap.rmf.base.client.ModelBase
public class LineItemQuantityBelowLimitErrorImpl
extends Object
implements LineItemQuantityBelowLimitError, io.vrap.rmf.base.client.ModelBase
Returned when attempting to create or update a Cart with a Line Item whose quantity is below the minCartQuantity limit defined in the InventoryEntry for that Line Item's SKU.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.LineItemQuantityBelowLimitError
LINE_ITEM_QUANTITY_BELOW_LIMIT -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Reference to the Line Item that caused the error."Quantity '$quantity' less than minimum '$minCartQuantity'."The minimum quantity required for this Line Item.The quantity that was requested.inthashCode()voidsetLineItem(String lineItem) Reference to the Line Item that caused the error.voidsetMessage(String message) "Quantity '$quantity' less than minimum '$minCartQuantity'."voidsetMinCartQuantity(Integer minCartQuantity) The minimum quantity required for this Line Item.voidsetQuantity(Integer quantity) The quantity that was requested.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.LineItemQuantityBelowLimitError
withLineItemQuantityBelowLimitErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
LineItemQuantityBelowLimitErrorImpl
public LineItemQuantityBelowLimitErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceLineItemQuantityBelowLimitError- Returns:
- code
-
getMessage
"Quantity '$quantity' less than minimum '$minCartQuantity'."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceLineItemQuantityBelowLimitError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getQuantity
The quantity that was requested.
- Specified by:
getQuantityin interfaceLineItemQuantityBelowLimitError- Returns:
- quantity
-
getMinCartQuantity
The minimum quantity required for this Line Item.
- Specified by:
getMinCartQuantityin interfaceLineItemQuantityBelowLimitError- Returns:
- minCartQuantity
-
getLineItem
Reference to the Line Item that caused the error.
- Specified by:
getLineItemin interfaceLineItemQuantityBelowLimitError- Returns:
- lineItem
-
setMessage
Description copied from interface:LineItemQuantityBelowLimitError"Quantity '$quantity' less than minimum '$minCartQuantity'."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceLineItemQuantityBelowLimitError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setQuantity
Description copied from interface:LineItemQuantityBelowLimitErrorThe quantity that was requested.
- Specified by:
setQuantityin interfaceLineItemQuantityBelowLimitError- Parameters:
quantity- value to be set
-
setMinCartQuantity
Description copied from interface:LineItemQuantityBelowLimitErrorThe minimum quantity required for this Line Item.
- Specified by:
setMinCartQuantityin interfaceLineItemQuantityBelowLimitError- Parameters:
minCartQuantity- value to be set
-
setLineItem
Description copied from interface:LineItemQuantityBelowLimitErrorReference to the Line Item that caused the error.
- Specified by:
setLineItemin interfaceLineItemQuantityBelowLimitError- Parameters:
lineItem- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceLineItemQuantityBelowLimitError
-