Class MatchingPriceNotFoundErrorImpl
- All Implemented Interfaces:
ErrorObject,MatchingPriceNotFoundError,io.vrap.rmf.base.client.ModelBase
Returned when the Product Variant does not have a Price according to the Product priceMode value for a selected currency, country, Customer Group, or Channel.
The error can be returned as a failed response to all update actions on Carts and Staged Orders.
The error is also returned as a failed response to:
- Authenticate (sign in) Customer and Authenticate (sign in) Customer in Store requests and Set CustomerGroup update action on Customers.
- Authenticate (sign in) Customer and Authenticate (sign in) Customer in Store requests on My Customer Profile.
- Create Cart, Create Cart in Store, Replicate Cart, and Replicate Cart in Store requests on Carts.
- Create Cart and Create Cart in Store and Replicate My Cart requests on My Carts.
- Create Cart in BusinessUnit and Replicate Cart in Business Unit requests on Associate Carts.
- Create Order from Cart and Create Order in Store from Cart requests on Orders.
- Create Order from Cart and Create Order in Store from Cart requests on My Orders.
- Create Order from Cart in BusinessUnit request on Associate Orders.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.MatchingPriceNotFoundError
MATCHING_PRICE_NOT_FOUND -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanChannel associated with the Price.getCode()Error identifier.Country code of the geographic location.Currency code of the country.Customer Group associated with the Price."The variant $variantId of product $productId does not contain a price for currency $currencyCode, $country, $customerGroup, $channel."Unique identifier of a Product.Unique identifier of a ProductVariant in the Product.inthashCode()voidsetChannel(ChannelReference channel) Channel associated with the Price.voidsetCountry(String country) Country code of the geographic location.voidsetCurrency(String currency) Currency code of the country.voidsetCustomerGroup(CustomerGroupReference customerGroup) Customer Group associated with the Price.voidsetMessage(String message) "The variant $variantId of product $productId does not contain a price for currency $currencyCode, $country, $customerGroup, $channel."voidsetProductId(String productId) Unique identifier of a Product.voidError-specific additional fields.voidsetVariantId(Integer variantId) Unique identifier of a ProductVariant in the Product.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.MatchingPriceNotFoundError
withMatchingPriceNotFoundErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
MatchingPriceNotFoundErrorImpl
public MatchingPriceNotFoundErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceMatchingPriceNotFoundError- Returns:
- code
-
getMessage
"The variant $variantId of product $productId does not contain a price for currency $currencyCode, $country, $customerGroup, $channel."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceMatchingPriceNotFoundError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getProductId
Unique identifier of a Product.
- Specified by:
getProductIdin interfaceMatchingPriceNotFoundError- Returns:
- productId
-
getVariantId
Unique identifier of a ProductVariant in the Product.
- Specified by:
getVariantIdin interfaceMatchingPriceNotFoundError- Returns:
- variantId
-
getCurrency
Currency code of the country.
- Specified by:
getCurrencyin interfaceMatchingPriceNotFoundError- Returns:
- currency
-
getCountry
Country code of the geographic location.
- Specified by:
getCountryin interfaceMatchingPriceNotFoundError- Returns:
- country
-
getCustomerGroup
Customer Group associated with the Price.
- Specified by:
getCustomerGroupin interfaceMatchingPriceNotFoundError- Returns:
- customerGroup
-
getChannel
Channel associated with the Price.
- Specified by:
getChannelin interfaceMatchingPriceNotFoundError- Returns:
- channel
-
setMessage
Description copied from interface:MatchingPriceNotFoundError"The variant $variantId of product $productId does not contain a price for currency $currencyCode, $country, $customerGroup, $channel."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceMatchingPriceNotFoundError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setProductId
Description copied from interface:MatchingPriceNotFoundErrorUnique identifier of a Product.
- Specified by:
setProductIdin interfaceMatchingPriceNotFoundError- Parameters:
productId- value to be set
-
setVariantId
Description copied from interface:MatchingPriceNotFoundErrorUnique identifier of a ProductVariant in the Product.
- Specified by:
setVariantIdin interfaceMatchingPriceNotFoundError- Parameters:
variantId- value to be set
-
setCurrency
Description copied from interface:MatchingPriceNotFoundErrorCurrency code of the country.
- Specified by:
setCurrencyin interfaceMatchingPriceNotFoundError- Parameters:
currency- value to be set
-
setCountry
Description copied from interface:MatchingPriceNotFoundErrorCountry code of the geographic location.
- Specified by:
setCountryin interfaceMatchingPriceNotFoundError- Parameters:
country- value to be set
-
setCustomerGroup
Description copied from interface:MatchingPriceNotFoundErrorCustomer Group associated with the Price.
- Specified by:
setCustomerGroupin interfaceMatchingPriceNotFoundError- Parameters:
customerGroup- value to be set
-
setChannel
Description copied from interface:MatchingPriceNotFoundErrorChannel associated with the Price.
- Specified by:
setChannelin interfaceMatchingPriceNotFoundError- Parameters:
channel- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceMatchingPriceNotFoundError
-