Class MissingRoleOnChannelErrorImpl
java.lang.Object
com.commercetools.api.models.error.MissingRoleOnChannelErrorImpl
- All Implemented Interfaces:
ErrorObject,MissingRoleOnChannelError,io.vrap.rmf.base.client.ModelBase
public class MissingRoleOnChannelErrorImpl
extends Object
implements MissingRoleOnChannelError, io.vrap.rmf.base.client.ModelBase
Returned when one of the following states occur:
- Channel is added or set on a Store with missing Channel
roles. - Standalone Price references a Channel that does not contain the
ProductDistributionrole.
The error is returned as a failed response to:
- Add Distribution Channel, Set Distribution Channel, Add Supply Channel, and Set Supply Channel update actions.
- Create StandalonePrice request.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.MissingRoleOnChannelError
MISSING_ROLE_ON_CHANNEL -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanResourceIdentifier to a given Channel.getCode()Error identifier."Given channel with $idOrKeyOfChannel does not have the required role $role."ProductDistributionfor Product Distribution Channels allowed for the Store.inthashCode()voidsetChannel(ChannelResourceIdentifier channel) ResourceIdentifier to a given Channel.voidsetMessage(String message) "Given channel with $idOrKeyOfChannel does not have the required role $role."voidsetMissingRole(ChannelRoleEnum missingRole) ProductDistributionfor Product Distribution Channels allowed for the Store.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface com.commercetools.api.models.error.MissingRoleOnChannelError
withMissingRoleOnChannelErrorMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionString
-
Constructor Details
-
MissingRoleOnChannelErrorImpl
public MissingRoleOnChannelErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceMissingRoleOnChannelError- Returns:
- code
-
getMessage
"Given channel with $idOrKeyOfChannel does not have the required role $role."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceMissingRoleOnChannelError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getChannel
ResourceIdentifier to a given Channel.
- Specified by:
getChannelin interfaceMissingRoleOnChannelError- Returns:
- channel
-
getMissingRole
ProductDistributionfor Product Distribution Channels allowed for the Store. Also required for Standalone Prices.InventorySupplyfor Inventory Supply Channels allowed for the Store.
- Specified by:
getMissingRolein interfaceMissingRoleOnChannelError- Returns:
- missingRole
-
setMessage
Description copied from interface:MissingRoleOnChannelError"Given channel with $idOrKeyOfChannel does not have the required role $role."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceMissingRoleOnChannelError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setChannel
Description copied from interface:MissingRoleOnChannelErrorResourceIdentifier to a given Channel.
- Specified by:
setChannelin interfaceMissingRoleOnChannelError- Parameters:
channel- value to be set
-
setMissingRole
Description copied from interface:MissingRoleOnChannelErrorProductDistributionfor Product Distribution Channels allowed for the Store. Also required for Standalone Prices.InventorySupplyfor Inventory Supply Channels allowed for the Store.
- Specified by:
setMissingRolein interfaceMissingRoleOnChannelError- Parameters:
missingRole- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceMissingRoleOnChannelError
-