Class PriceChangedErrorImpl
- All Implemented Interfaces:
ErrorObject,PriceChangedError,io.vrap.rmf.base.client.ModelBase
Returned when the Price or Tax Rate of some Line Items or Shipping Rate of some Shipping Methods changed since they were last added to the Cart.
When a Cart is frozen, the error can be returned as a failed response to all update actions on Carts and My Carts.
The error is also returned as a failed response to:
- Create Order from Cart and Create Order in Store from Cart requests on Orders.
- Create Order from Cart and Create Order in Store from Cart requests on My Orders.
- Create Order from Cart in BusinessUnit request on Associate Orders.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.PriceChangedError
PRICE_CHANGED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.Unique identifiers of the Line Items for which the Price or TaxRate has changed.Plain text description of the reason for the Price change.trueif the ShippingRate has changed.inthashCode()voidsetLineItems(String... lineItems) Unique identifiers of the Line Items for which the Price or TaxRate has changed.voidsetLineItems(List<String> lineItems) Unique identifiers of the Line Items for which the Price or TaxRate has changed.voidsetMessage(String message) Plain text description of the reason for the Price change.voidsetShipping(Boolean shipping) trueif the ShippingRate has changed.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.PriceChangedError
withPriceChangedError
-
Constructor Details
-
PriceChangedErrorImpl
public PriceChangedErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfacePriceChangedError- Returns:
- code
-
getMessage
Plain text description of the reason for the Price change. For example,
"The price or tax of some line items changed at the time of placing the order: $lineItems.".- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfacePriceChangedError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getLineItems
Unique identifiers of the Line Items for which the Price or TaxRate has changed.
- Specified by:
getLineItemsin interfacePriceChangedError- Returns:
- lineItems
-
getShipping
trueif the ShippingRate has changed.- Specified by:
getShippingin interfacePriceChangedError- Returns:
- shipping
-
setMessage
Description copied from interface:PriceChangedErrorPlain text description of the reason for the Price change. For example,
"The price or tax of some line items changed at the time of placing the order: $lineItems.".- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfacePriceChangedError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setLineItems
Description copied from interface:PriceChangedErrorUnique identifiers of the Line Items for which the Price or TaxRate has changed.
- Specified by:
setLineItemsin interfacePriceChangedError- Parameters:
lineItems- values to be set
-
setLineItems
Description copied from interface:PriceChangedErrorUnique identifiers of the Line Items for which the Price or TaxRate has changed.
- Specified by:
setLineItemsin interfacePriceChangedError- Parameters:
lineItems- values to be set
-
setShipping
Description copied from interface:PriceChangedErrortrueif the ShippingRate has changed.- Specified by:
setShippingin interfacePriceChangedError- Parameters:
shipping- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfacePriceChangedError
-