Class ProductAssignmentMissingErrorImpl
- All Implemented Interfaces:
ErrorObject,ProductAssignmentMissingError,io.vrap.rmf.base.client.ModelBase
Returned when a Product is not assigned to the Product Selection. The error is returned as a failed response either to the Set Variant Selection or to the Set Variant Exclusion update action.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.ProductAssignmentMissingError
PRODUCT_ASSIGNMENT_MISSING -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleangetCode()Error identifier.For Product Selection of mode Individual, the message is:"A Product Variant Selection can only be set for a Product that has previously been added to the Product Selection."For Product Selection of mode IndividualExclusion, the message is:"A Variant Exclusion can only be set for a Product that has previously been added to the Product Selection of type Individual Exclusion."inthashCode()voidsetMessage(String message) For Product Selection of mode Individual, the message is:"A Product Variant Selection can only be set for a Product that has previously been added to the Product Selection."For Product Selection of mode IndividualExclusion, the message is:"A Variant Exclusion can only be set for a Product that has previously been added to the Product Selection of type Individual Exclusion."voidsetProduct(ProductReference product) voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.ProductAssignmentMissingError
withProductAssignmentMissingError
-
Constructor Details
-
ProductAssignmentMissingErrorImpl
public ProductAssignmentMissingErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceProductAssignmentMissingError- Returns:
- code
-
getMessage
For Product Selection of mode Individual, the message is:
"A Product Variant Selection can only be set for a Product that has previously been added to the Product Selection."For Product Selection of mode IndividualExclusion, the message is:"A Variant Exclusion can only be set for a Product that has previously been added to the Product Selection of type Individual Exclusion."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceProductAssignmentMissingError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getProduct
- Specified by:
getProductin interfaceProductAssignmentMissingError- Returns:
- product
-
setMessage
Description copied from interface:ProductAssignmentMissingErrorFor Product Selection of mode Individual, the message is:
"A Product Variant Selection can only be set for a Product that has previously been added to the Product Selection."For Product Selection of mode IndividualExclusion, the message is:"A Variant Exclusion can only be set for a Product that has previously been added to the Product Selection of type Individual Exclusion."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceProductAssignmentMissingError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setProduct
Description copied from interface:ProductAssignmentMissingError- Specified by:
setProductin interfaceProductAssignmentMissingError- Parameters:
product- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceProductAssignmentMissingError
-