Class SearchNotReadyErrorImpl
java.lang.Object
com.commercetools.api.models.error.SearchNotReadyErrorImpl
- All Implemented Interfaces:
ErrorObject,SearchNotReadyError,io.vrap.rmf.base.client.ModelBase
public class SearchNotReadyErrorImpl
extends Object
implements SearchNotReadyError, io.vrap.rmf.base.client.ModelBase
Returned if the requested search service is not ready. The search might be deactivated or indexing is in progress.
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.SearchNotReadyError
SEARCH_NOT_READY -
Constructor Summary
Constructors -
Method Summary
Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.SearchNotReadyError
withSearchNotReadyError
-
Constructor Details
-
SearchNotReadyErrorImpl
public SearchNotReadyErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceSearchNotReadyError- Returns:
- code
-
getMessage
$Search is not ready. Check the indexing-status endpoint and that the feature has been activated in the project settings.- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceSearchNotReadyError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
setMessage
Description copied from interface:SearchNotReadyError$Search is not ready. Check the indexing-status endpoint and that the feature has been activated in the project settings.- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceSearchNotReadyError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceSearchNotReadyError
-