Class ValidityLockConflictErrorImpl
- All Implemented Interfaces:
ErrorObject,ValidityLockConflictError,io.vrap.rmf.base.client.ModelBase
Returned when a modification is already in progress for the combination of SKU and price scope fields (but potentially different validity period) for a Standalone Price. Retry the same request after 300 ms.
The error is returned as a failed response to:
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.vrap.rmf.base.client.ModelBase
io.vrap.rmf.base.client.ModelBase.FilteredRecursiveToStringStyle -
Field Summary
Fields inherited from interface com.commercetools.api.models.error.ValidityLockConflictError
VALIDITY_LOCK_CONFLICT -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptioncopyDeep()booleanChannel for which the Standalone Price is valid.getCode()Error identifier.Country code of the geographic location.Currency code of the Standalone Price.CustomerGroup for which the Standalone Price is valid."Modification already in progress for the combination of SKU, price scope fields (but potentially different validity period).RecurrencePolicy for which the Standalone Price is valid.getSku()SKU for which the modification conflict occurred.inthashCode()voidsetChannel(ChannelResourceIdentifier channel) Channel for which the Standalone Price is valid.voidsetCountry(String country) Country code of the geographic location.voidsetCurrency(String currency) Currency code of the Standalone Price.voidsetCustomerGroup(CustomerGroupResourceIdentifier customerGroup) CustomerGroup for which the Standalone Price is valid.voidsetMessage(String message) "Modification already in progress for the combination of SKU, price scope fields (but potentially different validity period).voidsetRecurrencePolicy(RecurrencePolicyResourceIdentifier recurrencePolicy) RecurrencePolicy for which the Standalone Price is valid.voidSKU for which the modification conflict occurred.voidError-specific additional fields.toString()values()Error-specific additional fields.Methods inherited from interface com.commercetools.api.models.error.ErrorObject
withErrorObjectMethods inherited from interface io.vrap.rmf.base.client.ModelBase
reflectionString, reflectionStringMethods inherited from interface com.commercetools.api.models.error.ValidityLockConflictError
withValidityLockConflictError
-
Constructor Details
-
ValidityLockConflictErrorImpl
public ValidityLockConflictErrorImpl()create empty instance
-
-
Method Details
-
getCode
Description copied from interface:ErrorObjectError identifier.
- Specified by:
getCodein interfaceErrorObject- Specified by:
getCodein interfaceValidityLockConflictError- Returns:
- code
-
getMessage
"Modification already in progress for the combination of SKU, price scope fields (but potentially different validity period). Please retry after the current operation completes."- Specified by:
getMessagein interfaceErrorObject- Specified by:
getMessagein interfaceValidityLockConflictError- Returns:
- message
-
values
Error-specific additional fields.
- Specified by:
valuesin interfaceErrorObject- Returns:
- map of the pattern property values
-
getSku
SKU for which the modification conflict occurred.
- Specified by:
getSkuin interfaceValidityLockConflictError- Returns:
- sku
-
getCurrency
Currency code of the Standalone Price.
- Specified by:
getCurrencyin interfaceValidityLockConflictError- Returns:
- currency
-
getCountry
Country code of the geographic location.
- Specified by:
getCountryin interfaceValidityLockConflictError- Returns:
- country
-
getCustomerGroup
CustomerGroup for which the Standalone Price is valid.
- Specified by:
getCustomerGroupin interfaceValidityLockConflictError- Returns:
- customerGroup
-
getChannel
Channel for which the Standalone Price is valid.
- Specified by:
getChannelin interfaceValidityLockConflictError- Returns:
- channel
-
getRecurrencePolicy
RecurrencePolicy for which the Standalone Price is valid.
- Specified by:
getRecurrencePolicyin interfaceValidityLockConflictError- Returns:
- recurrencePolicy
-
setMessage
Description copied from interface:ValidityLockConflictError"Modification already in progress for the combination of SKU, price scope fields (but potentially different validity period). Please retry after the current operation completes."- Specified by:
setMessagein interfaceErrorObject- Specified by:
setMessagein interfaceValidityLockConflictError- Parameters:
message- value to be set
-
setValue
Description copied from interface:ErrorObjectError-specific additional fields.
- Specified by:
setValuein interfaceErrorObject- Parameters:
key- property namevalue- property value
-
setSku
Description copied from interface:ValidityLockConflictErrorSKU for which the modification conflict occurred.
- Specified by:
setSkuin interfaceValidityLockConflictError- Parameters:
sku- value to be set
-
setCurrency
Description copied from interface:ValidityLockConflictErrorCurrency code of the Standalone Price.
- Specified by:
setCurrencyin interfaceValidityLockConflictError- Parameters:
currency- value to be set
-
setCountry
Description copied from interface:ValidityLockConflictErrorCountry code of the geographic location.
- Specified by:
setCountryin interfaceValidityLockConflictError- Parameters:
country- value to be set
-
setCustomerGroup
Description copied from interface:ValidityLockConflictErrorCustomerGroup for which the Standalone Price is valid.
- Specified by:
setCustomerGroupin interfaceValidityLockConflictError- Parameters:
customerGroup- value to be set
-
setChannel
Description copied from interface:ValidityLockConflictErrorChannel for which the Standalone Price is valid.
- Specified by:
setChannelin interfaceValidityLockConflictError- Parameters:
channel- value to be set
-
setRecurrencePolicy
Description copied from interface:ValidityLockConflictErrorRecurrencePolicy for which the Standalone Price is valid.
- Specified by:
setRecurrencePolicyin interfaceValidityLockConflictError- Parameters:
recurrencePolicy- value to be set
-
equals
-
hashCode
public int hashCode() -
toString
-
copyDeep
- Specified by:
copyDeepin interfaceErrorObject- Specified by:
copyDeepin interfaceValidityLockConflictError
-